************************************************************************************************
************************************************************************************************
* Replication Materials for “The Mechanisms of Direct and Indirect Rule: Colonialism and Economic Development in Africa”
* Authors: Natalie Lest and Martha Wilfahrt
* Journal: Quarterly Journal of Political Science
* Version Date: 12 January 2010
************************************************************************************************
************************************************************************************************

cd "Letsa Wilfahrt_QJPS Replication Materials/Data/"

import delimited "Rd5_GIS Controls.csv", clear 
rename eanumb_ab EANUMB_AB
sort EANUMB_AB 
saveold "Rd5_GIS Controls.dta", replace


import delimited "Rd6_GIS Controls.csv", clear 
rename eanumb_ab EANUMB_AB
sort EANUMB_AB 
saveold "Rd6_GIS Controls.dta", replace

****************** ROUND 5 CLEANING 
* NOTE: full replication will require downloading the Cameroon Round 5 data from www.afrobarometer.org. Users will want to request geocoded data if they desire to replicate through final models.
* use CameroonRd5.dta

**Transformation of variable names: Round 5
rename Q18 Q18_R5
rename Q88A Q88A_R5
rename Q88B Q88B_R5
rename Q88C Q88C_R5
rename Q66C Q66C_R5
rename Q66D Q66D_R5
rename Q66E Q66E_R5

*Common variables
rename Q15 C15
rename Q25B C25B
rename Q26E C26D
rename Q27 C27
rename Q30C C30C
rename Q59A C59A
rename Q59B C59B
rename Q59C C59C
rename Q59D C59D
rename Q59E C59E
rename Q59F C59F
rename Q59G C59G
rename Q59H C59H
rename Q59I C59I
rename Q59J C59J
rename Q62B C62B
rename Q71C C71C
rename Q79A_CAMA C79A_CAMA
rename Q79A_CAMB C79A_CAMB
rename Q79A_CAMC C79A_CAMC
rename Q79C_CAMC C79C_CAMC
rename Q85B C85B
rename Q97 C97
rename Q1 C1
rename Q84 C84
rename Q66A C66A
rename Q66B C66B

*Gender
gen female = 0
replace female = 1 if THISINT == 2

gen Fako = 0
replace Fako = 1 if DISTRICT == 9

keep REGION URBRUR ARRONDISEMENT TOWNVILL EANUMB_AB Fako C66A C66B Q66C_R5 Q66D_R5 Q66E_R5 C79C_CAMC C84 female Q18_R5 C1 C97 C85B C79A_CAMC C79A_CAMB C79A_CAMA  C71C C62B C59J C59I C59H C59G C59F C59E C59D C59C C59B C59A C30C C27 C26D C25B C15 Q18_R5 Q88A_R5 Q88B_R5 Q88C_R5

gen Round = 5
sort EANUMB_AB
merge EANUMB_AB using "Rd5_GIS Controls.dta"
drop _merge

saveold "Cameroon_Rd5_CleanedForMerge.dta", replace


****************** ROUND 6 CLEANING 
* NOTE: full replication will require downloading the Cameroon Round 6 data from www.afrobarometer.org. Users will want to request geocoded data if they desire to replicate through final models.
* use CameroonRd6.dta

**Transformation of variable names: Round 6
*unique variables
rename Q24E Q24E_R6
rename Q52K Q52K_R6
rename Q53H Q53H_R6
rename Q68D Q68D_R6

*Common variables
rename Q14 C15
rename Q19B C25B
rename Q27E C26D
rename Q21 C27
rename Q24C C30C
rename Q52A C59A
rename Q52B C59B
rename Q52C C59C
rename Q52D C59D
rename Q52E C59E
rename Q52F C59F
rename Q52G C59G
rename Q52H C59H
rename Q52I C59I
rename Q52J C59J
rename Q59B C62B
rename Q68C C71C
rename Q85C2_CAM C79C_CAMC
rename Q82A_CAM C79A_CAMA
rename Q82B_CAM C79A_CAMB
rename Q82C_CAM C79A_CAMC
rename Q88B C85B
rename Q97 C97
rename Q1 C1
rename Q87 C84
rename Q67A C66A
rename Q67B C66B

*Gender
gen female = 0
replace female = 1 if THISINT == 3

gen Fako = 0
replace Fako = 1 if COUNTY == 9

gen ARRONDISEMENT = .
replace ARRONDISEMENT = 1 if DISTRICT == 1 
replace ARRONDISEMENT = 2 if DISTRICT == 5
replace ARRONDISEMENT = 4 if DISTRICT == 6
replace ARRONDISEMENT = 5 if DISTRICT == 7
replace ARRONDISEMENT = 8 if DISTRICT == 6
replace ARRONDISEMENT = 9 if DISTRICT == 7
replace ARRONDISEMENT = 11 if DISTRICT == 12 
replace ARRONDISEMENT = 13 if DISTRICT == 13 
replace ARRONDISEMENT = 14 if DISTRICT == 19
replace ARRONDISEMENT = 16 if DISTRICT == 21
replace ARRONDISEMENT = 17 if DISTRICT == 22
replace ARRONDISEMENT = 18 if DISTRICT == 23
replace ARRONDISEMENT = 19 if DISTRICT == 24
replace ARRONDISEMENT = 20 if DISTRICT == 25
replace ARRONDISEMENT = 21 if DISTRICT == 27
replace ARRONDISEMENT = 22 if DISTRICT == 28
replace ARRONDISEMENT = 25 if DISTRICT == 29
replace ARRONDISEMENT = 26 if DISTRICT == 32
replace ARRONDISEMENT = 27 if DISTRICT == 33
replace ARRONDISEMENT = 29 if DISTRICT == 35
replace ARRONDISEMENT = 30 if DISTRICT == 36
replace ARRONDISEMENT = 37 if DISTRICT == 40
replace ARRONDISEMENT = 38 if DISTRICT == 41
replace ARRONDISEMENT = 40 if DISTRICT == 42
replace ARRONDISEMENT = 42 if DISTRICT == 43
replace ARRONDISEMENT = 45 if DISTRICT == 45
replace ARRONDISEMENT = 47 if DISTRICT == 47
replace ARRONDISEMENT = 48 if DISTRICT == 48
replace ARRONDISEMENT = 50 if DISTRICT == 49
replace ARRONDISEMENT = 52 if DISTRICT == 50 
replace ARRONDISEMENT = 56 if DISTRICT == 52
replace ARRONDISEMENT = 57 if DISTRICT == 53
replace ARRONDISEMENT = 58 if DISTRICT == 54
replace ARRONDISEMENT = 59 if DISTRICT == 56
replace ARRONDISEMENT = 60 if DISTRICT == 58
replace ARRONDISEMENT = 61 if DISTRICT == 60
replace ARRONDISEMENT = 62 if DISTRICT == 61
replace ARRONDISEMENT = 64 if DISTRICT == 64
replace ARRONDISEMENT = 66 if DISTRICT == 65
replace ARRONDISEMENT = 67 if DISTRICT == 66
replace ARRONDISEMENT = 69 if DISTRICT == 68
replace ARRONDISEMENT = 70 if DISTRICT == 71
replace ARRONDISEMENT = 73 if DISTRICT == 73
replace ARRONDISEMENT = 74 if DISTRICT == 74
replace ARRONDISEMENT = 76 if DISTRICT == 76
replace ARRONDISEMENT = 77 if DISTRICT == 77
replace ARRONDISEMENT = 80 if DISTRICT == 79
replace ARRONDISEMENT = 81 if DISTRICT == 80
replace ARRONDISEMENT = 82 if DISTRICT == 81
replace ARRONDISEMENT = 83 if DISTRICT == 82
replace ARRONDISEMENT = 84 if DISTRICT == 83
replace ARRONDISEMENT = 85 if DISTRICT == 85
replace ARRONDISEMENT = 86 if DISTRICT == 86
replace ARRONDISEMENT = 87 if DISTRICT == 87
replace ARRONDISEMENT = 88 if DISTRICT == 88
replace ARRONDISEMENT = 89 if DISTRICT == 89
replace ARRONDISEMENT = 90 if DISTRICT == 90
replace ARRONDISEMENT = 91 if DISTRICT == 91
replace ARRONDISEMENT = 93 if DISTRICT == 2
replace ARRONDISEMENT = 94 if DISTRICT == 3
replace ARRONDISEMENT = 95 if DISTRICT == 4
replace ARRONDISEMENT = 96 if DISTRICT == 10
replace ARRONDISEMENT = 97 if DISTRICT == 1
replace ARRONDISEMENT = 98 if DISTRICT == 14
replace ARRONDISEMENT = 99 if DISTRICT == 15
replace ARRONDISEMENT = 100 if DISTRICT == 16
replace ARRONDISEMENT = 101 if DISTRICT == 17
replace ARRONDISEMENT = 102 if DISTRICT == 18
replace ARRONDISEMENT = 103 if DISTRICT == 20
replace ARRONDISEMENT = 104 if DISTRICT == 26
replace ARRONDISEMENT = 105 if DISTRICT == 30
replace ARRONDISEMENT = 106 if DISTRICT == 31
replace ARRONDISEMENT = 107 if DISTRICT == 34
replace ARRONDISEMENT = 108 if DISTRICT == 37
replace ARRONDISEMENT = 109 if DISTRICT == 38
replace ARRONDISEMENT = 110 if DISTRICT == 39
replace ARRONDISEMENT = 111 if DISTRICT == 44
replace ARRONDISEMENT = 112 if DISTRICT == 46
replace ARRONDISEMENT = 113 if DISTRICT == 51
replace ARRONDISEMENT = 114 if DISTRICT == 55
replace ARRONDISEMENT = 115 if DISTRICT == 59
replace ARRONDISEMENT = 116 if DISTRICT == 62
replace ARRONDISEMENT = 117 if DISTRICT == 63
replace ARRONDISEMENT = 118 if DISTRICT == 67
replace ARRONDISEMENT = 119 if DISTRICT == 69 | DISTRICT == 70
replace ARRONDISEMENT = 120 if DISTRICT == 72
replace ARRONDISEMENT = 121 if DISTRICT == 75
replace ARRONDISEMENT = 122 if DISTRICT == 78
replace ARRONDISEMENT = 123 if DISTRICT == 84

keep REGION URBRUR ARRONDISEMENT TOWNVILL EANUMB_AB Fako female C79A_CAMC C79A_CAMA C79A_CAMB C66A C66B C84 C1 C97 C85B C79C_CAMC C71C C62B C59J C59I C59H C59G C59F C59E C59D C59C C59B C59A C30C C27 C26D C25B C15 Q68D_R6 Q53H_R6 Q52K_R6 Q24E_R6

gen Round = 6
sort EANUMB_AB
merge EANUMB_AB using "Rd6_GIS Controls.dta"
drop _merge 

saveold "Cameroon_Rd6_CleanedForMerge.dta", replace

** MERGE AB ROUNDS TOGETHER AND CLEAN
use Cameroon_Rd6_CleanedForMerge.dta, clear
append using Cameroon_Rd5_CleanedForMerge.dta

gen anglophone=0
replace anglophone=1 if REGION== 9 | REGION== 12

**Round
replace Round=0 if Round==5
replace Round=1 if Round==6
label define round1 0 "Round 5" 1 "Round 6"
label values Round round1

gen ln_d_Railway_km = log(d_railway_km)
gen ln_d_Protestant_km_1960 = log(d_protestant_1960_km)
gen ln_d_regcapital_km = log(d_regionalcapital_km)
gen ln_d_yaounde_km = log(d_yaounde_km)
gen ln_d_coast_km = log(d_coastline_km)
gen Ln_WorldPop10_5km = log(worldpop10_5km)
gen ln_d_nigeria_km = log(d_nigeria_km)
gen d_border_km=d_anglofrench_border_km

replace ln_d_Railway_km = 0 if ln_d_Railway_km < 0
replace ln_d_Protestant_km_1960 = 0 if ln_d_Protestant_km_1960 < 0
replace ln_d_regcapital_km = 0 if ln_d_regcapital_km < 0
replace ln_d_yaounde_km = 0 if ln_d_yaounde_km < 0
replace ln_d_coast_km = 0 if ln_d_coast_km < 0
replace ln_d_nigeria_km = 0 if ln_d_nigeria_km < 0

* generate border cut-offs for loops
gen D_Border_Rounded = round(d_border_km, 1)
gen D_Border20 = D_Border_Rounded < 21
gen D_Border21 = D_Border_Rounded < 22
gen D_Border22 = D_Border_Rounded < 23
gen D_Border23 = D_Border_Rounded < 24
gen D_Border24 = D_Border_Rounded < 25
gen D_Border25 = D_Border_Rounded < 26
gen D_Border26 = D_Border_Rounded < 27
gen D_Border27 = D_Border_Rounded < 28
gen D_Border28 = D_Border_Rounded < 29
gen D_Border29 = D_Border_Rounded < 30
gen D_Border30 = D_Border_Rounded < 31
gen D_Border31 = D_Border_Rounded < 32
gen D_Border32 = D_Border_Rounded < 32
gen D_Border33 = D_Border_Rounded < 34
gen D_Border34 = D_Border_Rounded < 35
gen D_Border35 = D_Border_Rounded < 36
gen D_Border36 = D_Border_Rounded < 37
gen D_Border37 = D_Border_Rounded < 38
gen D_Border38 = D_Border_Rounded < 39
gen D_Border39 = D_Border_Rounded < 40
gen D_Border40 = D_Border_Rounded < 41
gen D_Border41 = D_Border_Rounded < 42
gen D_Border42 = D_Border_Rounded < 43
gen D_Border43 = D_Border_Rounded < 44
gen D_Border44 = D_Border_Rounded < 45
gen D_Border45 = D_Border_Rounded < 46
gen D_Border46 = D_Border_Rounded < 47
gen D_Border47 = D_Border_Rounded < 48
gen D_Border48 = D_Border_Rounded < 49
gen D_Border49 = D_Border_Rounded < 50
gen D_Border50 = D_Border_Rounded < 51
gen D_Border51 = D_Border_Rounded < 52
gen D_Border52 = D_Border_Rounded < 53
gen D_Border53 = D_Border_Rounded < 54
gen D_Border54 = D_Border_Rounded < 55
gen D_Border55 = D_Border_Rounded < 56
gen D_Border56 = D_Border_Rounded < 57
gen D_Border57 = D_Border_Rounded < 58
gen D_Border58 = D_Border_Rounded < 59
gen D_Border59 = D_Border_Rounded < 60
gen D_Border60 = D_Border_Rounded < 61
gen D_Border61 = D_Border_Rounded < 62
gen D_Border62 = D_Border_Rounded < 63
gen D_Border63 = D_Border_Rounded < 64
gen D_Border64 = D_Border_Rounded < 65
gen D_Border65 = D_Border_Rounded < 66
gen D_Border66 = D_Border_Rounded < 67
gen D_Border67 = D_Border_Rounded < 68
gen D_Border68 = D_Border_Rounded < 69
gen D_Border69 = D_Border_Rounded < 70
gen D_Border70 = D_Border_Rounded < 71
gen D_Border71 = D_Border_Rounded < 72
gen D_Border72 = D_Border_Rounded < 73
gen D_Border73 = D_Border_Rounded < 74
gen D_Border74 = D_Border_Rounded < 75
gen D_Border75 = D_Border_Rounded < 76
gen D_Border76 = D_Border_Rounded < 77
gen D_Border77 = D_Border_Rounded < 78
gen D_Border78 = D_Border_Rounded < 79
gen D_Border79 = D_Border_Rounded < 80
gen D_Border80 = D_Border_Rounded < 81

gen Anglo_x_Border = anglophone*d_border_km
gen Lat_x_Long = latitude*longitude
gen latitude2 = latitude*latitude
gen latitude3 = latitude*latitude*latitude
gen longitude2 = longitude*longitude
gen longitude3 = longitude*longitude*longitude
gen lat_x_long2 = latitude*longitude2
gen lat2_x_long = latitude2*longitude
gen d_border_km2 = d_border_km*d_border_km
gen d_border_km3 = d_border_km*d_border_km*d_border_km

gen d_border_UK = 0
replace d_border_UK = d_border_km if anglophone == 1
gen d_border_French = 0
replace d_border_French = d_border_km if anglophone == 0

gen anglophone_20e = 0
replace anglophone_20e = 1 if anglophone == 1  
replace anglophone_20e = 1 if d_border_French  < 21
gen anglophone_40e = 0
replace anglophone_40e = 1 if anglophone == 1  
replace anglophone_40e = 1 if d_border_French < 41
gen anglophone_60e = 0
replace anglophone_60e = 1 if anglophone == 1  
replace anglophone_60e = 1 if d_border_French < 61

gen anglophone_20w = 0
replace anglophone_20w = 1 if anglophone == 1 
replace anglophone_20w = 0 if d_border_UK < 21 
gen anglophone_40w = 0
replace anglophone_40w = 1 if anglophone == 1 
replace anglophone_40w = 0 if d_border_UK < 41
gen anglophone_60w = 0
replace anglophone_60w = 1 if anglophone == 1 
replace anglophone_60w = 0 if d_border_UK < 61 


gen D_Placebo_60W_km_UK = 0
replace D_Placebo_60W_km_UK = d_placebo_60w_km if anglophone_60w == 1
gen D_Placebo_60W_km_French = 0
replace D_Placebo_60W_km_French = d_placebo_60w_km if anglophone_60w == 0

gen D_Placebo_40W_km_UK = 0
replace D_Placebo_40W_km_UK = d_placebo_40w_km if anglophone_40w == 1
gen D_Placebo_40W_km_French = 0
replace D_Placebo_40W_km_French = d_placebo_40w_km if anglophone_40w == 0

gen D_Placebo_20W_km_UK = 0
replace D_Placebo_20W_km_UK = d_placebo_20w_km if anglophone_20w == 1
gen D_Placebo_20W_km_French = 0
replace D_Placebo_20W_km_French = d_placebo_20w_km if anglophone_20w == 0

gen D_Placebo_60E_km_UK = 0
replace D_Placebo_60E_km_UK = d_placebo_60e_km if anglophone_60e == 1
gen D_Placebo_60E_km_French = 0
replace D_Placebo_60E_km_French = d_placebo_60e_km if anglophone_60e == 0

gen D_Placebo_40E_km_UK = 0
replace D_Placebo_40E_km_UK = d_placebo_40e_km if anglophone_40e == 1
gen D_Placebo_40E_km_French = 0
replace D_Placebo_40E_km_French = d_placebo_40e_km if anglophone_40e == 0

gen D_Placebo_20E_km_UK = 0
replace D_Placebo_20E_km_UK = d_placebo_20e_km if anglophone_20e == 1
gen D_Placebo_20E_km_French = 0
replace D_Placebo_20E_km_French = d_placebo_20e_km if anglophone_20e == 0

* align between rounds for ethnicity ttests
replace ARRONDISEMENT = 3 if TOWNVILL == 13
replace ARRONDISEMENT = 4 if TOWNVILL == 142
replace ARRONDISEMENT = 5 if TOWNVILL == 71
replace ARRONDISEMENT = 7 if TOWNVILL == 11
replace ARRONDISEMENT = 14 if TOWNVILL == 143
replace ARRONDISEMENT = 16 if TOWNVILL == 7 | TOWNVILL == 41 | TOWNVILL == 118
replace ARRONDISEMENT = 17 if TOWNVILL == 27 | TOWNVILL == 107
replace ARRONDISEMENT = 18 if TOWNVILL == 24 | TOWNVILL == 28 | TOWNVILL == 76 | TOWNVILL == 104 | TOWNVILL == 123
replace ARRONDISEMENT = 19 if TOWNVILL == 30 | TOWNVILL == 67
replace ARRONDISEMENT = 20 if TOWNVILL == 22 | TOWNVILL == 81 | TOWNVILL == 102 | TOWNVILL == 79 | TOWNVILL == 105 | TOWNVILL == 132
replace ARRONDISEMENT = 21 if TOWNVILL == 10
replace ARRONDISEMENT = 25 if TOWNVILL == 74 | TOWNVILL == 114
replace ARRONDISEMENT = 36 if TOWNVILL == 115
replace ARRONDISEMENT = 44 if TOWNVILL == 29
replace ARRONDISEMENT = 46 if TOWNVILL == 84
replace ARRONDISEMENT = 55 if TOWNVILL == 53 | TOWNVILL == 42
replace ARRONDISEMENT = 56 if TOWNVILL == 17 | TOWNVILL == 18
replace ARRONDISEMENT = 58 if TOWNVILL == 89
replace ARRONDISEMENT = 70 if TOWNVILL == 54
replace ARRONDISEMENT = 71 if TOWNVILL == 15
replace ARRONDISEMENT = 72 if TOWNVILL == 117
replace ARRONDISEMENT = 81 if TOWNVILL == 101
replace ARRONDISEMENT = 83 if TOWNVILL == 20 | TOWNVILL == 102 | TOWNVILL == 23 | TOWNVILL == 60
replace ARRONDISEMENT = 84 if TOWNVILL == 68 | TOWNVILL == 2 | TOWNVILL == 37
replace ARRONDISEMENT = 116 if TOWNVILL == 1 | TOWNVILL == 128
replace ARRONDISEMENT = 119 if TOWNVILL == 4
replace ARRONDISEMENT = 14 if TOWNVILL == 6 | TOWNVILL == 36 
replace ARRONDISEMENT = 108 if TOWNVILL == 34
replace ARRONDISEMENT = 110 if TOWNVILL == 35
replace ARRONDISEMENT = 40 if TOWNVILL == 59
replace ARRONDISEMENT = 96 if TOWNVILL == 61
replace ARRONDISEMENT = 112 if TOWNVILL == 113 | TOWNVILL == 141
replace ARRONDISEMENT = 124 if TOWNVILL == 12
replace ARRONDISEMENT = 125 if TOWNVILL == 86
replace ARRONDISEMENT = 126 if TOWNVILL == 91
replace ARRONDISEMENT = 1127 if TOWNVILL == 93
replace ARRONDISEMENT = 128 if TOWNVILL == 121
replace ARRONDISEMENT = 129 if TOWNVILL == 126

**** VARIABLE CLEANING
*Age
replace C1=. if C1==-1 | C1==999
rename C1 age

*Education
replace C97=. if C97==12
rename C97 education

*Rural
replace URBRUR=0 if URBRUR==1
replace URBRUR=1 if URBRUR==2
rename URBRUR rural
label define rural1 0 "Urban" 1 "Rural", modify
label values rural rural1

gen Douala = 0
replace Douala = 1 if ARRONDISEMENT == 16 | ARRONDISEMENT == 17 | ARRONDISEMENT == 18 | ARRONDISEMENT == 19 | ARRONDISEMENT == 20

*Local government councilors listen
replace C62B=. if C62B==1 | C62B==6

*Performance: local government councilor
replace C71C=. if C71C==1 | C71C==6

*Contact a official of a government agency
replace C30C=. if C30C==6

*Member of a community group
replace C25B=. if C25B==1 | C25B==6
label define C25B1 2 "Not a member" 3 "Inactive member" 4 "Active member" 5 "Official leader"
label values C25B C25B1

*How much do you trust traditional leaders
replace Q52K_R6=. if Q52K_R6==1 | Q52K_R6==6

*Corruption: traditional leaders
replace Q53H_R6=. if Q53H_R6==1 | Q53H_R6==6

*Contact traditional leader
replace Q24E_R6=. if Q24E_R6==6

*Approve of the job of your traditional leader
replace Q68D_R6=. if Q68D_R6==6
replace Q68D_R6=. if Q68D_R6==1
replace Q68D_R6 = 1 if Q68D_R6 == 2
replace Q68D_R6 = 2 if Q68D_R6 == 3
replace Q68D_R6 = 3 if Q68D_R6 == 4
replace Q68D_R6 = 4 if Q68D_R6 == 5
label define Q68D 1 "Strongly disapprove" 2 "Disapprove" 3 "Approve" 4 "Strongly approve", modify
label values Q68D_R6 Q68D

*Ethnic or national identity
replace C85B=. if C85B==1 | C85B==7 | C85B==8
replace C85B=102 if C85B==2
replace C85B=103 if C85B==3
replace C85B=104 if C85B==4
replace C85B=105 if C85B==5
replace C85B=106 if C85B==6
replace C85B=5 if C85B==102
replace C85B=4 if C85B==103
replace C85B=3 if C85B==104
replace C85B=2 if C85B==105
replace C85B=1 if C85B==106

*To what extent does this network give access to jobs in the admin: a particular ethnic group
replace C79C_CAMC=. if C79C_CAMC==1 | C79C_CAMC==6

*Leaders should help own community vs. treat all equally
replace Q18_R5=. if Q18_R5==1 | Q18_R5==7
replace Q18_R5=. if Q18_R5==6

*Voted in the last election
replace C27=. if C27==10 | C27==11
replace C27=0 if C27==2 | C27==4 | C27==5 | C27==6 | C27==7 | C27==8 | C27==9
replace C27=1 if C27==3

*Discuss politics 
replace C15=. if C15==1 | C15==5

*Attended a protest march or demonstration
replace C26D=. if C26D==7 | C26D==1

*Are you satisfied with the regional balance in: the major training schools (ENAM, ENS, IRIC) 
replace C79A_CAMA=. if C79A_CAMA==7

*Are you satisfied with the regional balance in: appointments to senior levels of public administration
replace C79A_CAMB=. if C79A_CAMB==1 | C79A_CAMB==7

*Are you satisfied with the regional balance in: Military and Police training schools
replace C79A_CAMC=. if C79A_CAMC==7

*Trust relatives
replace Q88A_R5=. if Q88A_R5==1 | Q88A_R5==6

*Trust neighbors
replace Q88B_R5=. if Q88B_R5==1 | Q88B_R5==6

*Trust other people you know
replace Q88C_R5=. if Q88C_R5==1 | Q88C_R5==6

* Social Trust
gen SocialTrust = (Q88A_R5+Q88B_R5+Q88C_R5)/3

*Trust in the President
replace C59A=. if C59A==1 | C59A==6

*Trust in the National Assembly
replace C59B=. if C59B==1 | C59B==6

*Trust in ELECAM
replace C59C=. if C59C==1 | C59C==6

*Trust in the tax department
replace C59D=. if C59D==1 | C59D==6

*Trust in local government
replace C59E=. if C59E==1 | C59E==6

*Trust in the ruling party
replace C59F=. if C59F==1 | C59F==6

*Trust in opposition parties
replace C59G=. if C59G==1 | C59G==6

*Trust in the police
replace C59H=. if C59H==1 | C59H==6

*Trust in the army
replace C59I=. if C59I==1 | C59I==6

*Trust in the courts of law
replace C59J=. if C59J==1 | C59J==6

* Institutional_Trust
gen Institutional_Trust = (C59A+C59B+C59C+C59D+C59E+C59F+C59G+C59H+C59I+C59J)/10

gen Bamileke = 0
replace Bamileke = 1 if C84 == 3 | C84 == 8

*How well is LOCAL government maintaining roads
replace C66A=. if C66A==6

*How well is LOCAL government maintaining local markets
replace C66B=. if C66B==6

*How well is LOCAL govt maintaining local health standards
replace Q66C_R5=. if Q66C_R5==6

*How well is LOCAL govt keeping the community clean
replace Q66D_R5=. if Q66D_R5==6

*How well is the LOCAL govt managing the use of land
replace Q66E_R5=. if Q66E_R5==1 | Q66E_R5==6

saveold AfroBarometerData.dta, replace
