************************************************************************************************
************************************************************************************************
* Replication Materials for “The Mechanisms of Direct and Indirect Rule: Colonialism and Economic Development in Africa”
* Authors: Natalie Lest and Martha Wilfahrt
* Journal: Quarterly Journal of Political Science
* Version Date: 10 December 2010
************************************************************************************************
************************************************************************************************

cd "Letsa Wilfahrt_QJPS Replication Materials/Data/"

import delimited "Generalizability_GIS_Covariates.csv", clear
rename countryname CountryName
rename region_alt Region_Alt
rename round Round
rename urbrur Urban
gen urbrur = 2
replace urbrur = 1 if Urban == "Urban" | Urban == "Urban+C1137"
drop Urban
sort CountryName Region_Alt Round urbrur
saveold Generalizability_GIS_Covariates.dta, replace 

*** 3// GENERALIZABILITY DATA CLEANING DATA

** Round 6
* NOTE: full replication will require downloading the Pooled Round 6 Afrobarometer data from www.afrobarometer.org. 
* use merged_r6_data_2016_36countries2.dta, clear

drop if country == 1 | country == 7 | country == 9 | country == 19 | country == 20 | country == 21 | country == 25 | country == 33 | country == 5 | country == 15

rename Q1 age
replace age = . if age == -1 | age > 200
gen female = 0
replace female = 1 if Q101 == 2
rename Q97 education
replace education = . if education == -1 | education > 90
gen rural = 0
replace rural = 1 if urbrur == 2
replace rural = 0 if urbrur == 3
replace rural = 0 if urbrur == 460

replace urbrur = 1 if urbrur == 3
replace urbrur = 1 if urbrur == 460

gen anglophone = 0
replace anglophone = 1 if country == 3 | country == 11 | country == 13 | country == 14 | country == 15 | country == 17 | country == 22 | country == 24 | country == 27 | country == 28 | country == 29 | country == 30 | country == 31 | country == 34 | country == 35 | country == 36
gen francophone = 0
replace francophone = 1 if country == 2 | country == 4 | country == 5 | country == 6  | country == 8 | country == 10 | country == 12 | country == 16 | country == 18 | country == 23 | country == 26 | country == 32 

replace anglophone = 1 if region == 1228 & country == 6
replace anglophone = 1 if region == 1231 & country == 6

gen settler_colony = 0
replace settler_colony = 1 if country == 36 | country == 28 | country == 22 | country == 30 | country == 14

sort country LOCATION_LEVEL_1
encode LOCATION_LEVEL_1, gen(EANUMB)
decode country, gen(CountryName)
decode region, gen(RegionName)
gen Region_Alt = RegionName
replace Region_Alt = lower(Region_Alt)

encode Region_Alt, gen(Region_N)

replace Region_Alt = "moyen-ogoouie" if Region_N == 195
replace Region_Alt = "ngounie" if Region_N == 206
replace Region_Alt = "ogoouie-ivindo" if Region_N == 224
replace Region_Alt = "ogoouie-lolo" if Region_N == 225
replace Region_Alt = "ogoouie-maritime" if Region_N == 226
replace Region_Alt = "haut-ogoouie" if Region_N == 106

replace Region_Alt = "oueme" if Region_N == 237
replace Region_Alt = "lome commune" if Region_N == 161
replace Region_Alt = "mohale's hoek" if Region_N == 189
replace Region_Alt = "qacha's nek" if Region_N == 246
replace Region_Alt = "segou" if Region_N == 273
replace Region_Alt = "tillaberi" if Region_N == 282
replace Region_Alt = "kedougou" if Region_N == 151
replace Region_Alt = "sedhiou" if Region_N == 272

replace Region_Alt = "extreme-north" if Region_N == 84
replace Region_Alt = "yaounde" if Region_N == 57
replace Region_Alt = "boke" if Region_N == 33
replace Region_Alt = "labe" if Region_N == 153
replace Region_Alt = "nzerekore" if Region_N == 223

replace Region_Alt = "belier" if Region_N == 41
replace Region_Alt = "bagoue" if Region_N == 24
replace Region_Alt = "bore" if Region_N == 42
replace Region_Alt = "gbokle" if Region_N == 92
replace Region_Alt = "gbeke" if Region_N == 93
replace Region_Alt = "guemon" if Region_N == 100
replace Region_Alt = "goh" if Region_N == 101
replace Region_Alt = "indenie-djuablin" if Region_N == 113
replace Region_Alt = "la me" if Region_N == 152
replace Region_Alt = "lah-djiboua" if Region_N == 166
replace Region_Alt = "marahoue" if Region_N == 174
replace Region_Alt = "sud comoe" if Region_N == 269

rename Q59B Councilor_Listens
replace Councilor_Listens = . if Councilor_Listens == -1 | Councilor_Listens > 8

rename Q68C Councilor_Performance
replace Councilor_Performance = . if Councilor_Performance == -1 | Councilor_Performance > 4

rename Q24C Contact_Official
replace Contact_Official = . if Contact_Official == -1 | Contact_Official > 3

rename Q19B CommunityGroupMember
replace CommunityGroupMember = . if CommunityGroupMember == -1 | CommunityGroupMember > 3

rename Q52K Trust_TAs
replace Trust_TAs = . if Trust_TAs == -1 | Trust_TAs == 9

rename Q53H Corrupt_TAs
replace Corrupt_TAs = . if Corrupt_TAs == -1 | Corrupt_TAs == 9

rename Q24E Contact_TAs
replace Contact_TAs = . if Contact_TAs == -1 | Contact_TAs == 9

rename Q68D TA_Performance
replace TA_Performance = . if TA_Performance == -1 | TA_Performance > 4

rename Q88B EthnicIDs

replace EthnicIDs=. if EthnicIDs==- 1 | EthnicIDs > 5
revrs EthnicIDs, replace

rename Q67A LG_Roads
replace LG_Roads = . if LG_Roads == -1 | LG_Roads > 4

rename Q67B LG_Markets
replace LG_Markets = . if LG_Markets == -1 | LG_Markets > 4

rename Q14 DiscussPolitics
replace DiscussPolitics = . if DiscussPolitics == -1 | DiscussPolitics > 4

rename Q20B RaiseIssue
replace RaiseIssue = . if RaiseIssue == -1 | RaiseIssue > 4

rename Q27E AttendProtest
replace AttendProtest = . if AttendProtest == -1 | AttendProtest > 4

gen Voted = 0
replace Voted = 1 if Q21 == 1

foreach var of varlist Q52A-Q52J {
	replace `var' = . if `var' == -1 | `var' > 3
}

gen Institutional_Trust = (Q52A+Q52B+Q52C+Q52D+Q52E+Q52F+Q52G+Q52H+Q52I+Q52J)/10

gen Round = 6

keep Round Institutional_Trust Voted AttendProtest RaiseIssue DiscussPolitics LG_Roads LG_Markets TA_Performance EthnicIDs Councilor_Performance Councilor_Listens Corrupt_TAs Trust_TAs Contact_Official Contact_TAs CommunityGroupMember female rural age education anglophone francophone settler_colony CountryName EANUMB RegionName Region_Alt urbrur

saveold "AB_Rd6_ToAppend.dta", replace

** ROUND 5
* NOTE: full replication will require downloading the Pooled Round 5 Afrobarometer data from www.afrobarometer.org. 
*use "merged-round-5-data-34-countries-2011-2013-last-update-july-2015.dta", clear

drop if country == 4 | country == 8 | country == 12 | country == 21 | country == 25 | country == 31 | country == 32 | country == 33 | country == 34 | country == 35

rename Q1 age
replace age = . if age == -1 | age > 105
gen female = 0
replace female = 1 if Q101 == 2
rename Q97 education
replace education = . if education == -1 | education > 9
gen rural = 0
replace rural = 1 if urbrur == 2
replace rural = 0 if urbrur == 3

replace urbrur = 1 if urbrur == 3

gen anglophone = 0
replace anglophone = 1 if country == 2 | country == 5 | country == 6 | country == 7 | country == 10 | country == 13 | country == 14 | country == 16 | country == 17 | country == 18 | country == 19 | country == 20 | country == 22 | country == 30 
gen francophone = 0
replace francophone = 1 if country == 1 | country == 3 | country == 9 | country == 11 | country == 15 | country == 23 | country == 24 | country == 26 | country == 27 | country == 28 

replace anglophone = 1 if region == 1228 & country == 26
replace anglophone = 1 if region == 1231 & country == 26

gen settler_colony = 0
replace settler_colony = 1 if country == 13 | country == 16 | country == 20 | country == 7 | country == 30

decode country, gen(CountryName)
decode region, gen(RegionName)
gen Region_Alt = RegionName
replace Region_Alt = lower(Region_Alt)

replace CountryName = "Cote d'Ivoire" if country == 27

encode Region_Alt, gen(Region_N)

replace Region_Alt = "lome commune" if Region_N == 143
replace Region_Alt = "mohale's hoek" if Region_N == 170
replace Region_Alt = "qacha's nek" if Region_N == 219
replace Region_Alt = "segou" if Region_N == 245
replace Region_Alt = "tillaberi" if Region_N == 253
replace Region_Alt = "kedougou" if Region_N == 133
replace Region_Alt = "sedhiou" if Region_N == 244

replace Region_Alt = "boke" if Region_N == 31
replace Region_Alt = "labe" if Region_N == 134
replace Region_Alt = "nzerekore" if Region_N == 201

replace Region_Alt = "n'zi comoe" if Region_N == 200
replace Region_Alt = "abidjan" if Region_N == 261
replace Region_Alt = "vatovavy fitonany" if Region_N == 260

rename Q62B Councilor_Listens
replace Councilor_Listens = . if Councilor_Listens == -1 | Councilor_Listens > 8

rename Q71C Councilor_Performance
replace Councilor_Performance = . if Councilor_Performance == -1 | Councilor_Performance > 4

rename Q30C Contact_Official
replace Contact_Official = . if Contact_Official == -1 | Contact_Official > 3

rename Q25B CommunityGroupMember
replace CommunityGroupMember = . if CommunityGroupMember == -1 | CommunityGroupMember > 3

rename Q85B EthnicIDs

replace EthnicIDs=. if EthnicIDs==- 1 | EthnicIDs > 5
revrs EthnicIDs, replace

rename Q18 HelpOwnComm
replace HelpOwnComm = . if HelpOwnComm == -1 | HelpOwnComm > 4

rename Q66A LG_Roads
replace LG_Roads = . if LG_Roads == -1 | LG_Roads > 4

rename Q66B LG_Markets
replace LG_Markets = . if LG_Markets == -1 | LG_Markets > 4

rename Q66C LG_HealthStds
replace LG_HealthStds = . if LG_HealthStds == -1 | LG_HealthStds > 4

rename Q66D LG_Clean
replace LG_Clean = . if LG_Clean == -1 | LG_Clean > 4

rename Q66E LG_Land
replace LG_Land = . if LG_Land == -1 | LG_Land > 4

rename Q15 DiscussPolitics
replace DiscussPolitics = . if DiscussPolitics == -1 | DiscussPolitics > 4

rename Q26B RaiseIssue
replace RaiseIssue = . if RaiseIssue == -1 | RaiseIssue > 4

rename Q26D AttendProtest
replace AttendProtest = . if AttendProtest == -1 | AttendProtest > 4

gen Voted = 0
replace Voted = 1 if Q27 == 1

foreach var of varlist Q59A-Q59J {
	replace `var' = . if `var' == -1 | `var' > 3
}

gen Institutional_Trust = (Q59A+Q59B+Q59C+Q59D+Q59E+Q59F+Q59G+Q59H+Q59I+Q59J)/10

gen GeneralTrust = 0
replace GeneralTrust = 1 if Q87 == 1

foreach var of varlist Q88A-Q88C {
	replace `var' = . if `var' == -1 | `var' > 3
}
gen SocialTrust = (Q88A+Q88B+Q88C)/3

gen Round = 5

keep Round SocialTrust GeneralTrust DiscussPolitics RaiseIssue AttendProtest Voted Institutional_Trust LG_Clean LG_HealthStds LG_Land LG_Roads LG_Markets  EthnicIDs HelpOwnComm Councilor_Performance Councilor_Listens Contact_Official CommunityGroupMember female age rural education anglophone francophone settler_colony CountryName  RegionName Region_Alt urbrur

append using "AB_Rd6_ToAppend.dta"

sort CountryName Region_Alt Round urbrur
merge CountryName Region_Alt Round urbrur using Generalizability_GIS_Covariates.dta
drop _merge

gen ln_D_Capital_km = log(d_capital_km)

saveold GeneralizabilityData.dta, replace
