************************************************************************************************
************************************************************************************************
* Replication Materials for Supplementary Materials: “The Mechanisms of Direct and Indirect Rule: Colonialism and Economic Development in Africa”
* Authors: Natalie Lest and Martha Wilfahrt
* Journal: Quarterly Journal of Political Science
* Version Date: 12 January 2010
************************************************************************************************
************************************************************************************************

cd "Letsa Wilfahrt_QJPS Replication Materials/Data/"

import delimited "Nightlight_GIS Controls.csv", clear 
rename fid_grid_5km FID_GRID_5km
sort FID_GRID_5km 
saveold "Nightlight_GIS Controls.dta", replace

import delimited "DHS_1991_GIS Controls.csv", clear 
rename cluster Cluster
sort Cluster 
saveold "DHS_1991_GIS Controls.dta", replace

import delimited "DHS_2004_GIS Controls.csv", clear 
rename cluster Cluster
sort Cluster 
saveold "DHS_2004_GIS Controls.dta", replace

import delimited "DHS_2011_GIS Controls.csv", clear 
rename cluster Cluster
sort Cluster 
saveold "DHS_2011_GIS Controls.dta", replace

*****************************
*********** 1991 ************
*****************************

******************* HOUSEHOLD
* NOTE: full replication will require requesting access to and downloading Cameroon's 1991 Household Sample Demographic and Health Survey Data from https://www.dhsprogram.com/data/.  
* Open Data

rename hv001 Cluster

gen Urban = 1
replace Urban = 0 if hv023 == 3

rename shprov region
gen anglophone = 0
replace anglophone = 1 if region == 9
replace anglophone = 1 if region == 6

gen Douala = 0
replace Douala = 1 if Cluster == 92 | Cluster == 93 | Cluster == 94 | Cluster == 95 | Cluster == 96 | Cluster == 97 | Cluster == 98 | Cluster == 99 | Cluster == 100 | Cluster == 101 | Cluster == 102

gen Comp_Zone = 0
replace Comp_Zone = 1 if anglophone == 1
replace Comp_Zone = 1 if region == 4
replace Comp_Zone = 1 if region == 7
replace Comp_Zone = 0 if Douala == 1

rename hv202 hh_water_source
rename hv204 water_time
rename hv201 drinking_h20_source
rename hv205 toilet
replace toilet = 2 if toilet == 11
replace toilet = 1 if toilet == 21
replace toilet = 1 if toilet == 22
replace toilet = 0 if toilet == 31
replace toilet = 0 if toilet == 32
replace toilet = 0 if toilet == 33
replace toilet = . if toilet == 41
label define toilet 2 "flush toilet" 1 "latrine" 0 "no facilities"
label values toilet toilet 
rename hv206 electricity
rename hv207 radio
rename hv208 tv
rename hv209 fridge
rename hv210 bicycle
rename hv211 motocycle
rename hv212 car
gen floor_material = 0
replace floor_material = 0 if hv213 == 11
replace floor_material = 1 if hv213 == 21
replace floor_material = 1 if hv213 == 31
replace floor_material = 2 if hv213 == 32
replace floor_material = . if hv213 == 41
rename hv216 Rooms_Sleeping
gen ln_Rooms_Sleeping = log(Rooms_Sleeping)

gen Possessions_Transport = bicycle+ motocycle+ car
gen Possessions_HH = fridge + tv + radio 

gen Possessions_Pooled = bicycle+ motocycle+ car + fridge  + tv + radio

gen LeeSchultz_Possessions = bicycle+ motocycle+ car + fridge  + tv + radio + floor_material + toilet + ln_Rooms_Sleeping
gen LeeSchultz_Poss_NoElec = bicycle+ motocycle+ car + radio + floor_material + toilet + ln_Rooms_Sleeping

revrs toilet, replace
revrs drinking_h20_source, replace
replace drinking_h20_source = . if drinking_h20_source == 1
replace drinking_h20_source = . if drinking_h20_source == 2
replace floor_material = . if floor_material == 41

gen Water_Dummy = 0
replace Water_Dummy = 1 if drinking_h20_source > 6

sort Cluster
merge Cluster using "DHS_1991_GIS Controls.dta"
drop _merge 

sort Cluster
by Cluster: gen Cluster_N = _n
bysort Cluster (Cluster_N) : gen max_X = Cluster_N[_N]
by Cluster: egen Cluster_N_PipedH20 = sum(Water_Dummy)
by Cluster: gen Perc_PipedH20 = Cluster_N_PipedH20/max_X

gen Any_Water_Dummy = 0
replace Any_Water_Dummy = 1 if drinking_h20_source > 5

sort Cluster
by Cluster: egen Cluster_N_Any_H20 = sum(Any_Water_Dummy)
by Cluster: gen Perc_Any_H20 = Cluster_N_Any_H20/max_X

gen HH_Infrastructure = floor_material+ toilet

gen D_Border10 = 0
replace D_Border10 = 1 if d_border_km < 10
gen D_Border15 = 0
replace D_Border15 = 1 if d_border_km < 15
gen D_Border20 = 0
replace D_Border20 = 1 if d_border_km < 20
gen D_Border25 = 0
replace D_Border25 = 1 if d_border_km < 25
gen D_Border30 = 0
replace D_Border30 = 1 if d_border_km < 30
gen D_Border35 = 0
replace D_Border35 = 1 if d_border_km < 35
gen D_Border40 = 0
replace D_Border40 = 1 if d_border_km < 40
gen D_Border45 = 0
replace D_Border45 = 1 if d_border_km < 45
gen D_Border50 = 0
replace D_Border50 = 1 if d_border_km < 50
gen D_Border55 = 0
replace D_Border55 = 1 if d_border_km < 55
gen D_Border60 = 0
replace D_Border60 = 1 if d_border_km < 60
gen D_Border65 = 0
replace D_Border65 = 1 if d_border_km < 65
gen D_Border70 = 0
replace D_Border70 = 1 if d_border_km < 70
gen D_Border75 = 0
replace D_Border75 = 1 if d_border_km < 75
gen D_Border80 = 0
replace D_Border80 = 1 if d_border_km < 80
gen D_Border85 = 0
replace D_Border85 = 1 if d_border_km < 85
gen D_Border90 = 0
replace D_Border90 = 1 if d_border_km < 90
gen D_Border95 = 0
replace D_Border95 = 1 if d_border_km < 95
gen D_Border100 = 0
replace D_Border100 = 1 if d_border_km < 100

replace d_border_km = d_border_km + 1 if d_border_km < 1
replace d_coast_km = d_coast_km + 1 if d_coast_km < 1
replace d_yaounde_km = d_yaounde_km + 1 if d_yaounde_km < 1
replace d_regcapital_km = d_regcapital_km + 1 if d_regcapital_km < 1

gen ln_d_border_km = log(d_border_km)
gen ln_d_coast_km = log(d_coast_km)
gen ln_d_yaounde_km = log(d_yaounde_km)
gen ln_d_regcapital_km = log(d_regcapital_km)

gen ln_Sum_Population_5km = log(sum_population_5km)

gen Male_HH = 0
replace Male_HH = 1 if hv219 == 1

gen Year = 1991

gen Cluster2 = Cluster +1991000

keep Perc_Any_H20  Male_HH border_longitude border_latitude Douala cec_mean ln_Sum_Population_5km Cluster2 region LeeSchultz_Poss_NoElec d_border_km LeeSchultz_Possessions ln_d_border_km ln_d_coast_km ln_d_yaounde_km ln_d_regcapital_km Perc_PipedH20 Water_Dummy latitude longitude Possessions_Pooled HH_Infrastructure Cluster Year D_Border10 D_Border15 D_Border20 D_Border25 D_Border30 D_Border35 D_Border40 D_Border45 D_Border50 D_Border55 D_Border60 D_Border65 D_Border70 D_Border75 D_Border80 D_Border85 D_Border90 D_Border95 D_Border100 Comp_Zone anglophone drinking_h20_source toilet Possessions_HH Possessions_Transport floor_material Urban electricity avg_alt avg_prec avg_temp sum_population_5km d_border_km d_yaounde_km d_regcapital_km 

saveold "DHS_GIS_1991_Merged GIS.dta", replace


*****************************
*********** 2004 ************
*****************************
* NOTE: full replication will require requesting access to and downloading Cameroon's 2004 Household Sample Demographic and Health Survey Data from https://www.dhsprogram.com/data/.  
* Open Data

rename hv001 Cluster
sort Cluster

gen Urban = 1
replace Urban = 0 if hv025 == 2

rename hv024 region
gen anglophone = 0
replace anglophone = 1 if region == 11
replace anglophone = 1 if region == 8

gen Douala = 0
replace Douala = 1 if region == 3

gen Comp_Zone = 0
replace Comp_Zone = 1 if anglophone == 1
replace Comp_Zone = 1 if region == 6
replace Comp_Zone = 1 if region == 9
replace Comp_Zone = 0 if Douala == 1

rename hv204 water_time
rename hv201 drinking_h20_source
rename hv205 toilet
replace toilet = 2 if toilet == 11
replace toilet = 1 if toilet == 21
replace toilet = 1 if toilet == 22
replace toilet = 0 if toilet == 31
replace toilet = . if toilet == 96
label define toilet 2 "flush toilet" 1 "latrine" 0 "no facilities"
label values toilet toilet 
rename hv206 electricity
rename hv207 radio
rename hv208 tv
rename hv209 fridge
rename hv210 bicycle
rename hv211 motocycle
rename hv212 car
rename hv221 cell
rename hv226 cooking_fuel
gen floor_material = 0
replace floor_material = 0 if hv213 == 11
replace floor_material = 1 if hv213 == 21
replace floor_material = 1 if hv213 == 22
replace floor_material = 2 if hv213 == 31
replace floor_material = 2 if hv213 == 32
replace floor_material = 2 if hv213 == 33
replace floor_material = 2 if hv213 == 34
replace floor_material = 2 if hv213 == 35
replace floor_material = . if hv213 == 96
rename sh26a Rooms_Sleeping
gen ln_Rooms_Sleeping = log(Rooms_Sleeping)

gen Possessions_Transport = bicycle+ motocycle+ car
gen Possessions_HH = fridge + tv + radio 

gen Possessions_Pooled = bicycle+ motocycle+ car + fridge  + tv + radio

gen LeeSchultz_Possessions = bicycle+ motocycle+ car + fridge  + tv + radio + floor_material + toilet + ln_Rooms_Sleeping
gen LeeSchultz_Poss_NoElec = bicycle+ motocycle+ car + radio + floor_material + toilet + ln_Rooms_Sleeping

revrs drinking_h20_source, replace
replace drinking_h20_source = . if drinking_h20_source == 1
replace drinking_h20_source = . if drinking_h20_source == 2
replace floor_material = . if floor_material == 41

gen Water_Dummy = 0
replace Water_Dummy = 1 if drinking_h20_source > 7

sort Cluster
merge Cluster using "DHS_2004_GIS Controls.dta"
drop _merge 

sort Cluster
by Cluster: gen Cluster_N = _n
bysort Cluster (Cluster_N) : gen max_X = Cluster_N[_N]
by Cluster: egen Cluster_N_PipedH20 = sum(Water_Dummy)
by Cluster: gen Perc_PipedH20 = Cluster_N_PipedH20/max_X

gen Any_Water_Dummy = 0
replace Any_Water_Dummy = 1 if drinking_h20_source > 5

sort Cluster
by Cluster: egen Cluster_N_Any_H20 = sum(Any_Water_Dummy)
by Cluster: gen Perc_Any_H20 = Cluster_N_Any_H20/max_X

gen HH_Infrastructure = floor_material+ toilet

gen D_Border10 = 0
replace D_Border10 = 1 if d_border_km < 10
gen D_Border15 = 0
replace D_Border15 = 1 if d_border_km < 15
gen D_Border20 = 0
replace D_Border20 = 1 if d_border_km < 20
gen D_Border25 = 0
replace D_Border25 = 1 if d_border_km < 25
gen D_Border30 = 0
replace D_Border30 = 1 if d_border_km < 30
gen D_Border35 = 0
replace D_Border35 = 1 if d_border_km < 35
gen D_Border40 = 0
replace D_Border40 = 1 if d_border_km < 40
gen D_Border45 = 0
replace D_Border45 = 1 if d_border_km < 45
gen D_Border50 = 0
replace D_Border50 = 1 if d_border_km < 50
gen D_Border55 = 0
replace D_Border55 = 1 if d_border_km < 55
gen D_Border60 = 0
replace D_Border60 = 1 if d_border_km < 60
gen D_Border65 = 0
replace D_Border65 = 1 if d_border_km < 65
gen D_Border70 = 0
replace D_Border70 = 1 if d_border_km < 70
gen D_Border75 = 0
replace D_Border75 = 1 if d_border_km < 75
gen D_Border80 = 0
replace D_Border80 = 1 if d_border_km < 80
gen D_Border85 = 0
replace D_Border85 = 1 if d_border_km < 85
gen D_Border90 = 0
replace D_Border90 = 1 if d_border_km < 90
gen D_Border95 = 0
replace D_Border95 = 1 if d_border_km < 95
gen D_Border100 = 0
replace D_Border100 = 1 if d_border_km < 100

replace d_border_km = d_border_km + 1 if d_border_km < 1
replace d_coast_km = d_coast_km + 1 if d_coast_km < 1
replace d_yaounde_km = d_yaounde_km + 1 if d_yaounde_km < 1
replace d_regcapital_km = d_regcapital_km + 1 if d_regcapital_km < 1

gen ln_d_border_km = log(d_border_km)
gen ln_d_coast_km = log(d_coast_km)
gen ln_d_yaounde_km = log(d_yaounde_km)
gen ln_d_regcapital_km = log(d_regcapital_km)

gen ln_Sum_Population_5km = log(sum_population_5km)

gen Male_HH = 0
replace Male_HH = 1 if hv219 == 1
 
gen Year = 2004

gen Cluster2 = Cluster +2004000

keep Perc_Any_H20  Male_HH border_longitude border_latitude Douala cec_mean ln_Sum_Population_5km Cluster2 region LeeSchultz_Poss_NoElec d_border_km LeeSchultz_Possessions ln_d_border_km ln_d_coast_km ln_d_yaounde_km ln_d_regcapital_km Perc_PipedH20 Water_Dummy latitude longitude Possessions_Pooled HH_Infrastructure Cluster Year D_Border10 D_Border15 D_Border20 D_Border25 D_Border30 D_Border35 D_Border40 D_Border45 D_Border50 D_Border55 D_Border60 D_Border65 D_Border70 D_Border75 D_Border80 D_Border85 D_Border90 D_Border95 D_Border100 Comp_Zone anglophone drinking_h20_source toilet Possessions_HH Possessions_Transport floor_material Urban electricity avg_alt avg_prec avg_temp sum_population_5km d_border_km d_yaounde_km d_regcapital_km 

saveold "DHS_2004_Merged GIS.dta", replace


*****************************
*********** 2011 ************
*****************************

clear
clear mata
clear matrix
set maxvar 10000

******************* HOUSEHOLD
* NOTE: full replication will require requesting access to and downloading Cameroon's 2011 Household Sample Demographic and Health Survey Data from https://www.dhsprogram.com/data/.  
* Open Data

rename hv001 Cluster
sort Cluster

gen Urban = 1
replace Urban = 0 if hv025 == 2

rename hv024 region
gen anglophone = 0
replace anglophone = 1 if region == 11
replace anglophone = 1 if region == 8

gen Douala = 0
replace Douala = 1 if region == 3

gen Comp_Zone = 0
replace Comp_Zone = 1 if anglophone == 1
replace Comp_Zone = 1 if region == 6
replace Comp_Zone = 1 if region == 9
replace Comp_Zone = 0 if Douala == 1

rename hv204 water_time
rename hv201 drinking_h20_source
replace drinking_h20_source = . if drinking_h20_source == 99 | drinking_h20_source == 96
rename hv205 toilet
replace toilet = 2 if toilet == 11
replace toilet = 2 if toilet == 12
replace toilet = 2 if toilet == 13
replace toilet = 2 if toilet == 14
replace toilet = 1 if toilet == 21
replace toilet = 1 if toilet == 22
replace toilet = 1 if toilet == 23
replace toilet = 0 if toilet == 31
replace toilet = 0 if toilet == 42
replace toilet = 0 if toilet == 43
replace toilet = . if toilet > 60
label define toilet 2 "flush toilet" 1 "latrine" 0 "no facilities"
label values toilet toilet 
rename hv206 electricity
replace electricity = . if electricity == 9
rename hv207 radio
replace radio = . if radio == 9
rename hv208 tv
replace tv = . if tv == 9
rename hv209 fridge
replace fridge = . if fridge == 9
rename hv210 bicycle
replace bicycle = . if bicycle == 9
rename hv211 motocycle
replace motocycle = . if motocycle == 9
rename hv212 car
replace car = . if car == 9
rename hv221 cell
replace cell = . if cell == 9
*rename hv226 cooking_fuel
*replace cooking_fuel = . if cooking_fuel cell == 9
gen floor_material = 0
replace floor_material = 0 if hv213 == 11
replace floor_material = 0 if hv213 == 12
replace floor_material = 1 if hv213 == 21
replace floor_material = 1 if hv213 == 22
replace floor_material = 2 if hv213 == 32
replace floor_material = 2 if hv213 == 31
replace floor_material = 2 if hv213 == 32
replace floor_material = 2 if hv213 == 33
replace floor_material = 2 if hv213 == 34
replace floor_material = 2 if hv213 == 35
replace floor_material = . if hv213 == 96
replace floor_material = . if hv213 == 99
rename hv216 Rooms_Sleeping
gen ln_Rooms_Sleeping = log(Rooms_Sleeping)

gen Possessions_Transport = bicycle+ motocycle+ car
gen Possessions_HH = fridge + tv + radio 

gen Possessions_Pooled = bicycle+ motocycle+ car + fridge  + tv + radio

gen LeeSchultz_Possessions = bicycle+ motocycle+ car + fridge  + tv + radio + floor_material + toilet + ln_Rooms_Sleeping
gen LeeSchultz_Poss_NoElec = bicycle+ motocycle+ car + radio + floor_material + toilet + ln_Rooms_Sleeping

revrs drinking_h20_source, replace

gen Water_Dummy = 0
replace Water_Dummy = 1 if drinking_h20_source > 9

sort Cluster
merge Cluster using "DHS_2011_GIS Controls.dta"
drop _merge 

sort Cluster
by Cluster: gen Cluster_N = _n
bysort Cluster (Cluster_N) : gen max_X = Cluster_N[_N]
by Cluster: egen Cluster_N_PipedH20 = sum(Water_Dummy)
by Cluster: gen Perc_PipedH20 = Cluster_N_PipedH20/max_X

gen Any_Water_Dummy = 0
replace Any_Water_Dummy = 1 if drinking_h20_source > 8

sort Cluster
by Cluster: egen Cluster_N_Any_H20 = sum(Any_Water_Dummy)
by Cluster: gen Perc_Any_H20 = Cluster_N_Any_H20/max_X

gen HH_Infrastructure = floor_material+ toilet

gen D_Border10 = 0
replace D_Border10 = 1 if d_border_km < 10
gen D_Border15 = 0
replace D_Border15 = 1 if d_border_km < 15
gen D_Border20 = 0
replace D_Border20 = 1 if d_border_km < 20
gen D_Border25 = 0
replace D_Border25 = 1 if d_border_km < 25
gen D_Border30 = 0
replace D_Border30 = 1 if d_border_km < 30
gen D_Border35 = 0
replace D_Border35 = 1 if d_border_km < 35
gen D_Border40 = 0
replace D_Border40 = 1 if d_border_km < 40
gen D_Border45 = 0
replace D_Border45 = 1 if d_border_km < 45
gen D_Border50 = 0
replace D_Border50 = 1 if d_border_km < 50
gen D_Border55 = 0
replace D_Border55 = 1 if d_border_km < 55
gen D_Border60 = 0
replace D_Border60 = 1 if d_border_km < 60
gen D_Border65 = 0
replace D_Border65 = 1 if d_border_km < 65
gen D_Border70 = 0
replace D_Border70 = 1 if d_border_km < 70
gen D_Border75 = 0
replace D_Border75 = 1 if d_border_km < 75
gen D_Border80 = 0
replace D_Border80 = 1 if d_border_km < 80
gen D_Border85 = 0
replace D_Border85 = 1 if d_border_km < 85
gen D_Border90 = 0
replace D_Border90 = 1 if d_border_km < 90
gen D_Border95 = 0
replace D_Border95 = 1 if d_border_km < 95
gen D_Border100 = 0
replace D_Border100 = 1 if d_border_km < 100

replace d_border_km = d_border_km + 1 if d_border_km < 1
replace d_coast_km = d_coast_km + 1 if d_coast_km < 1
replace d_yaounde_km = d_yaounde_km + 1 if d_yaounde_km < 1
replace d_regcapital_km = d_regcapital_km + 1 if d_regcapital_km < 1

gen ln_d_border_km = log(d_border_km)
gen ln_d_coast_km = log(d_coast_km)
gen ln_d_yaounde_km = log(d_yaounde_km)
gen ln_d_regcapital_km = log(d_regcapital_km)
 
gen ln_Sum_Population_5km = log(sum_population_5km)

gen Year = 2011

gen Male_HH = 0
replace Male_HH = 1 if hv219 == 1
 
gen Cluster2 = Cluster +2011000

keep Perc_Any_H20 Male_HH border_longitude border_latitude Douala ln_Sum_Population_5km cec_mean Cluster2 region LeeSchultz_Poss_NoElec d_border_km LeeSchultz_Possessions ln_d_border_km ln_d_coast_km ln_d_yaounde_km ln_d_regcapital_km Perc_PipedH20 Water_Dummy latitude longitude Possessions_Pooled HH_Infrastructure Cluster Year D_Border10 D_Border15 D_Border20 D_Border25 D_Border30 D_Border35 D_Border40 D_Border45 D_Border50 D_Border55 D_Border60 D_Border65 D_Border70 D_Border75 D_Border80 D_Border85 D_Border90 D_Border95 D_Border100 Comp_Zone anglophone drinking_h20_source toilet Possessions_HH Possessions_Transport floor_material Urban electricity avg_alt avg_prec avg_temp sum_population_5km d_border_km d_coast_km d_yaounde_km d_regcapital_km 

saveold "DHS_GIS_2011_Merged GIS.dta", replace


************************************
*********** ALL MERGED *************
************************************

use "DHS_GIS_1991_Merged GIS.dta", clear
append using "DHS_2004_Merged GIS.dta"
append using "DHS_GIS_2011_Merged GIS.dta"

gen Ln_Pop_5km = log(sum_population_5km)

gen d_border_UK = 0
replace d_border_UK = d_border_km if anglophone == 1
gen d_border_French = 0
replace d_border_French = d_border_km if anglophone == 0

replace Comp_Zone = 1 if Douala == 1

collapse (mean) Perc_Any_H20 Perc_PipedH20 LeeSchultz_Poss_NoElec (first) border_longitude border_latitude Douala Comp_Zone cec_mean avg_prec avg_temp d_border_UK d_border_French region anglophone d_border_km latitude Ln_Pop_5km longitude Urban avg_alt ln_d_regcapital_km ln_d_yaounde_km ln_d_coast_km, by(Cluster2 Year)

egen z2_Perc_PipedH20 = std(Perc_PipedH20)

egen z2_LS_Poss_NoElec = std(LeeSchultz_Poss_NoElec)

** D_Border

gen D_Border_Rounded = round(d_border_km, 1)
gen D_Border15 = D_Border_Rounded < 16
gen D_Border16 = D_Border_Rounded < 17
gen D_Border17 = D_Border_Rounded < 18
gen D_Border18 = D_Border_Rounded < 19
gen D_Border19 = D_Border_Rounded < 20
gen D_Border20 = D_Border_Rounded < 21
gen D_Border21 = D_Border_Rounded < 22
gen D_Border22 = D_Border_Rounded < 23
gen D_Border23 = D_Border_Rounded < 24
gen D_Border24 = D_Border_Rounded < 25
gen D_Border25 = D_Border_Rounded < 26
gen D_Border26 = D_Border_Rounded < 27
gen D_Border27 = D_Border_Rounded < 28
gen D_Border28 = D_Border_Rounded < 29
gen D_Border29 = D_Border_Rounded < 30
gen D_Border30 = D_Border_Rounded < 31
gen D_Border31 = D_Border_Rounded < 32
gen D_Border32 = D_Border_Rounded < 32
gen D_Border33 = D_Border_Rounded < 34
gen D_Border34 = D_Border_Rounded < 35
gen D_Border35 = D_Border_Rounded < 36
gen D_Border36 = D_Border_Rounded < 37
gen D_Border37 = D_Border_Rounded < 38
gen D_Border38 = D_Border_Rounded < 39
gen D_Border39 = D_Border_Rounded < 40
gen D_Border40 = D_Border_Rounded < 41
gen D_Border41 = D_Border_Rounded < 42
gen D_Border42 = D_Border_Rounded < 43
gen D_Border43 = D_Border_Rounded < 44
gen D_Border44 = D_Border_Rounded < 45
gen D_Border45 = D_Border_Rounded < 46
gen D_Border46 = D_Border_Rounded < 47
gen D_Border47 = D_Border_Rounded < 48
gen D_Border48 = D_Border_Rounded < 49
gen D_Border49 = D_Border_Rounded < 50
gen D_Border50 = D_Border_Rounded < 51
gen D_Border51 = D_Border_Rounded < 52
gen D_Border52 = D_Border_Rounded < 53
gen D_Border53 = D_Border_Rounded < 54
gen D_Border54 = D_Border_Rounded < 55
gen D_Border55 = D_Border_Rounded < 56
gen D_Border56 = D_Border_Rounded < 57
gen D_Border57 = D_Border_Rounded < 58
gen D_Border58 = D_Border_Rounded < 59
gen D_Border59 = D_Border_Rounded < 60
gen D_Border60 = D_Border_Rounded < 61
gen D_Border61 = D_Border_Rounded < 62
gen D_Border62 = D_Border_Rounded < 63
gen D_Border63 = D_Border_Rounded < 64
gen D_Border64 = D_Border_Rounded < 65
gen D_Border65 = D_Border_Rounded < 66
gen D_Border66 = D_Border_Rounded < 67
gen D_Border67 = D_Border_Rounded < 68
gen D_Border68 = D_Border_Rounded < 69
gen D_Border69 = D_Border_Rounded < 70
gen D_Border70 = D_Border_Rounded < 71
gen D_Border71 = D_Border_Rounded < 72
gen D_Border72 = D_Border_Rounded < 73
gen D_Border73 = D_Border_Rounded < 74
gen D_Border74 = D_Border_Rounded < 75
gen D_Border75 = D_Border_Rounded < 76
gen D_Border76 = D_Border_Rounded < 77
gen D_Border77 = D_Border_Rounded < 78
gen D_Border78 = D_Border_Rounded < 79
gen D_Border79 = D_Border_Rounded < 80
gen D_Border80 = D_Border_Rounded < 81

gen latitude2 = latitude*latitude
gen longitude2 = longitude*longitude

gen Anglo_x_Border = anglophone*d_border_km
gen Lat_x_Long = latitude*longitude
gen d_border_km2 = d_border_km*d_border_km
gen d_border_km3 = d_border_km*d_border_km*d_border_km
gen latitude3= latitude*latitude*latitude 
gen longitude3 = longitude*longitude*longitude
gen lat2_x_long = latitude2*longitude
gen lat_x_long2 = latitude*longitude2

saveold "Merged_DHS Data.dta", replace


****************************************
*********** NIGHTLIGHT DATA ************
****************************************
import excel "NightlightData.xlsx", sheet("Sheet1") firstrow clear
keep FID Lt_Mean_1992 Lt_Mean_2004 Lt_Mean_2011 Lt_Mean_2013 Pop_Grid

rename Lt_Mean_1992 Lt_Mean1994
rename Lt_Mean_2004 Lt_Mean2004
rename Lt_Mean_2011 Lt_Mean2011
rename Lt_Mean_2013 Lt_Mean2013

reshape long Lt_Mean, i(FID) j(year)

rename FID FID_GRID_5km
sort FID_GRID_5km
saveold "Nightlight_Merged_PolygonFID.dta", replace


use "Nightlight_Merged_PolygonFID.dta", clear
merge FID_GRID_5km using "Nightlight_GIS Controls.dta"

gen Douala = 0
replace Douala = 1 if FID_GRID_5km == 8185 | FID_GRID_5km == 8363 | FID_GRID_5km == 8184 | FID_GRID_5km == 8364 | FID_GRID_5km == 8186 | FID_GRID_5km == 8187

gen CompZone = 0
replace CompZone = 1 if region == "Sud-Ouest" | region == "Nord-Ouest" | region == "Ouest" | region == "Littoral" 
replace CompZone = 1 if Douala == 1

rename cec_5cm cec_mean
rename mean_alt_1km avg_alt
rename avg_temp_5km avg_temp
rename avg_precipitation_5km avg_prec

gen anglophone = 0
replace anglophone = 1 if region == "Sud-Ouest" | region == "Nord-Ouest"

gen d_border_UK = 0
replace d_border_UK = d_border_km if anglophone == 1
gen d_border_French = 0
replace d_border_French = d_border_km if anglophone == 0

gen Urban = 0
replace Urban = 1 if Pop_Grid > 10000

gen Ln_Pop_Grid = log(Pop_Grid)
egen z2_Lt_Mean = std(Lt_Mean)

gen d_border_km_Anglo = d_border_km
replace d_border_km_Anglo = d_border_km*-1 if anglophone == 1

gen D_Border_Rounded = round(d_border_km, 1)
gen D_Border15 = D_Border_Rounded < 16
gen D_Border16 = D_Border_Rounded < 17
gen D_Border17 = D_Border_Rounded < 18
gen D_Border18 = D_Border_Rounded < 19
gen D_Border19 = D_Border_Rounded < 20
gen D_Border20 = D_Border_Rounded < 21
gen D_Border21 = D_Border_Rounded < 22
gen D_Border22 = D_Border_Rounded < 23
gen D_Border23 = D_Border_Rounded < 24
gen D_Border24 = D_Border_Rounded < 25
gen D_Border25 = D_Border_Rounded < 26
gen D_Border26 = D_Border_Rounded < 27
gen D_Border27 = D_Border_Rounded < 28
gen D_Border28 = D_Border_Rounded < 29
gen D_Border29 = D_Border_Rounded < 30
gen D_Border30 = D_Border_Rounded < 31
gen D_Border31 = D_Border_Rounded < 32
gen D_Border32 = D_Border_Rounded < 32
gen D_Border33 = D_Border_Rounded < 34
gen D_Border34 = D_Border_Rounded < 35
gen D_Border35 = D_Border_Rounded < 36
gen D_Border36 = D_Border_Rounded < 37
gen D_Border37 = D_Border_Rounded < 38
gen D_Border38 = D_Border_Rounded < 39
gen D_Border39 = D_Border_Rounded < 40
gen D_Border40 = D_Border_Rounded < 41
gen D_Border41 = D_Border_Rounded < 42
gen D_Border42 = D_Border_Rounded < 43
gen D_Border43 = D_Border_Rounded < 44
gen D_Border44 = D_Border_Rounded < 45
gen D_Border45 = D_Border_Rounded < 46
gen D_Border46 = D_Border_Rounded < 47
gen D_Border47 = D_Border_Rounded < 48
gen D_Border48 = D_Border_Rounded < 49
gen D_Border49 = D_Border_Rounded < 50
gen D_Border50 = D_Border_Rounded < 51
gen D_Border51 = D_Border_Rounded < 52
gen D_Border52 = D_Border_Rounded < 53
gen D_Border53 = D_Border_Rounded < 54
gen D_Border54 = D_Border_Rounded < 55
gen D_Border55 = D_Border_Rounded < 56
gen D_Border56 = D_Border_Rounded < 57
gen D_Border57 = D_Border_Rounded < 58
gen D_Border58 = D_Border_Rounded < 59
gen D_Border59 = D_Border_Rounded < 60
gen D_Border60 = D_Border_Rounded < 61
gen D_Border61 = D_Border_Rounded < 62
gen D_Border62 = D_Border_Rounded < 63
gen D_Border63 = D_Border_Rounded < 64
gen D_Border64 = D_Border_Rounded < 65
gen D_Border65 = D_Border_Rounded < 66
gen D_Border66 = D_Border_Rounded < 67
gen D_Border67 = D_Border_Rounded < 68
gen D_Border68 = D_Border_Rounded < 69
gen D_Border69 = D_Border_Rounded < 70
gen D_Border70 = D_Border_Rounded < 71
gen D_Border71 = D_Border_Rounded < 72
gen D_Border72 = D_Border_Rounded < 73
gen D_Border73 = D_Border_Rounded < 74
gen D_Border74 = D_Border_Rounded < 75
gen D_Border75 = D_Border_Rounded < 76
gen D_Border76 = D_Border_Rounded < 77
gen D_Border77 = D_Border_Rounded < 78
gen D_Border78 = D_Border_Rounded < 79
gen D_Border79 = D_Border_Rounded < 80
gen D_Border80 = D_Border_Rounded < 81

gen Anglo_x_Border = anglophone*d_border_km
gen latitude2 = latitude*latitude
gen longitude2 = longitude*longitude
gen Lat_x_Long = latitude*longitude
gen d_border_km2 = d_border_km*d_border_km
gen d_border_km3 = d_border_km*d_border_km*d_border_km
gen latitude3= latitude*latitude*latitude 
gen longitude3 = longitude*longitude*longitude
gen lat2_x_long = latitude2*longitude
gen lat_x_long2 = latitude*longitude2

gen ln_d_yaounde_km = log(d_yaounde_km+.1) 
gen ln_d_regcapital_km = log(d_regcapital_km+.1)
gen ln_d_coast_km = log(d_coast_km+.1)

saveold "Nightlight_GIS_FINAL.dta", replace



