************************************************************************************************
************************************************************************************************
* Replication Materials for “The Mechanisms of Direct and Indirect Rule: Colonialism and Economic Development in Africa”
* Authors: Natalie Lest and Martha Wilfahrt
* Journal: Quarterly Journal of Political Science
* Version Date: 12 January 2010
************************************************************************************************
************************************************************************************************

cd "Letsa Wilfahrt_QJPS Replication Materials/Data/"

use AfroBarometerData.dta, clear

graph set window fontface "Times New Roman"

* controls
global governance ln_d_yaounde_km ln_d_regcapital_km
global geo avg_temp avg_prec cec_mean avg_alt 
global AB female age education rural
global colonial ln_d_Protestant_km_1960 ln_d_Railway_km ln_d_coast_km

d $geo 
d $governance
d $AB
d $colonial

* polynomial
global MDpolynomial anglophone latitude longitude Lat_x_Long latitude2 longitude2 border_longitude border_latitude

d $MDpolynomial
 

************************************************************************************************
******************* FIGURE  3 - LOCAL COMMUNITY EMPOWERMENT MECHANISM **************************
************************************************************************************************

*a. Local government councilors listen C62B
use AfroBarometerData.dta, clear
keep if REGION==2 | REGION==7 | REGION==9 | REGION==10 | REGION==12

foreach var of varlist D_Border20-D_Border80 {
  quietly reg C62B $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance  Round if `var'==1, cluster(EANUMB_AB) robust 
	gen Beta_`var' = _b[anglophone]
	matrix c_`var' = e(V)
	gen Var_`var' = c_`var'[1,1]
} 

foreach var of varlist D_Border20-D_Border80 {
	gen SD_`var' = sqrt(Var_`var')
	gen CI_Upper_`var' = Beta_`var'+(SD_`var'*1.96)
	gen CI_Lower_`var' = Beta_`var'-(SD_`var'*1.96)
}


foreach var of varlist D_Border20-D_Border80 {
	gen SD_10_`var' = sqrt(Var_`var')
	gen CI_Upper_10_`var' = Beta_`var'+(SD_`var'*1.645)
	gen CI_Lower_10_`var' = Beta_`var'-(SD_`var'*1.645)
}

gen N = _n
drop if N !=1
keep N Beta_D_Border20 Beta_D_Border21 Beta_D_Border22 Beta_D_Border23 Beta_D_Border24 Beta_D_Border25 Beta_D_Border26 Beta_D_Border27 Beta_D_Border28 Beta_D_Border29 Beta_D_Border30 Beta_D_Border31 Beta_D_Border32 Beta_D_Border33 Beta_D_Border34 Beta_D_Border35 Beta_D_Border36 Beta_D_Border37 Beta_D_Border38 Beta_D_Border39 Beta_D_Border40 Beta_D_Border41 Beta_D_Border42 Beta_D_Border43 Beta_D_Border44 Beta_D_Border45 Beta_D_Border46 Beta_D_Border47 Beta_D_Border48 Beta_D_Border49 Beta_D_Border50 Beta_D_Border51 Beta_D_Border52 Beta_D_Border53 Beta_D_Border54 Beta_D_Border55 Beta_D_Border56 Beta_D_Border57 Beta_D_Border58 Beta_D_Border59 Beta_D_Border60 Beta_D_Border61 Beta_D_Border62 Beta_D_Border63 Beta_D_Border64 Beta_D_Border65 Beta_D_Border66 Beta_D_Border67 Beta_D_Border68 Beta_D_Border69 Beta_D_Border70 Beta_D_Border71 Beta_D_Border72 Beta_D_Border73 Beta_D_Border74 Beta_D_Border75 Beta_D_Border76 Beta_D_Border77 Beta_D_Border78 Beta_D_Border79 Beta_D_Border80 CI_Upper_D_Border20 CI_Upper_D_Border21 CI_Upper_D_Border22 CI_Upper_D_Border23 CI_Upper_D_Border24 CI_Upper_D_Border25 CI_Upper_D_Border26 CI_Upper_D_Border27 CI_Upper_D_Border28 CI_Upper_D_Border29 CI_Upper_D_Border30 CI_Upper_D_Border31 CI_Upper_D_Border32 CI_Upper_D_Border33 CI_Upper_D_Border34 CI_Upper_D_Border35 CI_Upper_D_Border36 CI_Upper_D_Border37 CI_Upper_D_Border38 CI_Upper_D_Border39 CI_Upper_D_Border40 CI_Upper_D_Border41 CI_Upper_D_Border42 CI_Upper_D_Border43 CI_Upper_D_Border44 CI_Upper_D_Border45 CI_Upper_D_Border46 CI_Upper_D_Border47 CI_Upper_D_Border48 CI_Upper_D_Border49 CI_Upper_D_Border50 CI_Upper_D_Border51 CI_Upper_D_Border52 CI_Upper_D_Border53 CI_Upper_D_Border54 CI_Upper_D_Border55 CI_Upper_D_Border56 CI_Upper_D_Border57 CI_Upper_D_Border58 CI_Upper_D_Border59 CI_Upper_D_Border60 CI_Upper_D_Border61 CI_Upper_D_Border62 CI_Upper_D_Border63 CI_Upper_D_Border64 CI_Upper_D_Border65 CI_Upper_D_Border66 CI_Upper_D_Border67 CI_Upper_D_Border68 CI_Upper_D_Border69 CI_Upper_D_Border70 CI_Upper_D_Border71 CI_Upper_D_Border72 CI_Upper_D_Border73 CI_Upper_D_Border74 CI_Upper_D_Border75 CI_Upper_D_Border76 CI_Upper_D_Border77 CI_Upper_D_Border78 CI_Upper_D_Border79 CI_Upper_D_Border80 CI_Lower_D_Border20 CI_Lower_D_Border21 CI_Lower_D_Border22 CI_Lower_D_Border23 CI_Lower_D_Border24 CI_Lower_D_Border25 CI_Lower_D_Border26 CI_Lower_D_Border27 CI_Lower_D_Border28 CI_Lower_D_Border29 CI_Lower_D_Border30 CI_Lower_D_Border31 CI_Lower_D_Border32 CI_Lower_D_Border33 CI_Lower_D_Border34 CI_Lower_D_Border35 CI_Lower_D_Border36 CI_Lower_D_Border37 CI_Lower_D_Border38 CI_Lower_D_Border39 CI_Lower_D_Border40 CI_Lower_D_Border41 CI_Lower_D_Border42 CI_Lower_D_Border43 CI_Lower_D_Border44 CI_Lower_D_Border45 CI_Lower_D_Border46 CI_Lower_D_Border47 CI_Lower_D_Border48 CI_Lower_D_Border49 CI_Lower_D_Border50 CI_Lower_D_Border51 CI_Lower_D_Border52 CI_Lower_D_Border53 CI_Lower_D_Border54 CI_Lower_D_Border55 CI_Lower_D_Border56 CI_Lower_D_Border57 CI_Lower_D_Border58 CI_Lower_D_Border59 CI_Lower_D_Border60 CI_Lower_D_Border61 CI_Lower_D_Border62 CI_Lower_D_Border63 CI_Lower_D_Border64 CI_Lower_D_Border65 CI_Lower_D_Border66 CI_Lower_D_Border67 CI_Lower_D_Border68 CI_Lower_D_Border69 CI_Lower_D_Border70 CI_Lower_D_Border71 CI_Lower_D_Border72 CI_Lower_D_Border73 CI_Lower_D_Border74 CI_Lower_D_Border75 CI_Lower_D_Border76 CI_Lower_D_Border77 CI_Lower_D_Border78 CI_Lower_D_Border79 CI_Lower_D_Border80 SD_10_D_Border20 CI_Upper_10_D_Border20 CI_Lower_10_D_Border20 SD_10_D_Border21 CI_Upper_10_D_Border21 CI_Lower_10_D_Border21 SD_10_D_Border22 CI_Upper_10_D_Border22 CI_Lower_10_D_Border22 SD_10_D_Border23 CI_Upper_10_D_Border23 CI_Lower_10_D_Border23 SD_10_D_Border24 CI_Upper_10_D_Border24 CI_Lower_10_D_Border24 SD_10_D_Border25 CI_Upper_10_D_Border25 CI_Lower_10_D_Border25 SD_10_D_Border26 CI_Upper_10_D_Border26 CI_Lower_10_D_Border26 SD_10_D_Border27 CI_Upper_10_D_Border27 CI_Lower_10_D_Border27 SD_10_D_Border28 CI_Upper_10_D_Border28 CI_Lower_10_D_Border28 SD_10_D_Border29 CI_Upper_10_D_Border29 CI_Lower_10_D_Border29 SD_10_D_Border30 CI_Upper_10_D_Border30 CI_Lower_10_D_Border30 SD_10_D_Border31 CI_Upper_10_D_Border31 CI_Lower_10_D_Border31 SD_10_D_Border32 CI_Upper_10_D_Border32 CI_Lower_10_D_Border32 SD_10_D_Border33 CI_Upper_10_D_Border33 CI_Lower_10_D_Border33 SD_10_D_Border34 CI_Upper_10_D_Border34 CI_Lower_10_D_Border34 SD_10_D_Border35 CI_Upper_10_D_Border35 CI_Lower_10_D_Border35 SD_10_D_Border36 CI_Upper_10_D_Border36 CI_Lower_10_D_Border36 SD_10_D_Border37 CI_Upper_10_D_Border37 CI_Lower_10_D_Border37 SD_10_D_Border38 CI_Upper_10_D_Border38 CI_Lower_10_D_Border38 SD_10_D_Border39 CI_Upper_10_D_Border39 CI_Lower_10_D_Border39 SD_10_D_Border40 CI_Upper_10_D_Border40 CI_Lower_10_D_Border40 SD_10_D_Border41 CI_Upper_10_D_Border41 CI_Lower_10_D_Border41 SD_10_D_Border42 CI_Upper_10_D_Border42 CI_Lower_10_D_Border42 SD_10_D_Border43 CI_Upper_10_D_Border43 CI_Lower_10_D_Border43 SD_10_D_Border44 CI_Upper_10_D_Border44 CI_Lower_10_D_Border44 SD_10_D_Border45 CI_Upper_10_D_Border45 CI_Lower_10_D_Border45 SD_10_D_Border46 CI_Upper_10_D_Border46 CI_Lower_10_D_Border46 SD_10_D_Border47 CI_Upper_10_D_Border47 CI_Lower_10_D_Border47 SD_10_D_Border48 CI_Upper_10_D_Border48 CI_Lower_10_D_Border48 SD_10_D_Border49 CI_Upper_10_D_Border49 CI_Lower_10_D_Border49 SD_10_D_Border50 CI_Upper_10_D_Border50 CI_Lower_10_D_Border50 SD_10_D_Border51 CI_Upper_10_D_Border51 CI_Lower_10_D_Border51 SD_10_D_Border52 CI_Upper_10_D_Border52 CI_Lower_10_D_Border52 SD_10_D_Border53 CI_Upper_10_D_Border53 CI_Lower_10_D_Border53 SD_10_D_Border54 CI_Upper_10_D_Border54 CI_Lower_10_D_Border54 SD_10_D_Border55 CI_Upper_10_D_Border55 CI_Lower_10_D_Border55 SD_10_D_Border56 CI_Upper_10_D_Border56 CI_Lower_10_D_Border56 SD_10_D_Border57 CI_Upper_10_D_Border57 CI_Lower_10_D_Border57 SD_10_D_Border58 CI_Upper_10_D_Border58 CI_Lower_10_D_Border58 SD_10_D_Border59 CI_Upper_10_D_Border59 CI_Lower_10_D_Border59 SD_10_D_Border60 CI_Upper_10_D_Border60 CI_Lower_10_D_Border60 SD_10_D_Border61 CI_Upper_10_D_Border61 CI_Lower_10_D_Border61 SD_10_D_Border62 CI_Upper_10_D_Border62 CI_Lower_10_D_Border62 SD_10_D_Border63 CI_Upper_10_D_Border63 CI_Lower_10_D_Border63 SD_10_D_Border64 CI_Upper_10_D_Border64 CI_Lower_10_D_Border64 SD_10_D_Border65 CI_Upper_10_D_Border65 CI_Lower_10_D_Border65 SD_10_D_Border66 CI_Upper_10_D_Border66 CI_Lower_10_D_Border66 SD_10_D_Border67 CI_Upper_10_D_Border67 CI_Lower_10_D_Border67 SD_10_D_Border68 CI_Upper_10_D_Border68 CI_Lower_10_D_Border68 SD_10_D_Border69 CI_Upper_10_D_Border69 CI_Lower_10_D_Border69 SD_10_D_Border70 CI_Upper_10_D_Border70 CI_Lower_10_D_Border70 SD_10_D_Border71 CI_Upper_10_D_Border71 CI_Lower_10_D_Border71 SD_10_D_Border72 CI_Upper_10_D_Border72 CI_Lower_10_D_Border72 SD_10_D_Border73 CI_Upper_10_D_Border73 CI_Lower_10_D_Border73 SD_10_D_Border74 CI_Upper_10_D_Border74 CI_Lower_10_D_Border74 SD_10_D_Border75 CI_Upper_10_D_Border75 CI_Lower_10_D_Border75 SD_10_D_Border76 CI_Upper_10_D_Border76 CI_Lower_10_D_Border76 SD_10_D_Border77 CI_Upper_10_D_Border77 CI_Lower_10_D_Border77 SD_10_D_Border78 CI_Upper_10_D_Border78 CI_Lower_10_D_Border78 SD_10_D_Border79 CI_Upper_10_D_Border79 CI_Lower_10_D_Border79 SD_10_D_Border80 CI_Upper_10_D_Border80 CI_Lower_10_D_Border80

reshape long Beta_D_Border CI_Upper_D_Border CI_Lower_D_Border CI_Upper_10_D_Border CI_Lower_10_D_Border, i(N) j(band)

twoway (line Beta_D_Border band, lcolor(black) lpattern(solid)) ///
	(line CI_Upper_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Lower_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Upper_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)) ///
	(line CI_Lower_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)), ///
    ytitle(Estimated Effect Anglophone, size(small)) ylabel(-.5(.5)2,  angle(horizontal))  ///
    xtitle("") xtitle(, size(small)) xlabel(20(10)80, labsize(vsmall))  ///
           yline(0, lcolor(gs10)) ///
      plotregion(lcolor(black)) ///
  legend(off) ///
        title(a. Local Councilors Listen to Ordinary People, size(medsmall)) ///
    scheme(s2mono) graphregion(fcolor(white)) 
  

*b. Performance: local government councilor over last 12 months C71C
use AfroBarometerData.dta, clear
keep if REGION==2 | REGION==7 | REGION==9 | REGION==10 | REGION==12

foreach var of varlist D_Border20-D_Border80 {
	quietly reg C71C $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance  Round if `var'==1, cluster(EANUMB_AB) robust 
	gen Beta_`var' = _b[anglophone]
	matrix c_`var' = e(V)
	gen Var_`var' = c_`var'[1,1]
} 

foreach var of varlist D_Border20-D_Border80 {
	gen SD_`var' = sqrt(Var_`var')
	gen CI_Upper_`var' = Beta_`var'+(SD_`var'*1.96)
	gen CI_Lower_`var' = Beta_`var'-(SD_`var'*1.96)
}

foreach var of varlist D_Border20-D_Border80 {
	gen SD_10_`var' = sqrt(Var_`var')
	gen CI_Upper_10_`var' = Beta_`var'+(SD_`var'*1.645)
	gen CI_Lower_10_`var' = Beta_`var'-(SD_`var'*1.645)
}

gen N = _n
drop if N !=1
keep N Beta_D_Border20 Beta_D_Border21 Beta_D_Border22 Beta_D_Border23 Beta_D_Border24 Beta_D_Border25 Beta_D_Border26 Beta_D_Border27 Beta_D_Border28 Beta_D_Border29 Beta_D_Border30 Beta_D_Border31 Beta_D_Border32 Beta_D_Border33 Beta_D_Border34 Beta_D_Border35 Beta_D_Border36 Beta_D_Border37 Beta_D_Border38 Beta_D_Border39 Beta_D_Border40 Beta_D_Border41 Beta_D_Border42 Beta_D_Border43 Beta_D_Border44 Beta_D_Border45 Beta_D_Border46 Beta_D_Border47 Beta_D_Border48 Beta_D_Border49 Beta_D_Border50 Beta_D_Border51 Beta_D_Border52 Beta_D_Border53 Beta_D_Border54 Beta_D_Border55 Beta_D_Border56 Beta_D_Border57 Beta_D_Border58 Beta_D_Border59 Beta_D_Border60 Beta_D_Border61 Beta_D_Border62 Beta_D_Border63 Beta_D_Border64 Beta_D_Border65 Beta_D_Border66 Beta_D_Border67 Beta_D_Border68 Beta_D_Border69 Beta_D_Border70 Beta_D_Border71 Beta_D_Border72 Beta_D_Border73 Beta_D_Border74 Beta_D_Border75 Beta_D_Border76 Beta_D_Border77 Beta_D_Border78 Beta_D_Border79 Beta_D_Border80 CI_Upper_D_Border20 CI_Upper_D_Border21 CI_Upper_D_Border22 CI_Upper_D_Border23 CI_Upper_D_Border24 CI_Upper_D_Border25 CI_Upper_D_Border26 CI_Upper_D_Border27 CI_Upper_D_Border28 CI_Upper_D_Border29 CI_Upper_D_Border30 CI_Upper_D_Border31 CI_Upper_D_Border32 CI_Upper_D_Border33 CI_Upper_D_Border34 CI_Upper_D_Border35 CI_Upper_D_Border36 CI_Upper_D_Border37 CI_Upper_D_Border38 CI_Upper_D_Border39 CI_Upper_D_Border40 CI_Upper_D_Border41 CI_Upper_D_Border42 CI_Upper_D_Border43 CI_Upper_D_Border44 CI_Upper_D_Border45 CI_Upper_D_Border46 CI_Upper_D_Border47 CI_Upper_D_Border48 CI_Upper_D_Border49 CI_Upper_D_Border50 CI_Upper_D_Border51 CI_Upper_D_Border52 CI_Upper_D_Border53 CI_Upper_D_Border54 CI_Upper_D_Border55 CI_Upper_D_Border56 CI_Upper_D_Border57 CI_Upper_D_Border58 CI_Upper_D_Border59 CI_Upper_D_Border60 CI_Upper_D_Border61 CI_Upper_D_Border62 CI_Upper_D_Border63 CI_Upper_D_Border64 CI_Upper_D_Border65 CI_Upper_D_Border66 CI_Upper_D_Border67 CI_Upper_D_Border68 CI_Upper_D_Border69 CI_Upper_D_Border70 CI_Upper_D_Border71 CI_Upper_D_Border72 CI_Upper_D_Border73 CI_Upper_D_Border74 CI_Upper_D_Border75 CI_Upper_D_Border76 CI_Upper_D_Border77 CI_Upper_D_Border78 CI_Upper_D_Border79 CI_Upper_D_Border80 CI_Lower_D_Border20 CI_Lower_D_Border21 CI_Lower_D_Border22 CI_Lower_D_Border23 CI_Lower_D_Border24 CI_Lower_D_Border25 CI_Lower_D_Border26 CI_Lower_D_Border27 CI_Lower_D_Border28 CI_Lower_D_Border29 CI_Lower_D_Border30 CI_Lower_D_Border31 CI_Lower_D_Border32 CI_Lower_D_Border33 CI_Lower_D_Border34 CI_Lower_D_Border35 CI_Lower_D_Border36 CI_Lower_D_Border37 CI_Lower_D_Border38 CI_Lower_D_Border39 CI_Lower_D_Border40 CI_Lower_D_Border41 CI_Lower_D_Border42 CI_Lower_D_Border43 CI_Lower_D_Border44 CI_Lower_D_Border45 CI_Lower_D_Border46 CI_Lower_D_Border47 CI_Lower_D_Border48 CI_Lower_D_Border49 CI_Lower_D_Border50 CI_Lower_D_Border51 CI_Lower_D_Border52 CI_Lower_D_Border53 CI_Lower_D_Border54 CI_Lower_D_Border55 CI_Lower_D_Border56 CI_Lower_D_Border57 CI_Lower_D_Border58 CI_Lower_D_Border59 CI_Lower_D_Border60 CI_Lower_D_Border61 CI_Lower_D_Border62 CI_Lower_D_Border63 CI_Lower_D_Border64 CI_Lower_D_Border65 CI_Lower_D_Border66 CI_Lower_D_Border67 CI_Lower_D_Border68 CI_Lower_D_Border69 CI_Lower_D_Border70 CI_Lower_D_Border71 CI_Lower_D_Border72 CI_Lower_D_Border73 CI_Lower_D_Border74 CI_Lower_D_Border75 CI_Lower_D_Border76 CI_Lower_D_Border77 CI_Lower_D_Border78 CI_Lower_D_Border79 CI_Lower_D_Border80 SD_10_D_Border20 CI_Upper_10_D_Border20 CI_Lower_10_D_Border20 SD_10_D_Border21 CI_Upper_10_D_Border21 CI_Lower_10_D_Border21 SD_10_D_Border22 CI_Upper_10_D_Border22 CI_Lower_10_D_Border22 SD_10_D_Border23 CI_Upper_10_D_Border23 CI_Lower_10_D_Border23 SD_10_D_Border24 CI_Upper_10_D_Border24 CI_Lower_10_D_Border24 SD_10_D_Border25 CI_Upper_10_D_Border25 CI_Lower_10_D_Border25 SD_10_D_Border26 CI_Upper_10_D_Border26 CI_Lower_10_D_Border26 SD_10_D_Border27 CI_Upper_10_D_Border27 CI_Lower_10_D_Border27 SD_10_D_Border28 CI_Upper_10_D_Border28 CI_Lower_10_D_Border28 SD_10_D_Border29 CI_Upper_10_D_Border29 CI_Lower_10_D_Border29 SD_10_D_Border30 CI_Upper_10_D_Border30 CI_Lower_10_D_Border30 SD_10_D_Border31 CI_Upper_10_D_Border31 CI_Lower_10_D_Border31 SD_10_D_Border32 CI_Upper_10_D_Border32 CI_Lower_10_D_Border32 SD_10_D_Border33 CI_Upper_10_D_Border33 CI_Lower_10_D_Border33 SD_10_D_Border34 CI_Upper_10_D_Border34 CI_Lower_10_D_Border34 SD_10_D_Border35 CI_Upper_10_D_Border35 CI_Lower_10_D_Border35 SD_10_D_Border36 CI_Upper_10_D_Border36 CI_Lower_10_D_Border36 SD_10_D_Border37 CI_Upper_10_D_Border37 CI_Lower_10_D_Border37 SD_10_D_Border38 CI_Upper_10_D_Border38 CI_Lower_10_D_Border38 SD_10_D_Border39 CI_Upper_10_D_Border39 CI_Lower_10_D_Border39 SD_10_D_Border40 CI_Upper_10_D_Border40 CI_Lower_10_D_Border40 SD_10_D_Border41 CI_Upper_10_D_Border41 CI_Lower_10_D_Border41 SD_10_D_Border42 CI_Upper_10_D_Border42 CI_Lower_10_D_Border42 SD_10_D_Border43 CI_Upper_10_D_Border43 CI_Lower_10_D_Border43 SD_10_D_Border44 CI_Upper_10_D_Border44 CI_Lower_10_D_Border44 SD_10_D_Border45 CI_Upper_10_D_Border45 CI_Lower_10_D_Border45 SD_10_D_Border46 CI_Upper_10_D_Border46 CI_Lower_10_D_Border46 SD_10_D_Border47 CI_Upper_10_D_Border47 CI_Lower_10_D_Border47 SD_10_D_Border48 CI_Upper_10_D_Border48 CI_Lower_10_D_Border48 SD_10_D_Border49 CI_Upper_10_D_Border49 CI_Lower_10_D_Border49 SD_10_D_Border50 CI_Upper_10_D_Border50 CI_Lower_10_D_Border50 SD_10_D_Border51 CI_Upper_10_D_Border51 CI_Lower_10_D_Border51 SD_10_D_Border52 CI_Upper_10_D_Border52 CI_Lower_10_D_Border52 SD_10_D_Border53 CI_Upper_10_D_Border53 CI_Lower_10_D_Border53 SD_10_D_Border54 CI_Upper_10_D_Border54 CI_Lower_10_D_Border54 SD_10_D_Border55 CI_Upper_10_D_Border55 CI_Lower_10_D_Border55 SD_10_D_Border56 CI_Upper_10_D_Border56 CI_Lower_10_D_Border56 SD_10_D_Border57 CI_Upper_10_D_Border57 CI_Lower_10_D_Border57 SD_10_D_Border58 CI_Upper_10_D_Border58 CI_Lower_10_D_Border58 SD_10_D_Border59 CI_Upper_10_D_Border59 CI_Lower_10_D_Border59 SD_10_D_Border60 CI_Upper_10_D_Border60 CI_Lower_10_D_Border60 SD_10_D_Border61 CI_Upper_10_D_Border61 CI_Lower_10_D_Border61 SD_10_D_Border62 CI_Upper_10_D_Border62 CI_Lower_10_D_Border62 SD_10_D_Border63 CI_Upper_10_D_Border63 CI_Lower_10_D_Border63 SD_10_D_Border64 CI_Upper_10_D_Border64 CI_Lower_10_D_Border64 SD_10_D_Border65 CI_Upper_10_D_Border65 CI_Lower_10_D_Border65 SD_10_D_Border66 CI_Upper_10_D_Border66 CI_Lower_10_D_Border66 SD_10_D_Border67 CI_Upper_10_D_Border67 CI_Lower_10_D_Border67 SD_10_D_Border68 CI_Upper_10_D_Border68 CI_Lower_10_D_Border68 SD_10_D_Border69 CI_Upper_10_D_Border69 CI_Lower_10_D_Border69 SD_10_D_Border70 CI_Upper_10_D_Border70 CI_Lower_10_D_Border70 SD_10_D_Border71 CI_Upper_10_D_Border71 CI_Lower_10_D_Border71 SD_10_D_Border72 CI_Upper_10_D_Border72 CI_Lower_10_D_Border72 SD_10_D_Border73 CI_Upper_10_D_Border73 CI_Lower_10_D_Border73 SD_10_D_Border74 CI_Upper_10_D_Border74 CI_Lower_10_D_Border74 SD_10_D_Border75 CI_Upper_10_D_Border75 CI_Lower_10_D_Border75 SD_10_D_Border76 CI_Upper_10_D_Border76 CI_Lower_10_D_Border76 SD_10_D_Border77 CI_Upper_10_D_Border77 CI_Lower_10_D_Border77 SD_10_D_Border78 CI_Upper_10_D_Border78 CI_Lower_10_D_Border78 SD_10_D_Border79 CI_Upper_10_D_Border79 CI_Lower_10_D_Border79 SD_10_D_Border80 CI_Upper_10_D_Border80 CI_Lower_10_D_Border80


reshape long Beta_D_Border CI_Upper_D_Border CI_Lower_D_Border CI_Upper_10_D_Border CI_Lower_10_D_Border, i(N) j(band)

twoway (line Beta_D_Border band, lcolor(black) lpattern(solid)) ///
	(line CI_Upper_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Lower_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Upper_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)) ///
	(line CI_Lower_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)), ///
    ytitle("", size(small)) ylabel(#6,  angle(horizontal)) yscale(r(-.5(.5)2)) ///
    xtitle("") xtitle(, size(small)) xlabel(20(10)80, labsize(vsmall))  ///
          yline(0, lcolor(gs10)) ///
      plotregion(lcolor(black)) ///
   legend(off) ///
        title(b. Approve of the Job of Your Local Councilor, size(medsmall)) ///
    scheme(s2mono) graphregion(fcolor(white)) 


*c. Contacted Government Official
use AfroBarometerData.dta, clear
keep if REGION==2 | REGION==7 | REGION==9 | REGION==10 | REGION==12

foreach var of varlist D_Border20-D_Border80 {
	quietly reg C30C $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance  Round if `var'==1, cluster(EANUMB_AB) robust 
	gen Beta_`var' = _b[anglophone]
	matrix c_`var' = e(V)
	gen Var_`var' = c_`var'[1,1]
} 

foreach var of varlist D_Border20-D_Border80 {
	gen SD_`var' = sqrt(Var_`var')
	gen CI_Upper_`var' = Beta_`var'+(SD_`var'*1.96)
	gen CI_Lower_`var' = Beta_`var'-(SD_`var'*1.96)
}


foreach var of varlist D_Border20-D_Border80 {
	gen SD_10_`var' = sqrt(Var_`var')
	gen CI_Upper_10_`var' = Beta_`var'+(SD_`var'*1.645)
	gen CI_Lower_10_`var' = Beta_`var'-(SD_`var'*1.645)
}

gen N = _n
drop if N !=1
keep N Beta_D_Border20 Beta_D_Border21 Beta_D_Border22 Beta_D_Border23 Beta_D_Border24 Beta_D_Border25 Beta_D_Border26 Beta_D_Border27 Beta_D_Border28 Beta_D_Border29 Beta_D_Border30 Beta_D_Border31 Beta_D_Border32 Beta_D_Border33 Beta_D_Border34 Beta_D_Border35 Beta_D_Border36 Beta_D_Border37 Beta_D_Border38 Beta_D_Border39 Beta_D_Border40 Beta_D_Border41 Beta_D_Border42 Beta_D_Border43 Beta_D_Border44 Beta_D_Border45 Beta_D_Border46 Beta_D_Border47 Beta_D_Border48 Beta_D_Border49 Beta_D_Border50 Beta_D_Border51 Beta_D_Border52 Beta_D_Border53 Beta_D_Border54 Beta_D_Border55 Beta_D_Border56 Beta_D_Border57 Beta_D_Border58 Beta_D_Border59 Beta_D_Border60 Beta_D_Border61 Beta_D_Border62 Beta_D_Border63 Beta_D_Border64 Beta_D_Border65 Beta_D_Border66 Beta_D_Border67 Beta_D_Border68 Beta_D_Border69 Beta_D_Border70 Beta_D_Border71 Beta_D_Border72 Beta_D_Border73 Beta_D_Border74 Beta_D_Border75 Beta_D_Border76 Beta_D_Border77 Beta_D_Border78 Beta_D_Border79 Beta_D_Border80 CI_Upper_D_Border20 CI_Upper_D_Border21 CI_Upper_D_Border22 CI_Upper_D_Border23 CI_Upper_D_Border24 CI_Upper_D_Border25 CI_Upper_D_Border26 CI_Upper_D_Border27 CI_Upper_D_Border28 CI_Upper_D_Border29 CI_Upper_D_Border30 CI_Upper_D_Border31 CI_Upper_D_Border32 CI_Upper_D_Border33 CI_Upper_D_Border34 CI_Upper_D_Border35 CI_Upper_D_Border36 CI_Upper_D_Border37 CI_Upper_D_Border38 CI_Upper_D_Border39 CI_Upper_D_Border40 CI_Upper_D_Border41 CI_Upper_D_Border42 CI_Upper_D_Border43 CI_Upper_D_Border44 CI_Upper_D_Border45 CI_Upper_D_Border46 CI_Upper_D_Border47 CI_Upper_D_Border48 CI_Upper_D_Border49 CI_Upper_D_Border50 CI_Upper_D_Border51 CI_Upper_D_Border52 CI_Upper_D_Border53 CI_Upper_D_Border54 CI_Upper_D_Border55 CI_Upper_D_Border56 CI_Upper_D_Border57 CI_Upper_D_Border58 CI_Upper_D_Border59 CI_Upper_D_Border60 CI_Upper_D_Border61 CI_Upper_D_Border62 CI_Upper_D_Border63 CI_Upper_D_Border64 CI_Upper_D_Border65 CI_Upper_D_Border66 CI_Upper_D_Border67 CI_Upper_D_Border68 CI_Upper_D_Border69 CI_Upper_D_Border70 CI_Upper_D_Border71 CI_Upper_D_Border72 CI_Upper_D_Border73 CI_Upper_D_Border74 CI_Upper_D_Border75 CI_Upper_D_Border76 CI_Upper_D_Border77 CI_Upper_D_Border78 CI_Upper_D_Border79 CI_Upper_D_Border80 CI_Lower_D_Border20 CI_Lower_D_Border21 CI_Lower_D_Border22 CI_Lower_D_Border23 CI_Lower_D_Border24 CI_Lower_D_Border25 CI_Lower_D_Border26 CI_Lower_D_Border27 CI_Lower_D_Border28 CI_Lower_D_Border29 CI_Lower_D_Border30 CI_Lower_D_Border31 CI_Lower_D_Border32 CI_Lower_D_Border33 CI_Lower_D_Border34 CI_Lower_D_Border35 CI_Lower_D_Border36 CI_Lower_D_Border37 CI_Lower_D_Border38 CI_Lower_D_Border39 CI_Lower_D_Border40 CI_Lower_D_Border41 CI_Lower_D_Border42 CI_Lower_D_Border43 CI_Lower_D_Border44 CI_Lower_D_Border45 CI_Lower_D_Border46 CI_Lower_D_Border47 CI_Lower_D_Border48 CI_Lower_D_Border49 CI_Lower_D_Border50 CI_Lower_D_Border51 CI_Lower_D_Border52 CI_Lower_D_Border53 CI_Lower_D_Border54 CI_Lower_D_Border55 CI_Lower_D_Border56 CI_Lower_D_Border57 CI_Lower_D_Border58 CI_Lower_D_Border59 CI_Lower_D_Border60 CI_Lower_D_Border61 CI_Lower_D_Border62 CI_Lower_D_Border63 CI_Lower_D_Border64 CI_Lower_D_Border65 CI_Lower_D_Border66 CI_Lower_D_Border67 CI_Lower_D_Border68 CI_Lower_D_Border69 CI_Lower_D_Border70 CI_Lower_D_Border71 CI_Lower_D_Border72 CI_Lower_D_Border73 CI_Lower_D_Border74 CI_Lower_D_Border75 CI_Lower_D_Border76 CI_Lower_D_Border77 CI_Lower_D_Border78 CI_Lower_D_Border79 CI_Lower_D_Border80 SD_10_D_Border20 CI_Upper_10_D_Border20 CI_Lower_10_D_Border20 SD_10_D_Border21 CI_Upper_10_D_Border21 CI_Lower_10_D_Border21 SD_10_D_Border22 CI_Upper_10_D_Border22 CI_Lower_10_D_Border22 SD_10_D_Border23 CI_Upper_10_D_Border23 CI_Lower_10_D_Border23 SD_10_D_Border24 CI_Upper_10_D_Border24 CI_Lower_10_D_Border24 SD_10_D_Border25 CI_Upper_10_D_Border25 CI_Lower_10_D_Border25 SD_10_D_Border26 CI_Upper_10_D_Border26 CI_Lower_10_D_Border26 SD_10_D_Border27 CI_Upper_10_D_Border27 CI_Lower_10_D_Border27 SD_10_D_Border28 CI_Upper_10_D_Border28 CI_Lower_10_D_Border28 SD_10_D_Border29 CI_Upper_10_D_Border29 CI_Lower_10_D_Border29 SD_10_D_Border30 CI_Upper_10_D_Border30 CI_Lower_10_D_Border30 SD_10_D_Border31 CI_Upper_10_D_Border31 CI_Lower_10_D_Border31 SD_10_D_Border32 CI_Upper_10_D_Border32 CI_Lower_10_D_Border32 SD_10_D_Border33 CI_Upper_10_D_Border33 CI_Lower_10_D_Border33 SD_10_D_Border34 CI_Upper_10_D_Border34 CI_Lower_10_D_Border34 SD_10_D_Border35 CI_Upper_10_D_Border35 CI_Lower_10_D_Border35 SD_10_D_Border36 CI_Upper_10_D_Border36 CI_Lower_10_D_Border36 SD_10_D_Border37 CI_Upper_10_D_Border37 CI_Lower_10_D_Border37 SD_10_D_Border38 CI_Upper_10_D_Border38 CI_Lower_10_D_Border38 SD_10_D_Border39 CI_Upper_10_D_Border39 CI_Lower_10_D_Border39 SD_10_D_Border40 CI_Upper_10_D_Border40 CI_Lower_10_D_Border40 SD_10_D_Border41 CI_Upper_10_D_Border41 CI_Lower_10_D_Border41 SD_10_D_Border42 CI_Upper_10_D_Border42 CI_Lower_10_D_Border42 SD_10_D_Border43 CI_Upper_10_D_Border43 CI_Lower_10_D_Border43 SD_10_D_Border44 CI_Upper_10_D_Border44 CI_Lower_10_D_Border44 SD_10_D_Border45 CI_Upper_10_D_Border45 CI_Lower_10_D_Border45 SD_10_D_Border46 CI_Upper_10_D_Border46 CI_Lower_10_D_Border46 SD_10_D_Border47 CI_Upper_10_D_Border47 CI_Lower_10_D_Border47 SD_10_D_Border48 CI_Upper_10_D_Border48 CI_Lower_10_D_Border48 SD_10_D_Border49 CI_Upper_10_D_Border49 CI_Lower_10_D_Border49 SD_10_D_Border50 CI_Upper_10_D_Border50 CI_Lower_10_D_Border50 SD_10_D_Border51 CI_Upper_10_D_Border51 CI_Lower_10_D_Border51 SD_10_D_Border52 CI_Upper_10_D_Border52 CI_Lower_10_D_Border52 SD_10_D_Border53 CI_Upper_10_D_Border53 CI_Lower_10_D_Border53 SD_10_D_Border54 CI_Upper_10_D_Border54 CI_Lower_10_D_Border54 SD_10_D_Border55 CI_Upper_10_D_Border55 CI_Lower_10_D_Border55 SD_10_D_Border56 CI_Upper_10_D_Border56 CI_Lower_10_D_Border56 SD_10_D_Border57 CI_Upper_10_D_Border57 CI_Lower_10_D_Border57 SD_10_D_Border58 CI_Upper_10_D_Border58 CI_Lower_10_D_Border58 SD_10_D_Border59 CI_Upper_10_D_Border59 CI_Lower_10_D_Border59 SD_10_D_Border60 CI_Upper_10_D_Border60 CI_Lower_10_D_Border60 SD_10_D_Border61 CI_Upper_10_D_Border61 CI_Lower_10_D_Border61 SD_10_D_Border62 CI_Upper_10_D_Border62 CI_Lower_10_D_Border62 SD_10_D_Border63 CI_Upper_10_D_Border63 CI_Lower_10_D_Border63 SD_10_D_Border64 CI_Upper_10_D_Border64 CI_Lower_10_D_Border64 SD_10_D_Border65 CI_Upper_10_D_Border65 CI_Lower_10_D_Border65 SD_10_D_Border66 CI_Upper_10_D_Border66 CI_Lower_10_D_Border66 SD_10_D_Border67 CI_Upper_10_D_Border67 CI_Lower_10_D_Border67 SD_10_D_Border68 CI_Upper_10_D_Border68 CI_Lower_10_D_Border68 SD_10_D_Border69 CI_Upper_10_D_Border69 CI_Lower_10_D_Border69 SD_10_D_Border70 CI_Upper_10_D_Border70 CI_Lower_10_D_Border70 SD_10_D_Border71 CI_Upper_10_D_Border71 CI_Lower_10_D_Border71 SD_10_D_Border72 CI_Upper_10_D_Border72 CI_Lower_10_D_Border72 SD_10_D_Border73 CI_Upper_10_D_Border73 CI_Lower_10_D_Border73 SD_10_D_Border74 CI_Upper_10_D_Border74 CI_Lower_10_D_Border74 SD_10_D_Border75 CI_Upper_10_D_Border75 CI_Lower_10_D_Border75 SD_10_D_Border76 CI_Upper_10_D_Border76 CI_Lower_10_D_Border76 SD_10_D_Border77 CI_Upper_10_D_Border77 CI_Lower_10_D_Border77 SD_10_D_Border78 CI_Upper_10_D_Border78 CI_Lower_10_D_Border78 SD_10_D_Border79 CI_Upper_10_D_Border79 CI_Lower_10_D_Border79 SD_10_D_Border80 CI_Upper_10_D_Border80 CI_Lower_10_D_Border80

reshape long Beta_D_Border CI_Upper_D_Border CI_Lower_D_Border CI_Upper_10_D_Border CI_Lower_10_D_Border, i(N) j(band)

twoway (line Beta_D_Border band, lcolor(black) lpattern(solid)) ///
	(line CI_Upper_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Lower_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Upper_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)) ///
	(line CI_Lower_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)), ///
    ytitle(Estimated Effect Anglophone, size(small)) ylabel(#6,  angle(horizontal)) yscale(r(-.5(.5)2)) ///
    xtitle(Distance from Border (km)) xtitle(, size(small)) xlabel(20(10)80, labsize(vsmall))  ///
          yline(0, lcolor(gs10)) ///
      plotregion(lcolor(black)) ///
   legend(off) ///
        title("c. Contacted Government Officials in Past Year", size(medsmall)) ///
    scheme(s2mono) graphregion(fcolor(white)) 
 
 
*d. Member of a Community Group
use AfroBarometerData.dta, clear
keep if REGION==2 | REGION==7 | REGION==9 | REGION==10 | REGION==12

foreach var of varlist D_Border20-D_Border80 {
	quietly reg C25B $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance Round if `var'==1, cluster(EANUMB_AB) robust 
	gen Beta_`var' = _b[anglophone]
	matrix c_`var' = e(V)
	gen Var_`var' = c_`var'[1,1]
} 

foreach var of varlist D_Border20-D_Border80 {
	gen SD_`var' = sqrt(Var_`var')
	gen CI_Upper_`var' = Beta_`var'+(SD_`var'*1.96)
	gen CI_Lower_`var' = Beta_`var'-(SD_`var'*1.96)
}


foreach var of varlist D_Border20-D_Border80 {
	gen SD_10_`var' = sqrt(Var_`var')
	gen CI_Upper_10_`var' = Beta_`var'+(SD_`var'*1.645)
	gen CI_Lower_10_`var' = Beta_`var'-(SD_`var'*1.645)
}

gen N = _n
drop if N !=1
keep N Beta_D_Border20 Beta_D_Border21 Beta_D_Border22 Beta_D_Border23 Beta_D_Border24 Beta_D_Border25 Beta_D_Border26 Beta_D_Border27 Beta_D_Border28 Beta_D_Border29 Beta_D_Border30 Beta_D_Border31 Beta_D_Border32 Beta_D_Border33 Beta_D_Border34 Beta_D_Border35 Beta_D_Border36 Beta_D_Border37 Beta_D_Border38 Beta_D_Border39 Beta_D_Border40 Beta_D_Border41 Beta_D_Border42 Beta_D_Border43 Beta_D_Border44 Beta_D_Border45 Beta_D_Border46 Beta_D_Border47 Beta_D_Border48 Beta_D_Border49 Beta_D_Border50 Beta_D_Border51 Beta_D_Border52 Beta_D_Border53 Beta_D_Border54 Beta_D_Border55 Beta_D_Border56 Beta_D_Border57 Beta_D_Border58 Beta_D_Border59 Beta_D_Border60 Beta_D_Border61 Beta_D_Border62 Beta_D_Border63 Beta_D_Border64 Beta_D_Border65 Beta_D_Border66 Beta_D_Border67 Beta_D_Border68 Beta_D_Border69 Beta_D_Border70 Beta_D_Border71 Beta_D_Border72 Beta_D_Border73 Beta_D_Border74 Beta_D_Border75 Beta_D_Border76 Beta_D_Border77 Beta_D_Border78 Beta_D_Border79 Beta_D_Border80 CI_Upper_D_Border20 CI_Upper_D_Border21 CI_Upper_D_Border22 CI_Upper_D_Border23 CI_Upper_D_Border24 CI_Upper_D_Border25 CI_Upper_D_Border26 CI_Upper_D_Border27 CI_Upper_D_Border28 CI_Upper_D_Border29 CI_Upper_D_Border30 CI_Upper_D_Border31 CI_Upper_D_Border32 CI_Upper_D_Border33 CI_Upper_D_Border34 CI_Upper_D_Border35 CI_Upper_D_Border36 CI_Upper_D_Border37 CI_Upper_D_Border38 CI_Upper_D_Border39 CI_Upper_D_Border40 CI_Upper_D_Border41 CI_Upper_D_Border42 CI_Upper_D_Border43 CI_Upper_D_Border44 CI_Upper_D_Border45 CI_Upper_D_Border46 CI_Upper_D_Border47 CI_Upper_D_Border48 CI_Upper_D_Border49 CI_Upper_D_Border50 CI_Upper_D_Border51 CI_Upper_D_Border52 CI_Upper_D_Border53 CI_Upper_D_Border54 CI_Upper_D_Border55 CI_Upper_D_Border56 CI_Upper_D_Border57 CI_Upper_D_Border58 CI_Upper_D_Border59 CI_Upper_D_Border60 CI_Upper_D_Border61 CI_Upper_D_Border62 CI_Upper_D_Border63 CI_Upper_D_Border64 CI_Upper_D_Border65 CI_Upper_D_Border66 CI_Upper_D_Border67 CI_Upper_D_Border68 CI_Upper_D_Border69 CI_Upper_D_Border70 CI_Upper_D_Border71 CI_Upper_D_Border72 CI_Upper_D_Border73 CI_Upper_D_Border74 CI_Upper_D_Border75 CI_Upper_D_Border76 CI_Upper_D_Border77 CI_Upper_D_Border78 CI_Upper_D_Border79 CI_Upper_D_Border80 CI_Lower_D_Border20 CI_Lower_D_Border21 CI_Lower_D_Border22 CI_Lower_D_Border23 CI_Lower_D_Border24 CI_Lower_D_Border25 CI_Lower_D_Border26 CI_Lower_D_Border27 CI_Lower_D_Border28 CI_Lower_D_Border29 CI_Lower_D_Border30 CI_Lower_D_Border31 CI_Lower_D_Border32 CI_Lower_D_Border33 CI_Lower_D_Border34 CI_Lower_D_Border35 CI_Lower_D_Border36 CI_Lower_D_Border37 CI_Lower_D_Border38 CI_Lower_D_Border39 CI_Lower_D_Border40 CI_Lower_D_Border41 CI_Lower_D_Border42 CI_Lower_D_Border43 CI_Lower_D_Border44 CI_Lower_D_Border45 CI_Lower_D_Border46 CI_Lower_D_Border47 CI_Lower_D_Border48 CI_Lower_D_Border49 CI_Lower_D_Border50 CI_Lower_D_Border51 CI_Lower_D_Border52 CI_Lower_D_Border53 CI_Lower_D_Border54 CI_Lower_D_Border55 CI_Lower_D_Border56 CI_Lower_D_Border57 CI_Lower_D_Border58 CI_Lower_D_Border59 CI_Lower_D_Border60 CI_Lower_D_Border61 CI_Lower_D_Border62 CI_Lower_D_Border63 CI_Lower_D_Border64 CI_Lower_D_Border65 CI_Lower_D_Border66 CI_Lower_D_Border67 CI_Lower_D_Border68 CI_Lower_D_Border69 CI_Lower_D_Border70 CI_Lower_D_Border71 CI_Lower_D_Border72 CI_Lower_D_Border73 CI_Lower_D_Border74 CI_Lower_D_Border75 CI_Lower_D_Border76 CI_Lower_D_Border77 CI_Lower_D_Border78 CI_Lower_D_Border79 CI_Lower_D_Border80 SD_10_D_Border20 CI_Upper_10_D_Border20 CI_Lower_10_D_Border20 SD_10_D_Border21 CI_Upper_10_D_Border21 CI_Lower_10_D_Border21 SD_10_D_Border22 CI_Upper_10_D_Border22 CI_Lower_10_D_Border22 SD_10_D_Border23 CI_Upper_10_D_Border23 CI_Lower_10_D_Border23 SD_10_D_Border24 CI_Upper_10_D_Border24 CI_Lower_10_D_Border24 SD_10_D_Border25 CI_Upper_10_D_Border25 CI_Lower_10_D_Border25 SD_10_D_Border26 CI_Upper_10_D_Border26 CI_Lower_10_D_Border26 SD_10_D_Border27 CI_Upper_10_D_Border27 CI_Lower_10_D_Border27 SD_10_D_Border28 CI_Upper_10_D_Border28 CI_Lower_10_D_Border28 SD_10_D_Border29 CI_Upper_10_D_Border29 CI_Lower_10_D_Border29 SD_10_D_Border30 CI_Upper_10_D_Border30 CI_Lower_10_D_Border30 SD_10_D_Border31 CI_Upper_10_D_Border31 CI_Lower_10_D_Border31 SD_10_D_Border32 CI_Upper_10_D_Border32 CI_Lower_10_D_Border32 SD_10_D_Border33 CI_Upper_10_D_Border33 CI_Lower_10_D_Border33 SD_10_D_Border34 CI_Upper_10_D_Border34 CI_Lower_10_D_Border34 SD_10_D_Border35 CI_Upper_10_D_Border35 CI_Lower_10_D_Border35 SD_10_D_Border36 CI_Upper_10_D_Border36 CI_Lower_10_D_Border36 SD_10_D_Border37 CI_Upper_10_D_Border37 CI_Lower_10_D_Border37 SD_10_D_Border38 CI_Upper_10_D_Border38 CI_Lower_10_D_Border38 SD_10_D_Border39 CI_Upper_10_D_Border39 CI_Lower_10_D_Border39 SD_10_D_Border40 CI_Upper_10_D_Border40 CI_Lower_10_D_Border40 SD_10_D_Border41 CI_Upper_10_D_Border41 CI_Lower_10_D_Border41 SD_10_D_Border42 CI_Upper_10_D_Border42 CI_Lower_10_D_Border42 SD_10_D_Border43 CI_Upper_10_D_Border43 CI_Lower_10_D_Border43 SD_10_D_Border44 CI_Upper_10_D_Border44 CI_Lower_10_D_Border44 SD_10_D_Border45 CI_Upper_10_D_Border45 CI_Lower_10_D_Border45 SD_10_D_Border46 CI_Upper_10_D_Border46 CI_Lower_10_D_Border46 SD_10_D_Border47 CI_Upper_10_D_Border47 CI_Lower_10_D_Border47 SD_10_D_Border48 CI_Upper_10_D_Border48 CI_Lower_10_D_Border48 SD_10_D_Border49 CI_Upper_10_D_Border49 CI_Lower_10_D_Border49 SD_10_D_Border50 CI_Upper_10_D_Border50 CI_Lower_10_D_Border50 SD_10_D_Border51 CI_Upper_10_D_Border51 CI_Lower_10_D_Border51 SD_10_D_Border52 CI_Upper_10_D_Border52 CI_Lower_10_D_Border52 SD_10_D_Border53 CI_Upper_10_D_Border53 CI_Lower_10_D_Border53 SD_10_D_Border54 CI_Upper_10_D_Border54 CI_Lower_10_D_Border54 SD_10_D_Border55 CI_Upper_10_D_Border55 CI_Lower_10_D_Border55 SD_10_D_Border56 CI_Upper_10_D_Border56 CI_Lower_10_D_Border56 SD_10_D_Border57 CI_Upper_10_D_Border57 CI_Lower_10_D_Border57 SD_10_D_Border58 CI_Upper_10_D_Border58 CI_Lower_10_D_Border58 SD_10_D_Border59 CI_Upper_10_D_Border59 CI_Lower_10_D_Border59 SD_10_D_Border60 CI_Upper_10_D_Border60 CI_Lower_10_D_Border60 SD_10_D_Border61 CI_Upper_10_D_Border61 CI_Lower_10_D_Border61 SD_10_D_Border62 CI_Upper_10_D_Border62 CI_Lower_10_D_Border62 SD_10_D_Border63 CI_Upper_10_D_Border63 CI_Lower_10_D_Border63 SD_10_D_Border64 CI_Upper_10_D_Border64 CI_Lower_10_D_Border64 SD_10_D_Border65 CI_Upper_10_D_Border65 CI_Lower_10_D_Border65 SD_10_D_Border66 CI_Upper_10_D_Border66 CI_Lower_10_D_Border66 SD_10_D_Border67 CI_Upper_10_D_Border67 CI_Lower_10_D_Border67 SD_10_D_Border68 CI_Upper_10_D_Border68 CI_Lower_10_D_Border68 SD_10_D_Border69 CI_Upper_10_D_Border69 CI_Lower_10_D_Border69 SD_10_D_Border70 CI_Upper_10_D_Border70 CI_Lower_10_D_Border70 SD_10_D_Border71 CI_Upper_10_D_Border71 CI_Lower_10_D_Border71 SD_10_D_Border72 CI_Upper_10_D_Border72 CI_Lower_10_D_Border72 SD_10_D_Border73 CI_Upper_10_D_Border73 CI_Lower_10_D_Border73 SD_10_D_Border74 CI_Upper_10_D_Border74 CI_Lower_10_D_Border74 SD_10_D_Border75 CI_Upper_10_D_Border75 CI_Lower_10_D_Border75 SD_10_D_Border76 CI_Upper_10_D_Border76 CI_Lower_10_D_Border76 SD_10_D_Border77 CI_Upper_10_D_Border77 CI_Lower_10_D_Border77 SD_10_D_Border78 CI_Upper_10_D_Border78 CI_Lower_10_D_Border78 SD_10_D_Border79 CI_Upper_10_D_Border79 CI_Lower_10_D_Border79 SD_10_D_Border80 CI_Upper_10_D_Border80 CI_Lower_10_D_Border80


reshape long Beta_D_Border CI_Upper_D_Border CI_Lower_D_Border CI_Upper_10_D_Border CI_Lower_10_D_Border, i(N) j(band)
	
twoway (line Beta_D_Border band, lcolor(black) lpattern(solid)) ///
	(line CI_Upper_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Lower_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Upper_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)) ///
	(line CI_Lower_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)), ///
   ytitle("", size(small)) ylabel(-.5(.5)2,  angle(horizontal))  ///
    xtitle(Distance from Border (km)) xtitle(, size(small)) xlabel(20(10)80, labsize(vsmall))  ///
           yline(0, lcolor(gs10)) ///
      plotregion(lcolor(black)) ///
  legend(off) ///
        title("d. Member of a Community Group", size(medsmall)) ///
    scheme(s2mono) graphregion(fcolor(white)) 
 

************************************************************************************************
********************** FIGURE  4 - TRADITIONAL AUTHORITY MECHANISM *****************************
************************************************************************************************

*a. How much do you trust traditional leaders (R6 only) Q52K_R6
use AfroBarometerData.dta, clear
keep if REGION==2 | REGION==7 | REGION==9 | REGION==10 | REGION==12

foreach var of varlist D_Border20-D_Border80 {
    quietly reg Q52K_R6 $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance i.Round if `var'==1, cluster(EANUMB_AB) robust 
	gen Beta_`var' = _b[anglophone]
	matrix c_`var' = e(V)
	gen Var_`var' = c_`var'[1,1]
} 

foreach var of varlist D_Border20-D_Border80 {
	gen SD_`var' = sqrt(Var_`var')
	gen CI_Upper_`var' = Beta_`var'+(SD_`var'*1.96)
	gen CI_Lower_`var' = Beta_`var'-(SD_`var'*1.96)
}


foreach var of varlist D_Border20-D_Border80 {
	gen SD_10_`var' = sqrt(Var_`var')
	gen CI_Upper_10_`var' = Beta_`var'+(SD_`var'*1.645)
	gen CI_Lower_10_`var' = Beta_`var'-(SD_`var'*1.645)
}

gen N = _n
drop if N !=1
keep N Beta_D_Border20 Beta_D_Border21 Beta_D_Border22 Beta_D_Border23 Beta_D_Border24 Beta_D_Border25 Beta_D_Border26 Beta_D_Border27 Beta_D_Border28 Beta_D_Border29 Beta_D_Border30 Beta_D_Border31 Beta_D_Border32 Beta_D_Border33 Beta_D_Border34 Beta_D_Border35 Beta_D_Border36 Beta_D_Border37 Beta_D_Border38 Beta_D_Border39 Beta_D_Border40 Beta_D_Border41 Beta_D_Border42 Beta_D_Border43 Beta_D_Border44 Beta_D_Border45 Beta_D_Border46 Beta_D_Border47 Beta_D_Border48 Beta_D_Border49 Beta_D_Border50 Beta_D_Border51 Beta_D_Border52 Beta_D_Border53 Beta_D_Border54 Beta_D_Border55 Beta_D_Border56 Beta_D_Border57 Beta_D_Border58 Beta_D_Border59 Beta_D_Border60 Beta_D_Border61 Beta_D_Border62 Beta_D_Border63 Beta_D_Border64 Beta_D_Border65 Beta_D_Border66 Beta_D_Border67 Beta_D_Border68 Beta_D_Border69 Beta_D_Border70 Beta_D_Border71 Beta_D_Border72 Beta_D_Border73 Beta_D_Border74 Beta_D_Border75 Beta_D_Border76 Beta_D_Border77 Beta_D_Border78 Beta_D_Border79 Beta_D_Border80 CI_Upper_D_Border20 CI_Upper_D_Border21 CI_Upper_D_Border22 CI_Upper_D_Border23 CI_Upper_D_Border24 CI_Upper_D_Border25 CI_Upper_D_Border26 CI_Upper_D_Border27 CI_Upper_D_Border28 CI_Upper_D_Border29 CI_Upper_D_Border30 CI_Upper_D_Border31 CI_Upper_D_Border32 CI_Upper_D_Border33 CI_Upper_D_Border34 CI_Upper_D_Border35 CI_Upper_D_Border36 CI_Upper_D_Border37 CI_Upper_D_Border38 CI_Upper_D_Border39 CI_Upper_D_Border40 CI_Upper_D_Border41 CI_Upper_D_Border42 CI_Upper_D_Border43 CI_Upper_D_Border44 CI_Upper_D_Border45 CI_Upper_D_Border46 CI_Upper_D_Border47 CI_Upper_D_Border48 CI_Upper_D_Border49 CI_Upper_D_Border50 CI_Upper_D_Border51 CI_Upper_D_Border52 CI_Upper_D_Border53 CI_Upper_D_Border54 CI_Upper_D_Border55 CI_Upper_D_Border56 CI_Upper_D_Border57 CI_Upper_D_Border58 CI_Upper_D_Border59 CI_Upper_D_Border60 CI_Upper_D_Border61 CI_Upper_D_Border62 CI_Upper_D_Border63 CI_Upper_D_Border64 CI_Upper_D_Border65 CI_Upper_D_Border66 CI_Upper_D_Border67 CI_Upper_D_Border68 CI_Upper_D_Border69 CI_Upper_D_Border70 CI_Upper_D_Border71 CI_Upper_D_Border72 CI_Upper_D_Border73 CI_Upper_D_Border74 CI_Upper_D_Border75 CI_Upper_D_Border76 CI_Upper_D_Border77 CI_Upper_D_Border78 CI_Upper_D_Border79 CI_Upper_D_Border80 CI_Lower_D_Border20 CI_Lower_D_Border21 CI_Lower_D_Border22 CI_Lower_D_Border23 CI_Lower_D_Border24 CI_Lower_D_Border25 CI_Lower_D_Border26 CI_Lower_D_Border27 CI_Lower_D_Border28 CI_Lower_D_Border29 CI_Lower_D_Border30 CI_Lower_D_Border31 CI_Lower_D_Border32 CI_Lower_D_Border33 CI_Lower_D_Border34 CI_Lower_D_Border35 CI_Lower_D_Border36 CI_Lower_D_Border37 CI_Lower_D_Border38 CI_Lower_D_Border39 CI_Lower_D_Border40 CI_Lower_D_Border41 CI_Lower_D_Border42 CI_Lower_D_Border43 CI_Lower_D_Border44 CI_Lower_D_Border45 CI_Lower_D_Border46 CI_Lower_D_Border47 CI_Lower_D_Border48 CI_Lower_D_Border49 CI_Lower_D_Border50 CI_Lower_D_Border51 CI_Lower_D_Border52 CI_Lower_D_Border53 CI_Lower_D_Border54 CI_Lower_D_Border55 CI_Lower_D_Border56 CI_Lower_D_Border57 CI_Lower_D_Border58 CI_Lower_D_Border59 CI_Lower_D_Border60 CI_Lower_D_Border61 CI_Lower_D_Border62 CI_Lower_D_Border63 CI_Lower_D_Border64 CI_Lower_D_Border65 CI_Lower_D_Border66 CI_Lower_D_Border67 CI_Lower_D_Border68 CI_Lower_D_Border69 CI_Lower_D_Border70 CI_Lower_D_Border71 CI_Lower_D_Border72 CI_Lower_D_Border73 CI_Lower_D_Border74 CI_Lower_D_Border75 CI_Lower_D_Border76 CI_Lower_D_Border77 CI_Lower_D_Border78 CI_Lower_D_Border79 CI_Lower_D_Border80 SD_10_D_Border20 CI_Upper_10_D_Border20 CI_Lower_10_D_Border20 SD_10_D_Border21 CI_Upper_10_D_Border21 CI_Lower_10_D_Border21 SD_10_D_Border22 CI_Upper_10_D_Border22 CI_Lower_10_D_Border22 SD_10_D_Border23 CI_Upper_10_D_Border23 CI_Lower_10_D_Border23 SD_10_D_Border24 CI_Upper_10_D_Border24 CI_Lower_10_D_Border24 SD_10_D_Border25 CI_Upper_10_D_Border25 CI_Lower_10_D_Border25 SD_10_D_Border26 CI_Upper_10_D_Border26 CI_Lower_10_D_Border26 SD_10_D_Border27 CI_Upper_10_D_Border27 CI_Lower_10_D_Border27 SD_10_D_Border28 CI_Upper_10_D_Border28 CI_Lower_10_D_Border28 SD_10_D_Border29 CI_Upper_10_D_Border29 CI_Lower_10_D_Border29 SD_10_D_Border30 CI_Upper_10_D_Border30 CI_Lower_10_D_Border30 SD_10_D_Border31 CI_Upper_10_D_Border31 CI_Lower_10_D_Border31 SD_10_D_Border32 CI_Upper_10_D_Border32 CI_Lower_10_D_Border32 SD_10_D_Border33 CI_Upper_10_D_Border33 CI_Lower_10_D_Border33 SD_10_D_Border34 CI_Upper_10_D_Border34 CI_Lower_10_D_Border34 SD_10_D_Border35 CI_Upper_10_D_Border35 CI_Lower_10_D_Border35 SD_10_D_Border36 CI_Upper_10_D_Border36 CI_Lower_10_D_Border36 SD_10_D_Border37 CI_Upper_10_D_Border37 CI_Lower_10_D_Border37 SD_10_D_Border38 CI_Upper_10_D_Border38 CI_Lower_10_D_Border38 SD_10_D_Border39 CI_Upper_10_D_Border39 CI_Lower_10_D_Border39 SD_10_D_Border40 CI_Upper_10_D_Border40 CI_Lower_10_D_Border40 SD_10_D_Border41 CI_Upper_10_D_Border41 CI_Lower_10_D_Border41 SD_10_D_Border42 CI_Upper_10_D_Border42 CI_Lower_10_D_Border42 SD_10_D_Border43 CI_Upper_10_D_Border43 CI_Lower_10_D_Border43 SD_10_D_Border44 CI_Upper_10_D_Border44 CI_Lower_10_D_Border44 SD_10_D_Border45 CI_Upper_10_D_Border45 CI_Lower_10_D_Border45 SD_10_D_Border46 CI_Upper_10_D_Border46 CI_Lower_10_D_Border46 SD_10_D_Border47 CI_Upper_10_D_Border47 CI_Lower_10_D_Border47 SD_10_D_Border48 CI_Upper_10_D_Border48 CI_Lower_10_D_Border48 SD_10_D_Border49 CI_Upper_10_D_Border49 CI_Lower_10_D_Border49 SD_10_D_Border50 CI_Upper_10_D_Border50 CI_Lower_10_D_Border50 SD_10_D_Border51 CI_Upper_10_D_Border51 CI_Lower_10_D_Border51 SD_10_D_Border52 CI_Upper_10_D_Border52 CI_Lower_10_D_Border52 SD_10_D_Border53 CI_Upper_10_D_Border53 CI_Lower_10_D_Border53 SD_10_D_Border54 CI_Upper_10_D_Border54 CI_Lower_10_D_Border54 SD_10_D_Border55 CI_Upper_10_D_Border55 CI_Lower_10_D_Border55 SD_10_D_Border56 CI_Upper_10_D_Border56 CI_Lower_10_D_Border56 SD_10_D_Border57 CI_Upper_10_D_Border57 CI_Lower_10_D_Border57 SD_10_D_Border58 CI_Upper_10_D_Border58 CI_Lower_10_D_Border58 SD_10_D_Border59 CI_Upper_10_D_Border59 CI_Lower_10_D_Border59 SD_10_D_Border60 CI_Upper_10_D_Border60 CI_Lower_10_D_Border60 SD_10_D_Border61 CI_Upper_10_D_Border61 CI_Lower_10_D_Border61 SD_10_D_Border62 CI_Upper_10_D_Border62 CI_Lower_10_D_Border62 SD_10_D_Border63 CI_Upper_10_D_Border63 CI_Lower_10_D_Border63 SD_10_D_Border64 CI_Upper_10_D_Border64 CI_Lower_10_D_Border64 SD_10_D_Border65 CI_Upper_10_D_Border65 CI_Lower_10_D_Border65 SD_10_D_Border66 CI_Upper_10_D_Border66 CI_Lower_10_D_Border66 SD_10_D_Border67 CI_Upper_10_D_Border67 CI_Lower_10_D_Border67 SD_10_D_Border68 CI_Upper_10_D_Border68 CI_Lower_10_D_Border68 SD_10_D_Border69 CI_Upper_10_D_Border69 CI_Lower_10_D_Border69 SD_10_D_Border70 CI_Upper_10_D_Border70 CI_Lower_10_D_Border70 SD_10_D_Border71 CI_Upper_10_D_Border71 CI_Lower_10_D_Border71 SD_10_D_Border72 CI_Upper_10_D_Border72 CI_Lower_10_D_Border72 SD_10_D_Border73 CI_Upper_10_D_Border73 CI_Lower_10_D_Border73 SD_10_D_Border74 CI_Upper_10_D_Border74 CI_Lower_10_D_Border74 SD_10_D_Border75 CI_Upper_10_D_Border75 CI_Lower_10_D_Border75 SD_10_D_Border76 CI_Upper_10_D_Border76 CI_Lower_10_D_Border76 SD_10_D_Border77 CI_Upper_10_D_Border77 CI_Lower_10_D_Border77 SD_10_D_Border78 CI_Upper_10_D_Border78 CI_Lower_10_D_Border78 SD_10_D_Border79 CI_Upper_10_D_Border79 CI_Lower_10_D_Border79 SD_10_D_Border80 CI_Upper_10_D_Border80 CI_Lower_10_D_Border80


reshape long Beta_D_Border CI_Upper_D_Border CI_Lower_D_Border CI_Upper_10_D_Border CI_Lower_10_D_Border, i(N) j(band)

twoway (line Beta_D_Border band, lcolor(black) lpattern(solid)) ///
	(line CI_Upper_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Lower_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Upper_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)) ///
	(line CI_Lower_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)), ///
    ytitle(Estimated Effect Anglophone, size(small)) ylabel(2(.5)-1.5,  angle(horizontal))  ///
    xtitle("") xtitle(, size(small)) xlabel(20(10)80, labsize(vsmall))  ///
         yline(0, lcolor(gs10)) ///
      plotregion(lcolor(black)) ///
    legend(off) ///
        title(a. Trust in Traditional Leaders, size(medsmall)) ///
    scheme(s2mono) graphregion(fcolor(white)) 
    
    
*b. Corruption: traditional leaders (R6 only) Q53H_R6
use AfroBarometerData.dta, clear
keep if REGION==2 | REGION==7 | REGION==9 | REGION==10 | REGION==12

foreach var of varlist D_Border20-D_Border80 {
	quietly reg Q53H_R6 $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance  Round if `var'==1, cluster(EANUMB_AB) robust 
	gen Beta_`var' = _b[anglophone]
	matrix c_`var' = e(V)
	gen Var_`var' = c_`var'[1,1]
} 

foreach var of varlist D_Border20-D_Border80 {
	gen SD_`var' = sqrt(Var_`var')
	gen CI_Upper_`var' = Beta_`var'+(SD_`var'*1.96)
	gen CI_Lower_`var' = Beta_`var'-(SD_`var'*1.96)
}


foreach var of varlist D_Border20-D_Border80 {
	gen SD_10_`var' = sqrt(Var_`var')
	gen CI_Upper_10_`var' = Beta_`var'+(SD_`var'*1.645)
	gen CI_Lower_10_`var' = Beta_`var'-(SD_`var'*1.645)
}

gen N = _n
drop if N !=1
keep N Beta_D_Border20 Beta_D_Border21 Beta_D_Border22 Beta_D_Border23 Beta_D_Border24 Beta_D_Border25 Beta_D_Border26 Beta_D_Border27 Beta_D_Border28 Beta_D_Border29 Beta_D_Border30 Beta_D_Border31 Beta_D_Border32 Beta_D_Border33 Beta_D_Border34 Beta_D_Border35 Beta_D_Border36 Beta_D_Border37 Beta_D_Border38 Beta_D_Border39 Beta_D_Border40 Beta_D_Border41 Beta_D_Border42 Beta_D_Border43 Beta_D_Border44 Beta_D_Border45 Beta_D_Border46 Beta_D_Border47 Beta_D_Border48 Beta_D_Border49 Beta_D_Border50 Beta_D_Border51 Beta_D_Border52 Beta_D_Border53 Beta_D_Border54 Beta_D_Border55 Beta_D_Border56 Beta_D_Border57 Beta_D_Border58 Beta_D_Border59 Beta_D_Border60 Beta_D_Border61 Beta_D_Border62 Beta_D_Border63 Beta_D_Border64 Beta_D_Border65 Beta_D_Border66 Beta_D_Border67 Beta_D_Border68 Beta_D_Border69 Beta_D_Border70 Beta_D_Border71 Beta_D_Border72 Beta_D_Border73 Beta_D_Border74 Beta_D_Border75 Beta_D_Border76 Beta_D_Border77 Beta_D_Border78 Beta_D_Border79 Beta_D_Border80 CI_Upper_D_Border20 CI_Upper_D_Border21 CI_Upper_D_Border22 CI_Upper_D_Border23 CI_Upper_D_Border24 CI_Upper_D_Border25 CI_Upper_D_Border26 CI_Upper_D_Border27 CI_Upper_D_Border28 CI_Upper_D_Border29 CI_Upper_D_Border30 CI_Upper_D_Border31 CI_Upper_D_Border32 CI_Upper_D_Border33 CI_Upper_D_Border34 CI_Upper_D_Border35 CI_Upper_D_Border36 CI_Upper_D_Border37 CI_Upper_D_Border38 CI_Upper_D_Border39 CI_Upper_D_Border40 CI_Upper_D_Border41 CI_Upper_D_Border42 CI_Upper_D_Border43 CI_Upper_D_Border44 CI_Upper_D_Border45 CI_Upper_D_Border46 CI_Upper_D_Border47 CI_Upper_D_Border48 CI_Upper_D_Border49 CI_Upper_D_Border50 CI_Upper_D_Border51 CI_Upper_D_Border52 CI_Upper_D_Border53 CI_Upper_D_Border54 CI_Upper_D_Border55 CI_Upper_D_Border56 CI_Upper_D_Border57 CI_Upper_D_Border58 CI_Upper_D_Border59 CI_Upper_D_Border60 CI_Upper_D_Border61 CI_Upper_D_Border62 CI_Upper_D_Border63 CI_Upper_D_Border64 CI_Upper_D_Border65 CI_Upper_D_Border66 CI_Upper_D_Border67 CI_Upper_D_Border68 CI_Upper_D_Border69 CI_Upper_D_Border70 CI_Upper_D_Border71 CI_Upper_D_Border72 CI_Upper_D_Border73 CI_Upper_D_Border74 CI_Upper_D_Border75 CI_Upper_D_Border76 CI_Upper_D_Border77 CI_Upper_D_Border78 CI_Upper_D_Border79 CI_Upper_D_Border80 CI_Lower_D_Border20 CI_Lower_D_Border21 CI_Lower_D_Border22 CI_Lower_D_Border23 CI_Lower_D_Border24 CI_Lower_D_Border25 CI_Lower_D_Border26 CI_Lower_D_Border27 CI_Lower_D_Border28 CI_Lower_D_Border29 CI_Lower_D_Border30 CI_Lower_D_Border31 CI_Lower_D_Border32 CI_Lower_D_Border33 CI_Lower_D_Border34 CI_Lower_D_Border35 CI_Lower_D_Border36 CI_Lower_D_Border37 CI_Lower_D_Border38 CI_Lower_D_Border39 CI_Lower_D_Border40 CI_Lower_D_Border41 CI_Lower_D_Border42 CI_Lower_D_Border43 CI_Lower_D_Border44 CI_Lower_D_Border45 CI_Lower_D_Border46 CI_Lower_D_Border47 CI_Lower_D_Border48 CI_Lower_D_Border49 CI_Lower_D_Border50 CI_Lower_D_Border51 CI_Lower_D_Border52 CI_Lower_D_Border53 CI_Lower_D_Border54 CI_Lower_D_Border55 CI_Lower_D_Border56 CI_Lower_D_Border57 CI_Lower_D_Border58 CI_Lower_D_Border59 CI_Lower_D_Border60 CI_Lower_D_Border61 CI_Lower_D_Border62 CI_Lower_D_Border63 CI_Lower_D_Border64 CI_Lower_D_Border65 CI_Lower_D_Border66 CI_Lower_D_Border67 CI_Lower_D_Border68 CI_Lower_D_Border69 CI_Lower_D_Border70 CI_Lower_D_Border71 CI_Lower_D_Border72 CI_Lower_D_Border73 CI_Lower_D_Border74 CI_Lower_D_Border75 CI_Lower_D_Border76 CI_Lower_D_Border77 CI_Lower_D_Border78 CI_Lower_D_Border79 CI_Lower_D_Border80 SD_10_D_Border20 CI_Upper_10_D_Border20 CI_Lower_10_D_Border20 SD_10_D_Border21 CI_Upper_10_D_Border21 CI_Lower_10_D_Border21 SD_10_D_Border22 CI_Upper_10_D_Border22 CI_Lower_10_D_Border22 SD_10_D_Border23 CI_Upper_10_D_Border23 CI_Lower_10_D_Border23 SD_10_D_Border24 CI_Upper_10_D_Border24 CI_Lower_10_D_Border24 SD_10_D_Border25 CI_Upper_10_D_Border25 CI_Lower_10_D_Border25 SD_10_D_Border26 CI_Upper_10_D_Border26 CI_Lower_10_D_Border26 SD_10_D_Border27 CI_Upper_10_D_Border27 CI_Lower_10_D_Border27 SD_10_D_Border28 CI_Upper_10_D_Border28 CI_Lower_10_D_Border28 SD_10_D_Border29 CI_Upper_10_D_Border29 CI_Lower_10_D_Border29 SD_10_D_Border30 CI_Upper_10_D_Border30 CI_Lower_10_D_Border30 SD_10_D_Border31 CI_Upper_10_D_Border31 CI_Lower_10_D_Border31 SD_10_D_Border32 CI_Upper_10_D_Border32 CI_Lower_10_D_Border32 SD_10_D_Border33 CI_Upper_10_D_Border33 CI_Lower_10_D_Border33 SD_10_D_Border34 CI_Upper_10_D_Border34 CI_Lower_10_D_Border34 SD_10_D_Border35 CI_Upper_10_D_Border35 CI_Lower_10_D_Border35 SD_10_D_Border36 CI_Upper_10_D_Border36 CI_Lower_10_D_Border36 SD_10_D_Border37 CI_Upper_10_D_Border37 CI_Lower_10_D_Border37 SD_10_D_Border38 CI_Upper_10_D_Border38 CI_Lower_10_D_Border38 SD_10_D_Border39 CI_Upper_10_D_Border39 CI_Lower_10_D_Border39 SD_10_D_Border40 CI_Upper_10_D_Border40 CI_Lower_10_D_Border40 SD_10_D_Border41 CI_Upper_10_D_Border41 CI_Lower_10_D_Border41 SD_10_D_Border42 CI_Upper_10_D_Border42 CI_Lower_10_D_Border42 SD_10_D_Border43 CI_Upper_10_D_Border43 CI_Lower_10_D_Border43 SD_10_D_Border44 CI_Upper_10_D_Border44 CI_Lower_10_D_Border44 SD_10_D_Border45 CI_Upper_10_D_Border45 CI_Lower_10_D_Border45 SD_10_D_Border46 CI_Upper_10_D_Border46 CI_Lower_10_D_Border46 SD_10_D_Border47 CI_Upper_10_D_Border47 CI_Lower_10_D_Border47 SD_10_D_Border48 CI_Upper_10_D_Border48 CI_Lower_10_D_Border48 SD_10_D_Border49 CI_Upper_10_D_Border49 CI_Lower_10_D_Border49 SD_10_D_Border50 CI_Upper_10_D_Border50 CI_Lower_10_D_Border50 SD_10_D_Border51 CI_Upper_10_D_Border51 CI_Lower_10_D_Border51 SD_10_D_Border52 CI_Upper_10_D_Border52 CI_Lower_10_D_Border52 SD_10_D_Border53 CI_Upper_10_D_Border53 CI_Lower_10_D_Border53 SD_10_D_Border54 CI_Upper_10_D_Border54 CI_Lower_10_D_Border54 SD_10_D_Border55 CI_Upper_10_D_Border55 CI_Lower_10_D_Border55 SD_10_D_Border56 CI_Upper_10_D_Border56 CI_Lower_10_D_Border56 SD_10_D_Border57 CI_Upper_10_D_Border57 CI_Lower_10_D_Border57 SD_10_D_Border58 CI_Upper_10_D_Border58 CI_Lower_10_D_Border58 SD_10_D_Border59 CI_Upper_10_D_Border59 CI_Lower_10_D_Border59 SD_10_D_Border60 CI_Upper_10_D_Border60 CI_Lower_10_D_Border60 SD_10_D_Border61 CI_Upper_10_D_Border61 CI_Lower_10_D_Border61 SD_10_D_Border62 CI_Upper_10_D_Border62 CI_Lower_10_D_Border62 SD_10_D_Border63 CI_Upper_10_D_Border63 CI_Lower_10_D_Border63 SD_10_D_Border64 CI_Upper_10_D_Border64 CI_Lower_10_D_Border64 SD_10_D_Border65 CI_Upper_10_D_Border65 CI_Lower_10_D_Border65 SD_10_D_Border66 CI_Upper_10_D_Border66 CI_Lower_10_D_Border66 SD_10_D_Border67 CI_Upper_10_D_Border67 CI_Lower_10_D_Border67 SD_10_D_Border68 CI_Upper_10_D_Border68 CI_Lower_10_D_Border68 SD_10_D_Border69 CI_Upper_10_D_Border69 CI_Lower_10_D_Border69 SD_10_D_Border70 CI_Upper_10_D_Border70 CI_Lower_10_D_Border70 SD_10_D_Border71 CI_Upper_10_D_Border71 CI_Lower_10_D_Border71 SD_10_D_Border72 CI_Upper_10_D_Border72 CI_Lower_10_D_Border72 SD_10_D_Border73 CI_Upper_10_D_Border73 CI_Lower_10_D_Border73 SD_10_D_Border74 CI_Upper_10_D_Border74 CI_Lower_10_D_Border74 SD_10_D_Border75 CI_Upper_10_D_Border75 CI_Lower_10_D_Border75 SD_10_D_Border76 CI_Upper_10_D_Border76 CI_Lower_10_D_Border76 SD_10_D_Border77 CI_Upper_10_D_Border77 CI_Lower_10_D_Border77 SD_10_D_Border78 CI_Upper_10_D_Border78 CI_Lower_10_D_Border78 SD_10_D_Border79 CI_Upper_10_D_Border79 CI_Lower_10_D_Border79 SD_10_D_Border80 CI_Upper_10_D_Border80 CI_Lower_10_D_Border80


reshape long Beta_D_Border CI_Upper_D_Border CI_Lower_D_Border CI_Upper_10_D_Border CI_Lower_10_D_Border, i(N) j(band)

twoway (line Beta_D_Border band, lcolor(black) lpattern(solid)) ///
	(line CI_Upper_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Lower_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Upper_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)) ///
	(line CI_Lower_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)), ///
    ytitle("", size(small))  ylabel(2(.5)-1.5,  angle(horizontal))  ///
    xtitle("") xtitle(, size(small)) xlabel(20(10)80, labsize(vsmall))  ///
          yline(0, lcolor(gs10)) ///
      plotregion(lcolor(black)) ///
   legend(off) ///
        title(b. Traditional Leaders are Corrupt, size(medsmall)) ///
    scheme(s2mono) graphregion(fcolor(white)) 


*c. Contact tradtional leader (R6 only) Q24E_R6
use AfroBarometerData.dta, clear
keep if REGION==2 | REGION==7 | REGION==9 | REGION==10 | REGION==12

foreach var of varlist D_Border20-D_Border80 {
    quietly reg Q24E_R6 $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance  Round if `var'==1, cluster(EANUMB_AB) robust 
	gen Beta_`var' = _b[anglophone]
	matrix c_`var' = e(V)
	gen Var_`var' = c_`var'[1,1]
} 

foreach var of varlist D_Border20-D_Border80 {
	gen SD_`var' = sqrt(Var_`var')
	gen CI_Upper_`var' = Beta_`var'+(SD_`var'*1.96)
	gen CI_Lower_`var' = Beta_`var'-(SD_`var'*1.96)
}


foreach var of varlist D_Border20-D_Border80 {
	gen SD_10_`var' = sqrt(Var_`var')
	gen CI_Upper_10_`var' = Beta_`var'+(SD_`var'*1.645)
	gen CI_Lower_10_`var' = Beta_`var'-(SD_`var'*1.645)
}

gen N = _n
drop if N !=1
keep N Beta_D_Border20 Beta_D_Border21 Beta_D_Border22 Beta_D_Border23 Beta_D_Border24 Beta_D_Border25 Beta_D_Border26 Beta_D_Border27 Beta_D_Border28 Beta_D_Border29 Beta_D_Border30 Beta_D_Border31 Beta_D_Border32 Beta_D_Border33 Beta_D_Border34 Beta_D_Border35 Beta_D_Border36 Beta_D_Border37 Beta_D_Border38 Beta_D_Border39 Beta_D_Border40 Beta_D_Border41 Beta_D_Border42 Beta_D_Border43 Beta_D_Border44 Beta_D_Border45 Beta_D_Border46 Beta_D_Border47 Beta_D_Border48 Beta_D_Border49 Beta_D_Border50 Beta_D_Border51 Beta_D_Border52 Beta_D_Border53 Beta_D_Border54 Beta_D_Border55 Beta_D_Border56 Beta_D_Border57 Beta_D_Border58 Beta_D_Border59 Beta_D_Border60 Beta_D_Border61 Beta_D_Border62 Beta_D_Border63 Beta_D_Border64 Beta_D_Border65 Beta_D_Border66 Beta_D_Border67 Beta_D_Border68 Beta_D_Border69 Beta_D_Border70 Beta_D_Border71 Beta_D_Border72 Beta_D_Border73 Beta_D_Border74 Beta_D_Border75 Beta_D_Border76 Beta_D_Border77 Beta_D_Border78 Beta_D_Border79 Beta_D_Border80 CI_Upper_D_Border20 CI_Upper_D_Border21 CI_Upper_D_Border22 CI_Upper_D_Border23 CI_Upper_D_Border24 CI_Upper_D_Border25 CI_Upper_D_Border26 CI_Upper_D_Border27 CI_Upper_D_Border28 CI_Upper_D_Border29 CI_Upper_D_Border30 CI_Upper_D_Border31 CI_Upper_D_Border32 CI_Upper_D_Border33 CI_Upper_D_Border34 CI_Upper_D_Border35 CI_Upper_D_Border36 CI_Upper_D_Border37 CI_Upper_D_Border38 CI_Upper_D_Border39 CI_Upper_D_Border40 CI_Upper_D_Border41 CI_Upper_D_Border42 CI_Upper_D_Border43 CI_Upper_D_Border44 CI_Upper_D_Border45 CI_Upper_D_Border46 CI_Upper_D_Border47 CI_Upper_D_Border48 CI_Upper_D_Border49 CI_Upper_D_Border50 CI_Upper_D_Border51 CI_Upper_D_Border52 CI_Upper_D_Border53 CI_Upper_D_Border54 CI_Upper_D_Border55 CI_Upper_D_Border56 CI_Upper_D_Border57 CI_Upper_D_Border58 CI_Upper_D_Border59 CI_Upper_D_Border60 CI_Upper_D_Border61 CI_Upper_D_Border62 CI_Upper_D_Border63 CI_Upper_D_Border64 CI_Upper_D_Border65 CI_Upper_D_Border66 CI_Upper_D_Border67 CI_Upper_D_Border68 CI_Upper_D_Border69 CI_Upper_D_Border70 CI_Upper_D_Border71 CI_Upper_D_Border72 CI_Upper_D_Border73 CI_Upper_D_Border74 CI_Upper_D_Border75 CI_Upper_D_Border76 CI_Upper_D_Border77 CI_Upper_D_Border78 CI_Upper_D_Border79 CI_Upper_D_Border80 CI_Lower_D_Border20 CI_Lower_D_Border21 CI_Lower_D_Border22 CI_Lower_D_Border23 CI_Lower_D_Border24 CI_Lower_D_Border25 CI_Lower_D_Border26 CI_Lower_D_Border27 CI_Lower_D_Border28 CI_Lower_D_Border29 CI_Lower_D_Border30 CI_Lower_D_Border31 CI_Lower_D_Border32 CI_Lower_D_Border33 CI_Lower_D_Border34 CI_Lower_D_Border35 CI_Lower_D_Border36 CI_Lower_D_Border37 CI_Lower_D_Border38 CI_Lower_D_Border39 CI_Lower_D_Border40 CI_Lower_D_Border41 CI_Lower_D_Border42 CI_Lower_D_Border43 CI_Lower_D_Border44 CI_Lower_D_Border45 CI_Lower_D_Border46 CI_Lower_D_Border47 CI_Lower_D_Border48 CI_Lower_D_Border49 CI_Lower_D_Border50 CI_Lower_D_Border51 CI_Lower_D_Border52 CI_Lower_D_Border53 CI_Lower_D_Border54 CI_Lower_D_Border55 CI_Lower_D_Border56 CI_Lower_D_Border57 CI_Lower_D_Border58 CI_Lower_D_Border59 CI_Lower_D_Border60 CI_Lower_D_Border61 CI_Lower_D_Border62 CI_Lower_D_Border63 CI_Lower_D_Border64 CI_Lower_D_Border65 CI_Lower_D_Border66 CI_Lower_D_Border67 CI_Lower_D_Border68 CI_Lower_D_Border69 CI_Lower_D_Border70 CI_Lower_D_Border71 CI_Lower_D_Border72 CI_Lower_D_Border73 CI_Lower_D_Border74 CI_Lower_D_Border75 CI_Lower_D_Border76 CI_Lower_D_Border77 CI_Lower_D_Border78 CI_Lower_D_Border79 CI_Lower_D_Border80 SD_10_D_Border20 CI_Upper_10_D_Border20 CI_Lower_10_D_Border20 SD_10_D_Border21 CI_Upper_10_D_Border21 CI_Lower_10_D_Border21 SD_10_D_Border22 CI_Upper_10_D_Border22 CI_Lower_10_D_Border22 SD_10_D_Border23 CI_Upper_10_D_Border23 CI_Lower_10_D_Border23 SD_10_D_Border24 CI_Upper_10_D_Border24 CI_Lower_10_D_Border24 SD_10_D_Border25 CI_Upper_10_D_Border25 CI_Lower_10_D_Border25 SD_10_D_Border26 CI_Upper_10_D_Border26 CI_Lower_10_D_Border26 SD_10_D_Border27 CI_Upper_10_D_Border27 CI_Lower_10_D_Border27 SD_10_D_Border28 CI_Upper_10_D_Border28 CI_Lower_10_D_Border28 SD_10_D_Border29 CI_Upper_10_D_Border29 CI_Lower_10_D_Border29 SD_10_D_Border30 CI_Upper_10_D_Border30 CI_Lower_10_D_Border30 SD_10_D_Border31 CI_Upper_10_D_Border31 CI_Lower_10_D_Border31 SD_10_D_Border32 CI_Upper_10_D_Border32 CI_Lower_10_D_Border32 SD_10_D_Border33 CI_Upper_10_D_Border33 CI_Lower_10_D_Border33 SD_10_D_Border34 CI_Upper_10_D_Border34 CI_Lower_10_D_Border34 SD_10_D_Border35 CI_Upper_10_D_Border35 CI_Lower_10_D_Border35 SD_10_D_Border36 CI_Upper_10_D_Border36 CI_Lower_10_D_Border36 SD_10_D_Border37 CI_Upper_10_D_Border37 CI_Lower_10_D_Border37 SD_10_D_Border38 CI_Upper_10_D_Border38 CI_Lower_10_D_Border38 SD_10_D_Border39 CI_Upper_10_D_Border39 CI_Lower_10_D_Border39 SD_10_D_Border40 CI_Upper_10_D_Border40 CI_Lower_10_D_Border40 SD_10_D_Border41 CI_Upper_10_D_Border41 CI_Lower_10_D_Border41 SD_10_D_Border42 CI_Upper_10_D_Border42 CI_Lower_10_D_Border42 SD_10_D_Border43 CI_Upper_10_D_Border43 CI_Lower_10_D_Border43 SD_10_D_Border44 CI_Upper_10_D_Border44 CI_Lower_10_D_Border44 SD_10_D_Border45 CI_Upper_10_D_Border45 CI_Lower_10_D_Border45 SD_10_D_Border46 CI_Upper_10_D_Border46 CI_Lower_10_D_Border46 SD_10_D_Border47 CI_Upper_10_D_Border47 CI_Lower_10_D_Border47 SD_10_D_Border48 CI_Upper_10_D_Border48 CI_Lower_10_D_Border48 SD_10_D_Border49 CI_Upper_10_D_Border49 CI_Lower_10_D_Border49 SD_10_D_Border50 CI_Upper_10_D_Border50 CI_Lower_10_D_Border50 SD_10_D_Border51 CI_Upper_10_D_Border51 CI_Lower_10_D_Border51 SD_10_D_Border52 CI_Upper_10_D_Border52 CI_Lower_10_D_Border52 SD_10_D_Border53 CI_Upper_10_D_Border53 CI_Lower_10_D_Border53 SD_10_D_Border54 CI_Upper_10_D_Border54 CI_Lower_10_D_Border54 SD_10_D_Border55 CI_Upper_10_D_Border55 CI_Lower_10_D_Border55 SD_10_D_Border56 CI_Upper_10_D_Border56 CI_Lower_10_D_Border56 SD_10_D_Border57 CI_Upper_10_D_Border57 CI_Lower_10_D_Border57 SD_10_D_Border58 CI_Upper_10_D_Border58 CI_Lower_10_D_Border58 SD_10_D_Border59 CI_Upper_10_D_Border59 CI_Lower_10_D_Border59 SD_10_D_Border60 CI_Upper_10_D_Border60 CI_Lower_10_D_Border60 SD_10_D_Border61 CI_Upper_10_D_Border61 CI_Lower_10_D_Border61 SD_10_D_Border62 CI_Upper_10_D_Border62 CI_Lower_10_D_Border62 SD_10_D_Border63 CI_Upper_10_D_Border63 CI_Lower_10_D_Border63 SD_10_D_Border64 CI_Upper_10_D_Border64 CI_Lower_10_D_Border64 SD_10_D_Border65 CI_Upper_10_D_Border65 CI_Lower_10_D_Border65 SD_10_D_Border66 CI_Upper_10_D_Border66 CI_Lower_10_D_Border66 SD_10_D_Border67 CI_Upper_10_D_Border67 CI_Lower_10_D_Border67 SD_10_D_Border68 CI_Upper_10_D_Border68 CI_Lower_10_D_Border68 SD_10_D_Border69 CI_Upper_10_D_Border69 CI_Lower_10_D_Border69 SD_10_D_Border70 CI_Upper_10_D_Border70 CI_Lower_10_D_Border70 SD_10_D_Border71 CI_Upper_10_D_Border71 CI_Lower_10_D_Border71 SD_10_D_Border72 CI_Upper_10_D_Border72 CI_Lower_10_D_Border72 SD_10_D_Border73 CI_Upper_10_D_Border73 CI_Lower_10_D_Border73 SD_10_D_Border74 CI_Upper_10_D_Border74 CI_Lower_10_D_Border74 SD_10_D_Border75 CI_Upper_10_D_Border75 CI_Lower_10_D_Border75 SD_10_D_Border76 CI_Upper_10_D_Border76 CI_Lower_10_D_Border76 SD_10_D_Border77 CI_Upper_10_D_Border77 CI_Lower_10_D_Border77 SD_10_D_Border78 CI_Upper_10_D_Border78 CI_Lower_10_D_Border78 SD_10_D_Border79 CI_Upper_10_D_Border79 CI_Lower_10_D_Border79 SD_10_D_Border80 CI_Upper_10_D_Border80 CI_Lower_10_D_Border80


reshape long Beta_D_Border CI_Upper_D_Border CI_Lower_D_Border CI_Upper_10_D_Border CI_Lower_10_D_Border, i(N) j(band)

twoway (line Beta_D_Border band, lcolor(black) lpattern(solid)) ///
	(line CI_Upper_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Lower_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Upper_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)) ///
	(line CI_Lower_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)), ///
    ytitle(Estimated Effect Anglophone, size(small))  ylabel(2(.5)-1.5,  angle(horizontal))  ///
    xtitle(Distance from Border (km) ) xtitle(, size(small)) xlabel(20(10)80, labsize(vsmall))  ///
          yline(0, lcolor(gs10)) ///
      plotregion(lcolor(black)) ///
   legend(off) ///
        title(c. Contacted Tradtional Leader in the Past Year, size(medsmall)) ///
    scheme(s2mono) graphregion(fcolor(white)) 
    

*d. Job Approval of TAs (R6 only) Q68D_R6
use AfroBarometerData.dta, clear
keep if REGION==2 | REGION==7 | REGION==9 | REGION==10 | REGION==12

foreach var of varlist D_Border20-D_Border80 {
    quietly reg Q68D_R6 $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance  Round if `var'==1, cluster(EANUMB_AB) robust 
	gen Beta_`var' = _b[anglophone]
	matrix c_`var' = e(V)
	gen Var_`var' = c_`var'[1,1]
} 

foreach var of varlist D_Border20-D_Border80 {
	gen SD_`var' = sqrt(Var_`var')
	gen CI_Upper_`var' = Beta_`var'+(SD_`var'*1.96)
	gen CI_Lower_`var' = Beta_`var'-(SD_`var'*1.96)
}


foreach var of varlist D_Border20-D_Border80 {
	gen SD_10_`var' = sqrt(Var_`var')
	gen CI_Upper_10_`var' = Beta_`var'+(SD_`var'*1.645)
	gen CI_Lower_10_`var' = Beta_`var'-(SD_`var'*1.645)
}

gen N = _n
drop if N !=1
keep N Beta_D_Border20 Beta_D_Border21 Beta_D_Border22 Beta_D_Border23 Beta_D_Border24 Beta_D_Border25 Beta_D_Border26 Beta_D_Border27 Beta_D_Border28 Beta_D_Border29 Beta_D_Border30 Beta_D_Border31 Beta_D_Border32 Beta_D_Border33 Beta_D_Border34 Beta_D_Border35 Beta_D_Border36 Beta_D_Border37 Beta_D_Border38 Beta_D_Border39 Beta_D_Border40 Beta_D_Border41 Beta_D_Border42 Beta_D_Border43 Beta_D_Border44 Beta_D_Border45 Beta_D_Border46 Beta_D_Border47 Beta_D_Border48 Beta_D_Border49 Beta_D_Border50 Beta_D_Border51 Beta_D_Border52 Beta_D_Border53 Beta_D_Border54 Beta_D_Border55 Beta_D_Border56 Beta_D_Border57 Beta_D_Border58 Beta_D_Border59 Beta_D_Border60 Beta_D_Border61 Beta_D_Border62 Beta_D_Border63 Beta_D_Border64 Beta_D_Border65 Beta_D_Border66 Beta_D_Border67 Beta_D_Border68 Beta_D_Border69 Beta_D_Border70 Beta_D_Border71 Beta_D_Border72 Beta_D_Border73 Beta_D_Border74 Beta_D_Border75 Beta_D_Border76 Beta_D_Border77 Beta_D_Border78 Beta_D_Border79 Beta_D_Border80 CI_Upper_D_Border20 CI_Upper_D_Border21 CI_Upper_D_Border22 CI_Upper_D_Border23 CI_Upper_D_Border24 CI_Upper_D_Border25 CI_Upper_D_Border26 CI_Upper_D_Border27 CI_Upper_D_Border28 CI_Upper_D_Border29 CI_Upper_D_Border30 CI_Upper_D_Border31 CI_Upper_D_Border32 CI_Upper_D_Border33 CI_Upper_D_Border34 CI_Upper_D_Border35 CI_Upper_D_Border36 CI_Upper_D_Border37 CI_Upper_D_Border38 CI_Upper_D_Border39 CI_Upper_D_Border40 CI_Upper_D_Border41 CI_Upper_D_Border42 CI_Upper_D_Border43 CI_Upper_D_Border44 CI_Upper_D_Border45 CI_Upper_D_Border46 CI_Upper_D_Border47 CI_Upper_D_Border48 CI_Upper_D_Border49 CI_Upper_D_Border50 CI_Upper_D_Border51 CI_Upper_D_Border52 CI_Upper_D_Border53 CI_Upper_D_Border54 CI_Upper_D_Border55 CI_Upper_D_Border56 CI_Upper_D_Border57 CI_Upper_D_Border58 CI_Upper_D_Border59 CI_Upper_D_Border60 CI_Upper_D_Border61 CI_Upper_D_Border62 CI_Upper_D_Border63 CI_Upper_D_Border64 CI_Upper_D_Border65 CI_Upper_D_Border66 CI_Upper_D_Border67 CI_Upper_D_Border68 CI_Upper_D_Border69 CI_Upper_D_Border70 CI_Upper_D_Border71 CI_Upper_D_Border72 CI_Upper_D_Border73 CI_Upper_D_Border74 CI_Upper_D_Border75 CI_Upper_D_Border76 CI_Upper_D_Border77 CI_Upper_D_Border78 CI_Upper_D_Border79 CI_Upper_D_Border80 CI_Lower_D_Border20 CI_Lower_D_Border21 CI_Lower_D_Border22 CI_Lower_D_Border23 CI_Lower_D_Border24 CI_Lower_D_Border25 CI_Lower_D_Border26 CI_Lower_D_Border27 CI_Lower_D_Border28 CI_Lower_D_Border29 CI_Lower_D_Border30 CI_Lower_D_Border31 CI_Lower_D_Border32 CI_Lower_D_Border33 CI_Lower_D_Border34 CI_Lower_D_Border35 CI_Lower_D_Border36 CI_Lower_D_Border37 CI_Lower_D_Border38 CI_Lower_D_Border39 CI_Lower_D_Border40 CI_Lower_D_Border41 CI_Lower_D_Border42 CI_Lower_D_Border43 CI_Lower_D_Border44 CI_Lower_D_Border45 CI_Lower_D_Border46 CI_Lower_D_Border47 CI_Lower_D_Border48 CI_Lower_D_Border49 CI_Lower_D_Border50 CI_Lower_D_Border51 CI_Lower_D_Border52 CI_Lower_D_Border53 CI_Lower_D_Border54 CI_Lower_D_Border55 CI_Lower_D_Border56 CI_Lower_D_Border57 CI_Lower_D_Border58 CI_Lower_D_Border59 CI_Lower_D_Border60 CI_Lower_D_Border61 CI_Lower_D_Border62 CI_Lower_D_Border63 CI_Lower_D_Border64 CI_Lower_D_Border65 CI_Lower_D_Border66 CI_Lower_D_Border67 CI_Lower_D_Border68 CI_Lower_D_Border69 CI_Lower_D_Border70 CI_Lower_D_Border71 CI_Lower_D_Border72 CI_Lower_D_Border73 CI_Lower_D_Border74 CI_Lower_D_Border75 CI_Lower_D_Border76 CI_Lower_D_Border77 CI_Lower_D_Border78 CI_Lower_D_Border79 CI_Lower_D_Border80 SD_10_D_Border20 CI_Upper_10_D_Border20 CI_Lower_10_D_Border20 SD_10_D_Border21 CI_Upper_10_D_Border21 CI_Lower_10_D_Border21 SD_10_D_Border22 CI_Upper_10_D_Border22 CI_Lower_10_D_Border22 SD_10_D_Border23 CI_Upper_10_D_Border23 CI_Lower_10_D_Border23 SD_10_D_Border24 CI_Upper_10_D_Border24 CI_Lower_10_D_Border24 SD_10_D_Border25 CI_Upper_10_D_Border25 CI_Lower_10_D_Border25 SD_10_D_Border26 CI_Upper_10_D_Border26 CI_Lower_10_D_Border26 SD_10_D_Border27 CI_Upper_10_D_Border27 CI_Lower_10_D_Border27 SD_10_D_Border28 CI_Upper_10_D_Border28 CI_Lower_10_D_Border28 SD_10_D_Border29 CI_Upper_10_D_Border29 CI_Lower_10_D_Border29 SD_10_D_Border30 CI_Upper_10_D_Border30 CI_Lower_10_D_Border30 SD_10_D_Border31 CI_Upper_10_D_Border31 CI_Lower_10_D_Border31 SD_10_D_Border32 CI_Upper_10_D_Border32 CI_Lower_10_D_Border32 SD_10_D_Border33 CI_Upper_10_D_Border33 CI_Lower_10_D_Border33 SD_10_D_Border34 CI_Upper_10_D_Border34 CI_Lower_10_D_Border34 SD_10_D_Border35 CI_Upper_10_D_Border35 CI_Lower_10_D_Border35 SD_10_D_Border36 CI_Upper_10_D_Border36 CI_Lower_10_D_Border36 SD_10_D_Border37 CI_Upper_10_D_Border37 CI_Lower_10_D_Border37 SD_10_D_Border38 CI_Upper_10_D_Border38 CI_Lower_10_D_Border38 SD_10_D_Border39 CI_Upper_10_D_Border39 CI_Lower_10_D_Border39 SD_10_D_Border40 CI_Upper_10_D_Border40 CI_Lower_10_D_Border40 SD_10_D_Border41 CI_Upper_10_D_Border41 CI_Lower_10_D_Border41 SD_10_D_Border42 CI_Upper_10_D_Border42 CI_Lower_10_D_Border42 SD_10_D_Border43 CI_Upper_10_D_Border43 CI_Lower_10_D_Border43 SD_10_D_Border44 CI_Upper_10_D_Border44 CI_Lower_10_D_Border44 SD_10_D_Border45 CI_Upper_10_D_Border45 CI_Lower_10_D_Border45 SD_10_D_Border46 CI_Upper_10_D_Border46 CI_Lower_10_D_Border46 SD_10_D_Border47 CI_Upper_10_D_Border47 CI_Lower_10_D_Border47 SD_10_D_Border48 CI_Upper_10_D_Border48 CI_Lower_10_D_Border48 SD_10_D_Border49 CI_Upper_10_D_Border49 CI_Lower_10_D_Border49 SD_10_D_Border50 CI_Upper_10_D_Border50 CI_Lower_10_D_Border50 SD_10_D_Border51 CI_Upper_10_D_Border51 CI_Lower_10_D_Border51 SD_10_D_Border52 CI_Upper_10_D_Border52 CI_Lower_10_D_Border52 SD_10_D_Border53 CI_Upper_10_D_Border53 CI_Lower_10_D_Border53 SD_10_D_Border54 CI_Upper_10_D_Border54 CI_Lower_10_D_Border54 SD_10_D_Border55 CI_Upper_10_D_Border55 CI_Lower_10_D_Border55 SD_10_D_Border56 CI_Upper_10_D_Border56 CI_Lower_10_D_Border56 SD_10_D_Border57 CI_Upper_10_D_Border57 CI_Lower_10_D_Border57 SD_10_D_Border58 CI_Upper_10_D_Border58 CI_Lower_10_D_Border58 SD_10_D_Border59 CI_Upper_10_D_Border59 CI_Lower_10_D_Border59 SD_10_D_Border60 CI_Upper_10_D_Border60 CI_Lower_10_D_Border60 SD_10_D_Border61 CI_Upper_10_D_Border61 CI_Lower_10_D_Border61 SD_10_D_Border62 CI_Upper_10_D_Border62 CI_Lower_10_D_Border62 SD_10_D_Border63 CI_Upper_10_D_Border63 CI_Lower_10_D_Border63 SD_10_D_Border64 CI_Upper_10_D_Border64 CI_Lower_10_D_Border64 SD_10_D_Border65 CI_Upper_10_D_Border65 CI_Lower_10_D_Border65 SD_10_D_Border66 CI_Upper_10_D_Border66 CI_Lower_10_D_Border66 SD_10_D_Border67 CI_Upper_10_D_Border67 CI_Lower_10_D_Border67 SD_10_D_Border68 CI_Upper_10_D_Border68 CI_Lower_10_D_Border68 SD_10_D_Border69 CI_Upper_10_D_Border69 CI_Lower_10_D_Border69 SD_10_D_Border70 CI_Upper_10_D_Border70 CI_Lower_10_D_Border70 SD_10_D_Border71 CI_Upper_10_D_Border71 CI_Lower_10_D_Border71 SD_10_D_Border72 CI_Upper_10_D_Border72 CI_Lower_10_D_Border72 SD_10_D_Border73 CI_Upper_10_D_Border73 CI_Lower_10_D_Border73 SD_10_D_Border74 CI_Upper_10_D_Border74 CI_Lower_10_D_Border74 SD_10_D_Border75 CI_Upper_10_D_Border75 CI_Lower_10_D_Border75 SD_10_D_Border76 CI_Upper_10_D_Border76 CI_Lower_10_D_Border76 SD_10_D_Border77 CI_Upper_10_D_Border77 CI_Lower_10_D_Border77 SD_10_D_Border78 CI_Upper_10_D_Border78 CI_Lower_10_D_Border78 SD_10_D_Border79 CI_Upper_10_D_Border79 CI_Lower_10_D_Border79 SD_10_D_Border80 CI_Upper_10_D_Border80 CI_Lower_10_D_Border80


reshape long Beta_D_Border CI_Upper_D_Border CI_Lower_D_Border CI_Upper_10_D_Border CI_Lower_10_D_Border, i(N) j(band)

twoway (line Beta_D_Border band, lcolor(black) lpattern(solid)) ///
	(line CI_Upper_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Lower_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Upper_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)) ///
	(line CI_Lower_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)), ///
    ytitle("", size(small))  ylabel(2(.5)-1.5,  angle(horizontal))  ///
    xtitle(Distance from Border (km) ) xtitle(, size(small)) xlabel(20(10)80, labsize(vsmall))  ///
          yline(0, lcolor(gs10)) ///
      plotregion(lcolor(black)) ///
   legend(off) ///
        title(d. Job Approval of Traditional Authorities, size(medsmall)) ///
    scheme(s2mono) graphregion(fcolor(white)) 
 
 
************************************************************************************************
******************************** FIGURE 5 - ETHNICITY MECHANISM ********************************
************************************************************************************************

*a. Ethnic or national identity C85B
use AfroBarometerData.dta, clear
keep if REGION==2 | REGION==7 | REGION==9 | REGION==10 | REGION==12

foreach var of varlist D_Border20-D_Border80 {
    quietly reg C85B $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance Round if `var'==1, cluster(EANUMB_AB) robust 
	gen Beta_`var' = _b[anglophone]
	matrix c_`var' = e(V)
	gen Var_`var' = c_`var'[1,1]
} 

foreach var of varlist D_Border20-D_Border80 {
	gen SD_`var' = sqrt(Var_`var')
	gen CI_Upper_`var' = Beta_`var'+(SD_`var'*1.96)
	gen CI_Lower_`var' = Beta_`var'-(SD_`var'*1.96)
}


foreach var of varlist D_Border20-D_Border80 {
	gen SD_10_`var' = sqrt(Var_`var')
	gen CI_Upper_10_`var' = Beta_`var'+(SD_`var'*1.645)
	gen CI_Lower_10_`var' = Beta_`var'-(SD_`var'*1.645)
}

gen N = _n
drop if N !=1
keep N Beta_D_Border20 Beta_D_Border21 Beta_D_Border22 Beta_D_Border23 Beta_D_Border24 Beta_D_Border25 Beta_D_Border26 Beta_D_Border27 Beta_D_Border28 Beta_D_Border29 Beta_D_Border30 Beta_D_Border31 Beta_D_Border32 Beta_D_Border33 Beta_D_Border34 Beta_D_Border35 Beta_D_Border36 Beta_D_Border37 Beta_D_Border38 Beta_D_Border39 Beta_D_Border40 Beta_D_Border41 Beta_D_Border42 Beta_D_Border43 Beta_D_Border44 Beta_D_Border45 Beta_D_Border46 Beta_D_Border47 Beta_D_Border48 Beta_D_Border49 Beta_D_Border50 Beta_D_Border51 Beta_D_Border52 Beta_D_Border53 Beta_D_Border54 Beta_D_Border55 Beta_D_Border56 Beta_D_Border57 Beta_D_Border58 Beta_D_Border59 Beta_D_Border60 Beta_D_Border61 Beta_D_Border62 Beta_D_Border63 Beta_D_Border64 Beta_D_Border65 Beta_D_Border66 Beta_D_Border67 Beta_D_Border68 Beta_D_Border69 Beta_D_Border70 Beta_D_Border71 Beta_D_Border72 Beta_D_Border73 Beta_D_Border74 Beta_D_Border75 Beta_D_Border76 Beta_D_Border77 Beta_D_Border78 Beta_D_Border79 Beta_D_Border80 CI_Upper_D_Border20 CI_Upper_D_Border21 CI_Upper_D_Border22 CI_Upper_D_Border23 CI_Upper_D_Border24 CI_Upper_D_Border25 CI_Upper_D_Border26 CI_Upper_D_Border27 CI_Upper_D_Border28 CI_Upper_D_Border29 CI_Upper_D_Border30 CI_Upper_D_Border31 CI_Upper_D_Border32 CI_Upper_D_Border33 CI_Upper_D_Border34 CI_Upper_D_Border35 CI_Upper_D_Border36 CI_Upper_D_Border37 CI_Upper_D_Border38 CI_Upper_D_Border39 CI_Upper_D_Border40 CI_Upper_D_Border41 CI_Upper_D_Border42 CI_Upper_D_Border43 CI_Upper_D_Border44 CI_Upper_D_Border45 CI_Upper_D_Border46 CI_Upper_D_Border47 CI_Upper_D_Border48 CI_Upper_D_Border49 CI_Upper_D_Border50 CI_Upper_D_Border51 CI_Upper_D_Border52 CI_Upper_D_Border53 CI_Upper_D_Border54 CI_Upper_D_Border55 CI_Upper_D_Border56 CI_Upper_D_Border57 CI_Upper_D_Border58 CI_Upper_D_Border59 CI_Upper_D_Border60 CI_Upper_D_Border61 CI_Upper_D_Border62 CI_Upper_D_Border63 CI_Upper_D_Border64 CI_Upper_D_Border65 CI_Upper_D_Border66 CI_Upper_D_Border67 CI_Upper_D_Border68 CI_Upper_D_Border69 CI_Upper_D_Border70 CI_Upper_D_Border71 CI_Upper_D_Border72 CI_Upper_D_Border73 CI_Upper_D_Border74 CI_Upper_D_Border75 CI_Upper_D_Border76 CI_Upper_D_Border77 CI_Upper_D_Border78 CI_Upper_D_Border79 CI_Upper_D_Border80 CI_Lower_D_Border20 CI_Lower_D_Border21 CI_Lower_D_Border22 CI_Lower_D_Border23 CI_Lower_D_Border24 CI_Lower_D_Border25 CI_Lower_D_Border26 CI_Lower_D_Border27 CI_Lower_D_Border28 CI_Lower_D_Border29 CI_Lower_D_Border30 CI_Lower_D_Border31 CI_Lower_D_Border32 CI_Lower_D_Border33 CI_Lower_D_Border34 CI_Lower_D_Border35 CI_Lower_D_Border36 CI_Lower_D_Border37 CI_Lower_D_Border38 CI_Lower_D_Border39 CI_Lower_D_Border40 CI_Lower_D_Border41 CI_Lower_D_Border42 CI_Lower_D_Border43 CI_Lower_D_Border44 CI_Lower_D_Border45 CI_Lower_D_Border46 CI_Lower_D_Border47 CI_Lower_D_Border48 CI_Lower_D_Border49 CI_Lower_D_Border50 CI_Lower_D_Border51 CI_Lower_D_Border52 CI_Lower_D_Border53 CI_Lower_D_Border54 CI_Lower_D_Border55 CI_Lower_D_Border56 CI_Lower_D_Border57 CI_Lower_D_Border58 CI_Lower_D_Border59 CI_Lower_D_Border60 CI_Lower_D_Border61 CI_Lower_D_Border62 CI_Lower_D_Border63 CI_Lower_D_Border64 CI_Lower_D_Border65 CI_Lower_D_Border66 CI_Lower_D_Border67 CI_Lower_D_Border68 CI_Lower_D_Border69 CI_Lower_D_Border70 CI_Lower_D_Border71 CI_Lower_D_Border72 CI_Lower_D_Border73 CI_Lower_D_Border74 CI_Lower_D_Border75 CI_Lower_D_Border76 CI_Lower_D_Border77 CI_Lower_D_Border78 CI_Lower_D_Border79 CI_Lower_D_Border80 SD_10_D_Border20 CI_Upper_10_D_Border20 CI_Lower_10_D_Border20 SD_10_D_Border21 CI_Upper_10_D_Border21 CI_Lower_10_D_Border21 SD_10_D_Border22 CI_Upper_10_D_Border22 CI_Lower_10_D_Border22 SD_10_D_Border23 CI_Upper_10_D_Border23 CI_Lower_10_D_Border23 SD_10_D_Border24 CI_Upper_10_D_Border24 CI_Lower_10_D_Border24 SD_10_D_Border25 CI_Upper_10_D_Border25 CI_Lower_10_D_Border25 SD_10_D_Border26 CI_Upper_10_D_Border26 CI_Lower_10_D_Border26 SD_10_D_Border27 CI_Upper_10_D_Border27 CI_Lower_10_D_Border27 SD_10_D_Border28 CI_Upper_10_D_Border28 CI_Lower_10_D_Border28 SD_10_D_Border29 CI_Upper_10_D_Border29 CI_Lower_10_D_Border29 SD_10_D_Border30 CI_Upper_10_D_Border30 CI_Lower_10_D_Border30 SD_10_D_Border31 CI_Upper_10_D_Border31 CI_Lower_10_D_Border31 SD_10_D_Border32 CI_Upper_10_D_Border32 CI_Lower_10_D_Border32 SD_10_D_Border33 CI_Upper_10_D_Border33 CI_Lower_10_D_Border33 SD_10_D_Border34 CI_Upper_10_D_Border34 CI_Lower_10_D_Border34 SD_10_D_Border35 CI_Upper_10_D_Border35 CI_Lower_10_D_Border35 SD_10_D_Border36 CI_Upper_10_D_Border36 CI_Lower_10_D_Border36 SD_10_D_Border37 CI_Upper_10_D_Border37 CI_Lower_10_D_Border37 SD_10_D_Border38 CI_Upper_10_D_Border38 CI_Lower_10_D_Border38 SD_10_D_Border39 CI_Upper_10_D_Border39 CI_Lower_10_D_Border39 SD_10_D_Border40 CI_Upper_10_D_Border40 CI_Lower_10_D_Border40 SD_10_D_Border41 CI_Upper_10_D_Border41 CI_Lower_10_D_Border41 SD_10_D_Border42 CI_Upper_10_D_Border42 CI_Lower_10_D_Border42 SD_10_D_Border43 CI_Upper_10_D_Border43 CI_Lower_10_D_Border43 SD_10_D_Border44 CI_Upper_10_D_Border44 CI_Lower_10_D_Border44 SD_10_D_Border45 CI_Upper_10_D_Border45 CI_Lower_10_D_Border45 SD_10_D_Border46 CI_Upper_10_D_Border46 CI_Lower_10_D_Border46 SD_10_D_Border47 CI_Upper_10_D_Border47 CI_Lower_10_D_Border47 SD_10_D_Border48 CI_Upper_10_D_Border48 CI_Lower_10_D_Border48 SD_10_D_Border49 CI_Upper_10_D_Border49 CI_Lower_10_D_Border49 SD_10_D_Border50 CI_Upper_10_D_Border50 CI_Lower_10_D_Border50 SD_10_D_Border51 CI_Upper_10_D_Border51 CI_Lower_10_D_Border51 SD_10_D_Border52 CI_Upper_10_D_Border52 CI_Lower_10_D_Border52 SD_10_D_Border53 CI_Upper_10_D_Border53 CI_Lower_10_D_Border53 SD_10_D_Border54 CI_Upper_10_D_Border54 CI_Lower_10_D_Border54 SD_10_D_Border55 CI_Upper_10_D_Border55 CI_Lower_10_D_Border55 SD_10_D_Border56 CI_Upper_10_D_Border56 CI_Lower_10_D_Border56 SD_10_D_Border57 CI_Upper_10_D_Border57 CI_Lower_10_D_Border57 SD_10_D_Border58 CI_Upper_10_D_Border58 CI_Lower_10_D_Border58 SD_10_D_Border59 CI_Upper_10_D_Border59 CI_Lower_10_D_Border59 SD_10_D_Border60 CI_Upper_10_D_Border60 CI_Lower_10_D_Border60 SD_10_D_Border61 CI_Upper_10_D_Border61 CI_Lower_10_D_Border61 SD_10_D_Border62 CI_Upper_10_D_Border62 CI_Lower_10_D_Border62 SD_10_D_Border63 CI_Upper_10_D_Border63 CI_Lower_10_D_Border63 SD_10_D_Border64 CI_Upper_10_D_Border64 CI_Lower_10_D_Border64 SD_10_D_Border65 CI_Upper_10_D_Border65 CI_Lower_10_D_Border65 SD_10_D_Border66 CI_Upper_10_D_Border66 CI_Lower_10_D_Border66 SD_10_D_Border67 CI_Upper_10_D_Border67 CI_Lower_10_D_Border67 SD_10_D_Border68 CI_Upper_10_D_Border68 CI_Lower_10_D_Border68 SD_10_D_Border69 CI_Upper_10_D_Border69 CI_Lower_10_D_Border69 SD_10_D_Border70 CI_Upper_10_D_Border70 CI_Lower_10_D_Border70 SD_10_D_Border71 CI_Upper_10_D_Border71 CI_Lower_10_D_Border71 SD_10_D_Border72 CI_Upper_10_D_Border72 CI_Lower_10_D_Border72 SD_10_D_Border73 CI_Upper_10_D_Border73 CI_Lower_10_D_Border73 SD_10_D_Border74 CI_Upper_10_D_Border74 CI_Lower_10_D_Border74 SD_10_D_Border75 CI_Upper_10_D_Border75 CI_Lower_10_D_Border75 SD_10_D_Border76 CI_Upper_10_D_Border76 CI_Lower_10_D_Border76 SD_10_D_Border77 CI_Upper_10_D_Border77 CI_Lower_10_D_Border77 SD_10_D_Border78 CI_Upper_10_D_Border78 CI_Lower_10_D_Border78 SD_10_D_Border79 CI_Upper_10_D_Border79 CI_Lower_10_D_Border79 SD_10_D_Border80 CI_Upper_10_D_Border80 CI_Lower_10_D_Border80


reshape long Beta_D_Border CI_Upper_D_Border CI_Lower_D_Border CI_Upper_10_D_Border CI_Lower_10_D_Border, i(N) j(band)

twoway (line Beta_D_Border band, lcolor(black) lpattern(solid)) ///
	(line CI_Upper_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Lower_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Upper_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)) ///
	(line CI_Lower_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)), ///
    ytitle(Estimated Effect Anglophone, size(small))  ylabel(2(.5)-1.5,  angle(horizontal)) ///
    xtitle("") xtitle(, size(small)) xlabel(20(10)80, labsize(vsmall))  ///
         yline(0, lcolor(gs10)) ///
      plotregion(lcolor(black)) ///
    legend(off) ///
        title(a. Ethnic ID Stronger than National ID, size(medsmall)) ///
    scheme(s2mono) graphregion(fcolor(white)) 


*b. To what extent does this network give access to jobs in the admin: a particular ethnic group C79C_CAMC
use AfroBarometerData.dta, clear
keep if REGION==2 | REGION==7 | REGION==9 | REGION==10 | REGION==12

foreach var of varlist D_Border20-D_Border80 {
    quietly reg C79C_CAMC $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance  Round if `var'==1, cluster(EANUMB_AB) robust 
	gen Beta_`var' = _b[anglophone]
	matrix c_`var' = e(V)
	gen Var_`var' = c_`var'[1,1]
} 

foreach var of varlist D_Border20-D_Border80 {
	gen SD_`var' = sqrt(Var_`var')
	gen CI_Upper_`var' = Beta_`var'+(SD_`var'*1.96)
	gen CI_Lower_`var' = Beta_`var'-(SD_`var'*1.96)
}


foreach var of varlist D_Border20-D_Border80 {
	gen SD_10_`var' = sqrt(Var_`var')
	gen CI_Upper_10_`var' = Beta_`var'+(SD_`var'*1.645)
	gen CI_Lower_10_`var' = Beta_`var'-(SD_`var'*1.645)
}

gen N = _n
drop if N !=1
keep N Beta_D_Border20 Beta_D_Border21 Beta_D_Border22 Beta_D_Border23 Beta_D_Border24 Beta_D_Border25 Beta_D_Border26 Beta_D_Border27 Beta_D_Border28 Beta_D_Border29 Beta_D_Border30 Beta_D_Border31 Beta_D_Border32 Beta_D_Border33 Beta_D_Border34 Beta_D_Border35 Beta_D_Border36 Beta_D_Border37 Beta_D_Border38 Beta_D_Border39 Beta_D_Border40 Beta_D_Border41 Beta_D_Border42 Beta_D_Border43 Beta_D_Border44 Beta_D_Border45 Beta_D_Border46 Beta_D_Border47 Beta_D_Border48 Beta_D_Border49 Beta_D_Border50 Beta_D_Border51 Beta_D_Border52 Beta_D_Border53 Beta_D_Border54 Beta_D_Border55 Beta_D_Border56 Beta_D_Border57 Beta_D_Border58 Beta_D_Border59 Beta_D_Border60 Beta_D_Border61 Beta_D_Border62 Beta_D_Border63 Beta_D_Border64 Beta_D_Border65 Beta_D_Border66 Beta_D_Border67 Beta_D_Border68 Beta_D_Border69 Beta_D_Border70 Beta_D_Border71 Beta_D_Border72 Beta_D_Border73 Beta_D_Border74 Beta_D_Border75 Beta_D_Border76 Beta_D_Border77 Beta_D_Border78 Beta_D_Border79 Beta_D_Border80 CI_Upper_D_Border20 CI_Upper_D_Border21 CI_Upper_D_Border22 CI_Upper_D_Border23 CI_Upper_D_Border24 CI_Upper_D_Border25 CI_Upper_D_Border26 CI_Upper_D_Border27 CI_Upper_D_Border28 CI_Upper_D_Border29 CI_Upper_D_Border30 CI_Upper_D_Border31 CI_Upper_D_Border32 CI_Upper_D_Border33 CI_Upper_D_Border34 CI_Upper_D_Border35 CI_Upper_D_Border36 CI_Upper_D_Border37 CI_Upper_D_Border38 CI_Upper_D_Border39 CI_Upper_D_Border40 CI_Upper_D_Border41 CI_Upper_D_Border42 CI_Upper_D_Border43 CI_Upper_D_Border44 CI_Upper_D_Border45 CI_Upper_D_Border46 CI_Upper_D_Border47 CI_Upper_D_Border48 CI_Upper_D_Border49 CI_Upper_D_Border50 CI_Upper_D_Border51 CI_Upper_D_Border52 CI_Upper_D_Border53 CI_Upper_D_Border54 CI_Upper_D_Border55 CI_Upper_D_Border56 CI_Upper_D_Border57 CI_Upper_D_Border58 CI_Upper_D_Border59 CI_Upper_D_Border60 CI_Upper_D_Border61 CI_Upper_D_Border62 CI_Upper_D_Border63 CI_Upper_D_Border64 CI_Upper_D_Border65 CI_Upper_D_Border66 CI_Upper_D_Border67 CI_Upper_D_Border68 CI_Upper_D_Border69 CI_Upper_D_Border70 CI_Upper_D_Border71 CI_Upper_D_Border72 CI_Upper_D_Border73 CI_Upper_D_Border74 CI_Upper_D_Border75 CI_Upper_D_Border76 CI_Upper_D_Border77 CI_Upper_D_Border78 CI_Upper_D_Border79 CI_Upper_D_Border80 CI_Lower_D_Border20 CI_Lower_D_Border21 CI_Lower_D_Border22 CI_Lower_D_Border23 CI_Lower_D_Border24 CI_Lower_D_Border25 CI_Lower_D_Border26 CI_Lower_D_Border27 CI_Lower_D_Border28 CI_Lower_D_Border29 CI_Lower_D_Border30 CI_Lower_D_Border31 CI_Lower_D_Border32 CI_Lower_D_Border33 CI_Lower_D_Border34 CI_Lower_D_Border35 CI_Lower_D_Border36 CI_Lower_D_Border37 CI_Lower_D_Border38 CI_Lower_D_Border39 CI_Lower_D_Border40 CI_Lower_D_Border41 CI_Lower_D_Border42 CI_Lower_D_Border43 CI_Lower_D_Border44 CI_Lower_D_Border45 CI_Lower_D_Border46 CI_Lower_D_Border47 CI_Lower_D_Border48 CI_Lower_D_Border49 CI_Lower_D_Border50 CI_Lower_D_Border51 CI_Lower_D_Border52 CI_Lower_D_Border53 CI_Lower_D_Border54 CI_Lower_D_Border55 CI_Lower_D_Border56 CI_Lower_D_Border57 CI_Lower_D_Border58 CI_Lower_D_Border59 CI_Lower_D_Border60 CI_Lower_D_Border61 CI_Lower_D_Border62 CI_Lower_D_Border63 CI_Lower_D_Border64 CI_Lower_D_Border65 CI_Lower_D_Border66 CI_Lower_D_Border67 CI_Lower_D_Border68 CI_Lower_D_Border69 CI_Lower_D_Border70 CI_Lower_D_Border71 CI_Lower_D_Border72 CI_Lower_D_Border73 CI_Lower_D_Border74 CI_Lower_D_Border75 CI_Lower_D_Border76 CI_Lower_D_Border77 CI_Lower_D_Border78 CI_Lower_D_Border79 CI_Lower_D_Border80 SD_10_D_Border20 CI_Upper_10_D_Border20 CI_Lower_10_D_Border20 SD_10_D_Border21 CI_Upper_10_D_Border21 CI_Lower_10_D_Border21 SD_10_D_Border22 CI_Upper_10_D_Border22 CI_Lower_10_D_Border22 SD_10_D_Border23 CI_Upper_10_D_Border23 CI_Lower_10_D_Border23 SD_10_D_Border24 CI_Upper_10_D_Border24 CI_Lower_10_D_Border24 SD_10_D_Border25 CI_Upper_10_D_Border25 CI_Lower_10_D_Border25 SD_10_D_Border26 CI_Upper_10_D_Border26 CI_Lower_10_D_Border26 SD_10_D_Border27 CI_Upper_10_D_Border27 CI_Lower_10_D_Border27 SD_10_D_Border28 CI_Upper_10_D_Border28 CI_Lower_10_D_Border28 SD_10_D_Border29 CI_Upper_10_D_Border29 CI_Lower_10_D_Border29 SD_10_D_Border30 CI_Upper_10_D_Border30 CI_Lower_10_D_Border30 SD_10_D_Border31 CI_Upper_10_D_Border31 CI_Lower_10_D_Border31 SD_10_D_Border32 CI_Upper_10_D_Border32 CI_Lower_10_D_Border32 SD_10_D_Border33 CI_Upper_10_D_Border33 CI_Lower_10_D_Border33 SD_10_D_Border34 CI_Upper_10_D_Border34 CI_Lower_10_D_Border34 SD_10_D_Border35 CI_Upper_10_D_Border35 CI_Lower_10_D_Border35 SD_10_D_Border36 CI_Upper_10_D_Border36 CI_Lower_10_D_Border36 SD_10_D_Border37 CI_Upper_10_D_Border37 CI_Lower_10_D_Border37 SD_10_D_Border38 CI_Upper_10_D_Border38 CI_Lower_10_D_Border38 SD_10_D_Border39 CI_Upper_10_D_Border39 CI_Lower_10_D_Border39 SD_10_D_Border40 CI_Upper_10_D_Border40 CI_Lower_10_D_Border40 SD_10_D_Border41 CI_Upper_10_D_Border41 CI_Lower_10_D_Border41 SD_10_D_Border42 CI_Upper_10_D_Border42 CI_Lower_10_D_Border42 SD_10_D_Border43 CI_Upper_10_D_Border43 CI_Lower_10_D_Border43 SD_10_D_Border44 CI_Upper_10_D_Border44 CI_Lower_10_D_Border44 SD_10_D_Border45 CI_Upper_10_D_Border45 CI_Lower_10_D_Border45 SD_10_D_Border46 CI_Upper_10_D_Border46 CI_Lower_10_D_Border46 SD_10_D_Border47 CI_Upper_10_D_Border47 CI_Lower_10_D_Border47 SD_10_D_Border48 CI_Upper_10_D_Border48 CI_Lower_10_D_Border48 SD_10_D_Border49 CI_Upper_10_D_Border49 CI_Lower_10_D_Border49 SD_10_D_Border50 CI_Upper_10_D_Border50 CI_Lower_10_D_Border50 SD_10_D_Border51 CI_Upper_10_D_Border51 CI_Lower_10_D_Border51 SD_10_D_Border52 CI_Upper_10_D_Border52 CI_Lower_10_D_Border52 SD_10_D_Border53 CI_Upper_10_D_Border53 CI_Lower_10_D_Border53 SD_10_D_Border54 CI_Upper_10_D_Border54 CI_Lower_10_D_Border54 SD_10_D_Border55 CI_Upper_10_D_Border55 CI_Lower_10_D_Border55 SD_10_D_Border56 CI_Upper_10_D_Border56 CI_Lower_10_D_Border56 SD_10_D_Border57 CI_Upper_10_D_Border57 CI_Lower_10_D_Border57 SD_10_D_Border58 CI_Upper_10_D_Border58 CI_Lower_10_D_Border58 SD_10_D_Border59 CI_Upper_10_D_Border59 CI_Lower_10_D_Border59 SD_10_D_Border60 CI_Upper_10_D_Border60 CI_Lower_10_D_Border60 SD_10_D_Border61 CI_Upper_10_D_Border61 CI_Lower_10_D_Border61 SD_10_D_Border62 CI_Upper_10_D_Border62 CI_Lower_10_D_Border62 SD_10_D_Border63 CI_Upper_10_D_Border63 CI_Lower_10_D_Border63 SD_10_D_Border64 CI_Upper_10_D_Border64 CI_Lower_10_D_Border64 SD_10_D_Border65 CI_Upper_10_D_Border65 CI_Lower_10_D_Border65 SD_10_D_Border66 CI_Upper_10_D_Border66 CI_Lower_10_D_Border66 SD_10_D_Border67 CI_Upper_10_D_Border67 CI_Lower_10_D_Border67 SD_10_D_Border68 CI_Upper_10_D_Border68 CI_Lower_10_D_Border68 SD_10_D_Border69 CI_Upper_10_D_Border69 CI_Lower_10_D_Border69 SD_10_D_Border70 CI_Upper_10_D_Border70 CI_Lower_10_D_Border70 SD_10_D_Border71 CI_Upper_10_D_Border71 CI_Lower_10_D_Border71 SD_10_D_Border72 CI_Upper_10_D_Border72 CI_Lower_10_D_Border72 SD_10_D_Border73 CI_Upper_10_D_Border73 CI_Lower_10_D_Border73 SD_10_D_Border74 CI_Upper_10_D_Border74 CI_Lower_10_D_Border74 SD_10_D_Border75 CI_Upper_10_D_Border75 CI_Lower_10_D_Border75 SD_10_D_Border76 CI_Upper_10_D_Border76 CI_Lower_10_D_Border76 SD_10_D_Border77 CI_Upper_10_D_Border77 CI_Lower_10_D_Border77 SD_10_D_Border78 CI_Upper_10_D_Border78 CI_Lower_10_D_Border78 SD_10_D_Border79 CI_Upper_10_D_Border79 CI_Lower_10_D_Border79 SD_10_D_Border80 CI_Upper_10_D_Border80 CI_Lower_10_D_Border80

reshape long Beta_D_Border CI_Upper_D_Border CI_Lower_D_Border CI_Upper_10_D_Border CI_Lower_10_D_Border, i(N) j(band)

twoway (line Beta_D_Border band, lcolor(black) lpattern(solid)) ///
	(line CI_Upper_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Lower_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Upper_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)) ///
	(line CI_Lower_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)), ///
    ytitle(Estimated Effect Anglophone, size(small))  ylabel(2(.5)-1.5, angle(horizontal)) ///
    xtitle("") xtitle(, size(small)) xlabel(20(10)80, labsize(vsmall))  ///
          yline(0, lcolor(gs10)) ///
      plotregion(lcolor(black)) ///
   legend(off) ///
        title(b. Ethnic Networks Provide Access to Gov. Jobs, size(medsmall)) ///
    scheme(s2mono) graphregion(fcolor(white)) 
  

*c. Leaders should help own community vs. treat all equally (R5 only) Q18_R5
use AfroBarometerData.dta, clear
keep if REGION==2 | REGION==7 | REGION==9 | REGION==10 | REGION==12

foreach var of varlist D_Border20-D_Border80 {
    quietly reg Q18_R5 $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance  Round if `var'==1, cluster(EANUMB_AB) robust 
	gen Beta_`var' = _b[anglophone]
	matrix c_`var' = e(V)
	gen Var_`var' = c_`var'[1,1]
} 

foreach var of varlist D_Border20-D_Border80 {
	gen SD_`var' = sqrt(Var_`var')
	gen CI_Upper_`var' = Beta_`var'+(SD_`var'*1.96)
	gen CI_Lower_`var' = Beta_`var'-(SD_`var'*1.96)
}

foreach var of varlist D_Border20-D_Border80 {
	gen SD_10_`var' = sqrt(Var_`var')
	gen CI_Upper_10_`var' = Beta_`var'+(SD_`var'*1.645)
	gen CI_Lower_10_`var' = Beta_`var'-(SD_`var'*1.645)
}

gen N = _n
drop if N !=1
keep N Beta_D_Border20 Beta_D_Border21 Beta_D_Border22 Beta_D_Border23 Beta_D_Border24 Beta_D_Border25 Beta_D_Border26 Beta_D_Border27 Beta_D_Border28 Beta_D_Border29 Beta_D_Border30 Beta_D_Border31 Beta_D_Border32 Beta_D_Border33 Beta_D_Border34 Beta_D_Border35 Beta_D_Border36 Beta_D_Border37 Beta_D_Border38 Beta_D_Border39 Beta_D_Border40 Beta_D_Border41 Beta_D_Border42 Beta_D_Border43 Beta_D_Border44 Beta_D_Border45 Beta_D_Border46 Beta_D_Border47 Beta_D_Border48 Beta_D_Border49 Beta_D_Border50 Beta_D_Border51 Beta_D_Border52 Beta_D_Border53 Beta_D_Border54 Beta_D_Border55 Beta_D_Border56 Beta_D_Border57 Beta_D_Border58 Beta_D_Border59 Beta_D_Border60 Beta_D_Border61 Beta_D_Border62 Beta_D_Border63 Beta_D_Border64 Beta_D_Border65 Beta_D_Border66 Beta_D_Border67 Beta_D_Border68 Beta_D_Border69 Beta_D_Border70 Beta_D_Border71 Beta_D_Border72 Beta_D_Border73 Beta_D_Border74 Beta_D_Border75 Beta_D_Border76 Beta_D_Border77 Beta_D_Border78 Beta_D_Border79 Beta_D_Border80 CI_Upper_D_Border20 CI_Upper_D_Border21 CI_Upper_D_Border22 CI_Upper_D_Border23 CI_Upper_D_Border24 CI_Upper_D_Border25 CI_Upper_D_Border26 CI_Upper_D_Border27 CI_Upper_D_Border28 CI_Upper_D_Border29 CI_Upper_D_Border30 CI_Upper_D_Border31 CI_Upper_D_Border32 CI_Upper_D_Border33 CI_Upper_D_Border34 CI_Upper_D_Border35 CI_Upper_D_Border36 CI_Upper_D_Border37 CI_Upper_D_Border38 CI_Upper_D_Border39 CI_Upper_D_Border40 CI_Upper_D_Border41 CI_Upper_D_Border42 CI_Upper_D_Border43 CI_Upper_D_Border44 CI_Upper_D_Border45 CI_Upper_D_Border46 CI_Upper_D_Border47 CI_Upper_D_Border48 CI_Upper_D_Border49 CI_Upper_D_Border50 CI_Upper_D_Border51 CI_Upper_D_Border52 CI_Upper_D_Border53 CI_Upper_D_Border54 CI_Upper_D_Border55 CI_Upper_D_Border56 CI_Upper_D_Border57 CI_Upper_D_Border58 CI_Upper_D_Border59 CI_Upper_D_Border60 CI_Upper_D_Border61 CI_Upper_D_Border62 CI_Upper_D_Border63 CI_Upper_D_Border64 CI_Upper_D_Border65 CI_Upper_D_Border66 CI_Upper_D_Border67 CI_Upper_D_Border68 CI_Upper_D_Border69 CI_Upper_D_Border70 CI_Upper_D_Border71 CI_Upper_D_Border72 CI_Upper_D_Border73 CI_Upper_D_Border74 CI_Upper_D_Border75 CI_Upper_D_Border76 CI_Upper_D_Border77 CI_Upper_D_Border78 CI_Upper_D_Border79 CI_Upper_D_Border80 CI_Lower_D_Border20 CI_Lower_D_Border21 CI_Lower_D_Border22 CI_Lower_D_Border23 CI_Lower_D_Border24 CI_Lower_D_Border25 CI_Lower_D_Border26 CI_Lower_D_Border27 CI_Lower_D_Border28 CI_Lower_D_Border29 CI_Lower_D_Border30 CI_Lower_D_Border31 CI_Lower_D_Border32 CI_Lower_D_Border33 CI_Lower_D_Border34 CI_Lower_D_Border35 CI_Lower_D_Border36 CI_Lower_D_Border37 CI_Lower_D_Border38 CI_Lower_D_Border39 CI_Lower_D_Border40 CI_Lower_D_Border41 CI_Lower_D_Border42 CI_Lower_D_Border43 CI_Lower_D_Border44 CI_Lower_D_Border45 CI_Lower_D_Border46 CI_Lower_D_Border47 CI_Lower_D_Border48 CI_Lower_D_Border49 CI_Lower_D_Border50 CI_Lower_D_Border51 CI_Lower_D_Border52 CI_Lower_D_Border53 CI_Lower_D_Border54 CI_Lower_D_Border55 CI_Lower_D_Border56 CI_Lower_D_Border57 CI_Lower_D_Border58 CI_Lower_D_Border59 CI_Lower_D_Border60 CI_Lower_D_Border61 CI_Lower_D_Border62 CI_Lower_D_Border63 CI_Lower_D_Border64 CI_Lower_D_Border65 CI_Lower_D_Border66 CI_Lower_D_Border67 CI_Lower_D_Border68 CI_Lower_D_Border69 CI_Lower_D_Border70 CI_Lower_D_Border71 CI_Lower_D_Border72 CI_Lower_D_Border73 CI_Lower_D_Border74 CI_Lower_D_Border75 CI_Lower_D_Border76 CI_Lower_D_Border77 CI_Lower_D_Border78 CI_Lower_D_Border79 CI_Lower_D_Border80 SD_10_D_Border20 CI_Upper_10_D_Border20 CI_Lower_10_D_Border20 SD_10_D_Border21 CI_Upper_10_D_Border21 CI_Lower_10_D_Border21 SD_10_D_Border22 CI_Upper_10_D_Border22 CI_Lower_10_D_Border22 SD_10_D_Border23 CI_Upper_10_D_Border23 CI_Lower_10_D_Border23 SD_10_D_Border24 CI_Upper_10_D_Border24 CI_Lower_10_D_Border24 SD_10_D_Border25 CI_Upper_10_D_Border25 CI_Lower_10_D_Border25 SD_10_D_Border26 CI_Upper_10_D_Border26 CI_Lower_10_D_Border26 SD_10_D_Border27 CI_Upper_10_D_Border27 CI_Lower_10_D_Border27 SD_10_D_Border28 CI_Upper_10_D_Border28 CI_Lower_10_D_Border28 SD_10_D_Border29 CI_Upper_10_D_Border29 CI_Lower_10_D_Border29 SD_10_D_Border30 CI_Upper_10_D_Border30 CI_Lower_10_D_Border30 SD_10_D_Border31 CI_Upper_10_D_Border31 CI_Lower_10_D_Border31 SD_10_D_Border32 CI_Upper_10_D_Border32 CI_Lower_10_D_Border32 SD_10_D_Border33 CI_Upper_10_D_Border33 CI_Lower_10_D_Border33 SD_10_D_Border34 CI_Upper_10_D_Border34 CI_Lower_10_D_Border34 SD_10_D_Border35 CI_Upper_10_D_Border35 CI_Lower_10_D_Border35 SD_10_D_Border36 CI_Upper_10_D_Border36 CI_Lower_10_D_Border36 SD_10_D_Border37 CI_Upper_10_D_Border37 CI_Lower_10_D_Border37 SD_10_D_Border38 CI_Upper_10_D_Border38 CI_Lower_10_D_Border38 SD_10_D_Border39 CI_Upper_10_D_Border39 CI_Lower_10_D_Border39 SD_10_D_Border40 CI_Upper_10_D_Border40 CI_Lower_10_D_Border40 SD_10_D_Border41 CI_Upper_10_D_Border41 CI_Lower_10_D_Border41 SD_10_D_Border42 CI_Upper_10_D_Border42 CI_Lower_10_D_Border42 SD_10_D_Border43 CI_Upper_10_D_Border43 CI_Lower_10_D_Border43 SD_10_D_Border44 CI_Upper_10_D_Border44 CI_Lower_10_D_Border44 SD_10_D_Border45 CI_Upper_10_D_Border45 CI_Lower_10_D_Border45 SD_10_D_Border46 CI_Upper_10_D_Border46 CI_Lower_10_D_Border46 SD_10_D_Border47 CI_Upper_10_D_Border47 CI_Lower_10_D_Border47 SD_10_D_Border48 CI_Upper_10_D_Border48 CI_Lower_10_D_Border48 SD_10_D_Border49 CI_Upper_10_D_Border49 CI_Lower_10_D_Border49 SD_10_D_Border50 CI_Upper_10_D_Border50 CI_Lower_10_D_Border50 SD_10_D_Border51 CI_Upper_10_D_Border51 CI_Lower_10_D_Border51 SD_10_D_Border52 CI_Upper_10_D_Border52 CI_Lower_10_D_Border52 SD_10_D_Border53 CI_Upper_10_D_Border53 CI_Lower_10_D_Border53 SD_10_D_Border54 CI_Upper_10_D_Border54 CI_Lower_10_D_Border54 SD_10_D_Border55 CI_Upper_10_D_Border55 CI_Lower_10_D_Border55 SD_10_D_Border56 CI_Upper_10_D_Border56 CI_Lower_10_D_Border56 SD_10_D_Border57 CI_Upper_10_D_Border57 CI_Lower_10_D_Border57 SD_10_D_Border58 CI_Upper_10_D_Border58 CI_Lower_10_D_Border58 SD_10_D_Border59 CI_Upper_10_D_Border59 CI_Lower_10_D_Border59 SD_10_D_Border60 CI_Upper_10_D_Border60 CI_Lower_10_D_Border60 SD_10_D_Border61 CI_Upper_10_D_Border61 CI_Lower_10_D_Border61 SD_10_D_Border62 CI_Upper_10_D_Border62 CI_Lower_10_D_Border62 SD_10_D_Border63 CI_Upper_10_D_Border63 CI_Lower_10_D_Border63 SD_10_D_Border64 CI_Upper_10_D_Border64 CI_Lower_10_D_Border64 SD_10_D_Border65 CI_Upper_10_D_Border65 CI_Lower_10_D_Border65 SD_10_D_Border66 CI_Upper_10_D_Border66 CI_Lower_10_D_Border66 SD_10_D_Border67 CI_Upper_10_D_Border67 CI_Lower_10_D_Border67 SD_10_D_Border68 CI_Upper_10_D_Border68 CI_Lower_10_D_Border68 SD_10_D_Border69 CI_Upper_10_D_Border69 CI_Lower_10_D_Border69 SD_10_D_Border70 CI_Upper_10_D_Border70 CI_Lower_10_D_Border70 SD_10_D_Border71 CI_Upper_10_D_Border71 CI_Lower_10_D_Border71 SD_10_D_Border72 CI_Upper_10_D_Border72 CI_Lower_10_D_Border72 SD_10_D_Border73 CI_Upper_10_D_Border73 CI_Lower_10_D_Border73 SD_10_D_Border74 CI_Upper_10_D_Border74 CI_Lower_10_D_Border74 SD_10_D_Border75 CI_Upper_10_D_Border75 CI_Lower_10_D_Border75 SD_10_D_Border76 CI_Upper_10_D_Border76 CI_Lower_10_D_Border76 SD_10_D_Border77 CI_Upper_10_D_Border77 CI_Lower_10_D_Border77 SD_10_D_Border78 CI_Upper_10_D_Border78 CI_Lower_10_D_Border78 SD_10_D_Border79 CI_Upper_10_D_Border79 CI_Lower_10_D_Border79 SD_10_D_Border80 CI_Upper_10_D_Border80 CI_Lower_10_D_Border80


reshape long Beta_D_Border CI_Upper_D_Border CI_Lower_D_Border CI_Upper_10_D_Border CI_Lower_10_D_Border, i(N) j(band)

twoway (line Beta_D_Border band, lcolor(black) lpattern(solid)) ///
	(line CI_Upper_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Lower_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Upper_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)) ///
	(line CI_Lower_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)), ///
    ytitle(Estimated Effect Anglophone, size(small))  ylabel(2(.5)-1.5,  angle(horizontal)) ///
    xtitle(Distance from Border (km) ) xtitle(, size(small)) xlabel(20(10)80, labsize(vsmall))  ///
           yline(0, lcolor(gs10)) ///
      plotregion(lcolor(black)) ///
  legend(off) ///
        title(c. Elected Leaders Should Help Own Groups First, size(medsmall)) ///
    scheme(s2mono) graphregion(fcolor(white)) 
 
************************************************************************************************
****************** TABLE 1 - MODEL RESULTS WITH COLONIAL CONTROLS INCLUDE **********************
************************************************************************************************
use AfroBarometerData.dta, clear
keep if REGION==2 | REGION==7 | REGION==9 | REGION==10 | REGION==12

**Mechanism #1 - Local Gov. Legitimacy
reg C62B $MDpolynomial Ln_WorldPop10_5km $AB $colonial $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg C71C $MDpolynomial Ln_WorldPop10_5km $AB $colonial $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg C30C $MDpolynomial Ln_WorldPop10_5km $AB $colonial $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg C25B $MDpolynomial Ln_WorldPop10_5km $AB $colonial $geo $governance  i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 

**Mechanism #2 - Traditional Authority
reg Q52K_R6 $MDpolynomial Ln_WorldPop10_5km $AB $colonial $geo $governance i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg Q53H_R6 $MDpolynomial Ln_WorldPop10_5km $AB $colonial $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg Q24E_R6 $MDpolynomial Ln_WorldPop10_5km $AB $colonial $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg Q68D_R6 $MDpolynomial Ln_WorldPop10_5km $AB $colonial $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 

**Mechanism #3 - Ethnicity
reg C85B $MDpolynomial Ln_WorldPop10_5km $AB $colonial $geo $governance i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg C79C_CAMC $MDpolynomial Ln_WorldPop10_5km $AB $colonial $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg Q18_R5 $MDpolynomial Ln_WorldPop10_5km $AB $colonial $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 


************************************************************************************************
*************************** FIGURE  6 - IS THIS SOCIAL CAPITAL? ********************************
************************************************************************************************

*a. SocialTrust C66A
use AfroBarometerData.dta, clear
keep if REGION==2 | REGION==7 | REGION==9 | REGION==10 | REGION==12

foreach var of varlist D_Border20-D_Border80 {
  quietly reg SocialTrust $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance  Round if `var'==1, cluster(EANUMB_AB) robust 
	gen Beta_`var' = _b[anglophone]
	matrix c_`var' = e(V)
	gen Var_`var' = c_`var'[1,1]
} 

foreach var of varlist D_Border20-D_Border80 {
	gen SD_`var' = sqrt(Var_`var')
	gen CI_Upper_`var' = Beta_`var'+(SD_`var'*1.96)
	gen CI_Lower_`var' = Beta_`var'-(SD_`var'*1.96)
}


foreach var of varlist D_Border20-D_Border80 {
	gen SD_10_`var' = sqrt(Var_`var')
	gen CI_Upper_10_`var' = Beta_`var'+(SD_`var'*1.645)
	gen CI_Lower_10_`var' = Beta_`var'-(SD_`var'*1.645)
}

gen N = _n
drop if N !=1
keep N Beta_D_Border20 Beta_D_Border21 Beta_D_Border22 Beta_D_Border23 Beta_D_Border24 Beta_D_Border25 Beta_D_Border26 Beta_D_Border27 Beta_D_Border28 Beta_D_Border29 Beta_D_Border30 Beta_D_Border31 Beta_D_Border32 Beta_D_Border33 Beta_D_Border34 Beta_D_Border35 Beta_D_Border36 Beta_D_Border37 Beta_D_Border38 Beta_D_Border39 Beta_D_Border40 Beta_D_Border41 Beta_D_Border42 Beta_D_Border43 Beta_D_Border44 Beta_D_Border45 Beta_D_Border46 Beta_D_Border47 Beta_D_Border48 Beta_D_Border49 Beta_D_Border50 Beta_D_Border51 Beta_D_Border52 Beta_D_Border53 Beta_D_Border54 Beta_D_Border55 Beta_D_Border56 Beta_D_Border57 Beta_D_Border58 Beta_D_Border59 Beta_D_Border60 Beta_D_Border61 Beta_D_Border62 Beta_D_Border63 Beta_D_Border64 Beta_D_Border65 Beta_D_Border66 Beta_D_Border67 Beta_D_Border68 Beta_D_Border69 Beta_D_Border70 Beta_D_Border71 Beta_D_Border72 Beta_D_Border73 Beta_D_Border74 Beta_D_Border75 Beta_D_Border76 Beta_D_Border77 Beta_D_Border78 Beta_D_Border79 Beta_D_Border80 CI_Upper_D_Border20 CI_Upper_D_Border21 CI_Upper_D_Border22 CI_Upper_D_Border23 CI_Upper_D_Border24 CI_Upper_D_Border25 CI_Upper_D_Border26 CI_Upper_D_Border27 CI_Upper_D_Border28 CI_Upper_D_Border29 CI_Upper_D_Border30 CI_Upper_D_Border31 CI_Upper_D_Border32 CI_Upper_D_Border33 CI_Upper_D_Border34 CI_Upper_D_Border35 CI_Upper_D_Border36 CI_Upper_D_Border37 CI_Upper_D_Border38 CI_Upper_D_Border39 CI_Upper_D_Border40 CI_Upper_D_Border41 CI_Upper_D_Border42 CI_Upper_D_Border43 CI_Upper_D_Border44 CI_Upper_D_Border45 CI_Upper_D_Border46 CI_Upper_D_Border47 CI_Upper_D_Border48 CI_Upper_D_Border49 CI_Upper_D_Border50 CI_Upper_D_Border51 CI_Upper_D_Border52 CI_Upper_D_Border53 CI_Upper_D_Border54 CI_Upper_D_Border55 CI_Upper_D_Border56 CI_Upper_D_Border57 CI_Upper_D_Border58 CI_Upper_D_Border59 CI_Upper_D_Border60 CI_Upper_D_Border61 CI_Upper_D_Border62 CI_Upper_D_Border63 CI_Upper_D_Border64 CI_Upper_D_Border65 CI_Upper_D_Border66 CI_Upper_D_Border67 CI_Upper_D_Border68 CI_Upper_D_Border69 CI_Upper_D_Border70 CI_Upper_D_Border71 CI_Upper_D_Border72 CI_Upper_D_Border73 CI_Upper_D_Border74 CI_Upper_D_Border75 CI_Upper_D_Border76 CI_Upper_D_Border77 CI_Upper_D_Border78 CI_Upper_D_Border79 CI_Upper_D_Border80 CI_Lower_D_Border20 CI_Lower_D_Border21 CI_Lower_D_Border22 CI_Lower_D_Border23 CI_Lower_D_Border24 CI_Lower_D_Border25 CI_Lower_D_Border26 CI_Lower_D_Border27 CI_Lower_D_Border28 CI_Lower_D_Border29 CI_Lower_D_Border30 CI_Lower_D_Border31 CI_Lower_D_Border32 CI_Lower_D_Border33 CI_Lower_D_Border34 CI_Lower_D_Border35 CI_Lower_D_Border36 CI_Lower_D_Border37 CI_Lower_D_Border38 CI_Lower_D_Border39 CI_Lower_D_Border40 CI_Lower_D_Border41 CI_Lower_D_Border42 CI_Lower_D_Border43 CI_Lower_D_Border44 CI_Lower_D_Border45 CI_Lower_D_Border46 CI_Lower_D_Border47 CI_Lower_D_Border48 CI_Lower_D_Border49 CI_Lower_D_Border50 CI_Lower_D_Border51 CI_Lower_D_Border52 CI_Lower_D_Border53 CI_Lower_D_Border54 CI_Lower_D_Border55 CI_Lower_D_Border56 CI_Lower_D_Border57 CI_Lower_D_Border58 CI_Lower_D_Border59 CI_Lower_D_Border60 CI_Lower_D_Border61 CI_Lower_D_Border62 CI_Lower_D_Border63 CI_Lower_D_Border64 CI_Lower_D_Border65 CI_Lower_D_Border66 CI_Lower_D_Border67 CI_Lower_D_Border68 CI_Lower_D_Border69 CI_Lower_D_Border70 CI_Lower_D_Border71 CI_Lower_D_Border72 CI_Lower_D_Border73 CI_Lower_D_Border74 CI_Lower_D_Border75 CI_Lower_D_Border76 CI_Lower_D_Border77 CI_Lower_D_Border78 CI_Lower_D_Border79 CI_Lower_D_Border80 SD_10_D_Border20 CI_Upper_10_D_Border20 CI_Lower_10_D_Border20 SD_10_D_Border21 CI_Upper_10_D_Border21 CI_Lower_10_D_Border21 SD_10_D_Border22 CI_Upper_10_D_Border22 CI_Lower_10_D_Border22 SD_10_D_Border23 CI_Upper_10_D_Border23 CI_Lower_10_D_Border23 SD_10_D_Border24 CI_Upper_10_D_Border24 CI_Lower_10_D_Border24 SD_10_D_Border25 CI_Upper_10_D_Border25 CI_Lower_10_D_Border25 SD_10_D_Border26 CI_Upper_10_D_Border26 CI_Lower_10_D_Border26 SD_10_D_Border27 CI_Upper_10_D_Border27 CI_Lower_10_D_Border27 SD_10_D_Border28 CI_Upper_10_D_Border28 CI_Lower_10_D_Border28 SD_10_D_Border29 CI_Upper_10_D_Border29 CI_Lower_10_D_Border29 SD_10_D_Border30 CI_Upper_10_D_Border30 CI_Lower_10_D_Border30 SD_10_D_Border31 CI_Upper_10_D_Border31 CI_Lower_10_D_Border31 SD_10_D_Border32 CI_Upper_10_D_Border32 CI_Lower_10_D_Border32 SD_10_D_Border33 CI_Upper_10_D_Border33 CI_Lower_10_D_Border33 SD_10_D_Border34 CI_Upper_10_D_Border34 CI_Lower_10_D_Border34 SD_10_D_Border35 CI_Upper_10_D_Border35 CI_Lower_10_D_Border35 SD_10_D_Border36 CI_Upper_10_D_Border36 CI_Lower_10_D_Border36 SD_10_D_Border37 CI_Upper_10_D_Border37 CI_Lower_10_D_Border37 SD_10_D_Border38 CI_Upper_10_D_Border38 CI_Lower_10_D_Border38 SD_10_D_Border39 CI_Upper_10_D_Border39 CI_Lower_10_D_Border39 SD_10_D_Border40 CI_Upper_10_D_Border40 CI_Lower_10_D_Border40 SD_10_D_Border41 CI_Upper_10_D_Border41 CI_Lower_10_D_Border41 SD_10_D_Border42 CI_Upper_10_D_Border42 CI_Lower_10_D_Border42 SD_10_D_Border43 CI_Upper_10_D_Border43 CI_Lower_10_D_Border43 SD_10_D_Border44 CI_Upper_10_D_Border44 CI_Lower_10_D_Border44 SD_10_D_Border45 CI_Upper_10_D_Border45 CI_Lower_10_D_Border45 SD_10_D_Border46 CI_Upper_10_D_Border46 CI_Lower_10_D_Border46 SD_10_D_Border47 CI_Upper_10_D_Border47 CI_Lower_10_D_Border47 SD_10_D_Border48 CI_Upper_10_D_Border48 CI_Lower_10_D_Border48 SD_10_D_Border49 CI_Upper_10_D_Border49 CI_Lower_10_D_Border49 SD_10_D_Border50 CI_Upper_10_D_Border50 CI_Lower_10_D_Border50 SD_10_D_Border51 CI_Upper_10_D_Border51 CI_Lower_10_D_Border51 SD_10_D_Border52 CI_Upper_10_D_Border52 CI_Lower_10_D_Border52 SD_10_D_Border53 CI_Upper_10_D_Border53 CI_Lower_10_D_Border53 SD_10_D_Border54 CI_Upper_10_D_Border54 CI_Lower_10_D_Border54 SD_10_D_Border55 CI_Upper_10_D_Border55 CI_Lower_10_D_Border55 SD_10_D_Border56 CI_Upper_10_D_Border56 CI_Lower_10_D_Border56 SD_10_D_Border57 CI_Upper_10_D_Border57 CI_Lower_10_D_Border57 SD_10_D_Border58 CI_Upper_10_D_Border58 CI_Lower_10_D_Border58 SD_10_D_Border59 CI_Upper_10_D_Border59 CI_Lower_10_D_Border59 SD_10_D_Border60 CI_Upper_10_D_Border60 CI_Lower_10_D_Border60 SD_10_D_Border61 CI_Upper_10_D_Border61 CI_Lower_10_D_Border61 SD_10_D_Border62 CI_Upper_10_D_Border62 CI_Lower_10_D_Border62 SD_10_D_Border63 CI_Upper_10_D_Border63 CI_Lower_10_D_Border63 SD_10_D_Border64 CI_Upper_10_D_Border64 CI_Lower_10_D_Border64 SD_10_D_Border65 CI_Upper_10_D_Border65 CI_Lower_10_D_Border65 SD_10_D_Border66 CI_Upper_10_D_Border66 CI_Lower_10_D_Border66 SD_10_D_Border67 CI_Upper_10_D_Border67 CI_Lower_10_D_Border67 SD_10_D_Border68 CI_Upper_10_D_Border68 CI_Lower_10_D_Border68 SD_10_D_Border69 CI_Upper_10_D_Border69 CI_Lower_10_D_Border69 SD_10_D_Border70 CI_Upper_10_D_Border70 CI_Lower_10_D_Border70 SD_10_D_Border71 CI_Upper_10_D_Border71 CI_Lower_10_D_Border71 SD_10_D_Border72 CI_Upper_10_D_Border72 CI_Lower_10_D_Border72 SD_10_D_Border73 CI_Upper_10_D_Border73 CI_Lower_10_D_Border73 SD_10_D_Border74 CI_Upper_10_D_Border74 CI_Lower_10_D_Border74 SD_10_D_Border75 CI_Upper_10_D_Border75 CI_Lower_10_D_Border75 SD_10_D_Border76 CI_Upper_10_D_Border76 CI_Lower_10_D_Border76 SD_10_D_Border77 CI_Upper_10_D_Border77 CI_Lower_10_D_Border77 SD_10_D_Border78 CI_Upper_10_D_Border78 CI_Lower_10_D_Border78 SD_10_D_Border79 CI_Upper_10_D_Border79 CI_Lower_10_D_Border79 SD_10_D_Border80 CI_Upper_10_D_Border80 CI_Lower_10_D_Border80

reshape long Beta_D_Border CI_Upper_D_Border CI_Lower_D_Border CI_Upper_10_D_Border CI_Lower_10_D_Border, i(N) j(band)

twoway (line Beta_D_Border band, lcolor(black) lpattern(solid)) ///
	(line CI_Upper_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Lower_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Upper_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)) ///
	(line CI_Lower_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)), ///
    ytitle(Estimated Effect Anglophone, size(small)) ylabel(-1.5(.5)1.5,  angle(horizontal))  ///
    xtitle("", size(small)) xlabel(20(10)80, labsize(vsmall))  ///
           yline(0, lcolor(gs10)) ///
      plotregion(lcolor(black)) ///
  legend(off) ///
        title(a. Social Trust, size(medsmall)) ///
    scheme(s2mono) graphregion(fcolor(white)) 
  

*b. Institutional_Trust 
use AfroBarometerData.dta, clear
keep if REGION==2 | REGION==7 | REGION==9 | REGION==10 | REGION==12

foreach var of varlist D_Border20-D_Border80 {
	quietly reg Institutional_Trust $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance  Round if `var'==1, cluster(EANUMB_AB) robust 
	gen Beta_`var' = _b[anglophone]
	matrix c_`var' = e(V)
	gen Var_`var' = c_`var'[1,1]
} 

foreach var of varlist D_Border20-D_Border80 {
	gen SD_`var' = sqrt(Var_`var')
	gen CI_Upper_`var' = Beta_`var'+(SD_`var'*1.96)
	gen CI_Lower_`var' = Beta_`var'-(SD_`var'*1.96)
}

foreach var of varlist D_Border20-D_Border80 {
	gen SD_10_`var' = sqrt(Var_`var')
	gen CI_Upper_10_`var' = Beta_`var'+(SD_`var'*1.645)
	gen CI_Lower_10_`var' = Beta_`var'-(SD_`var'*1.645)
}

gen N = _n
drop if N !=1
keep N Beta_D_Border20 Beta_D_Border21 Beta_D_Border22 Beta_D_Border23 Beta_D_Border24 Beta_D_Border25 Beta_D_Border26 Beta_D_Border27 Beta_D_Border28 Beta_D_Border29 Beta_D_Border30 Beta_D_Border31 Beta_D_Border32 Beta_D_Border33 Beta_D_Border34 Beta_D_Border35 Beta_D_Border36 Beta_D_Border37 Beta_D_Border38 Beta_D_Border39 Beta_D_Border40 Beta_D_Border41 Beta_D_Border42 Beta_D_Border43 Beta_D_Border44 Beta_D_Border45 Beta_D_Border46 Beta_D_Border47 Beta_D_Border48 Beta_D_Border49 Beta_D_Border50 Beta_D_Border51 Beta_D_Border52 Beta_D_Border53 Beta_D_Border54 Beta_D_Border55 Beta_D_Border56 Beta_D_Border57 Beta_D_Border58 Beta_D_Border59 Beta_D_Border60 Beta_D_Border61 Beta_D_Border62 Beta_D_Border63 Beta_D_Border64 Beta_D_Border65 Beta_D_Border66 Beta_D_Border67 Beta_D_Border68 Beta_D_Border69 Beta_D_Border70 Beta_D_Border71 Beta_D_Border72 Beta_D_Border73 Beta_D_Border74 Beta_D_Border75 Beta_D_Border76 Beta_D_Border77 Beta_D_Border78 Beta_D_Border79 Beta_D_Border80 CI_Upper_D_Border20 CI_Upper_D_Border21 CI_Upper_D_Border22 CI_Upper_D_Border23 CI_Upper_D_Border24 CI_Upper_D_Border25 CI_Upper_D_Border26 CI_Upper_D_Border27 CI_Upper_D_Border28 CI_Upper_D_Border29 CI_Upper_D_Border30 CI_Upper_D_Border31 CI_Upper_D_Border32 CI_Upper_D_Border33 CI_Upper_D_Border34 CI_Upper_D_Border35 CI_Upper_D_Border36 CI_Upper_D_Border37 CI_Upper_D_Border38 CI_Upper_D_Border39 CI_Upper_D_Border40 CI_Upper_D_Border41 CI_Upper_D_Border42 CI_Upper_D_Border43 CI_Upper_D_Border44 CI_Upper_D_Border45 CI_Upper_D_Border46 CI_Upper_D_Border47 CI_Upper_D_Border48 CI_Upper_D_Border49 CI_Upper_D_Border50 CI_Upper_D_Border51 CI_Upper_D_Border52 CI_Upper_D_Border53 CI_Upper_D_Border54 CI_Upper_D_Border55 CI_Upper_D_Border56 CI_Upper_D_Border57 CI_Upper_D_Border58 CI_Upper_D_Border59 CI_Upper_D_Border60 CI_Upper_D_Border61 CI_Upper_D_Border62 CI_Upper_D_Border63 CI_Upper_D_Border64 CI_Upper_D_Border65 CI_Upper_D_Border66 CI_Upper_D_Border67 CI_Upper_D_Border68 CI_Upper_D_Border69 CI_Upper_D_Border70 CI_Upper_D_Border71 CI_Upper_D_Border72 CI_Upper_D_Border73 CI_Upper_D_Border74 CI_Upper_D_Border75 CI_Upper_D_Border76 CI_Upper_D_Border77 CI_Upper_D_Border78 CI_Upper_D_Border79 CI_Upper_D_Border80 CI_Lower_D_Border20 CI_Lower_D_Border21 CI_Lower_D_Border22 CI_Lower_D_Border23 CI_Lower_D_Border24 CI_Lower_D_Border25 CI_Lower_D_Border26 CI_Lower_D_Border27 CI_Lower_D_Border28 CI_Lower_D_Border29 CI_Lower_D_Border30 CI_Lower_D_Border31 CI_Lower_D_Border32 CI_Lower_D_Border33 CI_Lower_D_Border34 CI_Lower_D_Border35 CI_Lower_D_Border36 CI_Lower_D_Border37 CI_Lower_D_Border38 CI_Lower_D_Border39 CI_Lower_D_Border40 CI_Lower_D_Border41 CI_Lower_D_Border42 CI_Lower_D_Border43 CI_Lower_D_Border44 CI_Lower_D_Border45 CI_Lower_D_Border46 CI_Lower_D_Border47 CI_Lower_D_Border48 CI_Lower_D_Border49 CI_Lower_D_Border50 CI_Lower_D_Border51 CI_Lower_D_Border52 CI_Lower_D_Border53 CI_Lower_D_Border54 CI_Lower_D_Border55 CI_Lower_D_Border56 CI_Lower_D_Border57 CI_Lower_D_Border58 CI_Lower_D_Border59 CI_Lower_D_Border60 CI_Lower_D_Border61 CI_Lower_D_Border62 CI_Lower_D_Border63 CI_Lower_D_Border64 CI_Lower_D_Border65 CI_Lower_D_Border66 CI_Lower_D_Border67 CI_Lower_D_Border68 CI_Lower_D_Border69 CI_Lower_D_Border70 CI_Lower_D_Border71 CI_Lower_D_Border72 CI_Lower_D_Border73 CI_Lower_D_Border74 CI_Lower_D_Border75 CI_Lower_D_Border76 CI_Lower_D_Border77 CI_Lower_D_Border78 CI_Lower_D_Border79 CI_Lower_D_Border80 SD_10_D_Border20 CI_Upper_10_D_Border20 CI_Lower_10_D_Border20 SD_10_D_Border21 CI_Upper_10_D_Border21 CI_Lower_10_D_Border21 SD_10_D_Border22 CI_Upper_10_D_Border22 CI_Lower_10_D_Border22 SD_10_D_Border23 CI_Upper_10_D_Border23 CI_Lower_10_D_Border23 SD_10_D_Border24 CI_Upper_10_D_Border24 CI_Lower_10_D_Border24 SD_10_D_Border25 CI_Upper_10_D_Border25 CI_Lower_10_D_Border25 SD_10_D_Border26 CI_Upper_10_D_Border26 CI_Lower_10_D_Border26 SD_10_D_Border27 CI_Upper_10_D_Border27 CI_Lower_10_D_Border27 SD_10_D_Border28 CI_Upper_10_D_Border28 CI_Lower_10_D_Border28 SD_10_D_Border29 CI_Upper_10_D_Border29 CI_Lower_10_D_Border29 SD_10_D_Border30 CI_Upper_10_D_Border30 CI_Lower_10_D_Border30 SD_10_D_Border31 CI_Upper_10_D_Border31 CI_Lower_10_D_Border31 SD_10_D_Border32 CI_Upper_10_D_Border32 CI_Lower_10_D_Border32 SD_10_D_Border33 CI_Upper_10_D_Border33 CI_Lower_10_D_Border33 SD_10_D_Border34 CI_Upper_10_D_Border34 CI_Lower_10_D_Border34 SD_10_D_Border35 CI_Upper_10_D_Border35 CI_Lower_10_D_Border35 SD_10_D_Border36 CI_Upper_10_D_Border36 CI_Lower_10_D_Border36 SD_10_D_Border37 CI_Upper_10_D_Border37 CI_Lower_10_D_Border37 SD_10_D_Border38 CI_Upper_10_D_Border38 CI_Lower_10_D_Border38 SD_10_D_Border39 CI_Upper_10_D_Border39 CI_Lower_10_D_Border39 SD_10_D_Border40 CI_Upper_10_D_Border40 CI_Lower_10_D_Border40 SD_10_D_Border41 CI_Upper_10_D_Border41 CI_Lower_10_D_Border41 SD_10_D_Border42 CI_Upper_10_D_Border42 CI_Lower_10_D_Border42 SD_10_D_Border43 CI_Upper_10_D_Border43 CI_Lower_10_D_Border43 SD_10_D_Border44 CI_Upper_10_D_Border44 CI_Lower_10_D_Border44 SD_10_D_Border45 CI_Upper_10_D_Border45 CI_Lower_10_D_Border45 SD_10_D_Border46 CI_Upper_10_D_Border46 CI_Lower_10_D_Border46 SD_10_D_Border47 CI_Upper_10_D_Border47 CI_Lower_10_D_Border47 SD_10_D_Border48 CI_Upper_10_D_Border48 CI_Lower_10_D_Border48 SD_10_D_Border49 CI_Upper_10_D_Border49 CI_Lower_10_D_Border49 SD_10_D_Border50 CI_Upper_10_D_Border50 CI_Lower_10_D_Border50 SD_10_D_Border51 CI_Upper_10_D_Border51 CI_Lower_10_D_Border51 SD_10_D_Border52 CI_Upper_10_D_Border52 CI_Lower_10_D_Border52 SD_10_D_Border53 CI_Upper_10_D_Border53 CI_Lower_10_D_Border53 SD_10_D_Border54 CI_Upper_10_D_Border54 CI_Lower_10_D_Border54 SD_10_D_Border55 CI_Upper_10_D_Border55 CI_Lower_10_D_Border55 SD_10_D_Border56 CI_Upper_10_D_Border56 CI_Lower_10_D_Border56 SD_10_D_Border57 CI_Upper_10_D_Border57 CI_Lower_10_D_Border57 SD_10_D_Border58 CI_Upper_10_D_Border58 CI_Lower_10_D_Border58 SD_10_D_Border59 CI_Upper_10_D_Border59 CI_Lower_10_D_Border59 SD_10_D_Border60 CI_Upper_10_D_Border60 CI_Lower_10_D_Border60 SD_10_D_Border61 CI_Upper_10_D_Border61 CI_Lower_10_D_Border61 SD_10_D_Border62 CI_Upper_10_D_Border62 CI_Lower_10_D_Border62 SD_10_D_Border63 CI_Upper_10_D_Border63 CI_Lower_10_D_Border63 SD_10_D_Border64 CI_Upper_10_D_Border64 CI_Lower_10_D_Border64 SD_10_D_Border65 CI_Upper_10_D_Border65 CI_Lower_10_D_Border65 SD_10_D_Border66 CI_Upper_10_D_Border66 CI_Lower_10_D_Border66 SD_10_D_Border67 CI_Upper_10_D_Border67 CI_Lower_10_D_Border67 SD_10_D_Border68 CI_Upper_10_D_Border68 CI_Lower_10_D_Border68 SD_10_D_Border69 CI_Upper_10_D_Border69 CI_Lower_10_D_Border69 SD_10_D_Border70 CI_Upper_10_D_Border70 CI_Lower_10_D_Border70 SD_10_D_Border71 CI_Upper_10_D_Border71 CI_Lower_10_D_Border71 SD_10_D_Border72 CI_Upper_10_D_Border72 CI_Lower_10_D_Border72 SD_10_D_Border73 CI_Upper_10_D_Border73 CI_Lower_10_D_Border73 SD_10_D_Border74 CI_Upper_10_D_Border74 CI_Lower_10_D_Border74 SD_10_D_Border75 CI_Upper_10_D_Border75 CI_Lower_10_D_Border75 SD_10_D_Border76 CI_Upper_10_D_Border76 CI_Lower_10_D_Border76 SD_10_D_Border77 CI_Upper_10_D_Border77 CI_Lower_10_D_Border77 SD_10_D_Border78 CI_Upper_10_D_Border78 CI_Lower_10_D_Border78 SD_10_D_Border79 CI_Upper_10_D_Border79 CI_Lower_10_D_Border79 SD_10_D_Border80 CI_Upper_10_D_Border80 CI_Lower_10_D_Border80


reshape long Beta_D_Border CI_Upper_D_Border CI_Lower_D_Border CI_Upper_10_D_Border CI_Lower_10_D_Border, i(N) j(band)

twoway (line Beta_D_Border band, lcolor(black) lpattern(solid)) ///
	(line CI_Upper_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Lower_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Upper_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)) ///
	(line CI_Lower_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)), ///
    ytitle("", size(small)) ylabel(#6,  angle(horizontal)) yscale(r(-1.5(.5)1.5)) ///
    xtitle("", size(small)) xlabel(20(10)80, labsize(vsmall))  ///
          yline(0, lcolor(gs10)) ///
      plotregion(lcolor(black)) ///
   legend(off) ///
        title(b. Institutional Trust, size(medsmall)) ///
    scheme(s2mono) graphregion(fcolor(white)) 

*c. Discuss Politics C15
use AfroBarometerData.dta, clear
keep if REGION==2 | REGION==7 | REGION==9 | REGION==10 | REGION==12

foreach var of varlist D_Border20-D_Border80 {
	quietly reg C15 $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance  Round if `var'==1, cluster(EANUMB_AB) robust 
	gen Beta_`var' = _b[anglophone]
	matrix c_`var' = e(V)
	gen Var_`var' = c_`var'[1,1]
} 

foreach var of varlist D_Border20-D_Border80 {
	gen SD_`var' = sqrt(Var_`var')
	gen CI_Upper_`var' = Beta_`var'+(SD_`var'*1.96)
	gen CI_Lower_`var' = Beta_`var'-(SD_`var'*1.96)
}


foreach var of varlist D_Border20-D_Border80 {
	gen SD_10_`var' = sqrt(Var_`var')
	gen CI_Upper_10_`var' = Beta_`var'+(SD_`var'*1.645)
	gen CI_Lower_10_`var' = Beta_`var'-(SD_`var'*1.645)
}

gen N = _n
drop if N !=1
keep N Beta_D_Border20 Beta_D_Border21 Beta_D_Border22 Beta_D_Border23 Beta_D_Border24 Beta_D_Border25 Beta_D_Border26 Beta_D_Border27 Beta_D_Border28 Beta_D_Border29 Beta_D_Border30 Beta_D_Border31 Beta_D_Border32 Beta_D_Border33 Beta_D_Border34 Beta_D_Border35 Beta_D_Border36 Beta_D_Border37 Beta_D_Border38 Beta_D_Border39 Beta_D_Border40 Beta_D_Border41 Beta_D_Border42 Beta_D_Border43 Beta_D_Border44 Beta_D_Border45 Beta_D_Border46 Beta_D_Border47 Beta_D_Border48 Beta_D_Border49 Beta_D_Border50 Beta_D_Border51 Beta_D_Border52 Beta_D_Border53 Beta_D_Border54 Beta_D_Border55 Beta_D_Border56 Beta_D_Border57 Beta_D_Border58 Beta_D_Border59 Beta_D_Border60 Beta_D_Border61 Beta_D_Border62 Beta_D_Border63 Beta_D_Border64 Beta_D_Border65 Beta_D_Border66 Beta_D_Border67 Beta_D_Border68 Beta_D_Border69 Beta_D_Border70 Beta_D_Border71 Beta_D_Border72 Beta_D_Border73 Beta_D_Border74 Beta_D_Border75 Beta_D_Border76 Beta_D_Border77 Beta_D_Border78 Beta_D_Border79 Beta_D_Border80 CI_Upper_D_Border20 CI_Upper_D_Border21 CI_Upper_D_Border22 CI_Upper_D_Border23 CI_Upper_D_Border24 CI_Upper_D_Border25 CI_Upper_D_Border26 CI_Upper_D_Border27 CI_Upper_D_Border28 CI_Upper_D_Border29 CI_Upper_D_Border30 CI_Upper_D_Border31 CI_Upper_D_Border32 CI_Upper_D_Border33 CI_Upper_D_Border34 CI_Upper_D_Border35 CI_Upper_D_Border36 CI_Upper_D_Border37 CI_Upper_D_Border38 CI_Upper_D_Border39 CI_Upper_D_Border40 CI_Upper_D_Border41 CI_Upper_D_Border42 CI_Upper_D_Border43 CI_Upper_D_Border44 CI_Upper_D_Border45 CI_Upper_D_Border46 CI_Upper_D_Border47 CI_Upper_D_Border48 CI_Upper_D_Border49 CI_Upper_D_Border50 CI_Upper_D_Border51 CI_Upper_D_Border52 CI_Upper_D_Border53 CI_Upper_D_Border54 CI_Upper_D_Border55 CI_Upper_D_Border56 CI_Upper_D_Border57 CI_Upper_D_Border58 CI_Upper_D_Border59 CI_Upper_D_Border60 CI_Upper_D_Border61 CI_Upper_D_Border62 CI_Upper_D_Border63 CI_Upper_D_Border64 CI_Upper_D_Border65 CI_Upper_D_Border66 CI_Upper_D_Border67 CI_Upper_D_Border68 CI_Upper_D_Border69 CI_Upper_D_Border70 CI_Upper_D_Border71 CI_Upper_D_Border72 CI_Upper_D_Border73 CI_Upper_D_Border74 CI_Upper_D_Border75 CI_Upper_D_Border76 CI_Upper_D_Border77 CI_Upper_D_Border78 CI_Upper_D_Border79 CI_Upper_D_Border80 CI_Lower_D_Border20 CI_Lower_D_Border21 CI_Lower_D_Border22 CI_Lower_D_Border23 CI_Lower_D_Border24 CI_Lower_D_Border25 CI_Lower_D_Border26 CI_Lower_D_Border27 CI_Lower_D_Border28 CI_Lower_D_Border29 CI_Lower_D_Border30 CI_Lower_D_Border31 CI_Lower_D_Border32 CI_Lower_D_Border33 CI_Lower_D_Border34 CI_Lower_D_Border35 CI_Lower_D_Border36 CI_Lower_D_Border37 CI_Lower_D_Border38 CI_Lower_D_Border39 CI_Lower_D_Border40 CI_Lower_D_Border41 CI_Lower_D_Border42 CI_Lower_D_Border43 CI_Lower_D_Border44 CI_Lower_D_Border45 CI_Lower_D_Border46 CI_Lower_D_Border47 CI_Lower_D_Border48 CI_Lower_D_Border49 CI_Lower_D_Border50 CI_Lower_D_Border51 CI_Lower_D_Border52 CI_Lower_D_Border53 CI_Lower_D_Border54 CI_Lower_D_Border55 CI_Lower_D_Border56 CI_Lower_D_Border57 CI_Lower_D_Border58 CI_Lower_D_Border59 CI_Lower_D_Border60 CI_Lower_D_Border61 CI_Lower_D_Border62 CI_Lower_D_Border63 CI_Lower_D_Border64 CI_Lower_D_Border65 CI_Lower_D_Border66 CI_Lower_D_Border67 CI_Lower_D_Border68 CI_Lower_D_Border69 CI_Lower_D_Border70 CI_Lower_D_Border71 CI_Lower_D_Border72 CI_Lower_D_Border73 CI_Lower_D_Border74 CI_Lower_D_Border75 CI_Lower_D_Border76 CI_Lower_D_Border77 CI_Lower_D_Border78 CI_Lower_D_Border79 CI_Lower_D_Border80 SD_10_D_Border20 CI_Upper_10_D_Border20 CI_Lower_10_D_Border20 SD_10_D_Border21 CI_Upper_10_D_Border21 CI_Lower_10_D_Border21 SD_10_D_Border22 CI_Upper_10_D_Border22 CI_Lower_10_D_Border22 SD_10_D_Border23 CI_Upper_10_D_Border23 CI_Lower_10_D_Border23 SD_10_D_Border24 CI_Upper_10_D_Border24 CI_Lower_10_D_Border24 SD_10_D_Border25 CI_Upper_10_D_Border25 CI_Lower_10_D_Border25 SD_10_D_Border26 CI_Upper_10_D_Border26 CI_Lower_10_D_Border26 SD_10_D_Border27 CI_Upper_10_D_Border27 CI_Lower_10_D_Border27 SD_10_D_Border28 CI_Upper_10_D_Border28 CI_Lower_10_D_Border28 SD_10_D_Border29 CI_Upper_10_D_Border29 CI_Lower_10_D_Border29 SD_10_D_Border30 CI_Upper_10_D_Border30 CI_Lower_10_D_Border30 SD_10_D_Border31 CI_Upper_10_D_Border31 CI_Lower_10_D_Border31 SD_10_D_Border32 CI_Upper_10_D_Border32 CI_Lower_10_D_Border32 SD_10_D_Border33 CI_Upper_10_D_Border33 CI_Lower_10_D_Border33 SD_10_D_Border34 CI_Upper_10_D_Border34 CI_Lower_10_D_Border34 SD_10_D_Border35 CI_Upper_10_D_Border35 CI_Lower_10_D_Border35 SD_10_D_Border36 CI_Upper_10_D_Border36 CI_Lower_10_D_Border36 SD_10_D_Border37 CI_Upper_10_D_Border37 CI_Lower_10_D_Border37 SD_10_D_Border38 CI_Upper_10_D_Border38 CI_Lower_10_D_Border38 SD_10_D_Border39 CI_Upper_10_D_Border39 CI_Lower_10_D_Border39 SD_10_D_Border40 CI_Upper_10_D_Border40 CI_Lower_10_D_Border40 SD_10_D_Border41 CI_Upper_10_D_Border41 CI_Lower_10_D_Border41 SD_10_D_Border42 CI_Upper_10_D_Border42 CI_Lower_10_D_Border42 SD_10_D_Border43 CI_Upper_10_D_Border43 CI_Lower_10_D_Border43 SD_10_D_Border44 CI_Upper_10_D_Border44 CI_Lower_10_D_Border44 SD_10_D_Border45 CI_Upper_10_D_Border45 CI_Lower_10_D_Border45 SD_10_D_Border46 CI_Upper_10_D_Border46 CI_Lower_10_D_Border46 SD_10_D_Border47 CI_Upper_10_D_Border47 CI_Lower_10_D_Border47 SD_10_D_Border48 CI_Upper_10_D_Border48 CI_Lower_10_D_Border48 SD_10_D_Border49 CI_Upper_10_D_Border49 CI_Lower_10_D_Border49 SD_10_D_Border50 CI_Upper_10_D_Border50 CI_Lower_10_D_Border50 SD_10_D_Border51 CI_Upper_10_D_Border51 CI_Lower_10_D_Border51 SD_10_D_Border52 CI_Upper_10_D_Border52 CI_Lower_10_D_Border52 SD_10_D_Border53 CI_Upper_10_D_Border53 CI_Lower_10_D_Border53 SD_10_D_Border54 CI_Upper_10_D_Border54 CI_Lower_10_D_Border54 SD_10_D_Border55 CI_Upper_10_D_Border55 CI_Lower_10_D_Border55 SD_10_D_Border56 CI_Upper_10_D_Border56 CI_Lower_10_D_Border56 SD_10_D_Border57 CI_Upper_10_D_Border57 CI_Lower_10_D_Border57 SD_10_D_Border58 CI_Upper_10_D_Border58 CI_Lower_10_D_Border58 SD_10_D_Border59 CI_Upper_10_D_Border59 CI_Lower_10_D_Border59 SD_10_D_Border60 CI_Upper_10_D_Border60 CI_Lower_10_D_Border60 SD_10_D_Border61 CI_Upper_10_D_Border61 CI_Lower_10_D_Border61 SD_10_D_Border62 CI_Upper_10_D_Border62 CI_Lower_10_D_Border62 SD_10_D_Border63 CI_Upper_10_D_Border63 CI_Lower_10_D_Border63 SD_10_D_Border64 CI_Upper_10_D_Border64 CI_Lower_10_D_Border64 SD_10_D_Border65 CI_Upper_10_D_Border65 CI_Lower_10_D_Border65 SD_10_D_Border66 CI_Upper_10_D_Border66 CI_Lower_10_D_Border66 SD_10_D_Border67 CI_Upper_10_D_Border67 CI_Lower_10_D_Border67 SD_10_D_Border68 CI_Upper_10_D_Border68 CI_Lower_10_D_Border68 SD_10_D_Border69 CI_Upper_10_D_Border69 CI_Lower_10_D_Border69 SD_10_D_Border70 CI_Upper_10_D_Border70 CI_Lower_10_D_Border70 SD_10_D_Border71 CI_Upper_10_D_Border71 CI_Lower_10_D_Border71 SD_10_D_Border72 CI_Upper_10_D_Border72 CI_Lower_10_D_Border72 SD_10_D_Border73 CI_Upper_10_D_Border73 CI_Lower_10_D_Border73 SD_10_D_Border74 CI_Upper_10_D_Border74 CI_Lower_10_D_Border74 SD_10_D_Border75 CI_Upper_10_D_Border75 CI_Lower_10_D_Border75 SD_10_D_Border76 CI_Upper_10_D_Border76 CI_Lower_10_D_Border76 SD_10_D_Border77 CI_Upper_10_D_Border77 CI_Lower_10_D_Border77 SD_10_D_Border78 CI_Upper_10_D_Border78 CI_Lower_10_D_Border78 SD_10_D_Border79 CI_Upper_10_D_Border79 CI_Lower_10_D_Border79 SD_10_D_Border80 CI_Upper_10_D_Border80 CI_Lower_10_D_Border80

reshape long Beta_D_Border CI_Upper_D_Border CI_Lower_D_Border CI_Upper_10_D_Border CI_Lower_10_D_Border, i(N) j(band)

twoway (line Beta_D_Border band, lcolor(black) lpattern(solid)) ///
	(line CI_Upper_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Lower_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Upper_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)) ///
	(line CI_Lower_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)), ///
    ytitle(Estimated Effect Anglophone, size(small)) ylabel(#6,  angle(horizontal)) yscale(r(-1.5(.5)1.5)) ///
    xtitle("", size(small)) xlabel(20(10)80, labsize(vsmall))  ///
          yline(0, lcolor(gs10)) ///
      plotregion(lcolor(black)) ///
   legend(off) ///
        title("c. Discuss Politics", size(medsmall)) ///
    scheme(s2mono) graphregion(fcolor(white)) 
 
*d. Voting C27
use AfroBarometerData.dta, clear
keep if REGION==2 | REGION==7 | REGION==9 | REGION==10 | REGION==12

foreach var of varlist D_Border20-D_Border80 {
	quietly logit C27 $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance Round if `var'==1, cluster(EANUMB_AB) robust 
	gen Beta_`var' = _b[anglophone]
	matrix c_`var' = e(V)
	gen Var_`var' = c_`var'[1,1]
} 

foreach var of varlist D_Border20-D_Border80 {
	gen SD_`var' = sqrt(Var_`var')
	gen CI_Upper_`var' = Beta_`var'+(SD_`var'*1.96)
	gen CI_Lower_`var' = Beta_`var'-(SD_`var'*1.96)
}

foreach var of varlist D_Border20-D_Border80 {
	gen SD_10_`var' = sqrt(Var_`var')
	gen CI_Upper_10_`var' = Beta_`var'+(SD_`var'*1.645)
	gen CI_Lower_10_`var' = Beta_`var'-(SD_`var'*1.645)
}

gen N = _n
drop if N !=1
keep N Beta_D_Border20 Beta_D_Border21 Beta_D_Border22 Beta_D_Border23 Beta_D_Border24 Beta_D_Border25 Beta_D_Border26 Beta_D_Border27 Beta_D_Border28 Beta_D_Border29 Beta_D_Border30 Beta_D_Border31 Beta_D_Border32 Beta_D_Border33 Beta_D_Border34 Beta_D_Border35 Beta_D_Border36 Beta_D_Border37 Beta_D_Border38 Beta_D_Border39 Beta_D_Border40 Beta_D_Border41 Beta_D_Border42 Beta_D_Border43 Beta_D_Border44 Beta_D_Border45 Beta_D_Border46 Beta_D_Border47 Beta_D_Border48 Beta_D_Border49 Beta_D_Border50 Beta_D_Border51 Beta_D_Border52 Beta_D_Border53 Beta_D_Border54 Beta_D_Border55 Beta_D_Border56 Beta_D_Border57 Beta_D_Border58 Beta_D_Border59 Beta_D_Border60 Beta_D_Border61 Beta_D_Border62 Beta_D_Border63 Beta_D_Border64 Beta_D_Border65 Beta_D_Border66 Beta_D_Border67 Beta_D_Border68 Beta_D_Border69 Beta_D_Border70 Beta_D_Border71 Beta_D_Border72 Beta_D_Border73 Beta_D_Border74 Beta_D_Border75 Beta_D_Border76 Beta_D_Border77 Beta_D_Border78 Beta_D_Border79 Beta_D_Border80 CI_Upper_D_Border20 CI_Upper_D_Border21 CI_Upper_D_Border22 CI_Upper_D_Border23 CI_Upper_D_Border24 CI_Upper_D_Border25 CI_Upper_D_Border26 CI_Upper_D_Border27 CI_Upper_D_Border28 CI_Upper_D_Border29 CI_Upper_D_Border30 CI_Upper_D_Border31 CI_Upper_D_Border32 CI_Upper_D_Border33 CI_Upper_D_Border34 CI_Upper_D_Border35 CI_Upper_D_Border36 CI_Upper_D_Border37 CI_Upper_D_Border38 CI_Upper_D_Border39 CI_Upper_D_Border40 CI_Upper_D_Border41 CI_Upper_D_Border42 CI_Upper_D_Border43 CI_Upper_D_Border44 CI_Upper_D_Border45 CI_Upper_D_Border46 CI_Upper_D_Border47 CI_Upper_D_Border48 CI_Upper_D_Border49 CI_Upper_D_Border50 CI_Upper_D_Border51 CI_Upper_D_Border52 CI_Upper_D_Border53 CI_Upper_D_Border54 CI_Upper_D_Border55 CI_Upper_D_Border56 CI_Upper_D_Border57 CI_Upper_D_Border58 CI_Upper_D_Border59 CI_Upper_D_Border60 CI_Upper_D_Border61 CI_Upper_D_Border62 CI_Upper_D_Border63 CI_Upper_D_Border64 CI_Upper_D_Border65 CI_Upper_D_Border66 CI_Upper_D_Border67 CI_Upper_D_Border68 CI_Upper_D_Border69 CI_Upper_D_Border70 CI_Upper_D_Border71 CI_Upper_D_Border72 CI_Upper_D_Border73 CI_Upper_D_Border74 CI_Upper_D_Border75 CI_Upper_D_Border76 CI_Upper_D_Border77 CI_Upper_D_Border78 CI_Upper_D_Border79 CI_Upper_D_Border80 CI_Lower_D_Border20 CI_Lower_D_Border21 CI_Lower_D_Border22 CI_Lower_D_Border23 CI_Lower_D_Border24 CI_Lower_D_Border25 CI_Lower_D_Border26 CI_Lower_D_Border27 CI_Lower_D_Border28 CI_Lower_D_Border29 CI_Lower_D_Border30 CI_Lower_D_Border31 CI_Lower_D_Border32 CI_Lower_D_Border33 CI_Lower_D_Border34 CI_Lower_D_Border35 CI_Lower_D_Border36 CI_Lower_D_Border37 CI_Lower_D_Border38 CI_Lower_D_Border39 CI_Lower_D_Border40 CI_Lower_D_Border41 CI_Lower_D_Border42 CI_Lower_D_Border43 CI_Lower_D_Border44 CI_Lower_D_Border45 CI_Lower_D_Border46 CI_Lower_D_Border47 CI_Lower_D_Border48 CI_Lower_D_Border49 CI_Lower_D_Border50 CI_Lower_D_Border51 CI_Lower_D_Border52 CI_Lower_D_Border53 CI_Lower_D_Border54 CI_Lower_D_Border55 CI_Lower_D_Border56 CI_Lower_D_Border57 CI_Lower_D_Border58 CI_Lower_D_Border59 CI_Lower_D_Border60 CI_Lower_D_Border61 CI_Lower_D_Border62 CI_Lower_D_Border63 CI_Lower_D_Border64 CI_Lower_D_Border65 CI_Lower_D_Border66 CI_Lower_D_Border67 CI_Lower_D_Border68 CI_Lower_D_Border69 CI_Lower_D_Border70 CI_Lower_D_Border71 CI_Lower_D_Border72 CI_Lower_D_Border73 CI_Lower_D_Border74 CI_Lower_D_Border75 CI_Lower_D_Border76 CI_Lower_D_Border77 CI_Lower_D_Border78 CI_Lower_D_Border79 CI_Lower_D_Border80 SD_10_D_Border20 CI_Upper_10_D_Border20 CI_Lower_10_D_Border20 SD_10_D_Border21 CI_Upper_10_D_Border21 CI_Lower_10_D_Border21 SD_10_D_Border22 CI_Upper_10_D_Border22 CI_Lower_10_D_Border22 SD_10_D_Border23 CI_Upper_10_D_Border23 CI_Lower_10_D_Border23 SD_10_D_Border24 CI_Upper_10_D_Border24 CI_Lower_10_D_Border24 SD_10_D_Border25 CI_Upper_10_D_Border25 CI_Lower_10_D_Border25 SD_10_D_Border26 CI_Upper_10_D_Border26 CI_Lower_10_D_Border26 SD_10_D_Border27 CI_Upper_10_D_Border27 CI_Lower_10_D_Border27 SD_10_D_Border28 CI_Upper_10_D_Border28 CI_Lower_10_D_Border28 SD_10_D_Border29 CI_Upper_10_D_Border29 CI_Lower_10_D_Border29 SD_10_D_Border30 CI_Upper_10_D_Border30 CI_Lower_10_D_Border30 SD_10_D_Border31 CI_Upper_10_D_Border31 CI_Lower_10_D_Border31 SD_10_D_Border32 CI_Upper_10_D_Border32 CI_Lower_10_D_Border32 SD_10_D_Border33 CI_Upper_10_D_Border33 CI_Lower_10_D_Border33 SD_10_D_Border34 CI_Upper_10_D_Border34 CI_Lower_10_D_Border34 SD_10_D_Border35 CI_Upper_10_D_Border35 CI_Lower_10_D_Border35 SD_10_D_Border36 CI_Upper_10_D_Border36 CI_Lower_10_D_Border36 SD_10_D_Border37 CI_Upper_10_D_Border37 CI_Lower_10_D_Border37 SD_10_D_Border38 CI_Upper_10_D_Border38 CI_Lower_10_D_Border38 SD_10_D_Border39 CI_Upper_10_D_Border39 CI_Lower_10_D_Border39 SD_10_D_Border40 CI_Upper_10_D_Border40 CI_Lower_10_D_Border40 SD_10_D_Border41 CI_Upper_10_D_Border41 CI_Lower_10_D_Border41 SD_10_D_Border42 CI_Upper_10_D_Border42 CI_Lower_10_D_Border42 SD_10_D_Border43 CI_Upper_10_D_Border43 CI_Lower_10_D_Border43 SD_10_D_Border44 CI_Upper_10_D_Border44 CI_Lower_10_D_Border44 SD_10_D_Border45 CI_Upper_10_D_Border45 CI_Lower_10_D_Border45 SD_10_D_Border46 CI_Upper_10_D_Border46 CI_Lower_10_D_Border46 SD_10_D_Border47 CI_Upper_10_D_Border47 CI_Lower_10_D_Border47 SD_10_D_Border48 CI_Upper_10_D_Border48 CI_Lower_10_D_Border48 SD_10_D_Border49 CI_Upper_10_D_Border49 CI_Lower_10_D_Border49 SD_10_D_Border50 CI_Upper_10_D_Border50 CI_Lower_10_D_Border50 SD_10_D_Border51 CI_Upper_10_D_Border51 CI_Lower_10_D_Border51 SD_10_D_Border52 CI_Upper_10_D_Border52 CI_Lower_10_D_Border52 SD_10_D_Border53 CI_Upper_10_D_Border53 CI_Lower_10_D_Border53 SD_10_D_Border54 CI_Upper_10_D_Border54 CI_Lower_10_D_Border54 SD_10_D_Border55 CI_Upper_10_D_Border55 CI_Lower_10_D_Border55 SD_10_D_Border56 CI_Upper_10_D_Border56 CI_Lower_10_D_Border56 SD_10_D_Border57 CI_Upper_10_D_Border57 CI_Lower_10_D_Border57 SD_10_D_Border58 CI_Upper_10_D_Border58 CI_Lower_10_D_Border58 SD_10_D_Border59 CI_Upper_10_D_Border59 CI_Lower_10_D_Border59 SD_10_D_Border60 CI_Upper_10_D_Border60 CI_Lower_10_D_Border60 SD_10_D_Border61 CI_Upper_10_D_Border61 CI_Lower_10_D_Border61 SD_10_D_Border62 CI_Upper_10_D_Border62 CI_Lower_10_D_Border62 SD_10_D_Border63 CI_Upper_10_D_Border63 CI_Lower_10_D_Border63 SD_10_D_Border64 CI_Upper_10_D_Border64 CI_Lower_10_D_Border64 SD_10_D_Border65 CI_Upper_10_D_Border65 CI_Lower_10_D_Border65 SD_10_D_Border66 CI_Upper_10_D_Border66 CI_Lower_10_D_Border66 SD_10_D_Border67 CI_Upper_10_D_Border67 CI_Lower_10_D_Border67 SD_10_D_Border68 CI_Upper_10_D_Border68 CI_Lower_10_D_Border68 SD_10_D_Border69 CI_Upper_10_D_Border69 CI_Lower_10_D_Border69 SD_10_D_Border70 CI_Upper_10_D_Border70 CI_Lower_10_D_Border70 SD_10_D_Border71 CI_Upper_10_D_Border71 CI_Lower_10_D_Border71 SD_10_D_Border72 CI_Upper_10_D_Border72 CI_Lower_10_D_Border72 SD_10_D_Border73 CI_Upper_10_D_Border73 CI_Lower_10_D_Border73 SD_10_D_Border74 CI_Upper_10_D_Border74 CI_Lower_10_D_Border74 SD_10_D_Border75 CI_Upper_10_D_Border75 CI_Lower_10_D_Border75 SD_10_D_Border76 CI_Upper_10_D_Border76 CI_Lower_10_D_Border76 SD_10_D_Border77 CI_Upper_10_D_Border77 CI_Lower_10_D_Border77 SD_10_D_Border78 CI_Upper_10_D_Border78 CI_Lower_10_D_Border78 SD_10_D_Border79 CI_Upper_10_D_Border79 CI_Lower_10_D_Border79 SD_10_D_Border80 CI_Upper_10_D_Border80 CI_Lower_10_D_Border80

reshape long Beta_D_Border CI_Upper_D_Border CI_Lower_D_Border CI_Upper_10_D_Border CI_Lower_10_D_Border, i(N) j(band)
	
twoway (line Beta_D_Border band, lcolor(black) lpattern(solid)) ///
	(line CI_Upper_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Lower_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Upper_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)) ///
	(line CI_Lower_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)), ///
   ytitle("", size(small)) ylabel(-1.5(.5)1.5,  angle(horizontal))  ///
    xtitle(Distance from Border (km)) xtitle(, size(small)) xlabel(20(10)80, labsize(vsmall))  ///
           yline(0, lcolor(gs10)) ///
      plotregion(lcolor(black)) ///
  legend(off) ///
        title("d. Voted in Last Election", size(medsmall)) ///
    scheme(s2mono) graphregion(fcolor(white)) 
 

*e. Attend Protest C26D
use AfroBarometerData.dta, clear
keep if REGION==2 | REGION==7 | REGION==9 | REGION==10 | REGION==12

foreach var of varlist D_Border20-D_Border80 {
  quietly reg C26D $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance  Round if `var'==1, cluster(EANUMB_AB) robust 
	gen Beta_`var' = _b[anglophone]
	matrix c_`var' = e(V)
	gen Var_`var' = c_`var'[1,1]
} 

foreach var of varlist D_Border20-D_Border80 {
	gen SD_`var' = sqrt(Var_`var')
	gen CI_Upper_`var' = Beta_`var'+(SD_`var'*1.96)
	gen CI_Lower_`var' = Beta_`var'-(SD_`var'*1.96)
}

foreach var of varlist D_Border20-D_Border80 {
	gen SD_10_`var' = sqrt(Var_`var')
	gen CI_Upper_10_`var' = Beta_`var'+(SD_`var'*1.645)
	gen CI_Lower_10_`var' = Beta_`var'-(SD_`var'*1.645)
}

gen N = _n
drop if N !=1
keep N Beta_D_Border20 Beta_D_Border21 Beta_D_Border22 Beta_D_Border23 Beta_D_Border24 Beta_D_Border25 Beta_D_Border26 Beta_D_Border27 Beta_D_Border28 Beta_D_Border29 Beta_D_Border30 Beta_D_Border31 Beta_D_Border32 Beta_D_Border33 Beta_D_Border34 Beta_D_Border35 Beta_D_Border36 Beta_D_Border37 Beta_D_Border38 Beta_D_Border39 Beta_D_Border40 Beta_D_Border41 Beta_D_Border42 Beta_D_Border43 Beta_D_Border44 Beta_D_Border45 Beta_D_Border46 Beta_D_Border47 Beta_D_Border48 Beta_D_Border49 Beta_D_Border50 Beta_D_Border51 Beta_D_Border52 Beta_D_Border53 Beta_D_Border54 Beta_D_Border55 Beta_D_Border56 Beta_D_Border57 Beta_D_Border58 Beta_D_Border59 Beta_D_Border60 Beta_D_Border61 Beta_D_Border62 Beta_D_Border63 Beta_D_Border64 Beta_D_Border65 Beta_D_Border66 Beta_D_Border67 Beta_D_Border68 Beta_D_Border69 Beta_D_Border70 Beta_D_Border71 Beta_D_Border72 Beta_D_Border73 Beta_D_Border74 Beta_D_Border75 Beta_D_Border76 Beta_D_Border77 Beta_D_Border78 Beta_D_Border79 Beta_D_Border80 CI_Upper_D_Border20 CI_Upper_D_Border21 CI_Upper_D_Border22 CI_Upper_D_Border23 CI_Upper_D_Border24 CI_Upper_D_Border25 CI_Upper_D_Border26 CI_Upper_D_Border27 CI_Upper_D_Border28 CI_Upper_D_Border29 CI_Upper_D_Border30 CI_Upper_D_Border31 CI_Upper_D_Border32 CI_Upper_D_Border33 CI_Upper_D_Border34 CI_Upper_D_Border35 CI_Upper_D_Border36 CI_Upper_D_Border37 CI_Upper_D_Border38 CI_Upper_D_Border39 CI_Upper_D_Border40 CI_Upper_D_Border41 CI_Upper_D_Border42 CI_Upper_D_Border43 CI_Upper_D_Border44 CI_Upper_D_Border45 CI_Upper_D_Border46 CI_Upper_D_Border47 CI_Upper_D_Border48 CI_Upper_D_Border49 CI_Upper_D_Border50 CI_Upper_D_Border51 CI_Upper_D_Border52 CI_Upper_D_Border53 CI_Upper_D_Border54 CI_Upper_D_Border55 CI_Upper_D_Border56 CI_Upper_D_Border57 CI_Upper_D_Border58 CI_Upper_D_Border59 CI_Upper_D_Border60 CI_Upper_D_Border61 CI_Upper_D_Border62 CI_Upper_D_Border63 CI_Upper_D_Border64 CI_Upper_D_Border65 CI_Upper_D_Border66 CI_Upper_D_Border67 CI_Upper_D_Border68 CI_Upper_D_Border69 CI_Upper_D_Border70 CI_Upper_D_Border71 CI_Upper_D_Border72 CI_Upper_D_Border73 CI_Upper_D_Border74 CI_Upper_D_Border75 CI_Upper_D_Border76 CI_Upper_D_Border77 CI_Upper_D_Border78 CI_Upper_D_Border79 CI_Upper_D_Border80 CI_Lower_D_Border20 CI_Lower_D_Border21 CI_Lower_D_Border22 CI_Lower_D_Border23 CI_Lower_D_Border24 CI_Lower_D_Border25 CI_Lower_D_Border26 CI_Lower_D_Border27 CI_Lower_D_Border28 CI_Lower_D_Border29 CI_Lower_D_Border30 CI_Lower_D_Border31 CI_Lower_D_Border32 CI_Lower_D_Border33 CI_Lower_D_Border34 CI_Lower_D_Border35 CI_Lower_D_Border36 CI_Lower_D_Border37 CI_Lower_D_Border38 CI_Lower_D_Border39 CI_Lower_D_Border40 CI_Lower_D_Border41 CI_Lower_D_Border42 CI_Lower_D_Border43 CI_Lower_D_Border44 CI_Lower_D_Border45 CI_Lower_D_Border46 CI_Lower_D_Border47 CI_Lower_D_Border48 CI_Lower_D_Border49 CI_Lower_D_Border50 CI_Lower_D_Border51 CI_Lower_D_Border52 CI_Lower_D_Border53 CI_Lower_D_Border54 CI_Lower_D_Border55 CI_Lower_D_Border56 CI_Lower_D_Border57 CI_Lower_D_Border58 CI_Lower_D_Border59 CI_Lower_D_Border60 CI_Lower_D_Border61 CI_Lower_D_Border62 CI_Lower_D_Border63 CI_Lower_D_Border64 CI_Lower_D_Border65 CI_Lower_D_Border66 CI_Lower_D_Border67 CI_Lower_D_Border68 CI_Lower_D_Border69 CI_Lower_D_Border70 CI_Lower_D_Border71 CI_Lower_D_Border72 CI_Lower_D_Border73 CI_Lower_D_Border74 CI_Lower_D_Border75 CI_Lower_D_Border76 CI_Lower_D_Border77 CI_Lower_D_Border78 CI_Lower_D_Border79 CI_Lower_D_Border80 SD_10_D_Border20 CI_Upper_10_D_Border20 CI_Lower_10_D_Border20 SD_10_D_Border21 CI_Upper_10_D_Border21 CI_Lower_10_D_Border21 SD_10_D_Border22 CI_Upper_10_D_Border22 CI_Lower_10_D_Border22 SD_10_D_Border23 CI_Upper_10_D_Border23 CI_Lower_10_D_Border23 SD_10_D_Border24 CI_Upper_10_D_Border24 CI_Lower_10_D_Border24 SD_10_D_Border25 CI_Upper_10_D_Border25 CI_Lower_10_D_Border25 SD_10_D_Border26 CI_Upper_10_D_Border26 CI_Lower_10_D_Border26 SD_10_D_Border27 CI_Upper_10_D_Border27 CI_Lower_10_D_Border27 SD_10_D_Border28 CI_Upper_10_D_Border28 CI_Lower_10_D_Border28 SD_10_D_Border29 CI_Upper_10_D_Border29 CI_Lower_10_D_Border29 SD_10_D_Border30 CI_Upper_10_D_Border30 CI_Lower_10_D_Border30 SD_10_D_Border31 CI_Upper_10_D_Border31 CI_Lower_10_D_Border31 SD_10_D_Border32 CI_Upper_10_D_Border32 CI_Lower_10_D_Border32 SD_10_D_Border33 CI_Upper_10_D_Border33 CI_Lower_10_D_Border33 SD_10_D_Border34 CI_Upper_10_D_Border34 CI_Lower_10_D_Border34 SD_10_D_Border35 CI_Upper_10_D_Border35 CI_Lower_10_D_Border35 SD_10_D_Border36 CI_Upper_10_D_Border36 CI_Lower_10_D_Border36 SD_10_D_Border37 CI_Upper_10_D_Border37 CI_Lower_10_D_Border37 SD_10_D_Border38 CI_Upper_10_D_Border38 CI_Lower_10_D_Border38 SD_10_D_Border39 CI_Upper_10_D_Border39 CI_Lower_10_D_Border39 SD_10_D_Border40 CI_Upper_10_D_Border40 CI_Lower_10_D_Border40 SD_10_D_Border41 CI_Upper_10_D_Border41 CI_Lower_10_D_Border41 SD_10_D_Border42 CI_Upper_10_D_Border42 CI_Lower_10_D_Border42 SD_10_D_Border43 CI_Upper_10_D_Border43 CI_Lower_10_D_Border43 SD_10_D_Border44 CI_Upper_10_D_Border44 CI_Lower_10_D_Border44 SD_10_D_Border45 CI_Upper_10_D_Border45 CI_Lower_10_D_Border45 SD_10_D_Border46 CI_Upper_10_D_Border46 CI_Lower_10_D_Border46 SD_10_D_Border47 CI_Upper_10_D_Border47 CI_Lower_10_D_Border47 SD_10_D_Border48 CI_Upper_10_D_Border48 CI_Lower_10_D_Border48 SD_10_D_Border49 CI_Upper_10_D_Border49 CI_Lower_10_D_Border49 SD_10_D_Border50 CI_Upper_10_D_Border50 CI_Lower_10_D_Border50 SD_10_D_Border51 CI_Upper_10_D_Border51 CI_Lower_10_D_Border51 SD_10_D_Border52 CI_Upper_10_D_Border52 CI_Lower_10_D_Border52 SD_10_D_Border53 CI_Upper_10_D_Border53 CI_Lower_10_D_Border53 SD_10_D_Border54 CI_Upper_10_D_Border54 CI_Lower_10_D_Border54 SD_10_D_Border55 CI_Upper_10_D_Border55 CI_Lower_10_D_Border55 SD_10_D_Border56 CI_Upper_10_D_Border56 CI_Lower_10_D_Border56 SD_10_D_Border57 CI_Upper_10_D_Border57 CI_Lower_10_D_Border57 SD_10_D_Border58 CI_Upper_10_D_Border58 CI_Lower_10_D_Border58 SD_10_D_Border59 CI_Upper_10_D_Border59 CI_Lower_10_D_Border59 SD_10_D_Border60 CI_Upper_10_D_Border60 CI_Lower_10_D_Border60 SD_10_D_Border61 CI_Upper_10_D_Border61 CI_Lower_10_D_Border61 SD_10_D_Border62 CI_Upper_10_D_Border62 CI_Lower_10_D_Border62 SD_10_D_Border63 CI_Upper_10_D_Border63 CI_Lower_10_D_Border63 SD_10_D_Border64 CI_Upper_10_D_Border64 CI_Lower_10_D_Border64 SD_10_D_Border65 CI_Upper_10_D_Border65 CI_Lower_10_D_Border65 SD_10_D_Border66 CI_Upper_10_D_Border66 CI_Lower_10_D_Border66 SD_10_D_Border67 CI_Upper_10_D_Border67 CI_Lower_10_D_Border67 SD_10_D_Border68 CI_Upper_10_D_Border68 CI_Lower_10_D_Border68 SD_10_D_Border69 CI_Upper_10_D_Border69 CI_Lower_10_D_Border69 SD_10_D_Border70 CI_Upper_10_D_Border70 CI_Lower_10_D_Border70 SD_10_D_Border71 CI_Upper_10_D_Border71 CI_Lower_10_D_Border71 SD_10_D_Border72 CI_Upper_10_D_Border72 CI_Lower_10_D_Border72 SD_10_D_Border73 CI_Upper_10_D_Border73 CI_Lower_10_D_Border73 SD_10_D_Border74 CI_Upper_10_D_Border74 CI_Lower_10_D_Border74 SD_10_D_Border75 CI_Upper_10_D_Border75 CI_Lower_10_D_Border75 SD_10_D_Border76 CI_Upper_10_D_Border76 CI_Lower_10_D_Border76 SD_10_D_Border77 CI_Upper_10_D_Border77 CI_Lower_10_D_Border77 SD_10_D_Border78 CI_Upper_10_D_Border78 CI_Lower_10_D_Border78 SD_10_D_Border79 CI_Upper_10_D_Border79 CI_Lower_10_D_Border79 SD_10_D_Border80 CI_Upper_10_D_Border80 CI_Lower_10_D_Border80

reshape long Beta_D_Border CI_Upper_D_Border CI_Lower_D_Border CI_Upper_10_D_Border CI_Lower_10_D_Border, i(N) j(band)

twoway (line Beta_D_Border band, lcolor(black) lpattern(solid)) ///
	(line CI_Upper_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Lower_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Upper_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)) ///
	(line CI_Lower_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)), ///
    ytitle(Estimated Effect Anglophone, size(small)) ylabel(-1.5(.5)1.5,  angle(horizontal))  ///
    xtitle(Distance from Border (km) ) xtitle(, size(small)) xlabel(20(10)80, labsize(vsmall))  ///
           yline(0, lcolor(gs10)) ///
      plotregion(lcolor(black)) ///
  legend(off) ///
        title(e. Attend a Protest, size(medsmall)) ///
    scheme(s2mono) graphregion(fcolor(white)) 

	
	
************************************************************************************************
*********************** TABLE 2 - GENERALIZABILITY OF THE ARGUMENT *****************************
************************************************************************************************
use GeneralizabilityData.dta, clear

* controls
global governance ln_D_Capital_km 
global geo avg_temp avg_prec cec_mean avg_alt
global AB female age education rural

d $geo 
d $governance
d $AB

 
**Mechanism #1 - Local Gov. Legitimacy
xtmixed Councilor_Listens anglophone $AB $governance $geo settler_colony || CountryName:, vce(robust)
xtmixed Councilor_Performance anglophone $AB $governance $geo settler_colony || CountryName:, vce(robust)
xtmixed Contact_Official anglophone $AB $governance $geo settler_colony || CountryName:, vce(robust)
xtmixed CommunityGroupMember anglophone $AB $governance $geo settler_colony || CountryName:, vce(robust)

**Mechanism #2 - Traditional Authority
xtmixed Trust_TAs anglophone $AB $governance $geo settler_colony || CountryName:, vce(robust)
xtmixed Corrupt_TAs anglophone $AB $governance $geo settler_colony || CountryName:, vce(robust)
xtmixed Contact_TAs anglophone $AB $governance $geo settler_colony || CountryName:, vce(robust)
xtmixed TA_Performance anglophone $AB $governance $geo settler_colony || CountryName:, vce(robust)

**Mechanism #2 - Ethnicity
xtmixed EthnicIDs anglophone $AB $governance $geo settler_colony || CountryName:, vce(robust)
xtmixed HelpOwnComm anglophone $AB $governance $geo settler_colony || CountryName:, vce(robust)
