************************************************************************************************
************************************************************************************************
* Replication Materials for Supplementary Materials: “The Mechanisms of Direct and Indirect Rule: Colonialism and Economic Development in Africa”
* Authors: Natalie Lest and Martha Wilfahrt
* Journal: Quarterly Journal of Political Science
* Version Date: 12 January 2010
************************************************************************************************
************************************************************************************************

cd "Letsa Wilfahrt_QJPS Replication Materials/Data/"

use AfroBarometerData.dta, clear

* controls
global governance ln_d_yaounde_km ln_d_regcapital_km
global geo avg_temp avg_prec cec_mean avg_alt 
global colonial ln_d_Protestant_km_1960 ln_d_Railway_km ln_d_coast_km
global AB female age education rural

d $geo 
d $governance
d $colonial
d $AB

* polynomials
global MDpolynomial anglophone latitude longitude Lat_x_Long latitude2 longitude2 border_longitude border_latitude
global LocalLinear anglophone d_border_km Anglo_x_Border
global CubicPolyDist anglophone d_border_km d_border_km2 d_border_km3
global MDCubicPoly anglophone latitude longitude latitude2 longitude2 Lat_x_Long latitude3 longitude3 lat_x_long2 lat2_x_long border_longitude border_latitude 

d $MDpolynomial
d $LocalLinear
d $CubicPolyDist
d $MDCubicPoly

************************************************************************************************
**************************** TABLE A1.2 - PRETREATMENT BALANCE *********************************
************************************************************************************************

import excel "GeoBalance_Grid Data.xlsx", sheet("Sheet1") firstrow clear

replace anglophone = 0 if anglophone == .

gen D_Border_Rounded = round(d_border_km, 1)
gen D_Border1 = D_Border_Rounded < 2
gen D_Border5 = D_Border_Rounded < 6
gen D_Border10 = D_Border_Rounded < 11
gen D_Border15 = D_Border_Rounded < 16
gen D_Border20 = D_Border_Rounded < 21
gen D_Border25 = D_Border_Rounded < 26
gen D_Border30 = D_Border_Rounded < 31
gen D_Border35 = D_Border_Rounded < 36
gen D_Border40 = D_Border_Rounded < 41
gen D_Border45 = D_Border_Rounded < 46
gen D_Border50 = D_Border_Rounded < 51
gen D_Border55 = D_Border_Rounded < 56
gen D_Border60 = D_Border_Rounded < 61
gen D_Border65 = D_Border_Rounded < 66
gen D_Border70 = D_Border_Rounded < 71
gen D_Border75 = D_Border_Rounded < 76
gen D_Border80 = D_Border_Rounded < 81
gen D_Border85 = D_Border_Rounded < 86
gen D_Border90 = D_Border_Rounded < 91
gen D_Border95 = D_Border_Rounded < 96
gen D_Border100 = D_Border_Rounded < 101

save "Geobalance_Data.dta", replace


* a. altitude
use Geobalance_Data.dta, clear

foreach var of varlist D_Border1 D_Border5 D_Border10 D_Border15 D_Border20 D_Border25 D_Border30 D_Border35 D_Border40 D_Border45 D_Border50 D_Border55  D_Border60 D_Border65 D_Border70  D_Border75 D_Border80 D_Border85 D_Border90 D_Border95 D_Border100 {
	quietly ttest avg_alt if `var' == 1, by(anglophone)
	gen T1`var'= r(mu_1)
	gen T2`var'= r(mu_2)
	gen T_SE_`var'= r(se)
} 


foreach var of varlist D_Border1 D_Border5 D_Border10 D_Border15 D_Border20 D_Border25 D_Border30 D_Border35 D_Border40 D_Border45 D_Border50 D_Border55  D_Border60 D_Border65 D_Border70  D_Border75 D_Border80 D_Border85 D_Border90 D_Border95 D_Border100 {
	gen T_Diff_`var' = T2`var'-T1`var'
	gen T_Upper_`var' = T_Diff_`var'+(T_SE_`var'*1.96)
	gen T_Lower_`var' = T_Diff_`var'-(T_SE_`var'*1.96)
} 

gen N = _n
drop if N !=1
keep N T_Diff_D_Border1 T_Upper_D_Border1 T_Lower_D_Border1 T_Diff_D_Border5 T_Upper_D_Border5 T_Lower_D_Border5 T_Diff_D_Border10 T_Upper_D_Border10 T_Lower_D_Border10 T_Diff_D_Border15 T_Upper_D_Border15 T_Lower_D_Border15 T_Diff_D_Border20 T_Upper_D_Border20 T_Lower_D_Border20 T_Diff_D_Border25 T_Upper_D_Border25 T_Lower_D_Border25 T_Diff_D_Border30 T_Upper_D_Border30 T_Lower_D_Border30 T_Diff_D_Border35 T_Upper_D_Border35 T_Lower_D_Border35 T_Diff_D_Border40 T_Upper_D_Border40 T_Lower_D_Border40 T_Diff_D_Border45 T_Upper_D_Border45 T_Lower_D_Border45 T_Diff_D_Border50 T_Upper_D_Border50 T_Lower_D_Border50 T_Diff_D_Border55 T_Upper_D_Border55 T_Lower_D_Border55 T_Diff_D_Border60 T_Upper_D_Border60 T_Lower_D_Border60 T_Diff_D_Border65 T_Upper_D_Border65 T_Lower_D_Border65 T_Diff_D_Border70 T_Upper_D_Border70 T_Lower_D_Border70 T_Diff_D_Border75 T_Upper_D_Border75 T_Lower_D_Border75 T_Diff_D_Border80 T_Upper_D_Border80 T_Lower_D_Border80 T_Diff_D_Border85 T_Upper_D_Border85 T_Lower_D_Border85 T_Diff_D_Border90 T_Upper_D_Border90 T_Lower_D_Border90 T_Diff_D_Border95 T_Upper_D_Border95 T_Lower_D_Border95 T_Diff_D_Border100 T_Upper_D_Border100 T_Lower_D_Border100

reshape long T_Diff_D_Border T_Upper_D_Border T_Lower_D_Border, i(N) j(band)

twoway (line T_Diff_D_Border band, lcolor(black) lpattern(solid)) ///
	(line T_Upper_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line T_Lower_D_Border band, lcolor(black) lpattern(tight_dot)), ///
    ytitle(Difference of Means, size(small)) ylabel(-300(50)50,  angle(horizontal))  ///
    xtitle(Distance from Border (km) ) xtitle(, size(small)) xlabel(, labsize(vsmall))  ///
       legend(off) ///
        title(a. Altitude, size(medsmall)) ///
    scheme(s2mono) graphregion(fcolor(white)) 


*b. Avg Precipitation
use Geobalance_Data.dta, clear

foreach var of varlist D_Border1 D_Border5 D_Border10 D_Border15 D_Border20 D_Border25 D_Border30 D_Border35 D_Border40 D_Border45 D_Border50 D_Border55  D_Border60 D_Border65 D_Border70  D_Border75 D_Border80 D_Border85 D_Border90 D_Border95 D_Border100 {
	quietly ttest avg_prec if `var' == 1, by(anglophone)
	return list
	gen T1`var'= r(mu_1)
	gen T2`var'= r(mu_2)
	gen T_SE_`var'= r(se)
} 


foreach var of varlist D_Border1 D_Border5 D_Border10 D_Border15 D_Border20 D_Border25 D_Border30 D_Border35 D_Border40 D_Border45 D_Border50 D_Border55  D_Border60 D_Border65 D_Border70  D_Border75 D_Border80 D_Border85 D_Border90 D_Border95 D_Border100 {
	gen T_Diff_`var' = T2`var'-T1`var'
	gen T_Upper_`var' = T_Diff_`var'+(T_SE_`var'*1.96)
	gen T_Lower_`var' = T_Diff_`var'-(T_SE_`var'*1.96)
} 


gen N = _n
drop if N !=1
keep N T_Diff_D_Border1 T_Upper_D_Border1 T_Lower_D_Border1 T_Diff_D_Border5 T_Upper_D_Border5 T_Lower_D_Border5 T_Diff_D_Border10 T_Upper_D_Border10 T_Lower_D_Border10 T_Diff_D_Border15 T_Upper_D_Border15 T_Lower_D_Border15 T_Diff_D_Border20 T_Upper_D_Border20 T_Lower_D_Border20 T_Diff_D_Border25 T_Upper_D_Border25 T_Lower_D_Border25 T_Diff_D_Border30 T_Upper_D_Border30 T_Lower_D_Border30 T_Diff_D_Border35 T_Upper_D_Border35 T_Lower_D_Border35 T_Diff_D_Border40 T_Upper_D_Border40 T_Lower_D_Border40 T_Diff_D_Border45 T_Upper_D_Border45 T_Lower_D_Border45 T_Diff_D_Border50 T_Upper_D_Border50 T_Lower_D_Border50 T_Diff_D_Border55 T_Upper_D_Border55 T_Lower_D_Border55 T_Diff_D_Border60 T_Upper_D_Border60 T_Lower_D_Border60 T_Diff_D_Border65 T_Upper_D_Border65 T_Lower_D_Border65 T_Diff_D_Border70 T_Upper_D_Border70 T_Lower_D_Border70 T_Diff_D_Border75 T_Upper_D_Border75 T_Lower_D_Border75 T_Diff_D_Border80 T_Upper_D_Border80 T_Lower_D_Border80 T_Diff_D_Border85 T_Upper_D_Border85 T_Lower_D_Border85 T_Diff_D_Border90 T_Upper_D_Border90 T_Lower_D_Border90 T_Diff_D_Border95 T_Upper_D_Border95 T_Lower_D_Border95 T_Diff_D_Border100 T_Upper_D_Border100 T_Lower_D_Border100

reshape long T_Diff_D_Border T_Upper_D_Border T_Lower_D_Border, i(N) j(band)

twoway (line T_Diff_D_Border band, lcolor(black) lpattern(solid)) ///
	(line T_Upper_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line T_Lower_D_Border band, lcolor(black) lpattern(tight_dot)), ///
    ytitle(Difference of Means, size(small)) ylabel(-300(50)50,  angle(horizontal))  ///
    xtitle(Distance from Border (km) ) xtitle(, size(small)) xlabel(, labsize(vsmall))  ///
       legend(off) ///
        title(b. Precipitation, size(medsmall)) ///
    scheme(s2mono) graphregion(fcolor(white)) 


*c. temperature
use Geobalance_Data.dta, clear

* create loop to generate difference in means and CI for bandwidths 10-100

foreach var of varlist D_Border1 D_Border5 D_Border10 D_Border15 D_Border20 D_Border25 D_Border30 D_Border35 D_Border40 D_Border45 D_Border50 D_Border55  D_Border60 D_Border65 D_Border70  D_Border75 D_Border80 D_Border85 D_Border90 D_Border95 D_Border100 {
	quietly ttest avg_temp if `var' == 1, by(anglophone)
	gen T1`var'= r(mu_1)
	gen T2`var'= r(mu_2)
	gen T_SE_`var'= r(se)
} 


foreach var of varlist D_Border1 D_Border5 D_Border10 D_Border15 D_Border20 D_Border25 D_Border30 D_Border35 D_Border40 D_Border45 D_Border50 D_Border55  D_Border60 D_Border65 D_Border70  D_Border75 D_Border80 D_Border85 D_Border90 D_Border95 D_Border100 {
	gen T_Diff_`var' = T2`var'-T1`var'
	gen T_Upper_`var' = T_Diff_`var'+(T_SE_`var'*1.96)
	gen T_Lower_`var' = T_Diff_`var'-(T_SE_`var'*1.96)
} 


gen N = _n
drop if N !=1
keep N T_Diff_D_Border1 T_Upper_D_Border1 T_Lower_D_Border1 T_Diff_D_Border5 T_Upper_D_Border5 T_Lower_D_Border5 T_Diff_D_Border10 T_Upper_D_Border10 T_Lower_D_Border10 T_Diff_D_Border15 T_Upper_D_Border15 T_Lower_D_Border15 T_Diff_D_Border20 T_Upper_D_Border20 T_Lower_D_Border20 T_Diff_D_Border25 T_Upper_D_Border25 T_Lower_D_Border25 T_Diff_D_Border30 T_Upper_D_Border30 T_Lower_D_Border30 T_Diff_D_Border35 T_Upper_D_Border35 T_Lower_D_Border35 T_Diff_D_Border40 T_Upper_D_Border40 T_Lower_D_Border40 T_Diff_D_Border45 T_Upper_D_Border45 T_Lower_D_Border45 T_Diff_D_Border50 T_Upper_D_Border50 T_Lower_D_Border50 T_Diff_D_Border55 T_Upper_D_Border55 T_Lower_D_Border55 T_Diff_D_Border60 T_Upper_D_Border60 T_Lower_D_Border60 T_Diff_D_Border65 T_Upper_D_Border65 T_Lower_D_Border65 T_Diff_D_Border70 T_Upper_D_Border70 T_Lower_D_Border70 T_Diff_D_Border75 T_Upper_D_Border75 T_Lower_D_Border75 T_Diff_D_Border80 T_Upper_D_Border80 T_Lower_D_Border80 T_Diff_D_Border85 T_Upper_D_Border85 T_Lower_D_Border85 T_Diff_D_Border90 T_Upper_D_Border90 T_Lower_D_Border90 T_Diff_D_Border95 T_Upper_D_Border95 T_Lower_D_Border95 T_Diff_D_Border100 T_Upper_D_Border100 T_Lower_D_Border100

reshape long T_Diff_D_Border T_Upper_D_Border T_Lower_D_Border, i(N) j(band)


twoway (line T_Diff_D_Border band, lcolor(black) lpattern(solid)) ///
	(line T_Upper_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line T_Lower_D_Border band, lcolor(black) lpattern(tight_dot)), ///
    ytitle(Difference of Means, size(small)) ylabel(-5(5)15,  angle(horizontal))  ///
    xtitle(Distance from Border (km) ) xtitle(, size(small)) xlabel(, labsize(vsmall))  ///
       legend(off) ///
        title(c. Average Temperature, size(medsmall)) ///
    scheme(s2mono) graphregion(fcolor(white)) 


*d. Average Soil Captation (CEC)
use Geobalance_Data.dta, clear

foreach var of varlist D_Border1 D_Border5 D_Border10 D_Border15 D_Border20 D_Border25 D_Border30 D_Border35 D_Border40 D_Border45 D_Border50 D_Border55  D_Border60 D_Border65 D_Border70  D_Border75 D_Border80 D_Border85 D_Border90 D_Border95 D_Border100 {
	ttest cec_mean if `var' == 1, by(anglophone)
	return list
	gen T1`var'= r(mu_1)
	gen T2`var'= r(mu_2)
	gen T_SE_`var'= r(se)
} 

foreach var of varlist D_Border1 D_Border5 D_Border10 D_Border15 D_Border20 D_Border25 D_Border30 D_Border35 D_Border40 D_Border45 D_Border50 D_Border55  D_Border60 D_Border65 D_Border70  D_Border75 D_Border80 D_Border85 D_Border90 D_Border95 D_Border100 {
	gen T_Diff_`var' = T2`var'-T1`var'
	gen T_Upper_`var' = T_Diff_`var'+(T_SE_`var'*1.96)
	gen T_Lower_`var' = T_Diff_`var'-(T_SE_`var'*1.96)
} 

gen N = _n
drop if N !=1
keep N T_Diff_D_Border1 T_Upper_D_Border1 T_Lower_D_Border1 T_Diff_D_Border5 T_Upper_D_Border5 T_Lower_D_Border5 T_Diff_D_Border10 T_Upper_D_Border10 T_Lower_D_Border10 T_Diff_D_Border15 T_Upper_D_Border15 T_Lower_D_Border15 T_Diff_D_Border20 T_Upper_D_Border20 T_Lower_D_Border20 T_Diff_D_Border25 T_Upper_D_Border25 T_Lower_D_Border25 T_Diff_D_Border30 T_Upper_D_Border30 T_Lower_D_Border30 T_Diff_D_Border35 T_Upper_D_Border35 T_Lower_D_Border35 T_Diff_D_Border40 T_Upper_D_Border40 T_Lower_D_Border40 T_Diff_D_Border45 T_Upper_D_Border45 T_Lower_D_Border45 T_Diff_D_Border50 T_Upper_D_Border50 T_Lower_D_Border50 T_Diff_D_Border55 T_Upper_D_Border55 T_Lower_D_Border55 T_Diff_D_Border60 T_Upper_D_Border60 T_Lower_D_Border60 T_Diff_D_Border65 T_Upper_D_Border65 T_Lower_D_Border65 T_Diff_D_Border70 T_Upper_D_Border70 T_Lower_D_Border70 T_Diff_D_Border75 T_Upper_D_Border75 T_Lower_D_Border75 T_Diff_D_Border80 T_Upper_D_Border80 T_Lower_D_Border80 T_Diff_D_Border85 T_Upper_D_Border85 T_Lower_D_Border85 T_Diff_D_Border90 T_Upper_D_Border90 T_Lower_D_Border90 T_Diff_D_Border95 T_Upper_D_Border95 T_Lower_D_Border95 T_Diff_D_Border100 T_Upper_D_Border100 T_Lower_D_Border100

reshape long T_Diff_D_Border T_Upper_D_Border T_Lower_D_Border, i(N) j(band)

twoway (line T_Diff_D_Border band, lcolor(black) lpattern(solid)) ///
	(line T_Upper_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line T_Lower_D_Border band, lcolor(black) lpattern(tight_dot)), ///
    ytitle(Difference of Means, size(small)) ylabel(-5(5)15,  angle(horizontal))  ///
    xtitle(Distance from Border (km) ) xtitle(, size(small)) xlabel(, labsize(vsmall))  ///
       legend(off) ///
        title(d. Average Soil CEC, size(medsmall)) ///
    scheme(s2mono) graphregion(fcolor(white)) 

* e. Precolonial centralization
use Nightlight_GIS_FINAL.dta, clear

gen D_Border1 = D_Border_Rounded < 2
gen D_Border5 = D_Border_Rounded < 6
gen D_Border10 = D_Border_Rounded < 11
gen D_Border85 = D_Border_Rounded < 86
gen D_Border90 = D_Border_Rounded < 91
gen D_Border95 = D_Border_Rounded < 96
gen D_Border100 = D_Border_Rounded < 101


foreach var of varlist D_Border1 D_Border5 D_Border10 D_Border15 D_Border20 D_Border25 D_Border30 D_Border35 D_Border40 D_Border45 D_Border50 D_Border55 D_Border60 D_Border65 D_Border70 D_Border75 D_Border80 D_Border85 D_Border90 D_Border95 D_Border100 {
	quietly ttest murdock_jurihier if `var' == 1, by(anglophone)
	gen T1`var'= r(mu_1)
	gen T2`var'= r(mu_2)
	gen T_SE_`var'= r(se)
} 


* generate Difference and 95% CIs

foreach var of varlist D_Border1 D_Border5 D_Border10 D_Border15 D_Border20 D_Border25 D_Border30 D_Border35 D_Border40 D_Border45 D_Border50 D_Border55 D_Border60 D_Border65 D_Border70 D_Border75 D_Border80 D_Border85 D_Border90 D_Border95 D_Border100 {
	gen T_Diff_`var' = T2`var'-T1`var'
	gen T_Upper_`var' = T_Diff_`var'+(T_SE_`var'*1.96)
	gen T_Lower_`var' = T_Diff_`var'-(T_SE_`var'*1.96)
} 


gen N = _n
drop if N !=1
keep N T_Diff_D_Border1 T_Upper_D_Border1 T_Lower_D_Border1 T_Diff_D_Border5 T_Upper_D_Border5 T_Lower_D_Border5 T_Diff_D_Border10 T_Upper_D_Border10 T_Lower_D_Border10 T_Diff_D_Border15 T_Upper_D_Border15 T_Lower_D_Border15 T_Diff_D_Border20 T_Upper_D_Border20 T_Lower_D_Border20 T_Diff_D_Border25 T_Upper_D_Border25 T_Lower_D_Border25 T_Diff_D_Border30 T_Upper_D_Border30 T_Lower_D_Border30 T_Diff_D_Border35 T_Upper_D_Border35 T_Lower_D_Border35 T_Diff_D_Border40 T_Upper_D_Border40 T_Lower_D_Border40 T_Diff_D_Border45 T_Upper_D_Border45 T_Lower_D_Border45 T_Diff_D_Border50 T_Upper_D_Border50 T_Lower_D_Border50 T_Diff_D_Border55 T_Upper_D_Border55 T_Lower_D_Border55 T_Diff_D_Border60 T_Upper_D_Border60 T_Lower_D_Border60 T_Diff_D_Border65 T_Upper_D_Border65 T_Lower_D_Border65 T_Diff_D_Border70 T_Upper_D_Border70 T_Lower_D_Border70 T_Diff_D_Border75 T_Upper_D_Border75 T_Lower_D_Border75 T_Diff_D_Border80 T_Upper_D_Border80 T_Lower_D_Border80 T_Diff_D_Border85 T_Upper_D_Border85 T_Lower_D_Border85 T_Diff_D_Border90 T_Upper_D_Border90 T_Lower_D_Border90 T_Diff_D_Border95 T_Upper_D_Border95 T_Lower_D_Border95 T_Diff_D_Border100 T_Upper_D_Border100 T_Lower_D_Border100

reshape long T_Diff_D_Border T_Upper_D_Border T_Lower_D_Border, i(N) j(band)

twoway (line T_Diff_D_Border band, lcolor(black) lpattern(solid)) ///
	(line T_Upper_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line T_Lower_D_Border band, lcolor(black) lpattern(tight_dot)), ///
    ytitle(Difference of Means, size(small)) ylabel(-1(.5)1,  angle(horizontal))  ///
    xtitle(Distance from Border (km) ) xtitle(, size(small)) xlabel(, labsize(vsmall))  ///
       legend(off) ///
        title(e. Precolonial Centralization, size(medsmall)) ///
    scheme(s2mono) graphregion(fcolor(white)) 



************************************************************************************************
************************** TABLE A2 - LEE AND SCHULTZ REPLICATION ******************************
************************************************************************************************

* Panel a: Avg Cluster Household Wealth
use "Merged_DHS Data.dta", clear
drop if Year == 1991
drop if Comp_Zone == 0

foreach var of varlist D_Border15-D_Border80 {
	quietly reg z2_LS_Poss_NoElec $MDpolynomial i.Year Ln_Pop_5km Urban $geo $governance if `var'==1, robust 
	gen Beta_`var' = _b[anglophone]
	matrix c_`var' = e(V)
	gen Var_`var' = c_`var'[1,1]
} 

foreach var of varlist D_Border15-D_Border80 {
	gen SD_`var' = sqrt(Var_`var')
	gen CI_Upper_`var' = Beta_`var'+(SD_`var'*1.96)
	gen CI_Lower_`var' = Beta_`var'-(SD_`var'*1.96)
}

foreach var of varlist D_Border15-D_Border80 {
	gen SD_10_`var' = sqrt(Var_`var')
	gen CI_Upper_10_`var' = Beta_`var'+(SD_`var'*1.645)
	gen CI_Lower_10_`var' = Beta_`var'-(SD_`var'*1.645)
}

gen N = _n
drop if N !=1
keep N Beta_D_Border15 Beta_D_Border16 Beta_D_Border17 Beta_D_Border18 Beta_D_Border19 Beta_D_Border20 Beta_D_Border21 Beta_D_Border22 Beta_D_Border23 Beta_D_Border24 Beta_D_Border25 Beta_D_Border26 Beta_D_Border27 Beta_D_Border28 Beta_D_Border29 Beta_D_Border30 Beta_D_Border31 Beta_D_Border32 Beta_D_Border33 Beta_D_Border34 Beta_D_Border35 Beta_D_Border36 Beta_D_Border37 Beta_D_Border38 Beta_D_Border39 Beta_D_Border40 Beta_D_Border41 Beta_D_Border42 Beta_D_Border43 Beta_D_Border44 Beta_D_Border45 Beta_D_Border46 Beta_D_Border47 Beta_D_Border48 Beta_D_Border49 Beta_D_Border50 Beta_D_Border51 Beta_D_Border52 Beta_D_Border53 Beta_D_Border54 Beta_D_Border55 Beta_D_Border56 Beta_D_Border57 Beta_D_Border58 Beta_D_Border59 Beta_D_Border60 Beta_D_Border61 Beta_D_Border62 Beta_D_Border63 Beta_D_Border64 Beta_D_Border65 Beta_D_Border66 Beta_D_Border67 Beta_D_Border68 Beta_D_Border69 Beta_D_Border70 Beta_D_Border71 Beta_D_Border72 Beta_D_Border73 Beta_D_Border74 Beta_D_Border75 Beta_D_Border76 Beta_D_Border77 Beta_D_Border78 Beta_D_Border79 Beta_D_Border80 CI_Upper_D_Border15 CI_Upper_D_Border16 CI_Upper_D_Border17 CI_Upper_D_Border18 CI_Upper_D_Border19 CI_Upper_D_Border20 CI_Upper_D_Border21 CI_Upper_D_Border22 CI_Upper_D_Border23 CI_Upper_D_Border24 CI_Upper_D_Border25 CI_Upper_D_Border26 CI_Upper_D_Border27 CI_Upper_D_Border28 CI_Upper_D_Border29 CI_Upper_D_Border30 CI_Upper_D_Border31 CI_Upper_D_Border32 CI_Upper_D_Border33 CI_Upper_D_Border34 CI_Upper_D_Border35 CI_Upper_D_Border36 CI_Upper_D_Border37 CI_Upper_D_Border38 CI_Upper_D_Border39 CI_Upper_D_Border40 CI_Upper_D_Border41 CI_Upper_D_Border42 CI_Upper_D_Border43 CI_Upper_D_Border44 CI_Upper_D_Border45 CI_Upper_D_Border46 CI_Upper_D_Border47 CI_Upper_D_Border48 CI_Upper_D_Border49 CI_Upper_D_Border50 CI_Upper_D_Border51 CI_Upper_D_Border52 CI_Upper_D_Border53 CI_Upper_D_Border54 CI_Upper_D_Border55 CI_Upper_D_Border56 CI_Upper_D_Border57 CI_Upper_D_Border58 CI_Upper_D_Border59 CI_Upper_D_Border60 CI_Upper_D_Border61 CI_Upper_D_Border62 CI_Upper_D_Border63 CI_Upper_D_Border64 CI_Upper_D_Border65 CI_Upper_D_Border66 CI_Upper_D_Border67 CI_Upper_D_Border68 CI_Upper_D_Border69 CI_Upper_D_Border70 CI_Upper_D_Border71 CI_Upper_D_Border72 CI_Upper_D_Border73 CI_Upper_D_Border74 CI_Upper_D_Border75 CI_Upper_D_Border76 CI_Upper_D_Border77 CI_Upper_D_Border78 CI_Upper_D_Border79 CI_Upper_D_Border80 CI_Lower_D_Border15 CI_Lower_D_Border16 CI_Lower_D_Border17 CI_Lower_D_Border18 CI_Lower_D_Border19 CI_Lower_D_Border20 CI_Lower_D_Border21 CI_Lower_D_Border22 CI_Lower_D_Border23 CI_Lower_D_Border24 CI_Lower_D_Border25 CI_Lower_D_Border26 CI_Lower_D_Border27 CI_Lower_D_Border28 CI_Lower_D_Border29 CI_Lower_D_Border30 CI_Lower_D_Border31 CI_Lower_D_Border32 CI_Lower_D_Border33 CI_Lower_D_Border34 CI_Lower_D_Border35 CI_Lower_D_Border36 CI_Lower_D_Border37 CI_Lower_D_Border38 CI_Lower_D_Border39 CI_Lower_D_Border40 CI_Lower_D_Border41 CI_Lower_D_Border42 CI_Lower_D_Border43 CI_Lower_D_Border44 CI_Lower_D_Border45 CI_Lower_D_Border46 CI_Lower_D_Border47 CI_Lower_D_Border48 CI_Lower_D_Border49 CI_Lower_D_Border50 CI_Lower_D_Border51 CI_Lower_D_Border52 CI_Lower_D_Border53 CI_Lower_D_Border54 CI_Lower_D_Border55 CI_Lower_D_Border56 CI_Lower_D_Border57 CI_Lower_D_Border58 CI_Lower_D_Border59 CI_Lower_D_Border60 CI_Lower_D_Border61 CI_Lower_D_Border62 CI_Lower_D_Border63 CI_Lower_D_Border64 CI_Lower_D_Border65 CI_Lower_D_Border66 CI_Lower_D_Border67 CI_Lower_D_Border68 CI_Lower_D_Border69 CI_Lower_D_Border70 CI_Lower_D_Border71 CI_Lower_D_Border72 CI_Lower_D_Border73 CI_Lower_D_Border74 CI_Lower_D_Border75 CI_Lower_D_Border76 CI_Lower_D_Border77 CI_Lower_D_Border78 CI_Lower_D_Border79 CI_Lower_D_Border80 SD_10_D_Border15 CI_Upper_10_D_Border15 CI_Lower_10_D_Border15 SD_10_D_Border16 CI_Upper_10_D_Border16 CI_Lower_10_D_Border16 SD_10_D_Border17 CI_Upper_10_D_Border17 CI_Lower_10_D_Border17 SD_10_D_Border18 CI_Upper_10_D_Border18 CI_Lower_10_D_Border18 SD_10_D_Border19 CI_Upper_10_D_Border19 CI_Lower_10_D_Border19 SD_10_D_Border20 CI_Upper_10_D_Border20 CI_Lower_10_D_Border20 SD_10_D_Border21 CI_Upper_10_D_Border21 CI_Lower_10_D_Border21 SD_10_D_Border22 CI_Upper_10_D_Border22 CI_Lower_10_D_Border22 SD_10_D_Border23 CI_Upper_10_D_Border23 CI_Lower_10_D_Border23 SD_10_D_Border24 CI_Upper_10_D_Border24 CI_Lower_10_D_Border24 SD_10_D_Border25 CI_Upper_10_D_Border25 CI_Lower_10_D_Border25 SD_10_D_Border26 CI_Upper_10_D_Border26 CI_Lower_10_D_Border26 SD_10_D_Border27 CI_Upper_10_D_Border27 CI_Lower_10_D_Border27 SD_10_D_Border28 CI_Upper_10_D_Border28 CI_Lower_10_D_Border28 SD_10_D_Border29 CI_Upper_10_D_Border29 CI_Lower_10_D_Border29 SD_10_D_Border30 CI_Upper_10_D_Border30 CI_Lower_10_D_Border30 SD_10_D_Border31 CI_Upper_10_D_Border31 CI_Lower_10_D_Border31 SD_10_D_Border32 CI_Upper_10_D_Border32 CI_Lower_10_D_Border32 SD_10_D_Border33 CI_Upper_10_D_Border33 CI_Lower_10_D_Border33 SD_10_D_Border34 CI_Upper_10_D_Border34 CI_Lower_10_D_Border34 SD_10_D_Border35 CI_Upper_10_D_Border35 CI_Lower_10_D_Border35 SD_10_D_Border36 CI_Upper_10_D_Border36 CI_Lower_10_D_Border36 SD_10_D_Border37 CI_Upper_10_D_Border37 CI_Lower_10_D_Border37 SD_10_D_Border38 CI_Upper_10_D_Border38 CI_Lower_10_D_Border38 SD_10_D_Border39 CI_Upper_10_D_Border39 CI_Lower_10_D_Border39 SD_10_D_Border40 CI_Upper_10_D_Border40 CI_Lower_10_D_Border40 SD_10_D_Border41 CI_Upper_10_D_Border41 CI_Lower_10_D_Border41 SD_10_D_Border42 CI_Upper_10_D_Border42 CI_Lower_10_D_Border42 SD_10_D_Border43 CI_Upper_10_D_Border43 CI_Lower_10_D_Border43 SD_10_D_Border44 CI_Upper_10_D_Border44 CI_Lower_10_D_Border44 SD_10_D_Border45 CI_Upper_10_D_Border45 CI_Lower_10_D_Border45 SD_10_D_Border46 CI_Upper_10_D_Border46 CI_Lower_10_D_Border46 SD_10_D_Border47 CI_Upper_10_D_Border47 CI_Lower_10_D_Border47 SD_10_D_Border48 CI_Upper_10_D_Border48 CI_Lower_10_D_Border48 SD_10_D_Border49 CI_Upper_10_D_Border49 CI_Lower_10_D_Border49 SD_10_D_Border50 CI_Upper_10_D_Border50 CI_Lower_10_D_Border50 SD_10_D_Border51 CI_Upper_10_D_Border51 CI_Lower_10_D_Border51 SD_10_D_Border52 CI_Upper_10_D_Border52 CI_Lower_10_D_Border52 SD_10_D_Border53 CI_Upper_10_D_Border53 CI_Lower_10_D_Border53 SD_10_D_Border54 CI_Upper_10_D_Border54 CI_Lower_10_D_Border54 SD_10_D_Border55 CI_Upper_10_D_Border55 CI_Lower_10_D_Border55 SD_10_D_Border56 CI_Upper_10_D_Border56 CI_Lower_10_D_Border56 SD_10_D_Border57 CI_Upper_10_D_Border57 CI_Lower_10_D_Border57 SD_10_D_Border58 CI_Upper_10_D_Border58 CI_Lower_10_D_Border58 SD_10_D_Border59 CI_Upper_10_D_Border59 CI_Lower_10_D_Border59 SD_10_D_Border60 CI_Upper_10_D_Border60 CI_Lower_10_D_Border60 SD_10_D_Border61 CI_Upper_10_D_Border61 CI_Lower_10_D_Border61 SD_10_D_Border62 CI_Upper_10_D_Border62 CI_Lower_10_D_Border62 SD_10_D_Border63 CI_Upper_10_D_Border63 CI_Lower_10_D_Border63 SD_10_D_Border64 CI_Upper_10_D_Border64 CI_Lower_10_D_Border64 SD_10_D_Border65 CI_Upper_10_D_Border65 CI_Lower_10_D_Border65 SD_10_D_Border66 CI_Upper_10_D_Border66 CI_Lower_10_D_Border66 SD_10_D_Border67 CI_Upper_10_D_Border67 CI_Lower_10_D_Border67 SD_10_D_Border68 CI_Upper_10_D_Border68 CI_Lower_10_D_Border68 SD_10_D_Border69 CI_Upper_10_D_Border69 CI_Lower_10_D_Border69 SD_10_D_Border70 CI_Upper_10_D_Border70 CI_Lower_10_D_Border70 SD_10_D_Border71 CI_Upper_10_D_Border71 CI_Lower_10_D_Border71 SD_10_D_Border72 CI_Upper_10_D_Border72 CI_Lower_10_D_Border72 SD_10_D_Border73 CI_Upper_10_D_Border73 CI_Lower_10_D_Border73 SD_10_D_Border74 CI_Upper_10_D_Border74 CI_Lower_10_D_Border74 SD_10_D_Border75 CI_Upper_10_D_Border75 CI_Lower_10_D_Border75 SD_10_D_Border76 CI_Upper_10_D_Border76 CI_Lower_10_D_Border76 SD_10_D_Border77 CI_Upper_10_D_Border77 CI_Lower_10_D_Border77 SD_10_D_Border78 CI_Upper_10_D_Border78 CI_Lower_10_D_Border78 SD_10_D_Border79 CI_Upper_10_D_Border79 CI_Lower_10_D_Border79 SD_10_D_Border80 CI_Upper_10_D_Border80 CI_Lower_10_D_Border80

reshape long Beta_D_Border CI_Upper_D_Border CI_Lower_D_Border CI_Upper_10_D_Border CI_Lower_10_D_Border, i(N) j(band)

twoway (line Beta_D_Border band, lcolor(black) lpattern(solid)) ///
	(line CI_Upper_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Lower_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Upper_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)) ///
	(line CI_Lower_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)), ///
    ytitle(Estimated Effect Anglophone, size(small)) ylabel(-.5(.5)1.5,  angle(horizontal))  ///
    xtitle(Distance from Border (km) ) xtitle(, size(small)) xlabel(15(10)80, labsize(vsmall))  ///
       yline(0, lcolor(gs10)) ///
      plotregion(lcolor(black)) ///
     legend(off) ///
       title(a. Avg Cluster Household Wealth, size(medsmall)) ///
    scheme(s2mono) graphregion(fcolor(white)) 

	
* Panel b: % Drinking water access
use "Merged_DHS Data.dta", clear
drop if Year == 1991
drop if Comp_Zone == 0

foreach var of varlist D_Border15-D_Border80 {
	quietly reg z2_Perc_PipedH20 $MDpolynomial i.Year Urban Ln_Pop_5km $geo $governance if `var'==1, robust 
	gen Beta_`var' = _b[anglophone]
	matrix c_`var' = e(V)
	gen Var_`var' = c_`var'[1,1]
} 

foreach var of varlist D_Border15-D_Border80 {
	gen SD_`var' = sqrt(Var_`var')
	gen CI_Upper_`var' = Beta_`var'+(SD_`var'*1.96)
	gen CI_Lower_`var' = Beta_`var'-(SD_`var'*1.96)
}

foreach var of varlist D_Border15-D_Border80 {
	gen SD_10_`var' = sqrt(Var_`var')
	gen CI_Upper_10_`var' = Beta_`var'+(SD_`var'*1.645)
	gen CI_Lower_10_`var' = Beta_`var'-(SD_`var'*1.645)
}

gen N = _n
drop if N !=1
keep N Beta_D_Border15 Beta_D_Border16 Beta_D_Border17 Beta_D_Border18 Beta_D_Border19 Beta_D_Border20 Beta_D_Border21 Beta_D_Border22 Beta_D_Border23 Beta_D_Border24 Beta_D_Border25 Beta_D_Border26 Beta_D_Border27 Beta_D_Border28 Beta_D_Border29 Beta_D_Border30 Beta_D_Border31 Beta_D_Border32 Beta_D_Border33 Beta_D_Border34 Beta_D_Border35 Beta_D_Border36 Beta_D_Border37 Beta_D_Border38 Beta_D_Border39 Beta_D_Border40 Beta_D_Border41 Beta_D_Border42 Beta_D_Border43 Beta_D_Border44 Beta_D_Border45 Beta_D_Border46 Beta_D_Border47 Beta_D_Border48 Beta_D_Border49 Beta_D_Border50 Beta_D_Border51 Beta_D_Border52 Beta_D_Border53 Beta_D_Border54 Beta_D_Border55 Beta_D_Border56 Beta_D_Border57 Beta_D_Border58 Beta_D_Border59 Beta_D_Border60 Beta_D_Border61 Beta_D_Border62 Beta_D_Border63 Beta_D_Border64 Beta_D_Border65 Beta_D_Border66 Beta_D_Border67 Beta_D_Border68 Beta_D_Border69 Beta_D_Border70 Beta_D_Border71 Beta_D_Border72 Beta_D_Border73 Beta_D_Border74 Beta_D_Border75 Beta_D_Border76 Beta_D_Border77 Beta_D_Border78 Beta_D_Border79 Beta_D_Border80 CI_Upper_D_Border15 CI_Upper_D_Border16 CI_Upper_D_Border17 CI_Upper_D_Border18 CI_Upper_D_Border19 CI_Upper_D_Border20 CI_Upper_D_Border21 CI_Upper_D_Border22 CI_Upper_D_Border23 CI_Upper_D_Border24 CI_Upper_D_Border25 CI_Upper_D_Border26 CI_Upper_D_Border27 CI_Upper_D_Border28 CI_Upper_D_Border29 CI_Upper_D_Border30 CI_Upper_D_Border31 CI_Upper_D_Border32 CI_Upper_D_Border33 CI_Upper_D_Border34 CI_Upper_D_Border35 CI_Upper_D_Border36 CI_Upper_D_Border37 CI_Upper_D_Border38 CI_Upper_D_Border39 CI_Upper_D_Border40 CI_Upper_D_Border41 CI_Upper_D_Border42 CI_Upper_D_Border43 CI_Upper_D_Border44 CI_Upper_D_Border45 CI_Upper_D_Border46 CI_Upper_D_Border47 CI_Upper_D_Border48 CI_Upper_D_Border49 CI_Upper_D_Border50 CI_Upper_D_Border51 CI_Upper_D_Border52 CI_Upper_D_Border53 CI_Upper_D_Border54 CI_Upper_D_Border55 CI_Upper_D_Border56 CI_Upper_D_Border57 CI_Upper_D_Border58 CI_Upper_D_Border59 CI_Upper_D_Border60 CI_Upper_D_Border61 CI_Upper_D_Border62 CI_Upper_D_Border63 CI_Upper_D_Border64 CI_Upper_D_Border65 CI_Upper_D_Border66 CI_Upper_D_Border67 CI_Upper_D_Border68 CI_Upper_D_Border69 CI_Upper_D_Border70 CI_Upper_D_Border71 CI_Upper_D_Border72 CI_Upper_D_Border73 CI_Upper_D_Border74 CI_Upper_D_Border75 CI_Upper_D_Border76 CI_Upper_D_Border77 CI_Upper_D_Border78 CI_Upper_D_Border79 CI_Upper_D_Border80 CI_Lower_D_Border15 CI_Lower_D_Border16 CI_Lower_D_Border17 CI_Lower_D_Border18 CI_Lower_D_Border19 CI_Lower_D_Border20 CI_Lower_D_Border21 CI_Lower_D_Border22 CI_Lower_D_Border23 CI_Lower_D_Border24 CI_Lower_D_Border25 CI_Lower_D_Border26 CI_Lower_D_Border27 CI_Lower_D_Border28 CI_Lower_D_Border29 CI_Lower_D_Border30 CI_Lower_D_Border31 CI_Lower_D_Border32 CI_Lower_D_Border33 CI_Lower_D_Border34 CI_Lower_D_Border35 CI_Lower_D_Border36 CI_Lower_D_Border37 CI_Lower_D_Border38 CI_Lower_D_Border39 CI_Lower_D_Border40 CI_Lower_D_Border41 CI_Lower_D_Border42 CI_Lower_D_Border43 CI_Lower_D_Border44 CI_Lower_D_Border45 CI_Lower_D_Border46 CI_Lower_D_Border47 CI_Lower_D_Border48 CI_Lower_D_Border49 CI_Lower_D_Border50 CI_Lower_D_Border51 CI_Lower_D_Border52 CI_Lower_D_Border53 CI_Lower_D_Border54 CI_Lower_D_Border55 CI_Lower_D_Border56 CI_Lower_D_Border57 CI_Lower_D_Border58 CI_Lower_D_Border59 CI_Lower_D_Border60 CI_Lower_D_Border61 CI_Lower_D_Border62 CI_Lower_D_Border63 CI_Lower_D_Border64 CI_Lower_D_Border65 CI_Lower_D_Border66 CI_Lower_D_Border67 CI_Lower_D_Border68 CI_Lower_D_Border69 CI_Lower_D_Border70 CI_Lower_D_Border71 CI_Lower_D_Border72 CI_Lower_D_Border73 CI_Lower_D_Border74 CI_Lower_D_Border75 CI_Lower_D_Border76 CI_Lower_D_Border77 CI_Lower_D_Border78 CI_Lower_D_Border79 CI_Lower_D_Border80 SD_10_D_Border15 CI_Upper_10_D_Border15 CI_Lower_10_D_Border15 SD_10_D_Border16 CI_Upper_10_D_Border16 CI_Lower_10_D_Border16 SD_10_D_Border17 CI_Upper_10_D_Border17 CI_Lower_10_D_Border17 SD_10_D_Border18 CI_Upper_10_D_Border18 CI_Lower_10_D_Border18 SD_10_D_Border19 CI_Upper_10_D_Border19 CI_Lower_10_D_Border19 SD_10_D_Border20 CI_Upper_10_D_Border20 CI_Lower_10_D_Border20 SD_10_D_Border21 CI_Upper_10_D_Border21 CI_Lower_10_D_Border21 SD_10_D_Border22 CI_Upper_10_D_Border22 CI_Lower_10_D_Border22 SD_10_D_Border23 CI_Upper_10_D_Border23 CI_Lower_10_D_Border23 SD_10_D_Border24 CI_Upper_10_D_Border24 CI_Lower_10_D_Border24 SD_10_D_Border25 CI_Upper_10_D_Border25 CI_Lower_10_D_Border25 SD_10_D_Border26 CI_Upper_10_D_Border26 CI_Lower_10_D_Border26 SD_10_D_Border27 CI_Upper_10_D_Border27 CI_Lower_10_D_Border27 SD_10_D_Border28 CI_Upper_10_D_Border28 CI_Lower_10_D_Border28 SD_10_D_Border29 CI_Upper_10_D_Border29 CI_Lower_10_D_Border29 SD_10_D_Border30 CI_Upper_10_D_Border30 CI_Lower_10_D_Border30 SD_10_D_Border31 CI_Upper_10_D_Border31 CI_Lower_10_D_Border31 SD_10_D_Border32 CI_Upper_10_D_Border32 CI_Lower_10_D_Border32 SD_10_D_Border33 CI_Upper_10_D_Border33 CI_Lower_10_D_Border33 SD_10_D_Border34 CI_Upper_10_D_Border34 CI_Lower_10_D_Border34 SD_10_D_Border35 CI_Upper_10_D_Border35 CI_Lower_10_D_Border35 SD_10_D_Border36 CI_Upper_10_D_Border36 CI_Lower_10_D_Border36 SD_10_D_Border37 CI_Upper_10_D_Border37 CI_Lower_10_D_Border37 SD_10_D_Border38 CI_Upper_10_D_Border38 CI_Lower_10_D_Border38 SD_10_D_Border39 CI_Upper_10_D_Border39 CI_Lower_10_D_Border39 SD_10_D_Border40 CI_Upper_10_D_Border40 CI_Lower_10_D_Border40 SD_10_D_Border41 CI_Upper_10_D_Border41 CI_Lower_10_D_Border41 SD_10_D_Border42 CI_Upper_10_D_Border42 CI_Lower_10_D_Border42 SD_10_D_Border43 CI_Upper_10_D_Border43 CI_Lower_10_D_Border43 SD_10_D_Border44 CI_Upper_10_D_Border44 CI_Lower_10_D_Border44 SD_10_D_Border45 CI_Upper_10_D_Border45 CI_Lower_10_D_Border45 SD_10_D_Border46 CI_Upper_10_D_Border46 CI_Lower_10_D_Border46 SD_10_D_Border47 CI_Upper_10_D_Border47 CI_Lower_10_D_Border47 SD_10_D_Border48 CI_Upper_10_D_Border48 CI_Lower_10_D_Border48 SD_10_D_Border49 CI_Upper_10_D_Border49 CI_Lower_10_D_Border49 SD_10_D_Border50 CI_Upper_10_D_Border50 CI_Lower_10_D_Border50 SD_10_D_Border51 CI_Upper_10_D_Border51 CI_Lower_10_D_Border51 SD_10_D_Border52 CI_Upper_10_D_Border52 CI_Lower_10_D_Border52 SD_10_D_Border53 CI_Upper_10_D_Border53 CI_Lower_10_D_Border53 SD_10_D_Border54 CI_Upper_10_D_Border54 CI_Lower_10_D_Border54 SD_10_D_Border55 CI_Upper_10_D_Border55 CI_Lower_10_D_Border55 SD_10_D_Border56 CI_Upper_10_D_Border56 CI_Lower_10_D_Border56 SD_10_D_Border57 CI_Upper_10_D_Border57 CI_Lower_10_D_Border57 SD_10_D_Border58 CI_Upper_10_D_Border58 CI_Lower_10_D_Border58 SD_10_D_Border59 CI_Upper_10_D_Border59 CI_Lower_10_D_Border59 SD_10_D_Border60 CI_Upper_10_D_Border60 CI_Lower_10_D_Border60 SD_10_D_Border61 CI_Upper_10_D_Border61 CI_Lower_10_D_Border61 SD_10_D_Border62 CI_Upper_10_D_Border62 CI_Lower_10_D_Border62 SD_10_D_Border63 CI_Upper_10_D_Border63 CI_Lower_10_D_Border63 SD_10_D_Border64 CI_Upper_10_D_Border64 CI_Lower_10_D_Border64 SD_10_D_Border65 CI_Upper_10_D_Border65 CI_Lower_10_D_Border65 SD_10_D_Border66 CI_Upper_10_D_Border66 CI_Lower_10_D_Border66 SD_10_D_Border67 CI_Upper_10_D_Border67 CI_Lower_10_D_Border67 SD_10_D_Border68 CI_Upper_10_D_Border68 CI_Lower_10_D_Border68 SD_10_D_Border69 CI_Upper_10_D_Border69 CI_Lower_10_D_Border69 SD_10_D_Border70 CI_Upper_10_D_Border70 CI_Lower_10_D_Border70 SD_10_D_Border71 CI_Upper_10_D_Border71 CI_Lower_10_D_Border71 SD_10_D_Border72 CI_Upper_10_D_Border72 CI_Lower_10_D_Border72 SD_10_D_Border73 CI_Upper_10_D_Border73 CI_Lower_10_D_Border73 SD_10_D_Border74 CI_Upper_10_D_Border74 CI_Lower_10_D_Border74 SD_10_D_Border75 CI_Upper_10_D_Border75 CI_Lower_10_D_Border75 SD_10_D_Border76 CI_Upper_10_D_Border76 CI_Lower_10_D_Border76 SD_10_D_Border77 CI_Upper_10_D_Border77 CI_Lower_10_D_Border77 SD_10_D_Border78 CI_Upper_10_D_Border78 CI_Lower_10_D_Border78 SD_10_D_Border79 CI_Upper_10_D_Border79 CI_Lower_10_D_Border79 SD_10_D_Border80 CI_Upper_10_D_Border80 CI_Lower_10_D_Border80

reshape long Beta_D_Border CI_Upper_D_Border CI_Lower_D_Border CI_Upper_10_D_Border CI_Lower_10_D_Border, i(N) j(band)

twoway (line Beta_D_Border band, lcolor(black) lpattern(solid)) ///
	(line CI_Upper_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Lower_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Upper_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)) ///
	(line CI_Lower_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)), ///
    ytitle(Estimated Effect Anglophone, size(small)) ylabel(-.5(.5)1.5,  angle(horizontal))  ///
    xtitle(Distance from Border (km) ) xtitle(, size(small)) xlabel(15(10)80, labsize(vsmall))  ///
    yline(0, lcolor(gs10)) ///
    plotregion(lcolor(black)) ///
    legend(off) ///
    title(b. % Drinking Water Access, size(medsmall)) ///
    scheme(s2mono) graphregion(fcolor(white)) 


* Panel c: Nightlight Data
use Nightlight_GIS_FINAL.dta, clear
drop if year == 1994

foreach var of varlist D_Border15-D_Border80 {
	quietly reg z2_Lt_Mean $MDpolynomial i.year Ln_Pop_Grid Urban $geo $governance if `var'==1 & CompZone == 1, robust cluster(commune)
	gen Beta_`var' = _b[anglophone]
	matrix c_`var' = e(V)
	gen Var_`var' = c_`var'[1,1]
} 

foreach var of varlist D_Border15-D_Border80 {
	gen SD_`var' = sqrt(Var_`var')
	gen CI_Upper_`var' = Beta_`var'+(SD_`var'*1.96)
	gen CI_Lower_`var' = Beta_`var'-(SD_`var'*1.96)
}

* estimates for each band are assigned to each observation so we can drop all of them and reshape to long = this will arrange our betas/CIs by band

foreach var of varlist D_Border15-D_Border80 {
	gen SD_10_`var' = sqrt(Var_`var')
	gen CI_Upper_10_`var' = Beta_`var'+(SD_`var'*1.645)
	gen CI_Lower_10_`var' = Beta_`var'-(SD_`var'*1.645)
}

gen N = _n
drop if N !=1
keep N Beta_D_Border15 Beta_D_Border16 Beta_D_Border17 Beta_D_Border18 Beta_D_Border19 Beta_D_Border20 Beta_D_Border21 Beta_D_Border22 Beta_D_Border23 Beta_D_Border24 Beta_D_Border25 Beta_D_Border26 Beta_D_Border27 Beta_D_Border28 Beta_D_Border29 Beta_D_Border30 Beta_D_Border31 Beta_D_Border32 Beta_D_Border33 Beta_D_Border34 Beta_D_Border35 Beta_D_Border36 Beta_D_Border37 Beta_D_Border38 Beta_D_Border39 Beta_D_Border40 Beta_D_Border41 Beta_D_Border42 Beta_D_Border43 Beta_D_Border44 Beta_D_Border45 Beta_D_Border46 Beta_D_Border47 Beta_D_Border48 Beta_D_Border49 Beta_D_Border50 Beta_D_Border51 Beta_D_Border52 Beta_D_Border53 Beta_D_Border54 Beta_D_Border55 Beta_D_Border56 Beta_D_Border57 Beta_D_Border58 Beta_D_Border59 Beta_D_Border60 Beta_D_Border61 Beta_D_Border62 Beta_D_Border63 Beta_D_Border64 Beta_D_Border65 Beta_D_Border66 Beta_D_Border67 Beta_D_Border68 Beta_D_Border69 Beta_D_Border70 Beta_D_Border71 Beta_D_Border72 Beta_D_Border73 Beta_D_Border74 Beta_D_Border75 Beta_D_Border76 Beta_D_Border77 Beta_D_Border78 Beta_D_Border79 Beta_D_Border80 CI_Upper_D_Border15 CI_Upper_D_Border16 CI_Upper_D_Border17 CI_Upper_D_Border18 CI_Upper_D_Border19 CI_Upper_D_Border20 CI_Upper_D_Border21 CI_Upper_D_Border22 CI_Upper_D_Border23 CI_Upper_D_Border24 CI_Upper_D_Border25 CI_Upper_D_Border26 CI_Upper_D_Border27 CI_Upper_D_Border28 CI_Upper_D_Border29 CI_Upper_D_Border30 CI_Upper_D_Border31 CI_Upper_D_Border32 CI_Upper_D_Border33 CI_Upper_D_Border34 CI_Upper_D_Border35 CI_Upper_D_Border36 CI_Upper_D_Border37 CI_Upper_D_Border38 CI_Upper_D_Border39 CI_Upper_D_Border40 CI_Upper_D_Border41 CI_Upper_D_Border42 CI_Upper_D_Border43 CI_Upper_D_Border44 CI_Upper_D_Border45 CI_Upper_D_Border46 CI_Upper_D_Border47 CI_Upper_D_Border48 CI_Upper_D_Border49 CI_Upper_D_Border50 CI_Upper_D_Border51 CI_Upper_D_Border52 CI_Upper_D_Border53 CI_Upper_D_Border54 CI_Upper_D_Border55 CI_Upper_D_Border56 CI_Upper_D_Border57 CI_Upper_D_Border58 CI_Upper_D_Border59 CI_Upper_D_Border60 CI_Upper_D_Border61 CI_Upper_D_Border62 CI_Upper_D_Border63 CI_Upper_D_Border64 CI_Upper_D_Border65 CI_Upper_D_Border66 CI_Upper_D_Border67 CI_Upper_D_Border68 CI_Upper_D_Border69 CI_Upper_D_Border70 CI_Upper_D_Border71 CI_Upper_D_Border72 CI_Upper_D_Border73 CI_Upper_D_Border74 CI_Upper_D_Border75 CI_Upper_D_Border76 CI_Upper_D_Border77 CI_Upper_D_Border78 CI_Upper_D_Border79 CI_Upper_D_Border80 CI_Lower_D_Border15 CI_Lower_D_Border16 CI_Lower_D_Border17 CI_Lower_D_Border18 CI_Lower_D_Border19 CI_Lower_D_Border20 CI_Lower_D_Border21 CI_Lower_D_Border22 CI_Lower_D_Border23 CI_Lower_D_Border24 CI_Lower_D_Border25 CI_Lower_D_Border26 CI_Lower_D_Border27 CI_Lower_D_Border28 CI_Lower_D_Border29 CI_Lower_D_Border30 CI_Lower_D_Border31 CI_Lower_D_Border32 CI_Lower_D_Border33 CI_Lower_D_Border34 CI_Lower_D_Border35 CI_Lower_D_Border36 CI_Lower_D_Border37 CI_Lower_D_Border38 CI_Lower_D_Border39 CI_Lower_D_Border40 CI_Lower_D_Border41 CI_Lower_D_Border42 CI_Lower_D_Border43 CI_Lower_D_Border44 CI_Lower_D_Border45 CI_Lower_D_Border46 CI_Lower_D_Border47 CI_Lower_D_Border48 CI_Lower_D_Border49 CI_Lower_D_Border50 CI_Lower_D_Border51 CI_Lower_D_Border52 CI_Lower_D_Border53 CI_Lower_D_Border54 CI_Lower_D_Border55 CI_Lower_D_Border56 CI_Lower_D_Border57 CI_Lower_D_Border58 CI_Lower_D_Border59 CI_Lower_D_Border60 CI_Lower_D_Border61 CI_Lower_D_Border62 CI_Lower_D_Border63 CI_Lower_D_Border64 CI_Lower_D_Border65 CI_Lower_D_Border66 CI_Lower_D_Border67 CI_Lower_D_Border68 CI_Lower_D_Border69 CI_Lower_D_Border70 CI_Lower_D_Border71 CI_Lower_D_Border72 CI_Lower_D_Border73 CI_Lower_D_Border74 CI_Lower_D_Border75 CI_Lower_D_Border76 CI_Lower_D_Border77 CI_Lower_D_Border78 CI_Lower_D_Border79 CI_Lower_D_Border80 SD_10_D_Border15 CI_Upper_10_D_Border15 CI_Lower_10_D_Border15 SD_10_D_Border16 CI_Upper_10_D_Border16 CI_Lower_10_D_Border16 SD_10_D_Border17 CI_Upper_10_D_Border17 CI_Lower_10_D_Border17 SD_10_D_Border18 CI_Upper_10_D_Border18 CI_Lower_10_D_Border18 SD_10_D_Border19 CI_Upper_10_D_Border19 CI_Lower_10_D_Border19 SD_10_D_Border20 CI_Upper_10_D_Border20 CI_Lower_10_D_Border20 SD_10_D_Border21 CI_Upper_10_D_Border21 CI_Lower_10_D_Border21 SD_10_D_Border22 CI_Upper_10_D_Border22 CI_Lower_10_D_Border22 SD_10_D_Border23 CI_Upper_10_D_Border23 CI_Lower_10_D_Border23 SD_10_D_Border24 CI_Upper_10_D_Border24 CI_Lower_10_D_Border24 SD_10_D_Border25 CI_Upper_10_D_Border25 CI_Lower_10_D_Border25 SD_10_D_Border26 CI_Upper_10_D_Border26 CI_Lower_10_D_Border26 SD_10_D_Border27 CI_Upper_10_D_Border27 CI_Lower_10_D_Border27 SD_10_D_Border28 CI_Upper_10_D_Border28 CI_Lower_10_D_Border28 SD_10_D_Border29 CI_Upper_10_D_Border29 CI_Lower_10_D_Border29 SD_10_D_Border30 CI_Upper_10_D_Border30 CI_Lower_10_D_Border30 SD_10_D_Border31 CI_Upper_10_D_Border31 CI_Lower_10_D_Border31 SD_10_D_Border32 CI_Upper_10_D_Border32 CI_Lower_10_D_Border32 SD_10_D_Border33 CI_Upper_10_D_Border33 CI_Lower_10_D_Border33 SD_10_D_Border34 CI_Upper_10_D_Border34 CI_Lower_10_D_Border34 SD_10_D_Border35 CI_Upper_10_D_Border35 CI_Lower_10_D_Border35 SD_10_D_Border36 CI_Upper_10_D_Border36 CI_Lower_10_D_Border36 SD_10_D_Border37 CI_Upper_10_D_Border37 CI_Lower_10_D_Border37 SD_10_D_Border38 CI_Upper_10_D_Border38 CI_Lower_10_D_Border38 SD_10_D_Border39 CI_Upper_10_D_Border39 CI_Lower_10_D_Border39 SD_10_D_Border40 CI_Upper_10_D_Border40 CI_Lower_10_D_Border40 SD_10_D_Border41 CI_Upper_10_D_Border41 CI_Lower_10_D_Border41 SD_10_D_Border42 CI_Upper_10_D_Border42 CI_Lower_10_D_Border42 SD_10_D_Border43 CI_Upper_10_D_Border43 CI_Lower_10_D_Border43 SD_10_D_Border44 CI_Upper_10_D_Border44 CI_Lower_10_D_Border44 SD_10_D_Border45 CI_Upper_10_D_Border45 CI_Lower_10_D_Border45 SD_10_D_Border46 CI_Upper_10_D_Border46 CI_Lower_10_D_Border46 SD_10_D_Border47 CI_Upper_10_D_Border47 CI_Lower_10_D_Border47 SD_10_D_Border48 CI_Upper_10_D_Border48 CI_Lower_10_D_Border48 SD_10_D_Border49 CI_Upper_10_D_Border49 CI_Lower_10_D_Border49 SD_10_D_Border50 CI_Upper_10_D_Border50 CI_Lower_10_D_Border50 SD_10_D_Border51 CI_Upper_10_D_Border51 CI_Lower_10_D_Border51 SD_10_D_Border52 CI_Upper_10_D_Border52 CI_Lower_10_D_Border52 SD_10_D_Border53 CI_Upper_10_D_Border53 CI_Lower_10_D_Border53 SD_10_D_Border54 CI_Upper_10_D_Border54 CI_Lower_10_D_Border54 SD_10_D_Border55 CI_Upper_10_D_Border55 CI_Lower_10_D_Border55 SD_10_D_Border56 CI_Upper_10_D_Border56 CI_Lower_10_D_Border56 SD_10_D_Border57 CI_Upper_10_D_Border57 CI_Lower_10_D_Border57 SD_10_D_Border58 CI_Upper_10_D_Border58 CI_Lower_10_D_Border58 SD_10_D_Border59 CI_Upper_10_D_Border59 CI_Lower_10_D_Border59 SD_10_D_Border60 CI_Upper_10_D_Border60 CI_Lower_10_D_Border60 SD_10_D_Border61 CI_Upper_10_D_Border61 CI_Lower_10_D_Border61 SD_10_D_Border62 CI_Upper_10_D_Border62 CI_Lower_10_D_Border62 SD_10_D_Border63 CI_Upper_10_D_Border63 CI_Lower_10_D_Border63 SD_10_D_Border64 CI_Upper_10_D_Border64 CI_Lower_10_D_Border64 SD_10_D_Border65 CI_Upper_10_D_Border65 CI_Lower_10_D_Border65 SD_10_D_Border66 CI_Upper_10_D_Border66 CI_Lower_10_D_Border66 SD_10_D_Border67 CI_Upper_10_D_Border67 CI_Lower_10_D_Border67 SD_10_D_Border68 CI_Upper_10_D_Border68 CI_Lower_10_D_Border68 SD_10_D_Border69 CI_Upper_10_D_Border69 CI_Lower_10_D_Border69 SD_10_D_Border70 CI_Upper_10_D_Border70 CI_Lower_10_D_Border70 SD_10_D_Border71 CI_Upper_10_D_Border71 CI_Lower_10_D_Border71 SD_10_D_Border72 CI_Upper_10_D_Border72 CI_Lower_10_D_Border72 SD_10_D_Border73 CI_Upper_10_D_Border73 CI_Lower_10_D_Border73 SD_10_D_Border74 CI_Upper_10_D_Border74 CI_Lower_10_D_Border74 SD_10_D_Border75 CI_Upper_10_D_Border75 CI_Lower_10_D_Border75 SD_10_D_Border76 CI_Upper_10_D_Border76 CI_Lower_10_D_Border76 SD_10_D_Border77 CI_Upper_10_D_Border77 CI_Lower_10_D_Border77 SD_10_D_Border78 CI_Upper_10_D_Border78 CI_Lower_10_D_Border78 SD_10_D_Border79 CI_Upper_10_D_Border79 CI_Lower_10_D_Border79 SD_10_D_Border80 CI_Upper_10_D_Border80 CI_Lower_10_D_Border80

reshape long Beta_D_Border CI_Upper_D_Border CI_Lower_D_Border CI_Upper_10_D_Border CI_Lower_10_D_Border, i(N) j(band)

twoway (line Beta_D_Border band, lcolor(black) lpattern(solid)) ///
	(line CI_Upper_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Lower_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Upper_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)) ///
	(line CI_Lower_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)), ///
    ytitle(Estimated Effect Anglophone, size(small)) ylabel(-.1(.05).1,  angle(horizontal))  ///
    xtitle(Distance from Border (km) ) xtitle(, size(small)) xlabel(15(10)80, labsize(vsmall))  ///
    yline(0, lcolor(gs10)) ///
     legend(off) ///
     plotregion(lcolor(black)) ///
     title(c. Nightlight Data, size(medsmall)) ///
    scheme(s2mono) graphregion(fcolor(white)) 


************************************************************************************************
********************* TABLE A2 - LEE AND SCHULTZ MODEL REPLICATION *****************************
************************************************************************************************
use "Merged_DHS Data.dta", clear
drop if Comp_Zone == 0
drop if Year == 1991

reg z2_LS_Poss_NoElec anglophone d_border_UK d_border_French i.Year Urban Ln_Pop_5km ln_d_regcapital_km ln_d_yaounde_km ln_d_coast_km avg_alt cec_mean if d_border_km< 81, robust
reg z2_LS_Poss_NoElec anglophone d_border_UK d_border_French i.Year Urban Ln_Pop_5km ln_d_regcapital_km ln_d_yaounde_km ln_d_coast_km avg_alt cec_mean if d_border_km < 31, robust
reg z2_LS_Poss_NoElec anglophone d_border_UK d_border_French i.Year Urban Ln_Pop_5km ln_d_regcapital_km ln_d_yaounde_km ln_d_coast_km avg_alt cec_mean if d_border_km < 21, robust
reg z2_LS_Poss_NoElec anglophone d_border_UK d_border_French i.Year Urban Ln_Pop_5km ln_d_regcapital_km ln_d_yaounde_km ln_d_coast_km avg_alt cec_mean if d_border_km < 11,  robust

reg z2_Perc_PipedH20 anglophone d_border_UK d_border_French i.Year Urban Ln_Pop_5km ln_d_regcapital_km ln_d_yaounde_km ln_d_coast_km avg_alt cec_mean if d_border_km< 81, robust
reg z2_Perc_PipedH20 anglophone d_border_UK d_border_French i.Year Urban Ln_Pop_5km ln_d_regcapital_km ln_d_yaounde_km ln_d_coast_km avg_alt cec_mean if d_border_km < 31, robust
reg z2_Perc_PipedH20 anglophone d_border_UK d_border_French i.Year Urban Ln_Pop_5km ln_d_regcapital_km ln_d_yaounde_km ln_d_coast_km avg_alt cec_mean if d_border_km < 21, robust
reg z2_Perc_PipedH20 anglophone d_border_UK d_border_French i.Year Urban Ln_Pop_5km ln_d_regcapital_km ln_d_yaounde_km ln_d_coast_km avg_alt cec_mean if d_border_km < 11, robust

use Nightlight_GIS_FINAL.dta, clear
drop if year == 1994

reg z2_Lt_Mean anglophone d_border_UK d_border_French Urban Ln_Pop_Grid ln_d_regcapital_km ln_d_yaounde_km ln_d_coast_km avg_alt cec_mean i.year if CompZone == 1 & d_border_km < 81, robust
reg z2_Lt_Mean anglophone d_border_UK d_border_French Urban Ln_Pop_Grid ln_d_regcapital_km ln_d_yaounde_km ln_d_coast_km avg_alt cec_mean i.year if CompZone == 1 & d_border_km < 31, robust
reg z2_Lt_Mean anglophone d_border_UK d_border_French Urban Ln_Pop_Grid ln_d_regcapital_km ln_d_yaounde_km ln_d_coast_km avg_alt cec_mean i.year if CompZone == 1 & d_border_km < 21, robust
reg z2_Lt_Mean anglophone d_border_UK d_border_French Urban Ln_Pop_Grid ln_d_regcapital_km ln_d_yaounde_km ln_d_coast_km avg_alt cec_mean i.year if CompZone == 1 & d_border_km < 11,  robust


************************************************************************************************
**************************** TABLE A4.1-4.3 - SAMPLE MODEL RESULTS *****************************
************************************************************************************************
use AfroBarometerData.dta, clear
keep if REGION==2 | REGION==7 | REGION==9 | REGION==10 | REGION==12

*Table A4.1 - Local Government Legitimacy Mechanism
reg C62B $MDpolynomial $AB $geo i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg C62B $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 

reg C71C $MDpolynomial $AB $geo  i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg C71C $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 

reg C30C $MDpolynomial $AB $geo  i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg C30C $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 

reg C25B $MDpolynomial $AB $geo  i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg C25B $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance  i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 

*Table A4.2 - Traditional Authority Mechanism
reg Q52K_R6 $MDpolynomial $AB $geo i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg Q52K_R6 $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 

reg Q53H_R6 $MDpolynomial $AB $geo i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg Q53H_R6 $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 

reg Q24E_R6 $MDpolynomial $AB $geo i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg Q24E_R6 $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 

reg Q68D_R6 $MDpolynomial $AB $geo i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg Q68D_R6 $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 

*Table A4.3 - Ethnicity Mechanism
reg C85B $MDpolynomial $AB $geo i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg C85B $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 

reg C79C_CAMC $MDpolynomial $AB $geo i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg C79C_CAMC $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 

reg Q18_R5 $MDpolynomial $AB $geo i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg Q18_R5 $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 


************************************************************************************************
************************** TABLE A5 - Afrobarometer Cluster Averages ***************************
************************************************************************************************
use AfroBarometerData.dta, clear
keep if REGION==2 | REGION==7 | REGION==9 | REGION==10 | REGION==12

collapse (mean) Q68D_R6 C25B C30C C71C C62B Q18_R5 C79C_CAMC C85B Q24E_R6 Q53H_R6 education Q52K_R6 (first) D_Border80 Lat_x_Long latitude2 longitude2 border_longitude border_latitude d_border_km2 d_border_km3 Anglo_x_Border latitude3 longitude3 lat_x_long2 lat2_x_long ln_d_Protestant_km_1960 ln_d_Railway_km  REGION anglophone d_border_km latitude longitude rural avg_temp avg_prec cec_mean avg_alt ln_d_coast_km ln_d_regcapital_km ln_d_yaounde_km Ln_WorldPop10_5km, by (Round EANUMB_AB) 

*Panel A - Local Government Legitimacy Mechanism
reg C62B $MDpolynomial rural Ln_WorldPop10_5km $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg C71C $MDpolynomial rural Ln_WorldPop10_5km $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg C30C $MDpolynomial rural Ln_WorldPop10_5km $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg C25B $MDpolynomial rural Ln_WorldPop10_5km $geo $governance  i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 

*Panel B - Traditional Authority Mechanism
reg Q52K_R6 $MDpolynomial rural Ln_WorldPop10_5km $geo $governance i.Round if D_Border80 == 1,  robust 
reg Q53H_R6 $MDpolynomial rural Ln_WorldPop10_5km $geo $governance i.Round if D_Border80 == 1,  robust 
reg Q24E_R6 $MDpolynomial rural Ln_WorldPop10_5km $geo $governance i.Round if D_Border80 == 1,  robust 
reg Q68D_R6 $MDpolynomial rural Ln_WorldPop10_5km $geo $governance i.Round if d_border_km < 81, robust

*Panel C - Ethnicity Mechanism
reg C85B $MDpolynomial rural Ln_WorldPop10_5km $geo $governance i.Round if D_Border80 == 1,  robust 
reg C79C_CAMC $MDpolynomial rural Ln_WorldPop10_5km $geo $governance i.Round if D_Border80 == 1,  robust 
reg Q18_R5 $MDpolynomial rural Ln_WorldPop10_5km $geo $governance i.Round if D_Border80 == 1,  robust 


************************************************************************************************
*********************** TABLE A6 - REPLICATION WITH WHOLE COUNTRY SAMPLE ************************
************************************************************************************************
use AfroBarometerData.dta, clear

*Panel A - Local Government Legitimacy Mechanism
reg C62B $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance i.Round, cluster(EANUMB_AB) robust 
reg C71C $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance i.Round, cluster(EANUMB_AB) robust 
reg C30C $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance    i.Round, cluster(EANUMB_AB) robust 
reg C25B $MDpolynomial  Ln_WorldPop10_5km $AB $geo $governance  i.Round, cluster(EANUMB_AB) robust 

*Panel B - Traditional Authority Mechanism
reg Q52K_R6 $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance i.Round, cluster(EANUMB_AB) robust 
reg Q53H_R6 $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance i.Round, cluster(EANUMB_AB) robust 
reg Q24E_R6 $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance i.Round, cluster(EANUMB_AB) robust 
reg Q68D_R6 $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance i.Round, cluster(EANUMB_AB) robust 

*Panel C - Ethnicity Mechanism
reg C85B $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance   i.Round, cluster(EANUMB_AB) robust 
reg C79C_CAMC $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance   i.Round, cluster(EANUMB_AB) robust 
reg Q18_R5 $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance   i.Round, cluster(EANUMB_AB) robust 


************************************************************************************************
*************************** TABLE A7 - REPLICATION WITH NO DOUALA ******************************
************************************************************************************************
use AfroBarometerData.dta, clear
keep if REGION==2 | REGION==7 | REGION==9 | REGION==10 | REGION==12

*Panel A - Local Government Legitimacy Mechanism
reg C62B $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81 & Douala == 0, cluster(EANUMB_AB) robust 
reg C71C $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81 & Douala == 0, cluster(EANUMB_AB) robust 
reg C30C $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81 & Douala == 0, cluster(EANUMB_AB) robust 
reg C25B $MDpolynomial   Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81 & Douala == 0, cluster(EANUMB_AB) robust 

*Panel B - Traditional Authority Mechanism
reg Q52K_R6 $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81 & Douala == 0, cluster(EANUMB_AB) robust 
reg Q53H_R6 $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81 & Douala == 0, cluster(EANUMB_AB) robust 
reg Q24E_R6 $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81 & Douala == 0, cluster(EANUMB_AB) robust 
reg Q68D_R6 $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 

*Panel C - Ethnicity Mechanism
reg C85B $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81 & Douala == 0, cluster(EANUMB_AB) robust 
reg C79C_CAMC $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81 & Douala == 0, cluster(EANUMB_AB) robust 
reg Q18_R5 $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81 & Douala == 0, cluster(EANUMB_AB) robust 


************************************************************************************************
******************** TABLE A8 - REPLICATION WITH ALTERNATIVE POLYNOMIAL ESTIMATES **************
************************************************************************************************
use AfroBarometerData.dta, clear
keep if REGION==2 | REGION==7 | REGION==9 | REGION==10 | REGION==12

*Table A8.1 - Local Government Legitimacy Mechanism
reg C62B $LocalLinear Ln_WorldPop10_5km $AB $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg C62B $CubicPolyDist Ln_WorldPop10_5km $AB $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg C62B $MDCubicPoly Ln_WorldPop10_5km $AB $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 

reg C71C $LocalLinear Ln_WorldPop10_5km $AB $geo $governance    i.Round if d_border_km < 81 , cluster(EANUMB_AB) robust 
reg C71C $CubicPolyDist Ln_WorldPop10_5km $AB $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg C71C $MDCubicPoly Ln_WorldPop10_5km $AB $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 

reg C30C $LocalLinear Ln_WorldPop10_5km $AB $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg C30C $CubicPolyDist Ln_WorldPop10_5km $AB $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg C30C $MDCubicPoly Ln_WorldPop10_5km $AB $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 

reg C25B $LocalLinear   Ln_WorldPop10_5km $AB $geo $governance  i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg C25B $CubicPolyDist   Ln_WorldPop10_5km $AB $geo $governance  i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg C25B $MDCubicPoly   Ln_WorldPop10_5km $AB $geo $governance  i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 

*Table A8.2 - Traditional Authority Mechanism
reg Q52K_R6 $LocalLinear Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg Q52K_R6 $CubicPolyDist Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg Q52K_R6 $MDCubicPoly Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 

reg Q53H_R6 $LocalLinear Ln_WorldPop10_5km $AB $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg Q53H_R6 $CubicPolyDist Ln_WorldPop10_5km $AB $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg Q53H_R6 $MDCubicPoly Ln_WorldPop10_5km $AB $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 

reg Q24E_R6 $LocalLinear Ln_WorldPop10_5km $AB $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg Q24E_R6 $CubicPolyDist Ln_WorldPop10_5km $AB $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg Q24E_R6 $MDCubicPoly Ln_WorldPop10_5km $AB $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 

reg Q68D_R6 $LocalLinear Ln_WorldPop10_5km $AB $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg Q68D_R6 $CubicPolyDist Ln_WorldPop10_5km $AB $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg Q68D_R6 $MDCubicPoly Ln_WorldPop10_5km $AB $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 

*Table A8.3 - Ethnicity Mechanism
reg C85B $LocalLinear Ln_WorldPop10_5km $AB $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg C85B $CubicPolyDist Ln_WorldPop10_5km $AB $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg C85B $MDCubicPoly Ln_WorldPop10_5km $AB $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 

reg C79C_CAMC $LocalLinear Ln_WorldPop10_5km $AB $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg C79C_CAMC $CubicPolyDist Ln_WorldPop10_5km $AB $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg C79C_CAMC $MDCubicPoly Ln_WorldPop10_5km $AB $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 

reg Q18_R5 $LocalLinear Ln_WorldPop10_5km $AB $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg Q18_R5 $CubicPolyDist Ln_WorldPop10_5km $AB $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg Q18_R5 $MDCubicPoly Ln_WorldPop10_5km $AB $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 


************************************************************************************************
***************** TABLE A9 - ALTERNATIVE MEASURES OF THE FIRST MECHANISM ***********************
************************************************************************************************
*a. Eval of Road Maintanance C66A
use AfroBarometerData.dta, clear
keep if REGION==2 | REGION==7 | REGION==9 | REGION==10 | REGION==12

foreach var of varlist D_Border20-D_Border80 {
  quietly reg C66A $MDpolynomial rural Ln_WorldPop10_5km $AB $geo $governance  Round if `var'==1, cluster(EANUMB_AB) robust 
	gen Beta_`var' = _b[anglophone]
	matrix c_`var' = e(V)
	gen Var_`var' = c_`var'[1,1]
} 

foreach var of varlist D_Border20-D_Border80 {
	gen SD_`var' = sqrt(Var_`var')
	gen CI_Upper_`var' = Beta_`var'+(SD_`var'*1.96)
	gen CI_Lower_`var' = Beta_`var'-(SD_`var'*1.96)
}


foreach var of varlist D_Border20-D_Border80 {
	gen SD_10_`var' = sqrt(Var_`var')
	gen CI_Upper_10_`var' = Beta_`var'+(SD_`var'*1.645)
	gen CI_Lower_10_`var' = Beta_`var'-(SD_`var'*1.645)
}

gen N = _n
drop if N !=1
keep N Beta_D_Border20 Beta_D_Border21 Beta_D_Border22 Beta_D_Border23 Beta_D_Border24 Beta_D_Border25 Beta_D_Border26 Beta_D_Border27 Beta_D_Border28 Beta_D_Border29 Beta_D_Border30 Beta_D_Border31 Beta_D_Border32 Beta_D_Border33 Beta_D_Border34 Beta_D_Border35 Beta_D_Border36 Beta_D_Border37 Beta_D_Border38 Beta_D_Border39 Beta_D_Border40 Beta_D_Border41 Beta_D_Border42 Beta_D_Border43 Beta_D_Border44 Beta_D_Border45 Beta_D_Border46 Beta_D_Border47 Beta_D_Border48 Beta_D_Border49 Beta_D_Border50 Beta_D_Border51 Beta_D_Border52 Beta_D_Border53 Beta_D_Border54 Beta_D_Border55 Beta_D_Border56 Beta_D_Border57 Beta_D_Border58 Beta_D_Border59 Beta_D_Border60 Beta_D_Border61 Beta_D_Border62 Beta_D_Border63 Beta_D_Border64 Beta_D_Border65 Beta_D_Border66 Beta_D_Border67 Beta_D_Border68 Beta_D_Border69 Beta_D_Border70 Beta_D_Border71 Beta_D_Border72 Beta_D_Border73 Beta_D_Border74 Beta_D_Border75 Beta_D_Border76 Beta_D_Border77 Beta_D_Border78 Beta_D_Border79 Beta_D_Border80 CI_Upper_D_Border20 CI_Upper_D_Border21 CI_Upper_D_Border22 CI_Upper_D_Border23 CI_Upper_D_Border24 CI_Upper_D_Border25 CI_Upper_D_Border26 CI_Upper_D_Border27 CI_Upper_D_Border28 CI_Upper_D_Border29 CI_Upper_D_Border30 CI_Upper_D_Border31 CI_Upper_D_Border32 CI_Upper_D_Border33 CI_Upper_D_Border34 CI_Upper_D_Border35 CI_Upper_D_Border36 CI_Upper_D_Border37 CI_Upper_D_Border38 CI_Upper_D_Border39 CI_Upper_D_Border40 CI_Upper_D_Border41 CI_Upper_D_Border42 CI_Upper_D_Border43 CI_Upper_D_Border44 CI_Upper_D_Border45 CI_Upper_D_Border46 CI_Upper_D_Border47 CI_Upper_D_Border48 CI_Upper_D_Border49 CI_Upper_D_Border50 CI_Upper_D_Border51 CI_Upper_D_Border52 CI_Upper_D_Border53 CI_Upper_D_Border54 CI_Upper_D_Border55 CI_Upper_D_Border56 CI_Upper_D_Border57 CI_Upper_D_Border58 CI_Upper_D_Border59 CI_Upper_D_Border60 CI_Upper_D_Border61 CI_Upper_D_Border62 CI_Upper_D_Border63 CI_Upper_D_Border64 CI_Upper_D_Border65 CI_Upper_D_Border66 CI_Upper_D_Border67 CI_Upper_D_Border68 CI_Upper_D_Border69 CI_Upper_D_Border70 CI_Upper_D_Border71 CI_Upper_D_Border72 CI_Upper_D_Border73 CI_Upper_D_Border74 CI_Upper_D_Border75 CI_Upper_D_Border76 CI_Upper_D_Border77 CI_Upper_D_Border78 CI_Upper_D_Border79 CI_Upper_D_Border80 CI_Lower_D_Border20 CI_Lower_D_Border21 CI_Lower_D_Border22 CI_Lower_D_Border23 CI_Lower_D_Border24 CI_Lower_D_Border25 CI_Lower_D_Border26 CI_Lower_D_Border27 CI_Lower_D_Border28 CI_Lower_D_Border29 CI_Lower_D_Border30 CI_Lower_D_Border31 CI_Lower_D_Border32 CI_Lower_D_Border33 CI_Lower_D_Border34 CI_Lower_D_Border35 CI_Lower_D_Border36 CI_Lower_D_Border37 CI_Lower_D_Border38 CI_Lower_D_Border39 CI_Lower_D_Border40 CI_Lower_D_Border41 CI_Lower_D_Border42 CI_Lower_D_Border43 CI_Lower_D_Border44 CI_Lower_D_Border45 CI_Lower_D_Border46 CI_Lower_D_Border47 CI_Lower_D_Border48 CI_Lower_D_Border49 CI_Lower_D_Border50 CI_Lower_D_Border51 CI_Lower_D_Border52 CI_Lower_D_Border53 CI_Lower_D_Border54 CI_Lower_D_Border55 CI_Lower_D_Border56 CI_Lower_D_Border57 CI_Lower_D_Border58 CI_Lower_D_Border59 CI_Lower_D_Border60 CI_Lower_D_Border61 CI_Lower_D_Border62 CI_Lower_D_Border63 CI_Lower_D_Border64 CI_Lower_D_Border65 CI_Lower_D_Border66 CI_Lower_D_Border67 CI_Lower_D_Border68 CI_Lower_D_Border69 CI_Lower_D_Border70 CI_Lower_D_Border71 CI_Lower_D_Border72 CI_Lower_D_Border73 CI_Lower_D_Border74 CI_Lower_D_Border75 CI_Lower_D_Border76 CI_Lower_D_Border77 CI_Lower_D_Border78 CI_Lower_D_Border79 CI_Lower_D_Border80 SD_10_D_Border20 CI_Upper_10_D_Border20 CI_Lower_10_D_Border20 SD_10_D_Border21 CI_Upper_10_D_Border21 CI_Lower_10_D_Border21 SD_10_D_Border22 CI_Upper_10_D_Border22 CI_Lower_10_D_Border22 SD_10_D_Border23 CI_Upper_10_D_Border23 CI_Lower_10_D_Border23 SD_10_D_Border24 CI_Upper_10_D_Border24 CI_Lower_10_D_Border24 SD_10_D_Border25 CI_Upper_10_D_Border25 CI_Lower_10_D_Border25 SD_10_D_Border26 CI_Upper_10_D_Border26 CI_Lower_10_D_Border26 SD_10_D_Border27 CI_Upper_10_D_Border27 CI_Lower_10_D_Border27 SD_10_D_Border28 CI_Upper_10_D_Border28 CI_Lower_10_D_Border28 SD_10_D_Border29 CI_Upper_10_D_Border29 CI_Lower_10_D_Border29 SD_10_D_Border30 CI_Upper_10_D_Border30 CI_Lower_10_D_Border30 SD_10_D_Border31 CI_Upper_10_D_Border31 CI_Lower_10_D_Border31 SD_10_D_Border32 CI_Upper_10_D_Border32 CI_Lower_10_D_Border32 SD_10_D_Border33 CI_Upper_10_D_Border33 CI_Lower_10_D_Border33 SD_10_D_Border34 CI_Upper_10_D_Border34 CI_Lower_10_D_Border34 SD_10_D_Border35 CI_Upper_10_D_Border35 CI_Lower_10_D_Border35 SD_10_D_Border36 CI_Upper_10_D_Border36 CI_Lower_10_D_Border36 SD_10_D_Border37 CI_Upper_10_D_Border37 CI_Lower_10_D_Border37 SD_10_D_Border38 CI_Upper_10_D_Border38 CI_Lower_10_D_Border38 SD_10_D_Border39 CI_Upper_10_D_Border39 CI_Lower_10_D_Border39 SD_10_D_Border40 CI_Upper_10_D_Border40 CI_Lower_10_D_Border40 SD_10_D_Border41 CI_Upper_10_D_Border41 CI_Lower_10_D_Border41 SD_10_D_Border42 CI_Upper_10_D_Border42 CI_Lower_10_D_Border42 SD_10_D_Border43 CI_Upper_10_D_Border43 CI_Lower_10_D_Border43 SD_10_D_Border44 CI_Upper_10_D_Border44 CI_Lower_10_D_Border44 SD_10_D_Border45 CI_Upper_10_D_Border45 CI_Lower_10_D_Border45 SD_10_D_Border46 CI_Upper_10_D_Border46 CI_Lower_10_D_Border46 SD_10_D_Border47 CI_Upper_10_D_Border47 CI_Lower_10_D_Border47 SD_10_D_Border48 CI_Upper_10_D_Border48 CI_Lower_10_D_Border48 SD_10_D_Border49 CI_Upper_10_D_Border49 CI_Lower_10_D_Border49 SD_10_D_Border50 CI_Upper_10_D_Border50 CI_Lower_10_D_Border50 SD_10_D_Border51 CI_Upper_10_D_Border51 CI_Lower_10_D_Border51 SD_10_D_Border52 CI_Upper_10_D_Border52 CI_Lower_10_D_Border52 SD_10_D_Border53 CI_Upper_10_D_Border53 CI_Lower_10_D_Border53 SD_10_D_Border54 CI_Upper_10_D_Border54 CI_Lower_10_D_Border54 SD_10_D_Border55 CI_Upper_10_D_Border55 CI_Lower_10_D_Border55 SD_10_D_Border56 CI_Upper_10_D_Border56 CI_Lower_10_D_Border56 SD_10_D_Border57 CI_Upper_10_D_Border57 CI_Lower_10_D_Border57 SD_10_D_Border58 CI_Upper_10_D_Border58 CI_Lower_10_D_Border58 SD_10_D_Border59 CI_Upper_10_D_Border59 CI_Lower_10_D_Border59 SD_10_D_Border60 CI_Upper_10_D_Border60 CI_Lower_10_D_Border60 SD_10_D_Border61 CI_Upper_10_D_Border61 CI_Lower_10_D_Border61 SD_10_D_Border62 CI_Upper_10_D_Border62 CI_Lower_10_D_Border62 SD_10_D_Border63 CI_Upper_10_D_Border63 CI_Lower_10_D_Border63 SD_10_D_Border64 CI_Upper_10_D_Border64 CI_Lower_10_D_Border64 SD_10_D_Border65 CI_Upper_10_D_Border65 CI_Lower_10_D_Border65 SD_10_D_Border66 CI_Upper_10_D_Border66 CI_Lower_10_D_Border66 SD_10_D_Border67 CI_Upper_10_D_Border67 CI_Lower_10_D_Border67 SD_10_D_Border68 CI_Upper_10_D_Border68 CI_Lower_10_D_Border68 SD_10_D_Border69 CI_Upper_10_D_Border69 CI_Lower_10_D_Border69 SD_10_D_Border70 CI_Upper_10_D_Border70 CI_Lower_10_D_Border70 SD_10_D_Border71 CI_Upper_10_D_Border71 CI_Lower_10_D_Border71 SD_10_D_Border72 CI_Upper_10_D_Border72 CI_Lower_10_D_Border72 SD_10_D_Border73 CI_Upper_10_D_Border73 CI_Lower_10_D_Border73 SD_10_D_Border74 CI_Upper_10_D_Border74 CI_Lower_10_D_Border74 SD_10_D_Border75 CI_Upper_10_D_Border75 CI_Lower_10_D_Border75 SD_10_D_Border76 CI_Upper_10_D_Border76 CI_Lower_10_D_Border76 SD_10_D_Border77 CI_Upper_10_D_Border77 CI_Lower_10_D_Border77 SD_10_D_Border78 CI_Upper_10_D_Border78 CI_Lower_10_D_Border78 SD_10_D_Border79 CI_Upper_10_D_Border79 CI_Lower_10_D_Border79 SD_10_D_Border80 CI_Upper_10_D_Border80 CI_Lower_10_D_Border80

reshape long Beta_D_Border CI_Upper_D_Border CI_Lower_D_Border CI_Upper_10_D_Border CI_Lower_10_D_Border, i(N) j(band)

twoway (line Beta_D_Border band, lcolor(black) lpattern(solid)) ///
	(line CI_Upper_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Lower_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Upper_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)) ///
	(line CI_Lower_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)), ///
    ytitle(Estimated Effect Anglophone, size(small)) ylabel(-.5(.5)2,  angle(horizontal))  ///
    xtitle("", size(small)) xlabel(20(10)80, labsize(vsmall))  ///
           yline(0, lcolor(gs10)) ///
      plotregion(lcolor(black)) ///
  legend(off) ///
        title(a. Maintaining Roads, size(medsmall)) ///
    scheme(s2mono) graphregion(fcolor(white)) 


*b. Eval of Market Maintanance C66B
use AfroBarometerData.dta, clear
keep if REGION==2 | REGION==7 | REGION==9 | REGION==10 | REGION==12

foreach var of varlist D_Border20-D_Border80 {
	quietly reg C66B $MDpolynomial rural Ln_WorldPop10_5km $AB $geo $governance  Round if `var'==1, cluster(EANUMB_AB) robust 
	gen Beta_`var' = _b[anglophone]
	matrix c_`var' = e(V)
	gen Var_`var' = c_`var'[1,1]
} 

foreach var of varlist D_Border20-D_Border80 {
	gen SD_`var' = sqrt(Var_`var')
	gen CI_Upper_`var' = Beta_`var'+(SD_`var'*1.96)
	gen CI_Lower_`var' = Beta_`var'-(SD_`var'*1.96)
}

foreach var of varlist D_Border20-D_Border80 {
	gen SD_10_`var' = sqrt(Var_`var')
	gen CI_Upper_10_`var' = Beta_`var'+(SD_`var'*1.645)
	gen CI_Lower_10_`var' = Beta_`var'-(SD_`var'*1.645)
}

gen N = _n
drop if N !=1
keep N Beta_D_Border20 Beta_D_Border21 Beta_D_Border22 Beta_D_Border23 Beta_D_Border24 Beta_D_Border25 Beta_D_Border26 Beta_D_Border27 Beta_D_Border28 Beta_D_Border29 Beta_D_Border30 Beta_D_Border31 Beta_D_Border32 Beta_D_Border33 Beta_D_Border34 Beta_D_Border35 Beta_D_Border36 Beta_D_Border37 Beta_D_Border38 Beta_D_Border39 Beta_D_Border40 Beta_D_Border41 Beta_D_Border42 Beta_D_Border43 Beta_D_Border44 Beta_D_Border45 Beta_D_Border46 Beta_D_Border47 Beta_D_Border48 Beta_D_Border49 Beta_D_Border50 Beta_D_Border51 Beta_D_Border52 Beta_D_Border53 Beta_D_Border54 Beta_D_Border55 Beta_D_Border56 Beta_D_Border57 Beta_D_Border58 Beta_D_Border59 Beta_D_Border60 Beta_D_Border61 Beta_D_Border62 Beta_D_Border63 Beta_D_Border64 Beta_D_Border65 Beta_D_Border66 Beta_D_Border67 Beta_D_Border68 Beta_D_Border69 Beta_D_Border70 Beta_D_Border71 Beta_D_Border72 Beta_D_Border73 Beta_D_Border74 Beta_D_Border75 Beta_D_Border76 Beta_D_Border77 Beta_D_Border78 Beta_D_Border79 Beta_D_Border80 CI_Upper_D_Border20 CI_Upper_D_Border21 CI_Upper_D_Border22 CI_Upper_D_Border23 CI_Upper_D_Border24 CI_Upper_D_Border25 CI_Upper_D_Border26 CI_Upper_D_Border27 CI_Upper_D_Border28 CI_Upper_D_Border29 CI_Upper_D_Border30 CI_Upper_D_Border31 CI_Upper_D_Border32 CI_Upper_D_Border33 CI_Upper_D_Border34 CI_Upper_D_Border35 CI_Upper_D_Border36 CI_Upper_D_Border37 CI_Upper_D_Border38 CI_Upper_D_Border39 CI_Upper_D_Border40 CI_Upper_D_Border41 CI_Upper_D_Border42 CI_Upper_D_Border43 CI_Upper_D_Border44 CI_Upper_D_Border45 CI_Upper_D_Border46 CI_Upper_D_Border47 CI_Upper_D_Border48 CI_Upper_D_Border49 CI_Upper_D_Border50 CI_Upper_D_Border51 CI_Upper_D_Border52 CI_Upper_D_Border53 CI_Upper_D_Border54 CI_Upper_D_Border55 CI_Upper_D_Border56 CI_Upper_D_Border57 CI_Upper_D_Border58 CI_Upper_D_Border59 CI_Upper_D_Border60 CI_Upper_D_Border61 CI_Upper_D_Border62 CI_Upper_D_Border63 CI_Upper_D_Border64 CI_Upper_D_Border65 CI_Upper_D_Border66 CI_Upper_D_Border67 CI_Upper_D_Border68 CI_Upper_D_Border69 CI_Upper_D_Border70 CI_Upper_D_Border71 CI_Upper_D_Border72 CI_Upper_D_Border73 CI_Upper_D_Border74 CI_Upper_D_Border75 CI_Upper_D_Border76 CI_Upper_D_Border77 CI_Upper_D_Border78 CI_Upper_D_Border79 CI_Upper_D_Border80 CI_Lower_D_Border20 CI_Lower_D_Border21 CI_Lower_D_Border22 CI_Lower_D_Border23 CI_Lower_D_Border24 CI_Lower_D_Border25 CI_Lower_D_Border26 CI_Lower_D_Border27 CI_Lower_D_Border28 CI_Lower_D_Border29 CI_Lower_D_Border30 CI_Lower_D_Border31 CI_Lower_D_Border32 CI_Lower_D_Border33 CI_Lower_D_Border34 CI_Lower_D_Border35 CI_Lower_D_Border36 CI_Lower_D_Border37 CI_Lower_D_Border38 CI_Lower_D_Border39 CI_Lower_D_Border40 CI_Lower_D_Border41 CI_Lower_D_Border42 CI_Lower_D_Border43 CI_Lower_D_Border44 CI_Lower_D_Border45 CI_Lower_D_Border46 CI_Lower_D_Border47 CI_Lower_D_Border48 CI_Lower_D_Border49 CI_Lower_D_Border50 CI_Lower_D_Border51 CI_Lower_D_Border52 CI_Lower_D_Border53 CI_Lower_D_Border54 CI_Lower_D_Border55 CI_Lower_D_Border56 CI_Lower_D_Border57 CI_Lower_D_Border58 CI_Lower_D_Border59 CI_Lower_D_Border60 CI_Lower_D_Border61 CI_Lower_D_Border62 CI_Lower_D_Border63 CI_Lower_D_Border64 CI_Lower_D_Border65 CI_Lower_D_Border66 CI_Lower_D_Border67 CI_Lower_D_Border68 CI_Lower_D_Border69 CI_Lower_D_Border70 CI_Lower_D_Border71 CI_Lower_D_Border72 CI_Lower_D_Border73 CI_Lower_D_Border74 CI_Lower_D_Border75 CI_Lower_D_Border76 CI_Lower_D_Border77 CI_Lower_D_Border78 CI_Lower_D_Border79 CI_Lower_D_Border80 SD_10_D_Border20 CI_Upper_10_D_Border20 CI_Lower_10_D_Border20 SD_10_D_Border21 CI_Upper_10_D_Border21 CI_Lower_10_D_Border21 SD_10_D_Border22 CI_Upper_10_D_Border22 CI_Lower_10_D_Border22 SD_10_D_Border23 CI_Upper_10_D_Border23 CI_Lower_10_D_Border23 SD_10_D_Border24 CI_Upper_10_D_Border24 CI_Lower_10_D_Border24 SD_10_D_Border25 CI_Upper_10_D_Border25 CI_Lower_10_D_Border25 SD_10_D_Border26 CI_Upper_10_D_Border26 CI_Lower_10_D_Border26 SD_10_D_Border27 CI_Upper_10_D_Border27 CI_Lower_10_D_Border27 SD_10_D_Border28 CI_Upper_10_D_Border28 CI_Lower_10_D_Border28 SD_10_D_Border29 CI_Upper_10_D_Border29 CI_Lower_10_D_Border29 SD_10_D_Border30 CI_Upper_10_D_Border30 CI_Lower_10_D_Border30 SD_10_D_Border31 CI_Upper_10_D_Border31 CI_Lower_10_D_Border31 SD_10_D_Border32 CI_Upper_10_D_Border32 CI_Lower_10_D_Border32 SD_10_D_Border33 CI_Upper_10_D_Border33 CI_Lower_10_D_Border33 SD_10_D_Border34 CI_Upper_10_D_Border34 CI_Lower_10_D_Border34 SD_10_D_Border35 CI_Upper_10_D_Border35 CI_Lower_10_D_Border35 SD_10_D_Border36 CI_Upper_10_D_Border36 CI_Lower_10_D_Border36 SD_10_D_Border37 CI_Upper_10_D_Border37 CI_Lower_10_D_Border37 SD_10_D_Border38 CI_Upper_10_D_Border38 CI_Lower_10_D_Border38 SD_10_D_Border39 CI_Upper_10_D_Border39 CI_Lower_10_D_Border39 SD_10_D_Border40 CI_Upper_10_D_Border40 CI_Lower_10_D_Border40 SD_10_D_Border41 CI_Upper_10_D_Border41 CI_Lower_10_D_Border41 SD_10_D_Border42 CI_Upper_10_D_Border42 CI_Lower_10_D_Border42 SD_10_D_Border43 CI_Upper_10_D_Border43 CI_Lower_10_D_Border43 SD_10_D_Border44 CI_Upper_10_D_Border44 CI_Lower_10_D_Border44 SD_10_D_Border45 CI_Upper_10_D_Border45 CI_Lower_10_D_Border45 SD_10_D_Border46 CI_Upper_10_D_Border46 CI_Lower_10_D_Border46 SD_10_D_Border47 CI_Upper_10_D_Border47 CI_Lower_10_D_Border47 SD_10_D_Border48 CI_Upper_10_D_Border48 CI_Lower_10_D_Border48 SD_10_D_Border49 CI_Upper_10_D_Border49 CI_Lower_10_D_Border49 SD_10_D_Border50 CI_Upper_10_D_Border50 CI_Lower_10_D_Border50 SD_10_D_Border51 CI_Upper_10_D_Border51 CI_Lower_10_D_Border51 SD_10_D_Border52 CI_Upper_10_D_Border52 CI_Lower_10_D_Border52 SD_10_D_Border53 CI_Upper_10_D_Border53 CI_Lower_10_D_Border53 SD_10_D_Border54 CI_Upper_10_D_Border54 CI_Lower_10_D_Border54 SD_10_D_Border55 CI_Upper_10_D_Border55 CI_Lower_10_D_Border55 SD_10_D_Border56 CI_Upper_10_D_Border56 CI_Lower_10_D_Border56 SD_10_D_Border57 CI_Upper_10_D_Border57 CI_Lower_10_D_Border57 SD_10_D_Border58 CI_Upper_10_D_Border58 CI_Lower_10_D_Border58 SD_10_D_Border59 CI_Upper_10_D_Border59 CI_Lower_10_D_Border59 SD_10_D_Border60 CI_Upper_10_D_Border60 CI_Lower_10_D_Border60 SD_10_D_Border61 CI_Upper_10_D_Border61 CI_Lower_10_D_Border61 SD_10_D_Border62 CI_Upper_10_D_Border62 CI_Lower_10_D_Border62 SD_10_D_Border63 CI_Upper_10_D_Border63 CI_Lower_10_D_Border63 SD_10_D_Border64 CI_Upper_10_D_Border64 CI_Lower_10_D_Border64 SD_10_D_Border65 CI_Upper_10_D_Border65 CI_Lower_10_D_Border65 SD_10_D_Border66 CI_Upper_10_D_Border66 CI_Lower_10_D_Border66 SD_10_D_Border67 CI_Upper_10_D_Border67 CI_Lower_10_D_Border67 SD_10_D_Border68 CI_Upper_10_D_Border68 CI_Lower_10_D_Border68 SD_10_D_Border69 CI_Upper_10_D_Border69 CI_Lower_10_D_Border69 SD_10_D_Border70 CI_Upper_10_D_Border70 CI_Lower_10_D_Border70 SD_10_D_Border71 CI_Upper_10_D_Border71 CI_Lower_10_D_Border71 SD_10_D_Border72 CI_Upper_10_D_Border72 CI_Lower_10_D_Border72 SD_10_D_Border73 CI_Upper_10_D_Border73 CI_Lower_10_D_Border73 SD_10_D_Border74 CI_Upper_10_D_Border74 CI_Lower_10_D_Border74 SD_10_D_Border75 CI_Upper_10_D_Border75 CI_Lower_10_D_Border75 SD_10_D_Border76 CI_Upper_10_D_Border76 CI_Lower_10_D_Border76 SD_10_D_Border77 CI_Upper_10_D_Border77 CI_Lower_10_D_Border77 SD_10_D_Border78 CI_Upper_10_D_Border78 CI_Lower_10_D_Border78 SD_10_D_Border79 CI_Upper_10_D_Border79 CI_Lower_10_D_Border79 SD_10_D_Border80 CI_Upper_10_D_Border80 CI_Lower_10_D_Border80


reshape long Beta_D_Border CI_Upper_D_Border CI_Lower_D_Border CI_Upper_10_D_Border CI_Lower_10_D_Border, i(N) j(band)

twoway (line Beta_D_Border band, lcolor(black) lpattern(solid)) ///
	(line CI_Upper_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Lower_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Upper_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)) ///
	(line CI_Lower_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)), ///
    ytitle("", size(small)) ylabel(#6,  angle(horizontal)) yscale(r(-.5(.5)2)) ///
    xtitle("", size(small)) xlabel(20(10)80, labsize(vsmall))  ///
          yline(0, lcolor(gs10)) ///
      plotregion(lcolor(black)) ///
   legend(off) ///
        title(b. Maintaining Markets, size(medsmall)) ///
    scheme(s2mono) graphregion(fcolor(white)) 

*c. Eval of Maintaining Health Standards Q66C_R5
use AfroBarometerData.dta, clear
keep if REGION==2 | REGION==7 | REGION==9 | REGION==10 | REGION==12

foreach var of varlist D_Border20-D_Border80 {
	quietly reg Q66C_R5 $MDpolynomial rural Ln_WorldPop10_5km $AB $geo $governance  Round if `var'==1, cluster(EANUMB_AB) robust 
	gen Beta_`var' = _b[anglophone]
	matrix c_`var' = e(V)
	gen Var_`var' = c_`var'[1,1]
} 

foreach var of varlist D_Border20-D_Border80 {
	gen SD_`var' = sqrt(Var_`var')
	gen CI_Upper_`var' = Beta_`var'+(SD_`var'*1.96)
	gen CI_Lower_`var' = Beta_`var'-(SD_`var'*1.96)
}


foreach var of varlist D_Border20-D_Border80 {
	gen SD_10_`var' = sqrt(Var_`var')
	gen CI_Upper_10_`var' = Beta_`var'+(SD_`var'*1.645)
	gen CI_Lower_10_`var' = Beta_`var'-(SD_`var'*1.645)
}

gen N = _n
drop if N !=1
keep N Beta_D_Border20 Beta_D_Border21 Beta_D_Border22 Beta_D_Border23 Beta_D_Border24 Beta_D_Border25 Beta_D_Border26 Beta_D_Border27 Beta_D_Border28 Beta_D_Border29 Beta_D_Border30 Beta_D_Border31 Beta_D_Border32 Beta_D_Border33 Beta_D_Border34 Beta_D_Border35 Beta_D_Border36 Beta_D_Border37 Beta_D_Border38 Beta_D_Border39 Beta_D_Border40 Beta_D_Border41 Beta_D_Border42 Beta_D_Border43 Beta_D_Border44 Beta_D_Border45 Beta_D_Border46 Beta_D_Border47 Beta_D_Border48 Beta_D_Border49 Beta_D_Border50 Beta_D_Border51 Beta_D_Border52 Beta_D_Border53 Beta_D_Border54 Beta_D_Border55 Beta_D_Border56 Beta_D_Border57 Beta_D_Border58 Beta_D_Border59 Beta_D_Border60 Beta_D_Border61 Beta_D_Border62 Beta_D_Border63 Beta_D_Border64 Beta_D_Border65 Beta_D_Border66 Beta_D_Border67 Beta_D_Border68 Beta_D_Border69 Beta_D_Border70 Beta_D_Border71 Beta_D_Border72 Beta_D_Border73 Beta_D_Border74 Beta_D_Border75 Beta_D_Border76 Beta_D_Border77 Beta_D_Border78 Beta_D_Border79 Beta_D_Border80 CI_Upper_D_Border20 CI_Upper_D_Border21 CI_Upper_D_Border22 CI_Upper_D_Border23 CI_Upper_D_Border24 CI_Upper_D_Border25 CI_Upper_D_Border26 CI_Upper_D_Border27 CI_Upper_D_Border28 CI_Upper_D_Border29 CI_Upper_D_Border30 CI_Upper_D_Border31 CI_Upper_D_Border32 CI_Upper_D_Border33 CI_Upper_D_Border34 CI_Upper_D_Border35 CI_Upper_D_Border36 CI_Upper_D_Border37 CI_Upper_D_Border38 CI_Upper_D_Border39 CI_Upper_D_Border40 CI_Upper_D_Border41 CI_Upper_D_Border42 CI_Upper_D_Border43 CI_Upper_D_Border44 CI_Upper_D_Border45 CI_Upper_D_Border46 CI_Upper_D_Border47 CI_Upper_D_Border48 CI_Upper_D_Border49 CI_Upper_D_Border50 CI_Upper_D_Border51 CI_Upper_D_Border52 CI_Upper_D_Border53 CI_Upper_D_Border54 CI_Upper_D_Border55 CI_Upper_D_Border56 CI_Upper_D_Border57 CI_Upper_D_Border58 CI_Upper_D_Border59 CI_Upper_D_Border60 CI_Upper_D_Border61 CI_Upper_D_Border62 CI_Upper_D_Border63 CI_Upper_D_Border64 CI_Upper_D_Border65 CI_Upper_D_Border66 CI_Upper_D_Border67 CI_Upper_D_Border68 CI_Upper_D_Border69 CI_Upper_D_Border70 CI_Upper_D_Border71 CI_Upper_D_Border72 CI_Upper_D_Border73 CI_Upper_D_Border74 CI_Upper_D_Border75 CI_Upper_D_Border76 CI_Upper_D_Border77 CI_Upper_D_Border78 CI_Upper_D_Border79 CI_Upper_D_Border80 CI_Lower_D_Border20 CI_Lower_D_Border21 CI_Lower_D_Border22 CI_Lower_D_Border23 CI_Lower_D_Border24 CI_Lower_D_Border25 CI_Lower_D_Border26 CI_Lower_D_Border27 CI_Lower_D_Border28 CI_Lower_D_Border29 CI_Lower_D_Border30 CI_Lower_D_Border31 CI_Lower_D_Border32 CI_Lower_D_Border33 CI_Lower_D_Border34 CI_Lower_D_Border35 CI_Lower_D_Border36 CI_Lower_D_Border37 CI_Lower_D_Border38 CI_Lower_D_Border39 CI_Lower_D_Border40 CI_Lower_D_Border41 CI_Lower_D_Border42 CI_Lower_D_Border43 CI_Lower_D_Border44 CI_Lower_D_Border45 CI_Lower_D_Border46 CI_Lower_D_Border47 CI_Lower_D_Border48 CI_Lower_D_Border49 CI_Lower_D_Border50 CI_Lower_D_Border51 CI_Lower_D_Border52 CI_Lower_D_Border53 CI_Lower_D_Border54 CI_Lower_D_Border55 CI_Lower_D_Border56 CI_Lower_D_Border57 CI_Lower_D_Border58 CI_Lower_D_Border59 CI_Lower_D_Border60 CI_Lower_D_Border61 CI_Lower_D_Border62 CI_Lower_D_Border63 CI_Lower_D_Border64 CI_Lower_D_Border65 CI_Lower_D_Border66 CI_Lower_D_Border67 CI_Lower_D_Border68 CI_Lower_D_Border69 CI_Lower_D_Border70 CI_Lower_D_Border71 CI_Lower_D_Border72 CI_Lower_D_Border73 CI_Lower_D_Border74 CI_Lower_D_Border75 CI_Lower_D_Border76 CI_Lower_D_Border77 CI_Lower_D_Border78 CI_Lower_D_Border79 CI_Lower_D_Border80 SD_10_D_Border20 CI_Upper_10_D_Border20 CI_Lower_10_D_Border20 SD_10_D_Border21 CI_Upper_10_D_Border21 CI_Lower_10_D_Border21 SD_10_D_Border22 CI_Upper_10_D_Border22 CI_Lower_10_D_Border22 SD_10_D_Border23 CI_Upper_10_D_Border23 CI_Lower_10_D_Border23 SD_10_D_Border24 CI_Upper_10_D_Border24 CI_Lower_10_D_Border24 SD_10_D_Border25 CI_Upper_10_D_Border25 CI_Lower_10_D_Border25 SD_10_D_Border26 CI_Upper_10_D_Border26 CI_Lower_10_D_Border26 SD_10_D_Border27 CI_Upper_10_D_Border27 CI_Lower_10_D_Border27 SD_10_D_Border28 CI_Upper_10_D_Border28 CI_Lower_10_D_Border28 SD_10_D_Border29 CI_Upper_10_D_Border29 CI_Lower_10_D_Border29 SD_10_D_Border30 CI_Upper_10_D_Border30 CI_Lower_10_D_Border30 SD_10_D_Border31 CI_Upper_10_D_Border31 CI_Lower_10_D_Border31 SD_10_D_Border32 CI_Upper_10_D_Border32 CI_Lower_10_D_Border32 SD_10_D_Border33 CI_Upper_10_D_Border33 CI_Lower_10_D_Border33 SD_10_D_Border34 CI_Upper_10_D_Border34 CI_Lower_10_D_Border34 SD_10_D_Border35 CI_Upper_10_D_Border35 CI_Lower_10_D_Border35 SD_10_D_Border36 CI_Upper_10_D_Border36 CI_Lower_10_D_Border36 SD_10_D_Border37 CI_Upper_10_D_Border37 CI_Lower_10_D_Border37 SD_10_D_Border38 CI_Upper_10_D_Border38 CI_Lower_10_D_Border38 SD_10_D_Border39 CI_Upper_10_D_Border39 CI_Lower_10_D_Border39 SD_10_D_Border40 CI_Upper_10_D_Border40 CI_Lower_10_D_Border40 SD_10_D_Border41 CI_Upper_10_D_Border41 CI_Lower_10_D_Border41 SD_10_D_Border42 CI_Upper_10_D_Border42 CI_Lower_10_D_Border42 SD_10_D_Border43 CI_Upper_10_D_Border43 CI_Lower_10_D_Border43 SD_10_D_Border44 CI_Upper_10_D_Border44 CI_Lower_10_D_Border44 SD_10_D_Border45 CI_Upper_10_D_Border45 CI_Lower_10_D_Border45 SD_10_D_Border46 CI_Upper_10_D_Border46 CI_Lower_10_D_Border46 SD_10_D_Border47 CI_Upper_10_D_Border47 CI_Lower_10_D_Border47 SD_10_D_Border48 CI_Upper_10_D_Border48 CI_Lower_10_D_Border48 SD_10_D_Border49 CI_Upper_10_D_Border49 CI_Lower_10_D_Border49 SD_10_D_Border50 CI_Upper_10_D_Border50 CI_Lower_10_D_Border50 SD_10_D_Border51 CI_Upper_10_D_Border51 CI_Lower_10_D_Border51 SD_10_D_Border52 CI_Upper_10_D_Border52 CI_Lower_10_D_Border52 SD_10_D_Border53 CI_Upper_10_D_Border53 CI_Lower_10_D_Border53 SD_10_D_Border54 CI_Upper_10_D_Border54 CI_Lower_10_D_Border54 SD_10_D_Border55 CI_Upper_10_D_Border55 CI_Lower_10_D_Border55 SD_10_D_Border56 CI_Upper_10_D_Border56 CI_Lower_10_D_Border56 SD_10_D_Border57 CI_Upper_10_D_Border57 CI_Lower_10_D_Border57 SD_10_D_Border58 CI_Upper_10_D_Border58 CI_Lower_10_D_Border58 SD_10_D_Border59 CI_Upper_10_D_Border59 CI_Lower_10_D_Border59 SD_10_D_Border60 CI_Upper_10_D_Border60 CI_Lower_10_D_Border60 SD_10_D_Border61 CI_Upper_10_D_Border61 CI_Lower_10_D_Border61 SD_10_D_Border62 CI_Upper_10_D_Border62 CI_Lower_10_D_Border62 SD_10_D_Border63 CI_Upper_10_D_Border63 CI_Lower_10_D_Border63 SD_10_D_Border64 CI_Upper_10_D_Border64 CI_Lower_10_D_Border64 SD_10_D_Border65 CI_Upper_10_D_Border65 CI_Lower_10_D_Border65 SD_10_D_Border66 CI_Upper_10_D_Border66 CI_Lower_10_D_Border66 SD_10_D_Border67 CI_Upper_10_D_Border67 CI_Lower_10_D_Border67 SD_10_D_Border68 CI_Upper_10_D_Border68 CI_Lower_10_D_Border68 SD_10_D_Border69 CI_Upper_10_D_Border69 CI_Lower_10_D_Border69 SD_10_D_Border70 CI_Upper_10_D_Border70 CI_Lower_10_D_Border70 SD_10_D_Border71 CI_Upper_10_D_Border71 CI_Lower_10_D_Border71 SD_10_D_Border72 CI_Upper_10_D_Border72 CI_Lower_10_D_Border72 SD_10_D_Border73 CI_Upper_10_D_Border73 CI_Lower_10_D_Border73 SD_10_D_Border74 CI_Upper_10_D_Border74 CI_Lower_10_D_Border74 SD_10_D_Border75 CI_Upper_10_D_Border75 CI_Lower_10_D_Border75 SD_10_D_Border76 CI_Upper_10_D_Border76 CI_Lower_10_D_Border76 SD_10_D_Border77 CI_Upper_10_D_Border77 CI_Lower_10_D_Border77 SD_10_D_Border78 CI_Upper_10_D_Border78 CI_Lower_10_D_Border78 SD_10_D_Border79 CI_Upper_10_D_Border79 CI_Lower_10_D_Border79 SD_10_D_Border80 CI_Upper_10_D_Border80 CI_Lower_10_D_Border80

reshape long Beta_D_Border CI_Upper_D_Border CI_Lower_D_Border CI_Upper_10_D_Border CI_Lower_10_D_Border, i(N) j(band)

twoway (line Beta_D_Border band, lcolor(black) lpattern(solid)) ///
	(line CI_Upper_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Lower_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Upper_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)) ///
	(line CI_Lower_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)), ///
    ytitle(Estimated Effect Anglophone, size(small)) ylabel(#6,  angle(horizontal)) yscale(r(-.5(.5)2)) ///
    xtitle("", size(small)) xlabel(20(10)80, labsize(vsmall))  ///
          yline(0, lcolor(gs10)) ///
      plotregion(lcolor(black)) ///
   legend(off) ///
        title("c. Maintaining Health Standards", size(medsmall)) ///
    scheme(s2mono) graphregion(fcolor(white)) 
 
 
*d. Eval of Community Cleanliness Q66D_R5
use AfroBarometerData.dta, clear
keep if REGION==2 | REGION==7 | REGION==9 | REGION==10 | REGION==12

foreach var of varlist D_Border20-D_Border80 {
	quietly reg Q66D_R5 $MDpolynomial  rural Ln_WorldPop10_5km $AB $geo $governance Round if `var'==1, cluster(EANUMB_AB) robust 
	gen Beta_`var' = _b[anglophone]
	matrix c_`var' = e(V)
	gen Var_`var' = c_`var'[1,1]
} 

foreach var of varlist D_Border20-D_Border80 {
	gen SD_`var' = sqrt(Var_`var')
	gen CI_Upper_`var' = Beta_`var'+(SD_`var'*1.96)
	gen CI_Lower_`var' = Beta_`var'-(SD_`var'*1.96)
}

foreach var of varlist D_Border20-D_Border80 {
	gen SD_10_`var' = sqrt(Var_`var')
	gen CI_Upper_10_`var' = Beta_`var'+(SD_`var'*1.645)
	gen CI_Lower_10_`var' = Beta_`var'-(SD_`var'*1.645)
}

gen N = _n
drop if N !=1
keep N Beta_D_Border20 Beta_D_Border21 Beta_D_Border22 Beta_D_Border23 Beta_D_Border24 Beta_D_Border25 Beta_D_Border26 Beta_D_Border27 Beta_D_Border28 Beta_D_Border29 Beta_D_Border30 Beta_D_Border31 Beta_D_Border32 Beta_D_Border33 Beta_D_Border34 Beta_D_Border35 Beta_D_Border36 Beta_D_Border37 Beta_D_Border38 Beta_D_Border39 Beta_D_Border40 Beta_D_Border41 Beta_D_Border42 Beta_D_Border43 Beta_D_Border44 Beta_D_Border45 Beta_D_Border46 Beta_D_Border47 Beta_D_Border48 Beta_D_Border49 Beta_D_Border50 Beta_D_Border51 Beta_D_Border52 Beta_D_Border53 Beta_D_Border54 Beta_D_Border55 Beta_D_Border56 Beta_D_Border57 Beta_D_Border58 Beta_D_Border59 Beta_D_Border60 Beta_D_Border61 Beta_D_Border62 Beta_D_Border63 Beta_D_Border64 Beta_D_Border65 Beta_D_Border66 Beta_D_Border67 Beta_D_Border68 Beta_D_Border69 Beta_D_Border70 Beta_D_Border71 Beta_D_Border72 Beta_D_Border73 Beta_D_Border74 Beta_D_Border75 Beta_D_Border76 Beta_D_Border77 Beta_D_Border78 Beta_D_Border79 Beta_D_Border80 CI_Upper_D_Border20 CI_Upper_D_Border21 CI_Upper_D_Border22 CI_Upper_D_Border23 CI_Upper_D_Border24 CI_Upper_D_Border25 CI_Upper_D_Border26 CI_Upper_D_Border27 CI_Upper_D_Border28 CI_Upper_D_Border29 CI_Upper_D_Border30 CI_Upper_D_Border31 CI_Upper_D_Border32 CI_Upper_D_Border33 CI_Upper_D_Border34 CI_Upper_D_Border35 CI_Upper_D_Border36 CI_Upper_D_Border37 CI_Upper_D_Border38 CI_Upper_D_Border39 CI_Upper_D_Border40 CI_Upper_D_Border41 CI_Upper_D_Border42 CI_Upper_D_Border43 CI_Upper_D_Border44 CI_Upper_D_Border45 CI_Upper_D_Border46 CI_Upper_D_Border47 CI_Upper_D_Border48 CI_Upper_D_Border49 CI_Upper_D_Border50 CI_Upper_D_Border51 CI_Upper_D_Border52 CI_Upper_D_Border53 CI_Upper_D_Border54 CI_Upper_D_Border55 CI_Upper_D_Border56 CI_Upper_D_Border57 CI_Upper_D_Border58 CI_Upper_D_Border59 CI_Upper_D_Border60 CI_Upper_D_Border61 CI_Upper_D_Border62 CI_Upper_D_Border63 CI_Upper_D_Border64 CI_Upper_D_Border65 CI_Upper_D_Border66 CI_Upper_D_Border67 CI_Upper_D_Border68 CI_Upper_D_Border69 CI_Upper_D_Border70 CI_Upper_D_Border71 CI_Upper_D_Border72 CI_Upper_D_Border73 CI_Upper_D_Border74 CI_Upper_D_Border75 CI_Upper_D_Border76 CI_Upper_D_Border77 CI_Upper_D_Border78 CI_Upper_D_Border79 CI_Upper_D_Border80 CI_Lower_D_Border20 CI_Lower_D_Border21 CI_Lower_D_Border22 CI_Lower_D_Border23 CI_Lower_D_Border24 CI_Lower_D_Border25 CI_Lower_D_Border26 CI_Lower_D_Border27 CI_Lower_D_Border28 CI_Lower_D_Border29 CI_Lower_D_Border30 CI_Lower_D_Border31 CI_Lower_D_Border32 CI_Lower_D_Border33 CI_Lower_D_Border34 CI_Lower_D_Border35 CI_Lower_D_Border36 CI_Lower_D_Border37 CI_Lower_D_Border38 CI_Lower_D_Border39 CI_Lower_D_Border40 CI_Lower_D_Border41 CI_Lower_D_Border42 CI_Lower_D_Border43 CI_Lower_D_Border44 CI_Lower_D_Border45 CI_Lower_D_Border46 CI_Lower_D_Border47 CI_Lower_D_Border48 CI_Lower_D_Border49 CI_Lower_D_Border50 CI_Lower_D_Border51 CI_Lower_D_Border52 CI_Lower_D_Border53 CI_Lower_D_Border54 CI_Lower_D_Border55 CI_Lower_D_Border56 CI_Lower_D_Border57 CI_Lower_D_Border58 CI_Lower_D_Border59 CI_Lower_D_Border60 CI_Lower_D_Border61 CI_Lower_D_Border62 CI_Lower_D_Border63 CI_Lower_D_Border64 CI_Lower_D_Border65 CI_Lower_D_Border66 CI_Lower_D_Border67 CI_Lower_D_Border68 CI_Lower_D_Border69 CI_Lower_D_Border70 CI_Lower_D_Border71 CI_Lower_D_Border72 CI_Lower_D_Border73 CI_Lower_D_Border74 CI_Lower_D_Border75 CI_Lower_D_Border76 CI_Lower_D_Border77 CI_Lower_D_Border78 CI_Lower_D_Border79 CI_Lower_D_Border80 SD_10_D_Border20 CI_Upper_10_D_Border20 CI_Lower_10_D_Border20 SD_10_D_Border21 CI_Upper_10_D_Border21 CI_Lower_10_D_Border21 SD_10_D_Border22 CI_Upper_10_D_Border22 CI_Lower_10_D_Border22 SD_10_D_Border23 CI_Upper_10_D_Border23 CI_Lower_10_D_Border23 SD_10_D_Border24 CI_Upper_10_D_Border24 CI_Lower_10_D_Border24 SD_10_D_Border25 CI_Upper_10_D_Border25 CI_Lower_10_D_Border25 SD_10_D_Border26 CI_Upper_10_D_Border26 CI_Lower_10_D_Border26 SD_10_D_Border27 CI_Upper_10_D_Border27 CI_Lower_10_D_Border27 SD_10_D_Border28 CI_Upper_10_D_Border28 CI_Lower_10_D_Border28 SD_10_D_Border29 CI_Upper_10_D_Border29 CI_Lower_10_D_Border29 SD_10_D_Border30 CI_Upper_10_D_Border30 CI_Lower_10_D_Border30 SD_10_D_Border31 CI_Upper_10_D_Border31 CI_Lower_10_D_Border31 SD_10_D_Border32 CI_Upper_10_D_Border32 CI_Lower_10_D_Border32 SD_10_D_Border33 CI_Upper_10_D_Border33 CI_Lower_10_D_Border33 SD_10_D_Border34 CI_Upper_10_D_Border34 CI_Lower_10_D_Border34 SD_10_D_Border35 CI_Upper_10_D_Border35 CI_Lower_10_D_Border35 SD_10_D_Border36 CI_Upper_10_D_Border36 CI_Lower_10_D_Border36 SD_10_D_Border37 CI_Upper_10_D_Border37 CI_Lower_10_D_Border37 SD_10_D_Border38 CI_Upper_10_D_Border38 CI_Lower_10_D_Border38 SD_10_D_Border39 CI_Upper_10_D_Border39 CI_Lower_10_D_Border39 SD_10_D_Border40 CI_Upper_10_D_Border40 CI_Lower_10_D_Border40 SD_10_D_Border41 CI_Upper_10_D_Border41 CI_Lower_10_D_Border41 SD_10_D_Border42 CI_Upper_10_D_Border42 CI_Lower_10_D_Border42 SD_10_D_Border43 CI_Upper_10_D_Border43 CI_Lower_10_D_Border43 SD_10_D_Border44 CI_Upper_10_D_Border44 CI_Lower_10_D_Border44 SD_10_D_Border45 CI_Upper_10_D_Border45 CI_Lower_10_D_Border45 SD_10_D_Border46 CI_Upper_10_D_Border46 CI_Lower_10_D_Border46 SD_10_D_Border47 CI_Upper_10_D_Border47 CI_Lower_10_D_Border47 SD_10_D_Border48 CI_Upper_10_D_Border48 CI_Lower_10_D_Border48 SD_10_D_Border49 CI_Upper_10_D_Border49 CI_Lower_10_D_Border49 SD_10_D_Border50 CI_Upper_10_D_Border50 CI_Lower_10_D_Border50 SD_10_D_Border51 CI_Upper_10_D_Border51 CI_Lower_10_D_Border51 SD_10_D_Border52 CI_Upper_10_D_Border52 CI_Lower_10_D_Border52 SD_10_D_Border53 CI_Upper_10_D_Border53 CI_Lower_10_D_Border53 SD_10_D_Border54 CI_Upper_10_D_Border54 CI_Lower_10_D_Border54 SD_10_D_Border55 CI_Upper_10_D_Border55 CI_Lower_10_D_Border55 SD_10_D_Border56 CI_Upper_10_D_Border56 CI_Lower_10_D_Border56 SD_10_D_Border57 CI_Upper_10_D_Border57 CI_Lower_10_D_Border57 SD_10_D_Border58 CI_Upper_10_D_Border58 CI_Lower_10_D_Border58 SD_10_D_Border59 CI_Upper_10_D_Border59 CI_Lower_10_D_Border59 SD_10_D_Border60 CI_Upper_10_D_Border60 CI_Lower_10_D_Border60 SD_10_D_Border61 CI_Upper_10_D_Border61 CI_Lower_10_D_Border61 SD_10_D_Border62 CI_Upper_10_D_Border62 CI_Lower_10_D_Border62 SD_10_D_Border63 CI_Upper_10_D_Border63 CI_Lower_10_D_Border63 SD_10_D_Border64 CI_Upper_10_D_Border64 CI_Lower_10_D_Border64 SD_10_D_Border65 CI_Upper_10_D_Border65 CI_Lower_10_D_Border65 SD_10_D_Border66 CI_Upper_10_D_Border66 CI_Lower_10_D_Border66 SD_10_D_Border67 CI_Upper_10_D_Border67 CI_Lower_10_D_Border67 SD_10_D_Border68 CI_Upper_10_D_Border68 CI_Lower_10_D_Border68 SD_10_D_Border69 CI_Upper_10_D_Border69 CI_Lower_10_D_Border69 SD_10_D_Border70 CI_Upper_10_D_Border70 CI_Lower_10_D_Border70 SD_10_D_Border71 CI_Upper_10_D_Border71 CI_Lower_10_D_Border71 SD_10_D_Border72 CI_Upper_10_D_Border72 CI_Lower_10_D_Border72 SD_10_D_Border73 CI_Upper_10_D_Border73 CI_Lower_10_D_Border73 SD_10_D_Border74 CI_Upper_10_D_Border74 CI_Lower_10_D_Border74 SD_10_D_Border75 CI_Upper_10_D_Border75 CI_Lower_10_D_Border75 SD_10_D_Border76 CI_Upper_10_D_Border76 CI_Lower_10_D_Border76 SD_10_D_Border77 CI_Upper_10_D_Border77 CI_Lower_10_D_Border77 SD_10_D_Border78 CI_Upper_10_D_Border78 CI_Lower_10_D_Border78 SD_10_D_Border79 CI_Upper_10_D_Border79 CI_Lower_10_D_Border79 SD_10_D_Border80 CI_Upper_10_D_Border80 CI_Lower_10_D_Border80

reshape long Beta_D_Border CI_Upper_D_Border CI_Lower_D_Border CI_Upper_10_D_Border CI_Lower_10_D_Border, i(N) j(band)
	
twoway (line Beta_D_Border band, lcolor(black) lpattern(solid)) ///
	(line CI_Upper_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Lower_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Upper_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)) ///
	(line CI_Lower_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)), ///
   ytitle("", size(small)) ylabel(-.5(.5)2,  angle(horizontal))  ///
    xtitle(Distance from Border (km)) xtitle(, size(small)) xlabel(20(10)80, labsize(vsmall))  ///
           yline(0, lcolor(gs10)) ///
      plotregion(lcolor(black)) ///
  legend(off) ///
        title("d. Maintaining Community Cleanliness", size(medsmall)) ///
    scheme(s2mono) graphregion(fcolor(white)) 
 

**e. Eval of Land Management Q66E_R5
use AfroBarometerData.dta, clear
keep if REGION==2 | REGION==7 | REGION==9 | REGION==10 | REGION==12

foreach var of varlist D_Border20-D_Border80 {
  quietly reg C66A $MDpolynomial rural Ln_WorldPop10_5km $AB $geo $governance  Round if `var'==1, cluster(EANUMB_AB) robust 
	gen Beta_`var' = _b[anglophone]
	matrix c_`var' = e(V)
	gen Var_`var' = c_`var'[1,1]
} 

foreach var of varlist D_Border20-D_Border80 {
	gen SD_`var' = sqrt(Var_`var')
	gen CI_Upper_`var' = Beta_`var'+(SD_`var'*1.96)
	gen CI_Lower_`var' = Beta_`var'-(SD_`var'*1.96)
}

foreach var of varlist D_Border20-D_Border80 {
	gen SD_10_`var' = sqrt(Var_`var')
	gen CI_Upper_10_`var' = Beta_`var'+(SD_`var'*1.645)
	gen CI_Lower_10_`var' = Beta_`var'-(SD_`var'*1.645)
}

gen N = _n
drop if N !=1
keep N Beta_D_Border20 Beta_D_Border21 Beta_D_Border22 Beta_D_Border23 Beta_D_Border24 Beta_D_Border25 Beta_D_Border26 Beta_D_Border27 Beta_D_Border28 Beta_D_Border29 Beta_D_Border30 Beta_D_Border31 Beta_D_Border32 Beta_D_Border33 Beta_D_Border34 Beta_D_Border35 Beta_D_Border36 Beta_D_Border37 Beta_D_Border38 Beta_D_Border39 Beta_D_Border40 Beta_D_Border41 Beta_D_Border42 Beta_D_Border43 Beta_D_Border44 Beta_D_Border45 Beta_D_Border46 Beta_D_Border47 Beta_D_Border48 Beta_D_Border49 Beta_D_Border50 Beta_D_Border51 Beta_D_Border52 Beta_D_Border53 Beta_D_Border54 Beta_D_Border55 Beta_D_Border56 Beta_D_Border57 Beta_D_Border58 Beta_D_Border59 Beta_D_Border60 Beta_D_Border61 Beta_D_Border62 Beta_D_Border63 Beta_D_Border64 Beta_D_Border65 Beta_D_Border66 Beta_D_Border67 Beta_D_Border68 Beta_D_Border69 Beta_D_Border70 Beta_D_Border71 Beta_D_Border72 Beta_D_Border73 Beta_D_Border74 Beta_D_Border75 Beta_D_Border76 Beta_D_Border77 Beta_D_Border78 Beta_D_Border79 Beta_D_Border80 CI_Upper_D_Border20 CI_Upper_D_Border21 CI_Upper_D_Border22 CI_Upper_D_Border23 CI_Upper_D_Border24 CI_Upper_D_Border25 CI_Upper_D_Border26 CI_Upper_D_Border27 CI_Upper_D_Border28 CI_Upper_D_Border29 CI_Upper_D_Border30 CI_Upper_D_Border31 CI_Upper_D_Border32 CI_Upper_D_Border33 CI_Upper_D_Border34 CI_Upper_D_Border35 CI_Upper_D_Border36 CI_Upper_D_Border37 CI_Upper_D_Border38 CI_Upper_D_Border39 CI_Upper_D_Border40 CI_Upper_D_Border41 CI_Upper_D_Border42 CI_Upper_D_Border43 CI_Upper_D_Border44 CI_Upper_D_Border45 CI_Upper_D_Border46 CI_Upper_D_Border47 CI_Upper_D_Border48 CI_Upper_D_Border49 CI_Upper_D_Border50 CI_Upper_D_Border51 CI_Upper_D_Border52 CI_Upper_D_Border53 CI_Upper_D_Border54 CI_Upper_D_Border55 CI_Upper_D_Border56 CI_Upper_D_Border57 CI_Upper_D_Border58 CI_Upper_D_Border59 CI_Upper_D_Border60 CI_Upper_D_Border61 CI_Upper_D_Border62 CI_Upper_D_Border63 CI_Upper_D_Border64 CI_Upper_D_Border65 CI_Upper_D_Border66 CI_Upper_D_Border67 CI_Upper_D_Border68 CI_Upper_D_Border69 CI_Upper_D_Border70 CI_Upper_D_Border71 CI_Upper_D_Border72 CI_Upper_D_Border73 CI_Upper_D_Border74 CI_Upper_D_Border75 CI_Upper_D_Border76 CI_Upper_D_Border77 CI_Upper_D_Border78 CI_Upper_D_Border79 CI_Upper_D_Border80 CI_Lower_D_Border20 CI_Lower_D_Border21 CI_Lower_D_Border22 CI_Lower_D_Border23 CI_Lower_D_Border24 CI_Lower_D_Border25 CI_Lower_D_Border26 CI_Lower_D_Border27 CI_Lower_D_Border28 CI_Lower_D_Border29 CI_Lower_D_Border30 CI_Lower_D_Border31 CI_Lower_D_Border32 CI_Lower_D_Border33 CI_Lower_D_Border34 CI_Lower_D_Border35 CI_Lower_D_Border36 CI_Lower_D_Border37 CI_Lower_D_Border38 CI_Lower_D_Border39 CI_Lower_D_Border40 CI_Lower_D_Border41 CI_Lower_D_Border42 CI_Lower_D_Border43 CI_Lower_D_Border44 CI_Lower_D_Border45 CI_Lower_D_Border46 CI_Lower_D_Border47 CI_Lower_D_Border48 CI_Lower_D_Border49 CI_Lower_D_Border50 CI_Lower_D_Border51 CI_Lower_D_Border52 CI_Lower_D_Border53 CI_Lower_D_Border54 CI_Lower_D_Border55 CI_Lower_D_Border56 CI_Lower_D_Border57 CI_Lower_D_Border58 CI_Lower_D_Border59 CI_Lower_D_Border60 CI_Lower_D_Border61 CI_Lower_D_Border62 CI_Lower_D_Border63 CI_Lower_D_Border64 CI_Lower_D_Border65 CI_Lower_D_Border66 CI_Lower_D_Border67 CI_Lower_D_Border68 CI_Lower_D_Border69 CI_Lower_D_Border70 CI_Lower_D_Border71 CI_Lower_D_Border72 CI_Lower_D_Border73 CI_Lower_D_Border74 CI_Lower_D_Border75 CI_Lower_D_Border76 CI_Lower_D_Border77 CI_Lower_D_Border78 CI_Lower_D_Border79 CI_Lower_D_Border80 SD_10_D_Border20 CI_Upper_10_D_Border20 CI_Lower_10_D_Border20 SD_10_D_Border21 CI_Upper_10_D_Border21 CI_Lower_10_D_Border21 SD_10_D_Border22 CI_Upper_10_D_Border22 CI_Lower_10_D_Border22 SD_10_D_Border23 CI_Upper_10_D_Border23 CI_Lower_10_D_Border23 SD_10_D_Border24 CI_Upper_10_D_Border24 CI_Lower_10_D_Border24 SD_10_D_Border25 CI_Upper_10_D_Border25 CI_Lower_10_D_Border25 SD_10_D_Border26 CI_Upper_10_D_Border26 CI_Lower_10_D_Border26 SD_10_D_Border27 CI_Upper_10_D_Border27 CI_Lower_10_D_Border27 SD_10_D_Border28 CI_Upper_10_D_Border28 CI_Lower_10_D_Border28 SD_10_D_Border29 CI_Upper_10_D_Border29 CI_Lower_10_D_Border29 SD_10_D_Border30 CI_Upper_10_D_Border30 CI_Lower_10_D_Border30 SD_10_D_Border31 CI_Upper_10_D_Border31 CI_Lower_10_D_Border31 SD_10_D_Border32 CI_Upper_10_D_Border32 CI_Lower_10_D_Border32 SD_10_D_Border33 CI_Upper_10_D_Border33 CI_Lower_10_D_Border33 SD_10_D_Border34 CI_Upper_10_D_Border34 CI_Lower_10_D_Border34 SD_10_D_Border35 CI_Upper_10_D_Border35 CI_Lower_10_D_Border35 SD_10_D_Border36 CI_Upper_10_D_Border36 CI_Lower_10_D_Border36 SD_10_D_Border37 CI_Upper_10_D_Border37 CI_Lower_10_D_Border37 SD_10_D_Border38 CI_Upper_10_D_Border38 CI_Lower_10_D_Border38 SD_10_D_Border39 CI_Upper_10_D_Border39 CI_Lower_10_D_Border39 SD_10_D_Border40 CI_Upper_10_D_Border40 CI_Lower_10_D_Border40 SD_10_D_Border41 CI_Upper_10_D_Border41 CI_Lower_10_D_Border41 SD_10_D_Border42 CI_Upper_10_D_Border42 CI_Lower_10_D_Border42 SD_10_D_Border43 CI_Upper_10_D_Border43 CI_Lower_10_D_Border43 SD_10_D_Border44 CI_Upper_10_D_Border44 CI_Lower_10_D_Border44 SD_10_D_Border45 CI_Upper_10_D_Border45 CI_Lower_10_D_Border45 SD_10_D_Border46 CI_Upper_10_D_Border46 CI_Lower_10_D_Border46 SD_10_D_Border47 CI_Upper_10_D_Border47 CI_Lower_10_D_Border47 SD_10_D_Border48 CI_Upper_10_D_Border48 CI_Lower_10_D_Border48 SD_10_D_Border49 CI_Upper_10_D_Border49 CI_Lower_10_D_Border49 SD_10_D_Border50 CI_Upper_10_D_Border50 CI_Lower_10_D_Border50 SD_10_D_Border51 CI_Upper_10_D_Border51 CI_Lower_10_D_Border51 SD_10_D_Border52 CI_Upper_10_D_Border52 CI_Lower_10_D_Border52 SD_10_D_Border53 CI_Upper_10_D_Border53 CI_Lower_10_D_Border53 SD_10_D_Border54 CI_Upper_10_D_Border54 CI_Lower_10_D_Border54 SD_10_D_Border55 CI_Upper_10_D_Border55 CI_Lower_10_D_Border55 SD_10_D_Border56 CI_Upper_10_D_Border56 CI_Lower_10_D_Border56 SD_10_D_Border57 CI_Upper_10_D_Border57 CI_Lower_10_D_Border57 SD_10_D_Border58 CI_Upper_10_D_Border58 CI_Lower_10_D_Border58 SD_10_D_Border59 CI_Upper_10_D_Border59 CI_Lower_10_D_Border59 SD_10_D_Border60 CI_Upper_10_D_Border60 CI_Lower_10_D_Border60 SD_10_D_Border61 CI_Upper_10_D_Border61 CI_Lower_10_D_Border61 SD_10_D_Border62 CI_Upper_10_D_Border62 CI_Lower_10_D_Border62 SD_10_D_Border63 CI_Upper_10_D_Border63 CI_Lower_10_D_Border63 SD_10_D_Border64 CI_Upper_10_D_Border64 CI_Lower_10_D_Border64 SD_10_D_Border65 CI_Upper_10_D_Border65 CI_Lower_10_D_Border65 SD_10_D_Border66 CI_Upper_10_D_Border66 CI_Lower_10_D_Border66 SD_10_D_Border67 CI_Upper_10_D_Border67 CI_Lower_10_D_Border67 SD_10_D_Border68 CI_Upper_10_D_Border68 CI_Lower_10_D_Border68 SD_10_D_Border69 CI_Upper_10_D_Border69 CI_Lower_10_D_Border69 SD_10_D_Border70 CI_Upper_10_D_Border70 CI_Lower_10_D_Border70 SD_10_D_Border71 CI_Upper_10_D_Border71 CI_Lower_10_D_Border71 SD_10_D_Border72 CI_Upper_10_D_Border72 CI_Lower_10_D_Border72 SD_10_D_Border73 CI_Upper_10_D_Border73 CI_Lower_10_D_Border73 SD_10_D_Border74 CI_Upper_10_D_Border74 CI_Lower_10_D_Border74 SD_10_D_Border75 CI_Upper_10_D_Border75 CI_Lower_10_D_Border75 SD_10_D_Border76 CI_Upper_10_D_Border76 CI_Lower_10_D_Border76 SD_10_D_Border77 CI_Upper_10_D_Border77 CI_Lower_10_D_Border77 SD_10_D_Border78 CI_Upper_10_D_Border78 CI_Lower_10_D_Border78 SD_10_D_Border79 CI_Upper_10_D_Border79 CI_Lower_10_D_Border79 SD_10_D_Border80 CI_Upper_10_D_Border80 CI_Lower_10_D_Border80

reshape long Beta_D_Border CI_Upper_D_Border CI_Lower_D_Border CI_Upper_10_D_Border CI_Lower_10_D_Border, i(N) j(band)

twoway (line Beta_D_Border band, lcolor(black) lpattern(solid)) ///
	(line CI_Upper_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Lower_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Upper_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)) ///
	(line CI_Lower_10_D_Border band, lcolor(gs12) lpattern(solid) lwidth(.25)), ///
    ytitle(Estimated Effect Anglophone, size(small)) ylabel(-.5(.5)2,  angle(horizontal))  ///
    xtitle(Distance from Border (km) ) xtitle(, size(small)) xlabel(20(10)80, labsize(vsmall))  ///
           yline(0, lcolor(gs10)) ///
      plotregion(lcolor(black)) ///
  legend(off) ///
        title(e. Managing Land, size(medsmall)) ///
    scheme(s2mono) graphregion(fcolor(white)) 
 

************************************************************************************************
*********************** TABLE A10 - REPLICATION ADDRESSING SPILLOVER EFFECTS *******************
************************************************************************************************
use AfroBarometerData.dta, clear
keep if REGION==2 | REGION==7 | REGION==9 | REGION==10 | REGION==12

*Table A10.1 - DISTANCE TO MT CAMEROON
*Panel A - Local Government Legitimacy Mechanism
reg C62B anglophone##c.d_mtcameroon_km $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg C71C anglophone##c.d_mtcameroon_km $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg C30C anglophone##c.d_mtcameroon_km $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg C25B anglophone##c.d_mtcameroon_km $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance  i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 

*Panel B - Traditional Authority Mechanism
reg Q52K_R6 anglophone##c.d_mtcameroon_km $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance   i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg Q53H_R6 anglophone##c.d_mtcameroon_km $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance   i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg Q24E_R6 anglophone##c.d_mtcameroon_km $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance   i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg Q68D_R6 anglophone##c.d_mtcameroon_km $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance   i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 

*Panel C - Ethnicity Mechanism
reg C85B anglophone##c.d_mtcameroon_km $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance   i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg C79C_CAMC anglophone##c.d_mtcameroon_km $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance   i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg Q18_R5 anglophone##c.d_mtcameroon_km $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance   i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 


*Table A10.2 - NO FAKO DEPARTMENT
drop if Fako == 1
*Panel A - Local Government Legitimacy Mechanism
reg C62B $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg C71C $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg C30C $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance    i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg C25B $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance  i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 

*Panel B - Traditional Authority Mechanism
reg Q52K_R6 $MDpolynomiaL Ln_WorldPop10_5km $AB $geo $governance   i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg Q53H_R6 $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance   i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg Q24E_R6 $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance   i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg Q68D_R6 $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance   i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 

*Panel C - Ethnicity Mechanism
reg C85B $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance   i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg C79C_CAMC $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance   i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg Q18_R5 $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance   i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 


***** FIGURES A10.1-A10.3 - INTERACTION OF TREATMENT AND DISTANCE TO MT CAMEROON 
use AfroBarometerData.dta, clear
keep if REGION==2 | REGION==7 | REGION==9 | REGION==10 | REGION==12

*Figure 10.1: Local Legitimacy Mechanism
reg C62B anglophone##c.d_mtcameroon_km latitude longitude Lat_x_Long latitude2 longitude2 border_longitude border_latitude rural Ln_WorldPop10_5km $AB $geo $governance  i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
quietly margins, at(d_mtcameroon_km = (0(50)300) anglophone=(0 1)) 
marginsplot, plotregion(lcolor(black)) ///
  ytitle("Linear Prediction", size(small)) ylabel(0(2)6, angle(horizontal)) ///
  legend(off) ///
  title(a. Local Councilors Listen to Ordinary People, size(medsmall)) ///
  scheme(s2mono) graphregion(fcolor(white)) 

reg C71C anglophone##c.d_mtcameroon_km latitude longitude Lat_x_Long latitude2 longitude2 border_longitude border_latitude rural Ln_WorldPop10_5km $AB $geo $governance   i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
quietly margins, at(d_mtcameroon_km = (0(50)300) anglophone=(0 1))  
marginsplot, plotregion(lcolor(black)) ///
  ytitle("", size(small)) ylabel(0(2)6, angle(horizontal)) ///
  legend(off) ///
  title(b. Approve of the Job of Your Local Councilor, size(medsmall)) ///
  scheme(s2mono) graphregion(fcolor(white)) 

reg C30C anglophone##c.d_mtcameroon_km latitude longitude Lat_x_Long latitude2 longitude2 border_longitude border_latitude rural Ln_WorldPop10_5km $AB $geo $governance   i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
quietly margins, at(d_mtcameroon_km = (0(50)300) anglophone=(0 1))  
marginsplot, plotregion(lcolor(black)) ///
  ytitle("Linear Prediction", size(small)) ylabel(0(2)6, angle(horizontal)) ///
  legend(off) ///
  title(c. Contacted Gov't Official in the Past Year, size(medsmall)) ///
  scheme(s2mono) graphregion(fcolor(white)) 
 
reg C25B anglophone##c.d_mtcameroon_km latitude longitude Lat_x_Long latitude2 longitude2 border_longitude border_latitude rural Ln_WorldPop10_5km $AB $geo $governance  i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
quietly margins, at(d_mtcameroon_km = (0(50)300) anglophone=(0 1))  
marginsplot, plotregion(lcolor(black)) ///
  legend(off) ///
  ytitle("", size(small)) ylabel(0(2)6, angle(horizontal)) ///
  title(d. Member of a Community Group, size(medsmall)) ///
  scheme(s2mono) graphregion(fcolor(white)) 

  
*Figure 10.2: Traditional Authority Mechanism
reg Q52K_R6 anglophone##c.d_mtcameroon_km latitude longitude Lat_x_Long latitude2 longitude2 border_longitude border_latitude rural Ln_WorldPop10_5km $AB $geo $governance if d_border_km < 81, cluster(EANUMB_AB) robust
quietly margins, at(d_mtcameroon_km = (0(50)300) anglophone=(0 1))  
marginsplot, plotregion(lcolor(black)) ///
  ytitle("Linear Prediction", size(small)) ylabel(-2(4)12, angle(horizontal)) ///
  legend(off) ///
  title(a. Trust in Traditional Leaders, size(medsmall)) ///
  scheme(s2mono) graphregion(fcolor(white)) 
    
reg Q53H_R6 anglophone##c.d_mtcameroon_km latitude longitude Lat_x_Long latitude2 longitude2 border_longitude border_latitude rural Ln_WorldPop10_5km $AB $geo $governance if d_border_km < 81, cluster(EANUMB_AB) robust 
quietly margins, at(d_mtcameroon_km = (0(50)300) anglophone=(0 1))  
marginsplot, plotregion(lcolor(black)) ///
 ytitle("", size(small)) ylabel(-2(4)12, angle(horizontal)) ///
  legend(off) ///
  title(b. Traditional Leaders are Corrupt, size(medsmall)) ///
  scheme(s2mono) graphregion(fcolor(white)) 
  
reg Q24E_R6 anglophone##c.d_mtcameroon_km latitude longitude Lat_x_Long latitude2 longitude2 border_longitude border_latitude rural Ln_WorldPop10_5km $AB $geo $governance if d_border_km < 81, cluster(EANUMB_AB) robust 
quietly margins, at(d_mtcameroon_km = (0(50)300) anglophone=(0 1))  
marginsplot, plotregion(lcolor(black)) ///
 ytitle("Linear Prediction", size(small)) ylabel(-2(4)12, angle(horizontal)) ///
  legend(off) ///
  title(c. Contacted Tradtional Leader in the Past Year, size(medsmall)) ///
  scheme(s2mono) graphregion(fcolor(white)) 
  	
reg Q68D_R6 anglophone##c.d_mtcameroon_km latitude longitude Lat_x_Long latitude2 longitude2 border_longitude border_latitude rural Ln_WorldPop10_5km $AB $geo $governance if d_border_km < 81, cluster(EANUMB_AB) robust 
quietly margins, at(d_mtcameroon_km = (0(50)300) anglophone=(0 1))  
marginsplot, plotregion(lcolor(black)) ///
 ytitle("Linear Prediction", size(small)) ylabel(-2(4)12, angle(horizontal)) ///
  legend(off) ///
  title(d. Approve of Traditional Leader Performance, size(medsmall)) ///
  scheme(s2mono) graphregion(fcolor(white)) 
 
	
*Figure 10.3: Ethnicity Mechanism
reg C85B anglophone##c.d_mtcameroon_km latitude longitude Lat_x_Long latitude2 longitude2 border_longitude border_latitude rural Ln_WorldPop10_5km $AB $geo $governance   i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
quietly margins, at(d_mtcameroon_km = (0(50)300) anglophone=(0 1))  
marginsplot, plotregion(lcolor(black)) ///
 ytitle("Linear Prediction", size(small)) ylabel(0(2)8, angle(horizontal)) ///
  legend(off) ///
  title(a. Ethnic Identity Stronger than National Identity, size(medsmall)) ///
  scheme(s2mono) graphregion(fcolor(white)) 
  
reg C79C_CAMC anglophone##c.d_mtcameroon_km latitude longitude Lat_x_Long latitude2 longitude2 border_longitude border_latitude rural Ln_WorldPop10_5km $AB $geo $governance   i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
quietly margins, at(d_mtcameroon_km = (0(50)300) anglophone=(0 1))  
marginsplot, plotregion(lcolor(black)) ///
 ytitle("", size(small)) ylabel(0(2)8, angle(horizontal)) ///
  legend(off) ///
  title(b. Ethnic Networks Provide Access to Government Jobs, size(medsmall)) ///
  scheme(s2mono) graphregion(fcolor(white)) 
  
reg Q18_R5 anglophone##c.d_mtcameroon_km latitude longitude Lat_x_Long latitude2 longitude2 border_longitude border_latitude rural Ln_WorldPop10_5km $AB $geo $governance if d_border_km < 81, cluster(EANUMB_AB) robust 
quietly margins, at(d_mtcameroon_km = (0(50)300) anglophone=(0 1))  
marginsplot, plotregion(lcolor(black)) ///
 ytitle("Linear Prediction", size(small)) ylabel(0(2)8, angle(horizontal)) ///
  legend(off) ///
  title(c. Elected Leaders Should Help Own Groups First, size(medsmall)) ///
  scheme(s2mono) graphregion(fcolor(white)) 
 

	
************************************************************************************************
************************ FIGURE A11.1-A11.3 - PLACEBO BORDERS **********************************
************************************************************************************************
ssc install coefplot, replace

use AfroBarometerData.dta, clear
keep if REGION==7 | REGION==9 | REGION==10 | REGION==12 | REGION==2

gen Round6 = 0
replace Round6 = 1 if Round == 1

* FIGURE A11.1 - Local Legitimacy Merchanism
*** H1a
reg C62B anglophone_60w  d_placebo_60w_km Ln_WorldPop10_5km $AB $geo $governance Round6 , cluster(EANUMB_AB) robust 
est sto p60w 
reg C62B anglophone_40w d_placebo_40w_km Ln_WorldPop10_5km $AB $geo $governance Round6 , cluster(EANUMB_AB) robust 
est sto p40w
reg C62B anglophone_20w d_placebo_20w_km Ln_WorldPop10_5km $AB $geo $governance Round6 , cluster(EANUMB_AB) robust 
est sto p20w
reg C62B anglophone d_border_km Ln_WorldPop10_5km $AB $geo $governance Round6 , cluster(EANUMB_AB) robust 
est sto pborder
reg C62B anglophone_20e d_placebo_20e_km Ln_WorldPop10_5km $AB $geo $governance  Round6 , cluster(EANUMB_AB) robust 
est sto p20e
reg C62B anglophone_40e d_placebo_40e_km Ln_WorldPop10_5km $AB $geo $governance Round6 , cluster(EANUMB_AB) robust 
est sto p40e
reg C62B anglophone_60e d_placebo_60e_km Ln_WorldPop10_5km $AB $geo $governance Round6 , cluster(EANUMB_AB) robust 
est sto p60e

coefplot p60w p40w p20w pborder p20e p40e p60e, vertical drop(Round6 d_placebo_60e_km d_placebo_40e_km d_placebo_20e_km d_border_km d_placebo_20w_km d_placebo_40w_km d_placebo_60w_km Ln_WorldPop10_5km avg_temp avg_prec cec_mean avg_alt ln_d_yaounde_km ln_d_regcapital_km female age education rural _cons) ///
  xlabel(1 "60w" 2 "40w" 3 "20w" 4 "Border" 5 "20e" 6 "40e" 7 "60e", labsize(small)) ///
  ytitle("Estimated Coefficient", size(small)) ylabel(-1(.4)1, labsize(small) angle(horizontal)) yline(0, lcolor(gs10)) ///
  legend(off) msymbol(D) msize(medsmall) mcolor(black) msize(medsmall) ///
  title(a. Local Councilor Listens, size(medsmall)) ///
  scheme(s2mono) graphregion(fcolor(white)) 

graph save Graph "Ab_Placebos_H1a.gph", replace

**** H1b
reg C71C anglophone_60w  d_placebo_60w_km Ln_WorldPop10_5km $AB $geo $governance  Round6 , cluster(EANUMB_AB) robust 
est sto p60w 
reg C71C anglophone_40w d_placebo_40w_km Ln_WorldPop10_5km $AB $geo $governance  Round6 , cluster(EANUMB_AB) robust 
est sto p40w
reg C71C anglophone_20w d_placebo_20w_km Ln_WorldPop10_5km $AB $geo $governance  Round6 , cluster(EANUMB_AB) robust 
est sto p20w
reg C71C anglophone d_border_km Ln_WorldPop10_5km $AB $geo $governance  Round6 , cluster(EANUMB_AB) robust 
est sto pborder
reg C71C anglophone_20e d_placebo_20e_km Ln_WorldPop10_5km $AB $geo $governance Round6 , cluster(EANUMB_AB) robust 
est sto p20e
reg C71C anglophone_40e d_placebo_40e_km Ln_WorldPop10_5km $AB $geo $governance  Round6 , cluster(EANUMB_AB) robust 
est sto p40e
reg C71C anglophone_60e d_placebo_60e_km Ln_WorldPop10_5km $AB $geo $governance  Round6 , cluster(EANUMB_AB) robust 
est sto p60e

coefplot p60w p40w p20w pborder p20e p40e p60e, vertical drop(Round6 d_placebo_60e_km d_placebo_40e_km d_placebo_20e_km d_border_km d_placebo_20w_km d_placebo_40w_km d_placebo_60w_km Ln_WorldPop10_5km avg_temp avg_prec cec_mean avg_alt ln_d_yaounde_km ln_d_regcapital_km female age education rural _cons) ///
  xlabel(1 "60w" 2 "40w" 3 "20w" 4 "Border" 5 "20e" 6 "40e" 7 "60e", labsize(small)) ///
  ytitle("Estimated Coefficient", size(small)) ylabel(-1(.4)1, labsize(small) angle(horizontal)) yline(0, lcolor(gs10)) ///
  legend(off) msymbol(D) mcolor(black) msize(medsmall) ///
  title(b. Approve Local Councilor's Performance, size(medsmall)) ///
  scheme(s2mono) graphregion(fcolor(white)) 
  
graph save Graph "Ab_Placebos_H1b.gph", replace


**** H1c  
reg C30C anglophone_60w  d_placebo_60w_km Ln_WorldPop10_5km $AB $geo $governance  Round6 , cluster(EANUMB_AB) robust 
est sto p60w 
reg C30C anglophone_40w d_placebo_40w_km Ln_WorldPop10_5km $AB $geo $governance Round6 , cluster(EANUMB_AB) robust 
est sto p40w
reg C30C anglophone_20w d_placebo_20w_km Ln_WorldPop10_5km $AB $geo $governance  Round6 , cluster(EANUMB_AB) robust 
est sto p20w
reg C30C anglophone d_border_km Ln_WorldPop10_5km $AB $geo $governance Round6 , cluster(EANUMB_AB) robust 
est sto pborder
reg C30C anglophone_20e d_placebo_20e_km Ln_WorldPop10_5km $AB $geo $governance  Round6 , cluster(EANUMB_AB) robust 
est sto p20e
reg C30C anglophone_40e d_placebo_40e_km Ln_WorldPop10_5km $AB $geo $governance Round6 , cluster(EANUMB_AB) robust 
est sto p40e
reg C30C anglophone_60e d_placebo_60e_km Ln_WorldPop10_5km $AB $geo $governance Round6 , cluster(EANUMB_AB) robust 
est sto p60e

coefplot (p60w, label("60w") mcolor(black)) (p40w, label("40w") mcolor(black)) (p20w, label("20w") mcolor(black)) (pborder, label("Border") mcolor(black)) (p20e, label("20e") mcolor(black)) (p40e, label("40e") mcolor(black)) (p60e, label("60e") mcolor(black)), ///
  vertical drop(Round6 d_placebo_60e_km d_placebo_40e_km d_placebo_20e_km d_border_km d_placebo_20w_km d_placebo_40w_km d_placebo_60w_km Ln_WorldPop10_5km avg_temp avg_prec cec_mean avg_alt ln_d_yaounde_km ln_d_regcapital_km female age education rural _cons) ///
  ytitle("Estimated Coefficient", size(small)) ylabel(-1(.4)1, labsize(small) angle(horizontal)) yline(0, lcolor(gs10)) ///
  xlabel(1 "60w" 2 "40w" 3 "20w" 4 "Border" 5 "20e" 6 "40e" 7 "60e", labsize(small)) ///
  legend(off) msymbol(D) mcolor(black) msize(medsmall) ///
  title(c. Contacted Official, size(medsmall)) ///
  scheme(s2mono) graphregion(fcolor(white)) 
  
graph save Graph "Ab_Placebos_H1c.gph", replace

**** H1d
reg C25B anglophone_60w  d_placebo_60w_km Ln_WorldPop10_5km $AB $geo $governance  Round6 , cluster(EANUMB_AB) robust 
est sto p60w 
reg C25B anglophone_40w d_placebo_40w_km Ln_WorldPop10_5km $AB $geo $governance Round6 , cluster(EANUMB_AB) robust 
est sto p40w
reg C25B anglophone_20w d_placebo_20w_km Ln_WorldPop10_5km $AB $geo $governance Round6 , cluster(EANUMB_AB) robust 
est sto p20w
reg C25B anglophone d_border_km Ln_WorldPop10_5km $AB $geo $governance Round6 , cluster(EANUMB_AB) robust 
est sto pborder
reg C25B anglophone_20e d_placebo_20e_km Ln_WorldPop10_5km $AB $geo $governance  Round6 , cluster(EANUMB_AB) robust 
est sto p20e
reg C25B anglophone_40e d_placebo_40e_km Ln_WorldPop10_5km $AB $geo $governance Round6 , cluster(EANUMB_AB) robust 
est sto p40e
reg C25B anglophone_60e d_placebo_60e_km  Ln_WorldPop10_5km $AB $geo $governance Round6 , cluster(EANUMB_AB) robust 
est sto p60e

coefplot (p60w, label("60w") mcolor(black)) (p40w, label("40w") mcolor(black)) (p20w, label("20w") mcolor(black)) (pborder, label("Border") mcolor(black)) (p20e, label("20e") mcolor(black)) (p40e, label("40e") mcolor(black)) (p60e, label("60e") mcolor(black)), ///
  vertical drop(Round6 d_placebo_60e_km d_placebo_40e_km d_placebo_20e_km d_border_km d_placebo_20w_km d_placebo_40w_km d_placebo_60w_km Ln_WorldPop10_5km avg_temp avg_prec cec_mean avg_alt ln_d_yaounde_km ln_d_regcapital_km female age education rural _cons) ///
  ytitle("Estimated Coefficient", size(small)) ylabel(-1(.4)1, labsize(small) angle(horizontal)) yline(0, lcolor(gs10)) ///
  xlabel(1 "60w" 2 "40w" 3 "20w" 4 "Border" 5 "20e" 6 "40e" 7 "60e", labsize(small)) ///
  legend(off) msymbol(D) mcolor(black) msize(medsmall) ///
  title(d. Member of a Community Group, size(medsmall)) ///
  scheme(s2mono) graphregion(fcolor(white)) 

graph save Graph "Ab_Placebos_H1d.gph", replace

** COMBINE
graph combine  "Ab_Placebos_H1a.gph" "Ab_Placebos_H1b.gph" "Ab_Placebos_H1c.gph" "Ab_Placebos_H1d.gph", ///
     col(2) ///
     subtitle("Standardized dependent variables with 95% Confidence Intervals", size(small) pos(6)) ///
	 title("Figure A11.1: ATE at Placebo for Local Legitimacy Mechanism", size(medsmall) pos(6)) ///
	 xsize(8) ysize(6) ///
     scheme(s2mono) graphregion(fcolor(white)) 

	 
* FIGURE A11.2 - Traditional Leader Mechanism
**** H2a
reg Q52K_R6 anglophone_60w  d_placebo_60w_km Ln_WorldPop10_5km $AB $geo $governance   , cluster(EANUMB_AB) robust 
est sto p60w 
reg Q52K_R6 anglophone_40w d_placebo_40w_km Ln_WorldPop10_5km $AB $geo $governance , cluster(EANUMB_AB) robust 
est sto p40w
reg Q52K_R6 anglophone_20w d_placebo_20w_km Ln_WorldPop10_5km $AB $geo $governance, cluster(EANUMB_AB) robust 
est sto p20w
reg Q52K_R6 anglophone d_border_km Ln_WorldPop10_5km $AB $geo $governance, cluster(EANUMB_AB) robust 
est sto pborder
reg Q52K_R6 anglophone_20e d_placebo_20e_km Ln_WorldPop10_5km $AB $geo $governance , cluster(EANUMB_AB) robust 
est sto p20e
reg Q52K_R6 anglophone_40e d_placebo_40e_km Ln_WorldPop10_5km $AB $geo $governance , cluster(EANUMB_AB) robust 
est sto p40e
reg Q52K_R6 anglophone_60e d_placebo_60e_km  Ln_WorldPop10_5km $AB $geo $governance, cluster(EANUMB_AB) robust 
est sto p60e

coefplot (p60w, label("60w") mcolor(black)) (p40w, label("40w") mcolor(black)) (p20w, label("20w") mcolor(black)) (pborder, label("Border") mcolor(black)) (p20e, label("20e") mcolor(black)) (p40e, label("40e") mcolor(black)) (p60e, label("60e") mcolor(black)), ///
  vertical drop(Round6 d_placebo_60e_km d_placebo_40e_km d_placebo_20e_km d_border_km d_placebo_20w_km d_placebo_40w_km d_placebo_60w_km Ln_WorldPop10_5km avg_temp avg_prec cec_mean avg_alt ln_d_yaounde_km ln_d_regcapital_km female age education rural _cons) ///
  ytitle("Estimated Coefficient", size(small)) ylabel(-1.8(.4)1, labsize(small) angle(horizontal)) yline(0, lcolor(gs10)) ///
  xlabel(1 "60w" 2 "40w" 3 "20w" 4 "Border" 5 "20e" 6 "40e" 7 "60e", labsize(small)) ///
  legend(off) msymbol(D) mcolor(black) msize(medsmall) ///
  title(a. Trust in Traditional Leaders, size(medsmall)) ///
  scheme(s2mono) graphregion(fcolor(white)) 

graph save Graph "Ab_Placebos_H2a.gph", replace

**** H2b
reg Q53H_R6 anglophone_60w  d_placebo_60w_km Ln_WorldPop10_5km $AB $geo $governance, cluster(EANUMB_AB) robust 
est sto p60w 
reg Q53H_R6 anglophone_40w d_placebo_40w_km Ln_WorldPop10_5km $AB $geo $governance , cluster(EANUMB_AB) robust 
est sto p40w
reg Q53H_R6 anglophone_20w d_placebo_20w_km  Ln_WorldPop10_5km $AB $geo $governance  , cluster(EANUMB_AB) robust 
est sto p20w
reg Q53H_R6 anglophone d_border_km Ln_WorldPop10_5km $AB $geo $governance , cluster(EANUMB_AB) robust 
est sto pborder
reg Q53H_R6 anglophone_20e d_placebo_20e_km Ln_WorldPop10_5km $AB $geo $governance  , cluster(EANUMB_AB) robust 
est sto p20e
reg Q53H_R6 anglophone_40e d_placebo_40e_km Ln_WorldPop10_5km $AB $geo $governance , cluster(EANUMB_AB) robust 
est sto p40e
reg Q53H_R6 anglophone_60e d_placebo_60e_km Ln_WorldPop10_5km $AB $geo $governance, cluster(EANUMB_AB) robust 
est sto p60e

coefplot (p60w, label("60w") mcolor(black)) (p40w, label("40w") mcolor(black)) (p20w, label("20w") mcolor(black)) (pborder, label("Border") mcolor(black)) (p20e, label("20e") mcolor(black)) (p40e, label("40e") mcolor(black)) (p60e, label("60e") mcolor(black)), ///
  vertical drop(Round6 d_placebo_60e_km d_placebo_40e_km d_placebo_20e_km d_border_km d_placebo_20w_km d_placebo_40w_km d_placebo_60w_km Ln_WorldPop10_5km avg_temp avg_prec cec_mean avg_alt ln_d_yaounde_km ln_d_regcapital_km female age education rural _cons) ///
  ytitle("Estimated Coefficient", size(small)) ylabel(-1.8(.4)1, labsize(small) angle(horizontal)) yline(0, lcolor(gs10)) ///
  xlabel(1 "60w" 2 "40w" 3 "20w" 4 "Border" 5 "20e" 6 "40e" 7 "60e", labsize(small)) ///
  legend(off) msymbol(D) mcolor(black) msize(medsmall) ///
  title(b. Traditional Leaders are Corrupt, size(medsmall)) ///
  scheme(s2mono) graphregion(fcolor(white)) 

graph save Graph "Ab_Placebos_H2b.gph", replace


**** H2c
reg Q24E_R6 anglophone_60w  d_placebo_60w_km Ln_WorldPop10_5km $AB $geo $governance , cluster(EANUMB_AB) robust 
est sto p60w 
reg Q24E_R6 anglophone_40w d_placebo_40w_km Ln_WorldPop10_5km $AB $geo $governance, cluster(EANUMB_AB) robust 
est sto p40w
reg Q24E_R6 anglophone_20w d_placebo_20w_km Ln_WorldPop10_5km $AB $geo $governance, cluster(EANUMB_AB) robust 
est sto p20w
reg Q24E_R6 anglophone d_border_km Ln_WorldPop10_5km $AB $geo $governance , cluster(EANUMB_AB) robust 
est sto pborder
reg Q24E_R6 anglophone_20e d_placebo_20e_km Ln_WorldPop10_5km $AB $geo $governance , cluster(EANUMB_AB) robust 
est sto p20e
reg Q24E_R6 anglophone_40e d_placebo_40e_km Ln_WorldPop10_5km $AB $geo $governance, cluster(EANUMB_AB) robust 
est sto p40e
reg Q24E_R6 anglophone_60e d_placebo_60e_km Ln_WorldPop10_5km $AB $geo $governance , cluster(EANUMB_AB) robust 
est sto p60e

coefplot (p60w, label("60w") mcolor(black)) (p40w, label("40w") mcolor(black)) (p20w, label("20w") mcolor(black)) (pborder, label("Border") mcolor(black)) (p20e, label("20e") mcolor(black)) (p40e, label("40e") mcolor(black)) (p60e, label("60e") mcolor(black)), ///
  vertical drop(Round6 d_placebo_60e_km d_placebo_40e_km d_placebo_20e_km d_border_km d_placebo_20w_km d_placebo_40w_km d_placebo_60w_km Ln_WorldPop10_5km avg_temp avg_prec cec_mean avg_alt ln_d_yaounde_km ln_d_regcapital_km female age education rural _cons) ///
  ytitle("Estimated Coefficient", size(small)) ylabel(-1.8(.4)1, labsize(small) angle(horizontal)) yline(0, lcolor(gs10)) ///
  xlabel(1 "60w" 2 "40w" 3 "20w" 4 "Border" 5 "20e" 6 "40e" 7 "60e", labsize(small)) ///
  legend(off) msymbol(D) mcolor(black) msize(medsmall) ///
  title(c. Contacted Traditional Leader in the Past Year, size(medsmall)) ///
  scheme(s2mono) graphregion(fcolor(white)) 

graph save Graph "Ab_Placebos_H2c.gph", replace


**** H2d
reg Q68D_R6 anglophone_60w  d_placebo_60w_km Ln_WorldPop10_5km $AB $geo $governance , cluster(EANUMB_AB) robust 
est sto p60w 
reg Q68D_R6 anglophone_40w d_placebo_40w_km Ln_WorldPop10_5km $AB $geo $governance , cluster(EANUMB_AB) robust 
est sto p40w
reg Q68D_R6 anglophone_20w d_placebo_20w_km Ln_WorldPop10_5km $AB $geo $governance , cluster(EANUMB_AB) robust 
est sto p20w
reg Q68D_R6 anglophone d_border_km Ln_WorldPop10_5km $AB $geo $governance  , cluster(EANUMB_AB) robust 
est sto pborder
reg Q68D_R6 anglophone_20e d_placebo_20e_km Ln_WorldPop10_5km $AB $geo $governance , cluster(EANUMB_AB) robust 
est sto p20e
reg Q68D_R6 anglophone_40e d_placebo_40e_km  Ln_WorldPop10_5km $AB $geo $governance , cluster(EANUMB_AB) robust 
est sto p40e
reg Q68D_R6 anglophone_60e d_placebo_60e_km  Ln_WorldPop10_5km $AB $geo $governance , cluster(EANUMB_AB) robust 
est sto p60e

coefplot (p60w, label("60w") mcolor(black)) (p40w, label("40w") mcolor(black)) (p20w, label("20w") mcolor(black)) (pborder, label("Border") mcolor(black)) (p20e, label("20e") mcolor(black)) (p40e, label("40e") mcolor(black)) (p60e, label("60e") mcolor(black)), ///
  vertical drop(Round6 d_placebo_60e_km d_placebo_40e_km d_placebo_20e_km d_border_km d_placebo_20w_km d_placebo_40w_km d_placebo_60w_km Ln_WorldPop10_5km avg_temp avg_prec cec_mean avg_alt ln_d_yaounde_km ln_d_regcapital_km female age education rural _cons) ///
  ytitle("Estimated Coefficient", size(small)) ylabel(-1.8(.4)1, labsize(small) angle(horizontal)) yline(0, lcolor(gs10)) ///
  xlabel(1 "60w" 2 "40w" 3 "20w" 4 "Border" 5 "20e" 6 "40e" 7 "60e", labsize(small)) ///
  legend(off) msymbol(D) mcolor(black) msize(medsmall) ///
  title(d. Approve of Traditional Leader Performance, size(medsmall)) ///
  scheme(s2mono) graphregion(fcolor(white)) 

graph save Graph "Ab_Placebos_H2da.gph", replace

** COMBINE
graph combine  "Ab_Placebos_H2a.gph" "Ab_Placebos_H2b.gph" "Ab_Placebos_H2c.gph" "Ab_Placebos_H2da.gph", ///
     col(2) ///
     subtitle("Standardized dependent variables with 95% Confidence Intervals", size(small) pos(6)) ///
	 title("Figure A11.2: ATE at Placebo for Traditional Authority Mechanism", size(medsmall) pos(6)) ///
	 xsize(8) ysize(6) ///
     scheme(s2mono) graphregion(fcolor(white)) 
 
 
* FIGURE A11.3 - Ethnicity Mechanism
**** H3a
reg C85B anglophone_60w  d_placebo_60w_km Ln_WorldPop10_5km $AB $geo $governance Round6, cluster(EANUMB_AB) robust 
est sto p60w 
reg C85B anglophone_40w d_placebo_40w_km Ln_WorldPop10_5km $AB $geo $governance Round6, cluster(EANUMB_AB) robust 
est sto p40w
reg C85B anglophone_20w d_placebo_20w_km Ln_WorldPop10_5km $AB $geo $governance Round6, cluster(EANUMB_AB) robust 
est sto p20w
reg C85B anglophone d_border_km Ln_WorldPop10_5km $AB $geo $governance Round6, cluster(EANUMB_AB) robust 
est sto pborder
reg C85B anglophone_20e d_placebo_20e_km Ln_WorldPop10_5km $AB $geo $governance Round6, cluster(EANUMB_AB) robust 
est sto p20e
reg C85B anglophone_40e d_placebo_40e_km Ln_WorldPop10_5km $AB $geo $governance Round6, cluster(EANUMB_AB) robust 
est sto p40e
reg C85B anglophone_60e d_placebo_60e_km  Ln_WorldPop10_5km $AB $geo $governance Round6, cluster(EANUMB_AB) robust 
est sto p60e

coefplot (p60w, label("60w") mcolor(black)) (p40w, label("40w") mcolor(black)) (p20w, label("20w") mcolor(black)) (pborder, label("Border") mcolor(black)) (p20e, label("20e") mcolor(black)) (p40e, label("40e") mcolor(black)) (p60e, label("60e") mcolor(black)), ///
  vertical drop(Round6 d_placebo_60e_km d_placebo_40e_km d_placebo_20e_km d_border_km d_placebo_20w_km d_placebo_40w_km d_placebo_60w_km Ln_WorldPop10_5km avg_temp avg_prec cec_mean avg_alt ln_d_yaounde_km ln_d_regcapital_km female age education rural _cons) ///
  ytitle("Estimated Coefficient", size(small)) ylabel(-2.2(.4)1.6, labsize(small) angle(horizontal)) yline(0, lcolor(gs10)) ///
  xlabel(1 "60w" 2 "40w" 3 "20w" 4 "Border" 5 "20e" 6 "40e" 7 "60e", labsize(small)) ///
  legend(off) msymbol(D) mcolor(black) ///
  title(a. Ethnic Identity Stronger than National Identity, size(medsmall)) ///
  scheme(s2mono) graphregion(fcolor(white)) 

graph save Graph "Ab_Placebos_H3a.gph", replace

**** H3b
reg C79C_CAMC anglophone_60w  d_placebo_60w_km Ln_WorldPop10_5km $AB $geo $governance Round6, cluster(EANUMB_AB) robust 
est sto p60w 
reg C79C_CAMC anglophone_40w d_placebo_40w_km Ln_WorldPop10_5km $AB $geo $governance Round6, cluster(EANUMB_AB) robust 
est sto p40w
reg C79C_CAMC anglophone_20w d_placebo_20w_km Ln_WorldPop10_5km $AB $geo $governance Round6, cluster(EANUMB_AB) robust 
est sto p20w
reg C79C_CAMC anglophone d_border_km Ln_WorldPop10_5km $AB $geo $governance Round6, cluster(EANUMB_AB) robust 
est sto pborder
reg C79C_CAMC anglophone_20e d_placebo_20e_km Ln_WorldPop10_5km $AB $geo $governance Round6, cluster(EANUMB_AB) robust 
est sto p20e
reg C79C_CAMC anglophone_40e d_placebo_40e_km Ln_WorldPop10_5km $AB $geo $governance Round6, cluster(EANUMB_AB) robust 
est sto p40e
reg C79C_CAMC anglophone_60e d_placebo_60e_km Ln_WorldPop10_5km $AB $geo $governance Round6, cluster(EANUMB_AB) robust 
est sto p60e

coefplot (p60w, label("60w") mcolor(black)) (p40w, label("40w") mcolor(black)) (p20w, label("20w") mcolor(black)) (pborder, label("Border") mcolor(black)) (p20e, label("20e") mcolor(black)) (p40e, label("40e") mcolor(black)) (p60e, label("60e") mcolor(black)), ///
  vertical drop(Round6 d_placebo_60e_km d_placebo_40e_km d_placebo_20e_km d_border_km d_placebo_20w_km d_placebo_40w_km d_placebo_60w_km Ln_WorldPop10_5km avg_temp avg_prec cec_mean avg_alt ln_d_yaounde_km ln_d_regcapital_km female age education rural _cons) ///
  ytitle("Estimated Coefficient", size(small)) ylabel(-2.2(.4)1.6, labsize(small) angle(horizontal)) yline(0, lcolor(gs10)) ///
    xlabel(1 "60w" 2 "40w" 3 "20w" 4 "Border" 5 "20e" 6 "40e" 7 "60e", labsize(small)) ///
  legend(off) msymbol(D) mcolor(black) ///
  title(b. Ethnic Networks Provide Access to Government Jobs, size(medsmall)) ///
  scheme(s2mono) graphregion(fcolor(white)) 

graph save Graph "Ab_Placebos_H3b.gph", replace


**** H3c
reg Q18_R5 anglophone_60w  d_placebo_60w_km Ln_WorldPop10_5km $AB $geo $governance , cluster(EANUMB_AB) robust 
est sto p60w 
reg Q18_R5 anglophone_40w d_placebo_40w_km Ln_WorldPop10_5km $AB $geo $governance , cluster(EANUMB_AB) robust 
est sto p40w
reg Q18_R5 anglophone_20w d_placebo_20w_km Ln_WorldPop10_5km $AB $geo $governance , cluster(EANUMB_AB) robust 
est sto p20w
reg Q18_R5 anglophone d_border_km Ln_WorldPop10_5km $AB $geo $governance , cluster(EANUMB_AB) robust 
est sto pborder
reg Q18_R5 anglophone_20e d_placebo_20e_km Ln_WorldPop10_5km $AB $geo $governance , cluster(EANUMB_AB) robust 
est sto p20e
reg Q18_R5 anglophone_40e d_placebo_40e_km Ln_WorldPop10_5km $AB $geo $governance , cluster(EANUMB_AB) robust 
est sto p40e
reg Q18_R5 anglophone_60e d_placebo_60e_km  Ln_WorldPop10_5km $AB $geo $governance , cluster(EANUMB_AB) robust 
est sto p60e

coefplot (p60w, label("60w") mcolor(black)) (p40w, label("40w") mcolor(black)) (p20w, label("20w") mcolor(black)) (pborder, label("Border") mcolor(black)) (p20e, label("20e") mcolor(black)) (p40e, label("40e") mcolor(black)) (p60e, label("60e") mcolor(black)), ///
  vertical drop(Round6 d_placebo_60e_km d_placebo_40e_km d_placebo_20e_km d_border_km d_placebo_20w_km d_placebo_40w_km d_placebo_60w_km Ln_WorldPop10_5km avg_temp avg_prec cec_mean avg_alt ln_d_yaounde_km ln_d_regcapital_km female age education rural _cons) ///
  ytitle("Estimated Coefficient", size(small)) ylabel(-2.2(.4)1.6, labsize(small) angle(horizontal)) yline(0, lcolor(gs7)) ///
    xlabel(0 "60w" 1 "40w" 2 "20w" 3 "Border" 4 "20e" 5 "40e" 6 "60e", labsize(small)) ///
  legend(off) msymbol(D) mcolor(black) ///
  title(c. Elected Leaders Should Help Own Groups First, size(medsmall)) ///
  scheme(s2mono) graphregion(fcolor(white)) 

graph save Graph "Ab_Placebos_H3c.gph", replace

** COMBINE
graph combine  "Ab_Placebos_H3a.gph" "Ab_Placebos_H3b.gph" "Ab_Placebos_H3c.gph", ///
     col(1) ///
	 title("Figure A11.3: ATE at Placebo for Ethnicity Mechanism", size(medsmall) pos(6)) ///
     subtitle("Standardized dependent variables with 95% Confidence Intervals", size(small) pos(6)) ///
	 	xsize(4) ysize(8) ///
     scheme(s2mono) graphregion(fcolor(white)) 

	 
************************************************************************************************
******************** TABLE A12 - GENERALIZABILITY OF SOCIAL CAPITAL FINDINGS *******************
************************************************************************************************
use GeneralizabilityData.dta, clear

global governance_gen ln_D_Capital_km 
global geo_gen avg_temp avg_prec cec_mean avg_alt

d $governance_gen
d $geo_gen

xtmixed SocialTrust anglophone $AB $governance_gen $geo_gen Round  settler_colony || CountryName:, vce(robust)
xtmixed Institutional_Trust anglophone $AB $governance_gen $geo_gen Round  settler_colony || CountryName: , vce(robust)
xtmixed DiscussPolitics anglophone $AB $governance_gen $geo_gen Round  settler_colony || CountryName:, vce(robust)
xtmelogit Voted  anglophone $AB $governance_gen $geo_gen Round  settler_colony || CountryName:
xtmixed AttendProtest anglophone $AB $governance_gen $geo_gen Round  settler_colony || CountryName:, vce(robust)


************************************************************************************************
******************* TABLE A13 - ALT EXPLANATIONS: PRECOLONIAL CENTRALIZATION *******************
************************************************************************************************
use AfroBarometerData.dta, clear
keep if REGION==2 | REGION==7 | REGION==9 | REGION==10 | REGION==12

*Panel A - Local Government Legitimacy Mechanism
reg C62B $MDpolynomial murdock_jurihier Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg C71C $MDpolynomial murdock_jurihier Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg C30C $MDpolynomial murdock_jurihier Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg C25B $MDpolynomial  murdock_jurihier Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 

*Panel B - Traditional Authority Mechanism
reg Q52K_R6 $MDpolynomial murdock_jurihier Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg Q53H_R6 $MDpolynomial murdock_jurihier Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg Q24E_R6 $MDpolynomial murdock_jurihier Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg Q68D_R6 $MDpolynomial murdock_jurihier Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 

*Panel C - Ethnicity Mechanism
reg C85B $MDpolynomial murdock_jurihier Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg C79C_CAMC $MDpolynomial murdock_jurihier Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg Q18_R5 $MDpolynomial murdock_jurihier Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 


************************************************************************************************
********************** TABLE A14 - ALT EXPLANATIONS: DISTANCE TO NIGERIA ***********************
************************************************************************************************
use AfroBarometerData.dta, clear
keep if REGION==2 | REGION==7 | REGION==9 | REGION==10 | REGION==12

*Panel A - Local Government Legitimacy Mechanism
reg C62B $MDpolynomial ln_d_nigeria_km Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg C71C $MDpolynomial ln_d_nigeria_km Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg C30C $MDpolynomial ln_d_nigeria_km Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg C25B $MDpolynomial  ln_d_nigeria_km Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 

*Panel B - Traditional Authority Mechanism
reg Q52K_R6 $MDpolynomial ln_d_nigeria_km Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg Q53H_R6 $MDpolynomial ln_d_nigeria_km Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg Q24E_R6 $MDpolynomial ln_d_nigeria_km Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg Q68D_R6 $MDpolynomial ln_d_nigeria_km Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 

*Panel C - Ethnicity Mechanism
reg C85B $MDpolynomial ln_d_nigeria_km Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg C79C_CAMC $MDpolynomial ln_d_nigeria_km Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg Q18_R5 $MDpolynomial ln_d_nigeria_km Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 


************************************************************************************************
******************** TABLE A15 - ALT EXPLANATIONS: BAMILEKE/BASSA EXCLUSION ********************
************************************************************************************************
use AfroBarometerData.dta, clear
keep if REGION==2 | REGION==7 | REGION==9 | REGION==10 | REGION==12

*Panel A - Local Government Legitimacy Mechanism
reg C62B $MDpolynomial Bamileke Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg C71C $MDpolynomial Bamileke Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg C30C $MDpolynomial Bamileke Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg C25B $MDpolynomial  Bamileke Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 

*Panel B - Traditional Authority Mechanism
reg Q52K_R6 $MDpolynomial Bamileke Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg Q53H_R6 $MDpolynomial Bamileke Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg Q24E_R6 $MDpolynomial Bamileke Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg Q68D_R6 $MDpolynomial Bamileke Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 

*Panel C - Ethnicity Mechanism
reg C85B $MDpolynomial Bamileke Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg C79C_CAMC $MDpolynomial Bamileke Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg Q18_R5 $MDpolynomial Bamileke Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 



************************************************************************************************
********************** TABLE A16- ELECTRICITY ACCESS OVER TIME *********************************
************************************************************************************************

* a. NIGHTLIGHT DATA 1994
use Nightlight_GIS_FINAL.dta, clear
drop if year != 1994

foreach var of varlist D_Border15-D_Border80 {
	quietly reg z2_Lt_Mean $MDpolynomial Ln_Pop_Grid Urban $geo $governance if `var'==1 & CompZone == 1, robust
	gen Beta_`var' = _b[anglophone]
	matrix c_`var' = e(V)
	gen Var_`var' = c_`var'[1,1]
} 

foreach var of varlist D_Border15-D_Border80 {
	gen SD_`var' = sqrt(Var_`var')
	gen CI_Upper_`var' = Beta_`var'+(SD_`var'*1.96)
	gen CI_Lower_`var' = Beta_`var'-(SD_`var'*1.96)
}

gen N = _n
drop if N !=1
keep N Beta_D_Border15 Beta_D_Border16 Beta_D_Border17 Beta_D_Border18 Beta_D_Border19 Beta_D_Border20 Beta_D_Border21 Beta_D_Border22 Beta_D_Border23 Beta_D_Border24 Beta_D_Border25 Beta_D_Border26 Beta_D_Border27 Beta_D_Border28 Beta_D_Border29 Beta_D_Border30 Beta_D_Border31 Beta_D_Border32 Beta_D_Border33 Beta_D_Border34 Beta_D_Border35 Beta_D_Border36 Beta_D_Border37 Beta_D_Border38 Beta_D_Border39 Beta_D_Border40 Beta_D_Border41 Beta_D_Border42 Beta_D_Border43 Beta_D_Border44 Beta_D_Border45 Beta_D_Border46 Beta_D_Border47 Beta_D_Border48 Beta_D_Border49 Beta_D_Border50 Beta_D_Border51 Beta_D_Border52 Beta_D_Border53 Beta_D_Border54 Beta_D_Border55 Beta_D_Border56 Beta_D_Border57 Beta_D_Border58 Beta_D_Border59 Beta_D_Border60 Beta_D_Border61 Beta_D_Border62 Beta_D_Border63 Beta_D_Border64 Beta_D_Border65 Beta_D_Border66 Beta_D_Border67 Beta_D_Border68 Beta_D_Border69 Beta_D_Border70 Beta_D_Border71 Beta_D_Border72 Beta_D_Border73 Beta_D_Border74 Beta_D_Border75 Beta_D_Border76 Beta_D_Border77 Beta_D_Border78 Beta_D_Border79 Beta_D_Border80 CI_Upper_D_Border15 CI_Upper_D_Border16 CI_Upper_D_Border17 CI_Upper_D_Border18 CI_Upper_D_Border19 CI_Upper_D_Border20 CI_Upper_D_Border21 CI_Upper_D_Border22 CI_Upper_D_Border23 CI_Upper_D_Border24 CI_Upper_D_Border25 CI_Upper_D_Border26 CI_Upper_D_Border27 CI_Upper_D_Border28 CI_Upper_D_Border29 CI_Upper_D_Border30 CI_Upper_D_Border31 CI_Upper_D_Border32 CI_Upper_D_Border33 CI_Upper_D_Border34 CI_Upper_D_Border35 CI_Upper_D_Border36 CI_Upper_D_Border37 CI_Upper_D_Border38 CI_Upper_D_Border39 CI_Upper_D_Border40 CI_Upper_D_Border41 CI_Upper_D_Border42 CI_Upper_D_Border43 CI_Upper_D_Border44 CI_Upper_D_Border45 CI_Upper_D_Border46 CI_Upper_D_Border47 CI_Upper_D_Border48 CI_Upper_D_Border49 CI_Upper_D_Border50 CI_Upper_D_Border51 CI_Upper_D_Border52 CI_Upper_D_Border53 CI_Upper_D_Border54 CI_Upper_D_Border55 CI_Upper_D_Border56 CI_Upper_D_Border57 CI_Upper_D_Border58 CI_Upper_D_Border59 CI_Upper_D_Border60 CI_Upper_D_Border61 CI_Upper_D_Border62 CI_Upper_D_Border63 CI_Upper_D_Border64 CI_Upper_D_Border65 CI_Upper_D_Border66 CI_Upper_D_Border67 CI_Upper_D_Border68 CI_Upper_D_Border69 CI_Upper_D_Border70 CI_Upper_D_Border71 CI_Upper_D_Border72 CI_Upper_D_Border73 CI_Upper_D_Border74 CI_Upper_D_Border75 CI_Upper_D_Border76 CI_Upper_D_Border77 CI_Upper_D_Border78 CI_Upper_D_Border79 CI_Upper_D_Border80 CI_Lower_D_Border15 CI_Lower_D_Border16 CI_Lower_D_Border17 CI_Lower_D_Border18 CI_Lower_D_Border19 CI_Lower_D_Border20 CI_Lower_D_Border21 CI_Lower_D_Border22 CI_Lower_D_Border23 CI_Lower_D_Border24 CI_Lower_D_Border25 CI_Lower_D_Border26 CI_Lower_D_Border27 CI_Lower_D_Border28 CI_Lower_D_Border29 CI_Lower_D_Border30 CI_Lower_D_Border31 CI_Lower_D_Border32 CI_Lower_D_Border33 CI_Lower_D_Border34 CI_Lower_D_Border35 CI_Lower_D_Border36 CI_Lower_D_Border37 CI_Lower_D_Border38 CI_Lower_D_Border39 CI_Lower_D_Border40 CI_Lower_D_Border41 CI_Lower_D_Border42 CI_Lower_D_Border43 CI_Lower_D_Border44 CI_Lower_D_Border45 CI_Lower_D_Border46 CI_Lower_D_Border47 CI_Lower_D_Border48 CI_Lower_D_Border49 CI_Lower_D_Border50 CI_Lower_D_Border51 CI_Lower_D_Border52 CI_Lower_D_Border53 CI_Lower_D_Border54 CI_Lower_D_Border55 CI_Lower_D_Border56 CI_Lower_D_Border57 CI_Lower_D_Border58 CI_Lower_D_Border59 CI_Lower_D_Border60 CI_Lower_D_Border61 CI_Lower_D_Border62 CI_Lower_D_Border63 CI_Lower_D_Border64 CI_Lower_D_Border65 CI_Lower_D_Border66 CI_Lower_D_Border67 CI_Lower_D_Border68 CI_Lower_D_Border69 CI_Lower_D_Border70 CI_Lower_D_Border71 CI_Lower_D_Border72 CI_Lower_D_Border73 CI_Lower_D_Border74 CI_Lower_D_Border75 CI_Lower_D_Border76 CI_Lower_D_Border77 CI_Lower_D_Border78 CI_Lower_D_Border79 CI_Lower_D_Border80

reshape long Beta_D_Border CI_Upper_D_Border CI_Lower_D_Border, i(N) j(band)

twoway (line Beta_D_Border band, lcolor(black) lpattern(solid)) ///
	(line CI_Upper_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Lower_D_Border band, lcolor(black) lpattern(tight_dot)), ///
    ytitle(Estimated Effect Anglophone, size(small)) ylabel(-.1(.05).1,  angle(horizontal))  ///
    xtitle(Distance from Border (km) ) xtitle(, size(small)) xlabel(15(10)80, labsize(vsmall))  ///
         yline(0, lcolor(gs10)) ///
  legend(off) ///
        title(a. Nightlight Data 1991, size(medsmall)) ///
    scheme(s2mono) graphregion(fcolor(white)) 
 

* b.  NIGHTLIGHT DATA 2004
use Nightlight_GIS_FINAL.dta, clear
drop if year != 2004

foreach var of varlist D_Border15-D_Border80 {
	quietly reg z2_Lt_Mean $MDpolynomial Ln_Pop_Grid Urban  $geo $governance if `var'==1 & CompZone == 1, robust
	gen Beta_`var' = _b[anglophone]
	matrix c_`var' = e(V)
	gen Var_`var' = c_`var'[1,1]
} 

foreach var of varlist D_Border15-D_Border80 {
	gen SD_`var' = sqrt(Var_`var')
	gen CI_Upper_`var' = Beta_`var'+(SD_`var'*1.96)
	gen CI_Lower_`var' = Beta_`var'-(SD_`var'*1.96)
}

gen N = _n
drop if N !=1
keep N Beta_D_Border15 Beta_D_Border16 Beta_D_Border17 Beta_D_Border18 Beta_D_Border19 Beta_D_Border20 Beta_D_Border21 Beta_D_Border22 Beta_D_Border23 Beta_D_Border24 Beta_D_Border25 Beta_D_Border26 Beta_D_Border27 Beta_D_Border28 Beta_D_Border29 Beta_D_Border30 Beta_D_Border31 Beta_D_Border32 Beta_D_Border33 Beta_D_Border34 Beta_D_Border35 Beta_D_Border36 Beta_D_Border37 Beta_D_Border38 Beta_D_Border39 Beta_D_Border40 Beta_D_Border41 Beta_D_Border42 Beta_D_Border43 Beta_D_Border44 Beta_D_Border45 Beta_D_Border46 Beta_D_Border47 Beta_D_Border48 Beta_D_Border49 Beta_D_Border50 Beta_D_Border51 Beta_D_Border52 Beta_D_Border53 Beta_D_Border54 Beta_D_Border55 Beta_D_Border56 Beta_D_Border57 Beta_D_Border58 Beta_D_Border59 Beta_D_Border60 Beta_D_Border61 Beta_D_Border62 Beta_D_Border63 Beta_D_Border64 Beta_D_Border65 Beta_D_Border66 Beta_D_Border67 Beta_D_Border68 Beta_D_Border69 Beta_D_Border70 Beta_D_Border71 Beta_D_Border72 Beta_D_Border73 Beta_D_Border74 Beta_D_Border75 Beta_D_Border76 Beta_D_Border77 Beta_D_Border78 Beta_D_Border79 Beta_D_Border80 CI_Upper_D_Border15 CI_Upper_D_Border16 CI_Upper_D_Border17 CI_Upper_D_Border18 CI_Upper_D_Border19 CI_Upper_D_Border20 CI_Upper_D_Border21 CI_Upper_D_Border22 CI_Upper_D_Border23 CI_Upper_D_Border24 CI_Upper_D_Border25 CI_Upper_D_Border26 CI_Upper_D_Border27 CI_Upper_D_Border28 CI_Upper_D_Border29 CI_Upper_D_Border30 CI_Upper_D_Border31 CI_Upper_D_Border32 CI_Upper_D_Border33 CI_Upper_D_Border34 CI_Upper_D_Border35 CI_Upper_D_Border36 CI_Upper_D_Border37 CI_Upper_D_Border38 CI_Upper_D_Border39 CI_Upper_D_Border40 CI_Upper_D_Border41 CI_Upper_D_Border42 CI_Upper_D_Border43 CI_Upper_D_Border44 CI_Upper_D_Border45 CI_Upper_D_Border46 CI_Upper_D_Border47 CI_Upper_D_Border48 CI_Upper_D_Border49 CI_Upper_D_Border50 CI_Upper_D_Border51 CI_Upper_D_Border52 CI_Upper_D_Border53 CI_Upper_D_Border54 CI_Upper_D_Border55 CI_Upper_D_Border56 CI_Upper_D_Border57 CI_Upper_D_Border58 CI_Upper_D_Border59 CI_Upper_D_Border60 CI_Upper_D_Border61 CI_Upper_D_Border62 CI_Upper_D_Border63 CI_Upper_D_Border64 CI_Upper_D_Border65 CI_Upper_D_Border66 CI_Upper_D_Border67 CI_Upper_D_Border68 CI_Upper_D_Border69 CI_Upper_D_Border70 CI_Upper_D_Border71 CI_Upper_D_Border72 CI_Upper_D_Border73 CI_Upper_D_Border74 CI_Upper_D_Border75 CI_Upper_D_Border76 CI_Upper_D_Border77 CI_Upper_D_Border78 CI_Upper_D_Border79 CI_Upper_D_Border80 CI_Lower_D_Border15 CI_Lower_D_Border16 CI_Lower_D_Border17 CI_Lower_D_Border18 CI_Lower_D_Border19 CI_Lower_D_Border20 CI_Lower_D_Border21 CI_Lower_D_Border22 CI_Lower_D_Border23 CI_Lower_D_Border24 CI_Lower_D_Border25 CI_Lower_D_Border26 CI_Lower_D_Border27 CI_Lower_D_Border28 CI_Lower_D_Border29 CI_Lower_D_Border30 CI_Lower_D_Border31 CI_Lower_D_Border32 CI_Lower_D_Border33 CI_Lower_D_Border34 CI_Lower_D_Border35 CI_Lower_D_Border36 CI_Lower_D_Border37 CI_Lower_D_Border38 CI_Lower_D_Border39 CI_Lower_D_Border40 CI_Lower_D_Border41 CI_Lower_D_Border42 CI_Lower_D_Border43 CI_Lower_D_Border44 CI_Lower_D_Border45 CI_Lower_D_Border46 CI_Lower_D_Border47 CI_Lower_D_Border48 CI_Lower_D_Border49 CI_Lower_D_Border50 CI_Lower_D_Border51 CI_Lower_D_Border52 CI_Lower_D_Border53 CI_Lower_D_Border54 CI_Lower_D_Border55 CI_Lower_D_Border56 CI_Lower_D_Border57 CI_Lower_D_Border58 CI_Lower_D_Border59 CI_Lower_D_Border60 CI_Lower_D_Border61 CI_Lower_D_Border62 CI_Lower_D_Border63 CI_Lower_D_Border64 CI_Lower_D_Border65 CI_Lower_D_Border66 CI_Lower_D_Border67 CI_Lower_D_Border68 CI_Lower_D_Border69 CI_Lower_D_Border70 CI_Lower_D_Border71 CI_Lower_D_Border72 CI_Lower_D_Border73 CI_Lower_D_Border74 CI_Lower_D_Border75 CI_Lower_D_Border76 CI_Lower_D_Border77 CI_Lower_D_Border78 CI_Lower_D_Border79 CI_Lower_D_Border80

reshape long Beta_D_Border CI_Upper_D_Border CI_Lower_D_Border, i(N) j(band)

twoway (line Beta_D_Border band, lcolor(black) lpattern(solid)) ///
	(line CI_Upper_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Lower_D_Border band, lcolor(black) lpattern(tight_dot)), ///
    ytitle(Estimated Effect Anglophone, size(small)) ylabel(-.1(.05).1,  angle(horizontal))  ///
    xtitle(Distance from Border (km) ) xtitle(, size(small)) xlabel(15(10)80, labsize(vsmall))  ///
         yline(0, lcolor(gs10)) ///
  legend(off) ///
        title(b. Nightlight Data 2004, size(medsmall)) ///
    scheme(s2mono) graphregion(fcolor(white)) 



* c. NIGHTLIGHT DATA 2011
use Nightlight_GIS_FINAL.dta, clear
drop if year != 2011

foreach var of varlist D_Border15-D_Border80 {
	quietly reg z2_Lt_Mean $MDpolynomial Ln_Pop_Grid Urban  $geo $governance if `var'==1 & CompZone == 1, robust
	gen Beta_`var' = _b[anglophone]
	matrix c_`var' = e(V)
	gen Var_`var' = c_`var'[1,1]
} 

foreach var of varlist D_Border15-D_Border80 {
	gen SD_`var' = sqrt(Var_`var')
	gen CI_Upper_`var' = Beta_`var'+(SD_`var'*1.96)
	gen CI_Lower_`var' = Beta_`var'-(SD_`var'*1.96)
}

gen N = _n
drop if N !=1
keep N Beta_D_Border15 Beta_D_Border16 Beta_D_Border17 Beta_D_Border18 Beta_D_Border19 Beta_D_Border20 Beta_D_Border21 Beta_D_Border22 Beta_D_Border23 Beta_D_Border24 Beta_D_Border25 Beta_D_Border26 Beta_D_Border27 Beta_D_Border28 Beta_D_Border29 Beta_D_Border30 Beta_D_Border31 Beta_D_Border32 Beta_D_Border33 Beta_D_Border34 Beta_D_Border35 Beta_D_Border36 Beta_D_Border37 Beta_D_Border38 Beta_D_Border39 Beta_D_Border40 Beta_D_Border41 Beta_D_Border42 Beta_D_Border43 Beta_D_Border44 Beta_D_Border45 Beta_D_Border46 Beta_D_Border47 Beta_D_Border48 Beta_D_Border49 Beta_D_Border50 Beta_D_Border51 Beta_D_Border52 Beta_D_Border53 Beta_D_Border54 Beta_D_Border55 Beta_D_Border56 Beta_D_Border57 Beta_D_Border58 Beta_D_Border59 Beta_D_Border60 Beta_D_Border61 Beta_D_Border62 Beta_D_Border63 Beta_D_Border64 Beta_D_Border65 Beta_D_Border66 Beta_D_Border67 Beta_D_Border68 Beta_D_Border69 Beta_D_Border70 Beta_D_Border71 Beta_D_Border72 Beta_D_Border73 Beta_D_Border74 Beta_D_Border75 Beta_D_Border76 Beta_D_Border77 Beta_D_Border78 Beta_D_Border79 Beta_D_Border80 CI_Upper_D_Border15 CI_Upper_D_Border16 CI_Upper_D_Border17 CI_Upper_D_Border18 CI_Upper_D_Border19 CI_Upper_D_Border20 CI_Upper_D_Border21 CI_Upper_D_Border22 CI_Upper_D_Border23 CI_Upper_D_Border24 CI_Upper_D_Border25 CI_Upper_D_Border26 CI_Upper_D_Border27 CI_Upper_D_Border28 CI_Upper_D_Border29 CI_Upper_D_Border30 CI_Upper_D_Border31 CI_Upper_D_Border32 CI_Upper_D_Border33 CI_Upper_D_Border34 CI_Upper_D_Border35 CI_Upper_D_Border36 CI_Upper_D_Border37 CI_Upper_D_Border38 CI_Upper_D_Border39 CI_Upper_D_Border40 CI_Upper_D_Border41 CI_Upper_D_Border42 CI_Upper_D_Border43 CI_Upper_D_Border44 CI_Upper_D_Border45 CI_Upper_D_Border46 CI_Upper_D_Border47 CI_Upper_D_Border48 CI_Upper_D_Border49 CI_Upper_D_Border50 CI_Upper_D_Border51 CI_Upper_D_Border52 CI_Upper_D_Border53 CI_Upper_D_Border54 CI_Upper_D_Border55 CI_Upper_D_Border56 CI_Upper_D_Border57 CI_Upper_D_Border58 CI_Upper_D_Border59 CI_Upper_D_Border60 CI_Upper_D_Border61 CI_Upper_D_Border62 CI_Upper_D_Border63 CI_Upper_D_Border64 CI_Upper_D_Border65 CI_Upper_D_Border66 CI_Upper_D_Border67 CI_Upper_D_Border68 CI_Upper_D_Border69 CI_Upper_D_Border70 CI_Upper_D_Border71 CI_Upper_D_Border72 CI_Upper_D_Border73 CI_Upper_D_Border74 CI_Upper_D_Border75 CI_Upper_D_Border76 CI_Upper_D_Border77 CI_Upper_D_Border78 CI_Upper_D_Border79 CI_Upper_D_Border80 CI_Lower_D_Border15 CI_Lower_D_Border16 CI_Lower_D_Border17 CI_Lower_D_Border18 CI_Lower_D_Border19 CI_Lower_D_Border20 CI_Lower_D_Border21 CI_Lower_D_Border22 CI_Lower_D_Border23 CI_Lower_D_Border24 CI_Lower_D_Border25 CI_Lower_D_Border26 CI_Lower_D_Border27 CI_Lower_D_Border28 CI_Lower_D_Border29 CI_Lower_D_Border30 CI_Lower_D_Border31 CI_Lower_D_Border32 CI_Lower_D_Border33 CI_Lower_D_Border34 CI_Lower_D_Border35 CI_Lower_D_Border36 CI_Lower_D_Border37 CI_Lower_D_Border38 CI_Lower_D_Border39 CI_Lower_D_Border40 CI_Lower_D_Border41 CI_Lower_D_Border42 CI_Lower_D_Border43 CI_Lower_D_Border44 CI_Lower_D_Border45 CI_Lower_D_Border46 CI_Lower_D_Border47 CI_Lower_D_Border48 CI_Lower_D_Border49 CI_Lower_D_Border50 CI_Lower_D_Border51 CI_Lower_D_Border52 CI_Lower_D_Border53 CI_Lower_D_Border54 CI_Lower_D_Border55 CI_Lower_D_Border56 CI_Lower_D_Border57 CI_Lower_D_Border58 CI_Lower_D_Border59 CI_Lower_D_Border60 CI_Lower_D_Border61 CI_Lower_D_Border62 CI_Lower_D_Border63 CI_Lower_D_Border64 CI_Lower_D_Border65 CI_Lower_D_Border66 CI_Lower_D_Border67 CI_Lower_D_Border68 CI_Lower_D_Border69 CI_Lower_D_Border70 CI_Lower_D_Border71 CI_Lower_D_Border72 CI_Lower_D_Border73 CI_Lower_D_Border74 CI_Lower_D_Border75 CI_Lower_D_Border76 CI_Lower_D_Border77 CI_Lower_D_Border78 CI_Lower_D_Border79 CI_Lower_D_Border80

reshape long Beta_D_Border CI_Upper_D_Border CI_Lower_D_Border, i(N) j(band)

twoway (line Beta_D_Border band, lcolor(black) lpattern(solid)) ///
	(line CI_Upper_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Lower_D_Border band, lcolor(black) lpattern(tight_dot)), ///
    ytitle(Estimated Effect Anglophone, size(small)) ylabel(-.1(.05).1,  angle(horizontal))  ///
    xtitle(Distance from Border (km) ) xtitle(, size(small)) xlabel(15(10)80, labsize(vsmall))  ///
         yline(0, lcolor(gs10)) ///
  legend(off) ///
        title(c. Nightlight Data 2011, size(medsmall)) ///
    scheme(s2mono) graphregion(fcolor(white)) 


* d. NIGHTLIGHT DATA 2013
use Nightlight_GIS_FINAL.dta, clear
drop if year != 2013

foreach var of varlist D_Border15-D_Border80 {
	quietly reg z2_Lt_Mean $MDpolynomial Ln_Pop_Grid Urban  $geo $governance if `var'==1 & CompZone == 1,  robust
	gen Beta_`var' = _b[anglophone]
	matrix c_`var' = e(V)
	gen Var_`var' = c_`var'[1,1]
} 

foreach var of varlist D_Border15-D_Border80 {
	gen SD_`var' = sqrt(Var_`var')
	gen CI_Upper_`var' = Beta_`var'+(SD_`var'*1.96)
	gen CI_Lower_`var' = Beta_`var'-(SD_`var'*1.96)
}

gen N = _n
drop if N !=1
keep N Beta_D_Border15 Beta_D_Border16 Beta_D_Border17 Beta_D_Border18 Beta_D_Border19 Beta_D_Border20 Beta_D_Border21 Beta_D_Border22 Beta_D_Border23 Beta_D_Border24 Beta_D_Border25 Beta_D_Border26 Beta_D_Border27 Beta_D_Border28 Beta_D_Border29 Beta_D_Border30 Beta_D_Border31 Beta_D_Border32 Beta_D_Border33 Beta_D_Border34 Beta_D_Border35 Beta_D_Border36 Beta_D_Border37 Beta_D_Border38 Beta_D_Border39 Beta_D_Border40 Beta_D_Border41 Beta_D_Border42 Beta_D_Border43 Beta_D_Border44 Beta_D_Border45 Beta_D_Border46 Beta_D_Border47 Beta_D_Border48 Beta_D_Border49 Beta_D_Border50 Beta_D_Border51 Beta_D_Border52 Beta_D_Border53 Beta_D_Border54 Beta_D_Border55 Beta_D_Border56 Beta_D_Border57 Beta_D_Border58 Beta_D_Border59 Beta_D_Border60 Beta_D_Border61 Beta_D_Border62 Beta_D_Border63 Beta_D_Border64 Beta_D_Border65 Beta_D_Border66 Beta_D_Border67 Beta_D_Border68 Beta_D_Border69 Beta_D_Border70 Beta_D_Border71 Beta_D_Border72 Beta_D_Border73 Beta_D_Border74 Beta_D_Border75 Beta_D_Border76 Beta_D_Border77 Beta_D_Border78 Beta_D_Border79 Beta_D_Border80 CI_Upper_D_Border15 CI_Upper_D_Border16 CI_Upper_D_Border17 CI_Upper_D_Border18 CI_Upper_D_Border19 CI_Upper_D_Border20 CI_Upper_D_Border21 CI_Upper_D_Border22 CI_Upper_D_Border23 CI_Upper_D_Border24 CI_Upper_D_Border25 CI_Upper_D_Border26 CI_Upper_D_Border27 CI_Upper_D_Border28 CI_Upper_D_Border29 CI_Upper_D_Border30 CI_Upper_D_Border31 CI_Upper_D_Border32 CI_Upper_D_Border33 CI_Upper_D_Border34 CI_Upper_D_Border35 CI_Upper_D_Border36 CI_Upper_D_Border37 CI_Upper_D_Border38 CI_Upper_D_Border39 CI_Upper_D_Border40 CI_Upper_D_Border41 CI_Upper_D_Border42 CI_Upper_D_Border43 CI_Upper_D_Border44 CI_Upper_D_Border45 CI_Upper_D_Border46 CI_Upper_D_Border47 CI_Upper_D_Border48 CI_Upper_D_Border49 CI_Upper_D_Border50 CI_Upper_D_Border51 CI_Upper_D_Border52 CI_Upper_D_Border53 CI_Upper_D_Border54 CI_Upper_D_Border55 CI_Upper_D_Border56 CI_Upper_D_Border57 CI_Upper_D_Border58 CI_Upper_D_Border59 CI_Upper_D_Border60 CI_Upper_D_Border61 CI_Upper_D_Border62 CI_Upper_D_Border63 CI_Upper_D_Border64 CI_Upper_D_Border65 CI_Upper_D_Border66 CI_Upper_D_Border67 CI_Upper_D_Border68 CI_Upper_D_Border69 CI_Upper_D_Border70 CI_Upper_D_Border71 CI_Upper_D_Border72 CI_Upper_D_Border73 CI_Upper_D_Border74 CI_Upper_D_Border75 CI_Upper_D_Border76 CI_Upper_D_Border77 CI_Upper_D_Border78 CI_Upper_D_Border79 CI_Upper_D_Border80 CI_Lower_D_Border15 CI_Lower_D_Border16 CI_Lower_D_Border17 CI_Lower_D_Border18 CI_Lower_D_Border19 CI_Lower_D_Border20 CI_Lower_D_Border21 CI_Lower_D_Border22 CI_Lower_D_Border23 CI_Lower_D_Border24 CI_Lower_D_Border25 CI_Lower_D_Border26 CI_Lower_D_Border27 CI_Lower_D_Border28 CI_Lower_D_Border29 CI_Lower_D_Border30 CI_Lower_D_Border31 CI_Lower_D_Border32 CI_Lower_D_Border33 CI_Lower_D_Border34 CI_Lower_D_Border35 CI_Lower_D_Border36 CI_Lower_D_Border37 CI_Lower_D_Border38 CI_Lower_D_Border39 CI_Lower_D_Border40 CI_Lower_D_Border41 CI_Lower_D_Border42 CI_Lower_D_Border43 CI_Lower_D_Border44 CI_Lower_D_Border45 CI_Lower_D_Border46 CI_Lower_D_Border47 CI_Lower_D_Border48 CI_Lower_D_Border49 CI_Lower_D_Border50 CI_Lower_D_Border51 CI_Lower_D_Border52 CI_Lower_D_Border53 CI_Lower_D_Border54 CI_Lower_D_Border55 CI_Lower_D_Border56 CI_Lower_D_Border57 CI_Lower_D_Border58 CI_Lower_D_Border59 CI_Lower_D_Border60 CI_Lower_D_Border61 CI_Lower_D_Border62 CI_Lower_D_Border63 CI_Lower_D_Border64 CI_Lower_D_Border65 CI_Lower_D_Border66 CI_Lower_D_Border67 CI_Lower_D_Border68 CI_Lower_D_Border69 CI_Lower_D_Border70 CI_Lower_D_Border71 CI_Lower_D_Border72 CI_Lower_D_Border73 CI_Lower_D_Border74 CI_Lower_D_Border75 CI_Lower_D_Border76 CI_Lower_D_Border77 CI_Lower_D_Border78 CI_Lower_D_Border79 CI_Lower_D_Border80

reshape long Beta_D_Border CI_Upper_D_Border CI_Lower_D_Border, i(N) j(band)

twoway (line Beta_D_Border band, lcolor(black) lpattern(solid)) ///
	(line CI_Upper_D_Border band, lcolor(black) lpattern(tight_dot)) ///
	(line CI_Lower_D_Border band, lcolor(black) lpattern(tight_dot)), ///
    ytitle(Estimated Effect Anglophone, size(small)) ylabel(-.1(.05).1,  angle(horizontal))  ///
    xtitle(Distance from Border (km) ) xtitle(, size(small)) xlabel(15(10)80, labsize(vsmall))  ///
        yline(0, lcolor(gs10)) ///
   legend(off) ///
        title(d. Nightlight Data 2013, size(medsmall)) ///
    scheme(s2mono) graphregion(fcolor(white)) 
	
	
************************************************************************************************
***************** TABLE A16 - ALT EXPLANATIONS: PERCEPTIONS OF CG FAVORITISM *******************
************************************************************************************************
use AfroBarometerData.dta, clear
keep if REGION==2 | REGION==7 | REGION==9 | REGION==10 | REGION==12

reg C79A_CAMA $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg C79A_CAMB $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 
reg C79A_CAMC $MDpolynomial Ln_WorldPop10_5km $AB $geo $governance i.Round if d_border_km < 81, cluster(EANUMB_AB) robust 

